/*========================== begin_copyright_notice ============================

Copyright (C) 2023 Intel Corporation

SPDX-License-Identifier: MIT

============================= end_copyright_notice ===========================*/

//     File Name:  md_metric_sets_ACM_GT3.cpp
//
//     Abstract:   C++ automated generated file that defines Metric Sets
//                 for each Concurrent Group

#include "md_metric_sets_ACM_GT3.h"
#include <algorithm>

#if MD_INCLUDE_ACM_GT3_METRICS

namespace MetricsDiscoveryInternal::MetricSets_ACM_GT3_PipelineStatistics
{
    CPipelineStatsMetricSet::CPipelineStatsMetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CPipelineStatsMetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "", 0, 0, 0x80000206, 0, 0, "", 0, "Intel_Raw_Pipeline_Statistics_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "IAVertices", "Input vertices",
                          "The total number of vertices that entered the 3D Pipeline.",
                          "3D Pipe/Input Assembler", ( METRIC_GROUP_NAME_ID_3D_PIPE * 0x1000000 ) | ( METRIC_GROUP_NAME_ID_IA * 0x10000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_OGL | API_TYPE_OGL4_X,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "vertices", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "IAPrimitives", "Input primitives",
                          "The total number of rendering primitives assembled and put into the input assembly stage of the 3D Pipeline.",
                          "3D Pipe/Input Assembler", ( METRIC_GROUP_NAME_ID_3D_PIPE * 0x1000000 ) | ( METRIC_GROUP_NAME_ID_IA * 0x10000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_OGL | API_TYPE_OGL4_X,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "triangles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "VsInvocations", "VS per vertex invocations",
                          "The total number of times a vertex shader was invoked. 3D rendering invokes the vertex shader once per vertex.",
                          "3D Pipe/Vertex Shader", ( METRIC_GROUP_NAME_ID_3D_PIPE * 0x1000000 ) | ( METRIC_GROUP_NAME_ID_VS * 0x10000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_OGL | API_TYPE_OGL4_X,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "invocations", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "HsInvocations", "HS invocations",
                          "The total number of times a hull shader was invoked.",
                          "3D Pipe/Hull Shader", ( METRIC_GROUP_NAME_ID_3D_PIPE * 0x1000000 ) | ( METRIC_GROUP_NAME_ID_HS * 0x10000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_OGL | API_TYPE_OGL4_X,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "invocations", 0, 0, HW_UNIT_GPU, availabilityEquation, "Hull|Control,hull|control,HS|TCS", nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x40" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "DsInvocations", "DS invocations",
                          "The total number of times a domain shader was invoked.",
                          "3D Pipe/Domain Shader", ( METRIC_GROUP_NAME_ID_3D_PIPE * 0x1000000 ) | ( METRIC_GROUP_NAME_ID_DS * 0x10000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_OGL | API_TYPE_OGL4_X,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "invocations", 0, 0, HW_UNIT_GPU, availabilityEquation, "Domain|Evaluation,domain|evaluation,DS|TES", nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x48" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GsInvocations", "GS per triangle invocations",
                          "The total number of times a geometry shader was invoked per triangle.",
                          "3D Pipe/Geometry Shader", ( METRIC_GROUP_NAME_ID_3D_PIPE * 0x1000000 ) | ( METRIC_GROUP_NAME_ID_GS * 0x10000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_OGL | API_TYPE_OGL4_X,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "invocations", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x18" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GsPrimitives", "Post-GS primitives",
                          "The total number of primitives that flowed through from GS to the clipper if GS was enabled.",
                          "3D Pipe/Geometry Shader", ( METRIC_GROUP_NAME_ID_3D_PIPE * 0x1000000 ) | ( METRIC_GROUP_NAME_ID_GS * 0x10000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_OGL | API_TYPE_OGL4_X,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "triangles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x20" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "ClipperInvocations", "Clipper invocations",
                          "The total number of primitives sent to the Clipper.",
                          "3D Pipe/Clipper", ( METRIC_GROUP_NAME_ID_3D_PIPE * 0x1000000 ) | ( METRIC_GROUP_NAME_ID_CL * 0x10000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_OGL | API_TYPE_OGL4_X,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "triangles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x28" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "ClipperPrimitives", "Clipper primitives",
                          "The total number of primitives that flowed out of the Clipper.",
                          "3D Pipe/Clipper", ( METRIC_GROUP_NAME_ID_3D_PIPE * 0x1000000 ) | ( METRIC_GROUP_NAME_ID_CL * 0x10000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_OGL | API_TYPE_OGL4_X,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "triangles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x30" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PsInvocations", "PS invocations",
                          "The total number of times a pixel shader was invoked. 3D rendering invokes a pixel shader once per pixel or subsample.",
                          "3D Pipe/Pixel Shader", ( METRIC_GROUP_NAME_ID_3D_PIPE * 0x1000000 ) | ( METRIC_GROUP_NAME_ID_PS * 0x10000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_OGL | API_TYPE_OGL4_X,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "invocations", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment,PS|FS,pixel|fragment", nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x38" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "CsInvocations", "CS invocations",
                          "The total number of times a compute shader was invoked.",
                          "3D Pipe/Compute Shader", ( METRIC_GROUP_NAME_ID_3D_PIPE * 0x1000000 ) | ( METRIC_GROUP_NAME_ID_CS * 0x10000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_OGL | API_TYPE_OGL4_X,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "invocations", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x50" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "CpsInvocations", "CPS invocations",
                          "The total number of times a coarse shader was invoked.",
                          "3D Pipe/Compute Shader", ( METRIC_GROUP_NAME_ID_3D_PIPE * 0x1000000 ) | ( METRIC_GROUP_NAME_ID_CS * 0x10000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_OGL | API_TYPE_OGL4_X,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "invocations", 0, 0, HW_UNIT_GPU, availabilityEquation, "PS|FS", nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x58" ) ) );
        }

        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
} // namespace MetricsDiscoveryInternal::MetricSets_ACM_GT3_PipelineStatistics

namespace MetricsDiscoveryInternal::MetricSets_ACM_GT3_OA
{
    void AddInformationSet( CConcurrentGroup* concurrentGroup )
    {
        CInformation* information = nullptr;
        information               = concurrentGroup->AddInformation( "QueryBeginTime", "Query Begin Time", "The measurement begin time.", "Report Meta Data", API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM | API_TYPE_MEDIA, INFORMATION_TYPE_TIMESTAMP, "ns", nullptr, 0 );
        if( information )
        {
            information->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" );
            information->SetDeltaReportReadEquation( "qw@0x1c0" );
            information->SetOverflowFunction( "NS_TIME" );
        }

        information = concurrentGroup->AddInformation( "CoreFrequencyMHz", "GPU Core Frequency", "The last GPU core (unslice) frequency in the measurement.", "Report Meta Data", API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM, INFORMATION_TYPE_VALUE, "MHz", nullptr, 1 );
        if( information )
        {
            information->SetSnapshotReportReadEquation( "dw@0x0 0x1ff AND 16666 UMUL 1000 UDIV" );
            information->SetDeltaReportReadEquation( "qw@0x218 1000000 UDIV" );
        }

        information = concurrentGroup->AddInformation( "XveSliceFrequencyMHz", "XVE Slice Frequency", "The last GPU Vector Engine Unit slice frequency in the measurement.", "Report Meta Data", API_TYPE_IOSTREAM, INFORMATION_TYPE_VALUE, "MHz", nullptr, 2 );
        if( information )
        {
            information->SetSnapshotReportReadEquation( "dw@0x0 25 >> dw@0x0 9 >> 0x3 AND OR 16666 UMUL 1000 UDIV" );
        }

        information = concurrentGroup->AddInformation( "ReportReason", "Report Reason", "The reason of the report.", "Report Meta Data", API_TYPE_IOSTREAM, INFORMATION_TYPE_REPORT_REASON, nullptr, nullptr, 3 );
        if( information )
        {
            information->SetSnapshotReportReadEquation( "dw@0x0 19 >> 0x7f AND" );
        }

        information = concurrentGroup->AddInformation( "ContextIdValid", "Context ID Valid", "When set indicates render context is valid", "Report Meta Data", API_TYPE_IOSTREAM, INFORMATION_TYPE_FLAG, nullptr, nullptr, 4 );
        if( information )
        {
            information->SetSnapshotReportReadEquation( "dw@0x0 16 >> 0x1 AND" );
        }

        information = concurrentGroup->AddInformation( "ContextId", "Context ID", "The context tag in which report has been taken.", "Report Meta Data", API_TYPE_IOSTREAM, INFORMATION_TYPE_CONTEXT_ID_TAG, nullptr, nullptr, 5 );
        if( information )
        {
            information->SetSnapshotReportReadEquation( "dw@0x08 0xfc7fffbf AND dw@0x0 16 >> 0x1 AND UMUL" );
        }

        information = concurrentGroup->AddInformation( "CoreFrequencyChanged", "GPU Core Frequency Changed", "The flag indicating that GPU core frequency has changed.", "Exception", API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL, INFORMATION_TYPE_FLAG, nullptr, nullptr, 6 );
        if( information )
        {
            information->SetDeltaReportReadEquation( "dw@0x214" );
        }

        information = concurrentGroup->AddInformation( "QuerySplitOccurred", "Query Split Occurred", "The flag indicating that query has been split during execution on the GPU.", "Exception", API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL, INFORMATION_TYPE_FLAG, nullptr, nullptr, 7 );
        if( information )
        {
            information->SetDeltaReportReadEquation( "dw@0x210" );
        }

        information = concurrentGroup->AddInformation( "ReportId", "Query report id", "Query report identification number.", "Report Meta Data", API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL, INFORMATION_TYPE_VALUE, nullptr, nullptr, 8 );
        if( information )
        {
            information->SetDeltaReportReadEquation( "dw@0x220" );
        }

        information = concurrentGroup->AddInformation( "ReportsCount", "Query reports count", "The number of available query reports.", "Report Meta Data", API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL, INFORMATION_TYPE_VALUE, nullptr, nullptr, 9 );
        if( information )
        {
            information->SetDeltaReportReadEquation( "dw@0x224" );
        }

        information = concurrentGroup->AddInformation( "OverrunOccured", "Query Overrun Occurred", "The flag indicating that Oa buffer has been overran.", "Exception", API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL, INFORMATION_TYPE_FLAG, nullptr, nullptr, 10 );
        if( information )
        {
            information->SetDeltaReportReadEquation( "dw@0x1dc" );
        }

        information = concurrentGroup->AddInformation( "SampleSequence", "Sample sequence", "Number identifying report sequence.", "Report Meta Data", API_TYPE_BBSTREAM, INFORMATION_TYPE_VALUE, nullptr, nullptr, 11 );
        if( information )
        {
            information->SetSnapshotReportReadEquation( "dw@0x0 0x7f AND" );
        }

        information = concurrentGroup->AddInformation( "SamplePhase", "Sample phase", "Buffer execution phase.", "Report Meta Data", API_TYPE_BBSTREAM, INFORMATION_TYPE_SAMPLE_PHASE, nullptr, nullptr, 12 );
        if( information )
        {
            information->SetSnapshotReportReadEquation( "dw@0x0 7 >> 0x01 AND" );
        }

        information = concurrentGroup->AddInformation( "GpuNode", "Gpu node", "GPU node buffer was sent to.", "Report Meta Data", API_TYPE_BBSTREAM, INFORMATION_TYPE_GPU_NODE, nullptr, nullptr, 13 );
        if( information )
        {
            information->SetSnapshotReportReadEquation( "dw@0x0 8 >> 0x07 AND" );
        }

        information = concurrentGroup->AddInformation( "MidQueryTimer", "Mid Query Timer", "The flag indicating that timer report was detected during query.", "Report Meta Data", API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL, INFORMATION_TYPE_FLAG, nullptr, nullptr, 14 );
        if( information )
        {
            information->SetDeltaReportReadEquation( "dw@0x1d8 0x01 AND" );
        }

        information = concurrentGroup->AddInformation( "MidQueryProgramming", "Mid Query Programming", "The flag indicating that counter programming report was detected during query.", "Report Meta Data", API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL, INFORMATION_TYPE_FLAG, nullptr, nullptr, 15 );
        if( information )
        {
            information->SetDeltaReportReadEquation( "dw@0x1d8 0x02 AND" );
        }

        information = concurrentGroup->AddInformation( "MidQueryMarker", "Mid Query Marker", "The flag indicating that query marker report was detected during query.", "Report Meta Data", API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL, INFORMATION_TYPE_FLAG, nullptr, nullptr, 16 );
        if( information )
        {
            information->SetDeltaReportReadEquation( "dw@0x1d8 0x04 AND" );
        }

        information = concurrentGroup->AddInformation( "MidQueryCtxSwitch", "Mid Query Context Switch", "The flag indicating that context switch report was detected during query.", "Report Meta Data", API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL, INFORMATION_TYPE_FLAG, nullptr, nullptr, 17 );
        if( information )
        {
            information->SetDeltaReportReadEquation( "dw@0x1d8 0x08 AND" );
        }

        information = concurrentGroup->AddInformation( "MidQueryC6", "Mid Query C6", "The flag indicating that C6 report was detected during query.", "Report Meta Data", API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL, INFORMATION_TYPE_FLAG, nullptr, nullptr, 18 );
        if( information )
        {
            information->SetDeltaReportReadEquation( "dw@0x1d8 0x10 AND" );
        }

        information = concurrentGroup->AddInformation( "MidQueryFreqChange", "Mid Query Freq Change", "The flag indicating that frequency change report was detected during query.", "Report Meta Data", API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL, INFORMATION_TYPE_FLAG, nullptr, nullptr, 19 );
        if( information )
        {
            information->SetDeltaReportReadEquation( "dw@0x1d8 0x20 AND" );
        }

        information = concurrentGroup->AddInformation( "MidQueryMmioTrigger", "Mid Query Mmio Trigger", "The flag indicating that mmio trigger report was detected during query.", "Report Meta Data", API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL, INFORMATION_TYPE_FLAG, nullptr, nullptr, 20 );
        if( information )
        {
            information->SetDeltaReportReadEquation( "dw@0x1d8 0x40 AND" );
        }

        information = concurrentGroup->AddInformation( "StreamMarker", "Stream marker", "Stream marker value.", "Report Meta Data", API_TYPE_IOSTREAM, INFORMATION_TYPE_VALUE, nullptr, nullptr, 21 );
        if( information )
        {
            information->SetSnapshotReportReadEquation( "dw@0x08 dw@0x0 19 >> 0x8 AND 0x0 == UMUL" );
        }

        information = concurrentGroup->AddInformation( "ReportError", "Query report error", "An error in the query execution, the received report should be ignored.", "Report Meta Data", API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL, INFORMATION_TYPE_FLAG, nullptr, nullptr, 22 );
        if( information )
        {
            information->SetDeltaReportReadEquation( "dw@0x2ac 0x13 AND" );
        }

        information = concurrentGroup->AddInformation( "ReportLost", "Query report lost", "Begin or end query report has not been triggered due to hw limitations.", "Report Meta Data", API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL, INFORMATION_TYPE_FLAG, nullptr, nullptr, 23 );
        if( information )
        {
            information->SetDeltaReportReadEquation( "dw@0x2ac 0x01 AND" );
        }

        information = concurrentGroup->AddInformation( "ReportInconsistent", "Query report inconsistent", "The contextId inconsistency in the Oa buffer within the query window.", "Report Meta Data", API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL, INFORMATION_TYPE_FLAG, nullptr, nullptr, 24 );
        if( information )
        {
            information->SetDeltaReportReadEquation( "dw@0x2ac 0x02 AND" );
        }

        information = concurrentGroup->AddInformation( "ReportCtxSwitchLost", "Query report context switch lost", "Oa buffer has not been browsed to find context switch reports to filter out unfamiliar contexts from the query report.", "Report Meta Data", API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL, INFORMATION_TYPE_FLAG, nullptr, nullptr, 25 );
        if( information )
        {
            information->SetDeltaReportReadEquation( "dw@0x2ac 0x08 AND" );
        }

        information = concurrentGroup->AddInformation( "ReportWithoutWorkload", "Query report missing workload", "Missing workload between query begin and query end.", "Report Meta Data", API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL, INFORMATION_TYPE_FLAG, nullptr, nullptr, 26 );
        if( information )
        {
            information->SetDeltaReportReadEquation( "dw@0x2ac 0x10 AND" );
        }
    }

    CRenderBasicMetricSet::CRenderBasicMetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRenderBasicMetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "VsThreads", "VS Threads Dispatched",
                          "The total number of vertex shader hardware threads dispatched.",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x14" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x18" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "HsThreads", "HS Threads Dispatched",
                          "The total number of hull shader hardware threads dispatched.",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, "hull|control,HS|TCS", "oa.fixed", 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x18" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x20" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "DsThreads", "DS Threads Dispatched",
                          "The total number of domain shader hardware threads dispatched.",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, "domain|evaluation,DS|TES", "oa.fixed", 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x1c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x28" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GsThreads", "GS Threads Dispatched",
                          "The total number of geometry shader hardware threads dispatched.",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x24:0xa5" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x38" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PsThreads", "PS Threads Dispatched",
                          "The total number of pixel shader hardware threads dispatched.",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, "PS|FS,pixel|fragment", "oa.fixed", 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x28:0xa6" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x40" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "CsThreads", "CS Threads Dispatched",
                          "The total number of compute shader hardware threads dispatched.",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x20:0xa4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x30" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XveActive", "XVE Active",
                          "The percentage of time in which the Execution Units were actively processing.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x2c:0xa7" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x48" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XveStall", "XVE Stall",
                          "The percentage of time in which the Execution Units were stalled.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x30:0xa8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x50" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XveThreadOccupancy", "XVE Thread Occupancy",
                          "The percentage of time in which hardware threads occupied XVEs.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "8 rd40@0x34:0xa9 FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "8 qw@0x58 FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XveFpuEmActive", "EM And FPU Pipes Active",
                          "The percentage of time in which XVE EM INT and FPU INT64 pipelines were actively processing.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x38:0xaa" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x60" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "VsFpuActive", "VS FPU Pipe Active",
                          "The percentage of time in which XVE FPU INT64 pipeline was actively processing a vertex shader instruction.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x3c:0xab" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x68" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "VsEmActive", "VS EM Pipe Active",
                          "The percentage of time in which XVE EM INT pipeline was actively processing a vertex shader instruction.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x40:0xac" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x70" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "VsSendActive", "VS Send Pipe Active",
                          "The percentage of time in which XVE send pipeline was actively processing a vertex shader instruction.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x44:0xad" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x78" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PsFpuActive", "PS FPU Pipe Active",
                          "The percentage of time in which XVE FPU INT64 pipeline was actively processing a pixel shader instruction.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "PS|FS,pixel|fragment", nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x48:0xae" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x80" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PsEmActive", "PS EM Pipe Active",
                          "The percentage of time in which XVE EM INT pipeline was actively processing a pixel shader instruction.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "PS|FS,pixel|fragment", nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x4c:0xaf" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x88" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PsSendActive", "PS Send Pipe Active",
                          "The percentage of time in which XVE send pipeline was actively processing a pixel shader instruction.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "PS|FS,pixel|fragment", nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x50:0xb0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x90" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "RasterizedPixels", "Rasterized Pixels",
                          "The total number of rasterized pixels.",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "pixels", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment,pixel|fragment", "oa.fixed", 20 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x64:0xb5" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0xb8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 4 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "HiDepthTestFails", "Early Hi-Depth Test Fails",
                          "The total number of pixels dropped on early hierarchical depth test.",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "pixels", 0, 0, HW_UNIT_GPU, availabilityEquation, "pixel|fragment", "oa.fixed", 21 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x68:0xb6" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 4 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "EarlyDepthTestFails", "Early Depth Test Fails",
                          "The total number of pixels dropped on early depth test.",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "pixels", 0, 0, HW_UNIT_GPU, availabilityEquation, "pixel|fragment", "oa.fixed", 22 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x6c:0xb7" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 4 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SamplesKilledInPs", "Samples Killed in PS",
                          "The total number of samples or pixels dropped in pixel shaders.",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "pixels", 0, 0, HW_UNIT_GPU, availabilityEquation, "PS|FS,pixel|fragment", "oa.fixed", 23 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x70" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 4 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PixelsFailingPostPsTests", "Pixels Failing Tests",
                          "The total number of pixels dropped on post-PS alpha, stencil, or depth tests.",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "pixels", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment,PS|FS,pixel|fragment", "oa.fixed", 24 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x74" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 4 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SamplesWritten", "Samples Written",
                          "The total number of samples or pixels written to all render targets.",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "pixels", 0, 0, HW_UNIT_GPU, availabilityEquation, "pixel|fragment", "oa.fixed", 25 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x78" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 4 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SamplesBlended", "Samples Blended",
                          "The total number of blended samples or pixels written to all render targets.",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "pixels", 0, 0, HW_UNIT_GPU, availabilityEquation, "pixel|fragment", "oa.fixed", 26 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x7c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 4 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SamplerTexels", "Sampler Texels",
                          "The total number of texels seen on input (with 2x2 accuracy) in all sampler units.",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "texels", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 27 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x80:0xbc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 4 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SamplerTexelMisses", "Sampler Texels Misses",
                          "The total number of texels lookups (with 2x2 accuracy) that missed L1 sampler cache.",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_BATCH | USAGE_FLAG_FRAME | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "texels", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 28 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x84:0xbd" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 4 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SlmReads", "SLM Bytes Read",
                          "The total number of reads from shared local memory.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "messages", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 29 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x88:0xbe" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x100" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $XeCoreTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SlmWrites", "SLM Writes",
                          "The total number of writes into shared local memory.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "messages", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 30 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x8c:0xbf" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x108" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $XeCoreTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "ShaderMemoryAccesses", "Shader Memory Accesses",
                          "The total number of shader memory accesses to L3.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "messages", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 31 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x90" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x110" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "ShaderAtomics", "Shader Atomic Memory Accesses",
                          "The total number of shader atomic memory accesses.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "messages", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 32 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x98" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x120" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "ShaderBarriers", "Shader Barrier Messages",
                          "The total number of shader barrier messages.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "messages", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 33 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x9c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x128" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GtiReadThroughput", "GTI Read Throughput",
                          "The total number of GPU memory bytes read from GTI.",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 34 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xa0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x130" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "128 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks 512 UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GtiWriteThroughput", "GTI Write Throughput",
                          "The total number of GPU memory bytes written to GTI.",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 35 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xb8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x138" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "128 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks 512 UMUL" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "Sampler00Busy", "Sampler Slice0 Xe Core0 is busy",
                          "The percentage of time when sampler slice0 Xe core0 is busy",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 36 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$XeCoreMask 1 AND";
        metric               = AddMetric( "SamplersBusy", "Samplers Busy",
                          "The percentage of time in which samplers or L1 cache are not idle.",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 37 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$$Sampler00Busy" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "Sampler00Bottleneck", "Sampler00 Bottleneck",
                          "The percentage of time in which Slice0 Sampler0 has been slowing down the pipe when processing XVE requests.",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 38 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$XeCoreMask 1 AND";
        metric               = AddMetric( "SamplerBottleneck", "Samplers Bottleneck",
                          "The percentage of time in which samplers have been slowing down the pipe when processing XVE requests.",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_INDICATE | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 39 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$$Sampler00Bottleneck" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c840000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e842800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02844000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04840010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a840800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c840037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xe458, 0x00005004, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe558, 0x00003008, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe658, 0x00011010, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe758, 0x00050012, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe45c, 0x00052051, REGISTER_TYPE_FLEX );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CComputeBasicMetricSet::CComputeBasicMetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CComputeBasicMetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "CsThreads", "CS Threads Dispatched",
                          "The total number of compute shader hardware threads dispatched.",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x20:0xa4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x30" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XveActive", "XVE Active",
                          "The percentage of time in which the Execution Units were actively processing.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x2c:0xa7" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x48" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XveStall", "XVE Stall",
                          "The percentage of time in which the Execution Units were stalled.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x30:0xa8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x50" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "FpuActive", "XVE FPU Pipe Active",
                          "The percentage of time in which XVE FPU INT64 pipeline was actively processing.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x34:0xa9" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x58" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "EmActive", "EM Pipe Active",
                          "The percentage of time in which XVE EM INT pipeline was actively processing.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x38:0xaa" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x60" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XmxActive", "XMX Pipe Active",
                          "The percentage of time in which XVE XMX pipeline was actively processing.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x3c:0xab" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x68" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XveFpuEmActive", "EM And FPU Pipes Active",
                          "The percentage of time in which XVE EM INT and FPU INT64 pipelines were actively processing.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x40:0xac" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x70" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XveFpuXmxActive", "XMX And FPU Pipes Active",
                          "The percentage of time in which XVE XMX and FPU INT64 pipelines were actively processing.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x44:0xad" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x78" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XveAvgIpcRate", "XVE AVG IPC Rate",
                          "The average rate of IPC calculated for 2 FPU pipelines.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_RATIO, RESULT_FLOAT, "number", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$XveFpuEmActive $FpuActive $EmActive FADD $EmActive FSUB FDIV 1 FADD" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "2" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SendActive", "Send Pipe Active",
                          "The percentage of time in which XVE send pipeline was actively processing.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x48:0xae" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x80" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XveThreadOccupancy", "XVE Thread Occupancy",
                          "The percentage of time in which hardware threads occupied XVEs.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "8 rd40@0x4c:0xaf FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "8 qw@0x88 FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XveFpuFlt16", "FPU FLT16 Instruction",
                          "The percentage of time in which FLT16 instruction were processed actively on FPU INT64 pipeline.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x50:0xb0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x90" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XveFpuFlt32", "FPU FLT32 Instruction",
                          "The percentage of time in which FLT32 instruction were processed actively on FPU INT64 pipeline.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x54:0xb1" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x98" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XveFpuFlt64", "FPU FLT64 Instruction",
                          "The percentage of time in which FLT64 instruction were processed actively on FPU INT64 pipeline.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x58:0xb2" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0xa0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SamplerTexels", "Sampler Texels",
                          "The total number of texels seen on input (with 2x2 accuracy) in all sampler units.",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "texels", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x80:0xbc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 4 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SamplerTexelMisses", "Sampler Texels Misses",
                          "The total number of texels lookups (with 2x2 accuracy) that missed L1 sampler cache.",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_BATCH | USAGE_FLAG_FRAME | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "texels", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x84:0xbd" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 4 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SlmReads", "SLM Bytes Read",
                          "The total number of reads from shared local memory.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "messages", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 20 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x88:0xbe" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x100" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $XeCoreTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SlmWrites", "SLM Writes",
                          "The total number of writes into shared local memory.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "messages", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 21 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x8c:0xbf" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x108" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $XeCoreTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "ShaderMemoryAccesses", "Shader Memory Accesses",
                          "The total number of shader memory accesses to L3.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "messages", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 22 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x90" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x110" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "ShaderAtomics", "Shader Atomic Memory Accesses",
                          "The total number of shader atomic memory accesses.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "messages", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 23 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x98" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x120" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "ShaderBarriers", "Shader Barrier Messages",
                          "The total number of shader barrier messages.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "messages", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 24 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x9c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x128" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GtiReadThroughput", "GTI Read Throughput",
                          "The total number of GPU memory bytes read from GTI.",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 25 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xa0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x130" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "128 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks 512 UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GtiWriteThroughput", "GTI Write Throughput",
                          "The total number of GPU memory bytes written to GTI.",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 26 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xb8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x138" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "128 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks 512 UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xe458, 0x00005004, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe558, 0x00001000, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe658, 0x00003009, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe758, 0x0000200a, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe45c, 0x00006008, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe55c, 0x0000b007, REGISTER_TYPE_FLEX );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CAsyncComputeMetricSet::CAsyncComputeMetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CAsyncComputeMetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_VULKAN | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_VULKAN | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_VULKAN | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_VULKAN | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "VsThreads", "VS Threads Dispatched",
                          "The total number of vertex shader hardware threads dispatched.",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_VULKAN | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x14" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x18" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "HsThreads", "HS Threads Dispatched",
                          "The total number of hull shader hardware threads dispatched.",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_VULKAN | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, "hull|control,HS|TCS", "oa.fixed", 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x18" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x20" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "DsThreads", "DS Threads Dispatched",
                          "The total number of domain shader hardware threads dispatched.",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_VULKAN | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, "domain|evaluation,DS|TES", "oa.fixed", 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x1c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x28" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GsThreads", "GS Threads Dispatched",
                          "The total number of geometry shader hardware threads dispatched.",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_VULKAN | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x24:0xa5" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x38" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PsThreads", "PS Threads Dispatched",
                          "The total number of pixel shader hardware threads dispatched.",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_VULKAN | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, "PS|FS,pixel|fragment", "oa.fixed", 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x28:0xa6" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x40" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "CsThreads", "CS Threads Dispatched",
                          "The total number of compute shader hardware threads dispatched.",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_VULKAN | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x20:0xa4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x30" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "FpuActive", "XVE FPU Pipe Active",
                          "The percentage of time in which XVE FPU INT64 pipeline was actively processing.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_VULKAN | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x2c:0xa7" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x48" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "VsFpuActive", "VS FPU Pipe Active",
                          "The percentage of time in which XVE FPU INT64 pipeline was actively processing a vertex shader instruction.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_VULKAN | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x30:0xa8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x50" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PsFpuActive", "PS FPU Pipe Active",
                          "The percentage of time in which XVE FPU INT64 pipeline was actively processing a pixel shader instruction.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_VULKAN | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "PS|FS,pixel|fragment", nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x34:0xa9" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x58" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "CsFpuActive", "CS FPU Pipe Active",
                          "The percentage of time in which XVE FPU INT64 pipeline was actively processing a compute shader instruction.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_VULKAN | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x38:0xaa" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x60" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AsyncCsFpuActive", "ASYNC CS FPU Pipe Active",
                          "The percentage of time in which XVE FPU INT64 pipeline was actively processing a compute shader instruction.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_VULKAN | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x3c:0xab" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x68" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "EmActive", "EM Pipe Active",
                          "The percentage of time in which XVE EM INT pipeline was actively processing.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_VULKAN | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x40:0xac" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x70" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "VsEmActive", "VS EM Pipe Active",
                          "The percentage of time in which XVE EM INT pipeline was actively processing a vertex shader instruction.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_VULKAN | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x44:0xad" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x78" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PsEmActive", "PS EM Pipe Active",
                          "The percentage of time in which XVE EM INT pipeline was actively processing a pixel shader instruction.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_VULKAN | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "PS|FS,pixel|fragment", nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x48:0xae" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x80" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "CsEmActive", "CS EM Pipe Active",
                          "The percentage of time in which XVE EM INT pipeline was actively processing a compute shader instruction.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_VULKAN | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x4c:0xaf" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x88" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AsyncCsEmActive", "ASYNC CS EM Pipe Active",
                          "The percentage of time in which XVE EM INT pipeline was actively processing a compute shader instruction.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_VULKAN | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x50:0xb0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x90" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XveThreadOccupancy", "XVE Thread Occupancy",
                          "The percentage of time in which hardware threads occupied XVEs.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_VULKAN | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 20 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "8 rd40@0x54:0xb1 FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "8 qw@0x98 FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XveActive", "XVE Active",
                          "The percentage of time in which the Execution Units were actively processing.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_VULKAN | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 21 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x58:0xb2" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0xa0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XveStall", "XVE Stall",
                          "The percentage of time in which the Execution Units were stalled.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_VULKAN | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 22 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x5c:0xb3" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0xa8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xe458, 0x00010000, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe558, 0x00060050, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe658, 0x00001090, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe758, 0x00051011, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe45c, 0x00091061, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe55c, 0x00004008, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe65c, 0x00000005, REGISTER_TYPE_FLEX );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CXveActivity1MetricSet::CXveActivity1MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CXveActivity1MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "VsThreads", "VS Threads Dispatched",
                          "The total number of vertex shader hardware threads dispatched.",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x14" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x18" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "HsThreads", "HS Threads Dispatched",
                          "The total number of hull shader hardware threads dispatched.",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, "hull|control,HS|TCS", "oa.fixed", 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x18" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x20" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "DsThreads", "DS Threads Dispatched",
                          "The total number of domain shader hardware threads dispatched.",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, "domain|evaluation,DS|TES", "oa.fixed", 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x1c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x28" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GsThreads", "GS Threads Dispatched",
                          "The total number of geometry shader hardware threads dispatched.",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x24:0xa5" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x38" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PsThreads", "PS Threads Dispatched",
                          "The total number of pixel shader hardware threads dispatched.",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, "PS|FS,pixel|fragment", "oa.fixed", 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x28:0xa6" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x40" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "CsThreads", "CS Threads Dispatched",
                          "The total number of compute shader hardware threads dispatched.",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x20:0xa4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x30" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "HsFpuActive", "HS FPU Pipe Active",
                          "The percentage of time in which XVE FPU INT64 pipeline was actively processing a hull shader instruction.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "hull|control,HS|TCS", nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x2c:0xa7" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x48" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "DsFpuActive", "DS FPU Pipe Active",
                          "The percentage of time in which XVE FPU INT64 pipeline was actively processing a domain shader instruction.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "domain|evaluation,DS|TES", nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x30:0xa8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x50" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GsFpuActive", "GS FPU Pipe Active",
                          "The percentage of time in which XVE FPU INT64 pipeline was actively processing a geometry shader instruction.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x34:0xa9" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x58" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "HsEmActive", "HS EM Pipe Active",
                          "The percentage of time in which XVE EM INT pipeline was actively processing a hull shader instruction.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "hull|control,HS|TCS", nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x38:0xaa" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x60" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "DsEmActive", "DS EM Pipe Active",
                          "The percentage of time in which XVE EM INT pipeline was actively processing a domain shader instruction.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "domain|evaluation,DS|TES", nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x3c:0xab" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x68" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GsEmActive", "GS EM Pipe Active",
                          "The percentage of time in which XVE EM INT pipeline was actively processing a geometry shader instruction.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x40:0xac" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x70" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "HsSendActive", "HS Send Pipe Active",
                          "The percentage of time in which XVE send pipeline was actively processing a hull shader instruction.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "hull|control,HS|TCS", nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x44:0xad" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x78" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "DsSendActive", "DS Send Pipe Active",
                          "The percentage of time in which XVE send pipeline was actively processing a domain shader instruction.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "domain|evaluation,DS|TES", nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x48:0xae" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x80" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GsSendActive", "GS Send Pipe Active",
                          "The percentage of time in which XVE send pipeline was actively processing a geometry shader instruction.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x4c:0xaf" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x88" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "CsSendActive", "CS Send Pipe Active",
                          "The percentage of time in which XVE send pipeline was actively processing a compute shader instruction.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x50:0xb0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x90" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xe458, 0x00030020, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe558, 0x00021040, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe658, 0x00041031, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe758, 0x00032022, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe45c, 0x00062042, REGISTER_TYPE_FLEX );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CGpuBusynessMetricSet::CGpuBusynessMetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CGpuBusynessMetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XveActive", "XVE Active",
                          "The percentage of time in which the Execution Units were actively processing.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x2c:0xa7" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x48" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XveStall", "XVE Stall",
                          "The percentage of time in which the Execution Units were stalled.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x30:0xa8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x50" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XveThreadOccupancy", "XVE Thread Occupancy",
                          "The percentage of time in which hardware threads occupied XVEs.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "8 rd40@0x34:0xa9 FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "8 qw@0x58 FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "VsThreads", "VS Threads Dispatched",
                          "The total number of vertex shader hardware threads dispatched.",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x14" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x18" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "HsThreads", "HS Threads Dispatched",
                          "The total number of hull shader hardware threads dispatched.",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, "hull|control,HS|TCS", "oa.fixed", 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x18" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x20" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "DsThreads", "DS Threads Dispatched",
                          "The total number of domain shader hardware threads dispatched.",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, "domain|evaluation,DS|TES", "oa.fixed", 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x1c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x28" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GsThreads", "GS Threads Dispatched",
                          "The total number of geometry shader hardware threads dispatched.",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x24:0xa5" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x38" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PsThreads", "PS Threads Dispatched",
                          "The total number of pixel shader hardware threads dispatched.",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, "PS|FS,pixel|fragment", "oa.fixed", 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x28:0xa6" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x40" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "CsThreads", "CS Threads Dispatched",
                          "The total number of compute shader hardware threads dispatched.",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x20:0xa4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x30" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "RenderBusy", "Render Ring Busy",
                          "The percentage of time when render command streamer was busy.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "ComputeEngine0Busy", "ComputeEngine0 Ring Busy",
                          "The percentage of time when compute command streamer 0 was busy.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "ComputeEngine1Busy", "ComputeEngine1 Ring Busy",
                          "The percentage of time when compute command streamer 1 was busy.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "ComputeEngine2Busy", "ComputeEngine2 Ring Busy",
                          "The percentage of time when compute command streamer 2 was busy.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "ComputeEngine3Busy", "ComputeEngine3 Ring Busy",
                          "The percentage of time when compute command streamer 3 was busy.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "BlitterBusy", "Blitter Ring Busy",
                          "The percentage of time when blitter command streamer was busy.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Vdbox00Busy", "Vdbox00 Ring Busy",
                          "The percentage of time when vdbox00 command streamer was busy.",
                          "Media", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Vebox0Busy", "Vebox0 Ring Busy",
                          "The percentage of time when vebox0 command streamer was busy.",
                          "Media", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 20 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Vdbox10Busy", "Vdbox10 Ring Busy",
                          "The percentage of time when vdbox10 command streamer was busy.",
                          "Media", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 21 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Vebox1Busy", "Vebox1 Ring Busy",
                          "The percentage of time when vebox1 command streamer was busy.",
                          "Media", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 22 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AnyComputeEngineBusy", "Any compute engine busy",
                          "The percentage of time when any compute engine is busy",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 23 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "RenderAndAnyComputeEngineBusy", "Render and any compute engines are simultaneously busy",
                          "The percentage of time when render and any compute engines are simultaneously busy",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 24 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x420a2400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a131200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040a0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120a0014, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00104000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02100002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00124000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00134000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a130024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x420a2400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a131200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040a0022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100a0014, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00102400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00120400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00134000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18012400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18042400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20042400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28042400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32040009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3c041200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10010004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f81f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000426e9, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020401f7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04041000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0604050c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0804091c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1004051c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1204010c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14040024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02085544, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00056800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032b6d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032490, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42031084, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030084, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030c62, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031084, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000081, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xe458, 0x00005004, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe558, 0x00000008, REGISTER_TYPE_FLEX );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CTestOaMetricSet::CTestOaMetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CTestOaMetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Counter0", "TestCounter0",
                          "HW test counter 0. Factor: 0.0",
                          "Test", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Counter1", "TestCounter1",
                          "HW test counter 1. Factor: 1.0",
                          "Test", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Counter2", "TestCounter2",
                          "HW test counter 2. Factor: 1.0",
                          "Test", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Counter3", "TestCounter3",
                          "HW test counter 3. Factor: 0.5",
                          "Test", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Counter4", "TestCounter4",
                          "HW test counter 4. Factor: 0.3333",
                          "Test", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Counter5", "TestCounter5",
                          "HW test counter 5. Factor: 0.3333",
                          "Test", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Counter6", "TestCounter6",
                          "HW test counter 6. Factor: 0.16666",
                          "Test", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Counter7", "TestCounter7",
                          "HW test counter 7. Factor: 0.6666",
                          "Test", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Counter8", "TestCounter8",
                          "HW test counter 8. Should be equal to 1 in IOStream or in OAG query mode",
                          "Test", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Counter9", "TestCounter9 - OAR enable",
                          "HW test counter 9. Should be equal to 1 in query.",
                          "Test", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x34080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06088000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080ff3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000003, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000007, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00100002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00100002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00100082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x001000c2, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffe7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00100001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ffe7, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CHDCAndSF_Slice01MetricSet::CHDCAndSF_Slice01MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CHDCAndSF_Slice01MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "NonSamplerShader00AccessStalledOnL3", "Slice0 Xe Core0 Non-sampler Shader Access Stalled On L3",
                          "Percentage of time when HDC has messages to L3, but it's stalled due to lack of credits (Slice0 Xe Core0)",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "NonSamplerShader01AccessStalledOnL3", "Slice0 Xe Core1 Non-sampler Shader Access Stalled On L3",
                          "Percentage of time when HDC has messages to L3, but it's stalled due to lack of credits (Slice0 Xe Core1)",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "NonSamplerShader02AccessStalledOnL3", "Slice0 Xe Core2 Non-sampler Shader Access Stalled On L3",
                          "Percentage of time when HDC has messages to L3, but it's stalled due to lack of credits (Slice0 Xe Core2)",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "NonSamplerShader03AccessStalledOnL3", "Slice0 Xe Core3 Non-sampler Shader Access Stalled On L3",
                          "Percentage of time when HDC has messages to L3, but it's stalled due to lack of credits (Slice0 Xe Core3)",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "NonSamplerShader10AccessStalledOnL3", "Slice1 Xe Core0 Non-sampler Shader Access Stalled On L3",
                          "Percentage of time when HDC has messages to L3, but it's stalled due to lack of credits (Slice1 Xe Core0)",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "NonSamplerShader11AccessStalledOnL3", "Slice1 Xe Core1 Non-sampler Shader Access Stalled On L3",
                          "Percentage of time when HDC has messages to L3, but it's stalled due to lack of credits (Slice1 Xe Core1)",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "NonSamplerShader12AccessStalledOnL3", "Slice1 Xe Core2 Non-sampler Shader Access Stalled On L3",
                          "Percentage of time when HDC has messages to L3, but it's stalled due to lack of credits (Slice1 Xe Core2)",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "NonSamplerShader13AccessStalledOnL3", "Slice1 Xe Core3 Non-sampler Shader Access Stalled On L3",
                          "Percentage of time when HDC has messages to L3, but it's stalled due to lack of credits (Slice1 Xe Core3)",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e8101e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea101e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec101e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee101e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f8101e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa101e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc101e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe101e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae10440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da10440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe10440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e38000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e64000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e74000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff0e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a55a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01076000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030047, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CHDCAndSF_Slice23MetricSet::CHDCAndSF_Slice23MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CHDCAndSF_Slice23MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "NonSamplerShader20AccessStalledOnL3", "Slice2 Xe Core0 Non-sampler Shader Access Stalled On L3",
                          "Percentage of time when HDC has messages to L3, but it's stalled due to lack of credits (Slice2 Xe Core0)",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "NonSamplerShader21AccessStalledOnL3", "Slice2 Xe Core1 Non-sampler Shader Access Stalled On L3",
                          "Percentage of time when HDC has messages to L3, but it's stalled due to lack of credits (Slice2 Xe Core1)",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "NonSamplerShader22AccessStalledOnL3", "Slice2 Xe Core2 Non-sampler Shader Access Stalled On L3",
                          "Percentage of time when HDC has messages to L3, but it's stalled due to lack of credits (Slice2 Xe Core2)",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "NonSamplerShader23AccessStalledOnL3", "Slice2 Xe Core3 Non-sampler Shader Access Stalled On L3",
                          "Percentage of time when HDC has messages to L3, but it's stalled due to lack of credits (Slice2 Xe Core3)",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "NonSamplerShader30AccessStalledOnL3", "Slice3 Xe Core0 Non-sampler Shader Access Stalled On L3",
                          "Percentage of time when HDC has messages to L3, but it's stalled due to lack of credits (Slice3 Xe Core0)",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "NonSamplerShader31AccessStalledOnL3", "Slice3 Xe Core1 Non-sampler Shader Access Stalled On L3",
                          "Percentage of time when HDC has messages to L3, but it's stalled due to lack of credits (Slice3 Xe Core1)",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "NonSamplerShader32AccessStalledOnL3", "Slice3 Xe Core2 Non-sampler Shader Access Stalled On L3",
                          "Percentage of time when HDC has messages to L3, but it's stalled due to lack of credits (Slice3 Xe Core2)",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "NonSamplerShader33AccessStalledOnL3", "Slice3 Xe Core3 Non-sampler Shader Access Stalled On L3",
                          "Percentage of time when HDC has messages to L3, but it's stalled due to lack of credits (Slice3 Xe Core3)",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e8101e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea101e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec101e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee101e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f8101e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa101e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc101e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe101e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae10440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da10440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe10440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e38000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e64000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e74000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff0e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a55a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01076000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030047, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CHDCAndSF_Slice45MetricSet::CHDCAndSF_Slice45MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CHDCAndSF_Slice45MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "NonSamplerShader40AccessStalledOnL3", "Slice4 Xe Core0 Non-sampler Shader Access Stalled On L3",
                          "Percentage of time when HDC has messages to L3, but it's stalled due to lack of credits (Slice4 Xe Core0)",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "NonSamplerShader41AccessStalledOnL3", "Slice4 Xe Core1 Non-sampler Shader Access Stalled On L3",
                          "Percentage of time when HDC has messages to L3, but it's stalled due to lack of credits (Slice4 Xe Core1)",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "NonSamplerShader42AccessStalledOnL3", "Slice4 Xe Core2 Non-sampler Shader Access Stalled On L3",
                          "Percentage of time when HDC has messages to L3, but it's stalled due to lack of credits (Slice4 Xe Core2)",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "NonSamplerShader43AccessStalledOnL3", "Slice4 Xe Core3 Non-sampler Shader Access Stalled On L3",
                          "Percentage of time when HDC has messages to L3, but it's stalled due to lack of credits (Slice4 Xe Core3)",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "NonSamplerShader50AccessStalledOnL3", "Slice5 Xe Core0 Non-sampler Shader Access Stalled On L3",
                          "Percentage of time when HDC has messages to L3, but it's stalled due to lack of credits (Slice5 Xe Core0)",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "NonSamplerShader51AccessStalledOnL3", "Slice5 Xe Core1 Non-sampler Shader Access Stalled On L3",
                          "Percentage of time when HDC has messages to L3, but it's stalled due to lack of credits (Slice5 Xe Core1)",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "NonSamplerShader52AccessStalledOnL3", "Slice5 Xe Core2 Non-sampler Shader Access Stalled On L3",
                          "Percentage of time when HDC has messages to L3, but it's stalled due to lack of credits (Slice5 Xe Core2)",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "NonSamplerShader53AccessStalledOnL3", "Slice5 Xe Core3 Non-sampler Shader Access Stalled On L3",
                          "Percentage of time when HDC has messages to L3, but it's stalled due to lack of credits (Slice5 Xe Core3)",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e8101e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea101e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec101e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee101e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f8101e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa101e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc101e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe101e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae10440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da10440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe10440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e38000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e64000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e74000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff0e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a55a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01076000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030049, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030047, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CHDCAndSF_Slice67MetricSet::CHDCAndSF_Slice67MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CHDCAndSF_Slice67MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "NonSamplerShader60AccessStalledOnL3", "Slice6 Xe Core0 Non-sampler Shader Access Stalled On L3",
                          "Percentage of time when HDC has messages to L3, but it's stalled due to lack of credits (Slice6 Xe Core0)",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "NonSamplerShader61AccessStalledOnL3", "Slice6 Xe Core1 Non-sampler Shader Access Stalled On L3",
                          "Percentage of time when HDC has messages to L3, but it's stalled due to lack of credits (Slice6 Xe Core1)",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "NonSamplerShader62AccessStalledOnL3", "Slice6 Xe Core2 Non-sampler Shader Access Stalled On L3",
                          "Percentage of time when HDC has messages to L3, but it's stalled due to lack of credits (Slice6 Xe Core2)",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "NonSamplerShader63AccessStalledOnL3", "Slice6 Xe Core3 Non-sampler Shader Access Stalled On L3",
                          "Percentage of time when HDC has messages to L3, but it's stalled due to lack of credits (Slice6 Xe Core3)",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "NonSamplerShader70AccessStalledOnL3", "Slice7 Xe Core0 Non-sampler Shader Access Stalled On L3",
                          "Percentage of time when HDC has messages to L3, but it's stalled due to lack of credits (Slice7 Xe Core0)",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "NonSamplerShader71AccessStalledOnL3", "Slice7 Xe Core1 Non-sampler Shader Access Stalled On L3",
                          "Percentage of time when HDC has messages to L3, but it's stalled due to lack of credits (Slice7 Xe Core1)",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "NonSamplerShader72AccessStalledOnL3", "Slice7 Xe Core2 Non-sampler Shader Access Stalled On L3",
                          "Percentage of time when HDC has messages to L3, but it's stalled due to lack of credits (Slice7 Xe Core2)",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "NonSamplerShader73AccessStalledOnL3", "Slice7 Xe Core3 Non-sampler Shader Access Stalled On L3",
                          "Percentage of time when HDC has messages to L3, but it's stalled due to lack of credits (Slice7 Xe Core3)",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e8101e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea101e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec101e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee101e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f8101e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa101e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc101e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe101e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae10440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da10440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe10440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e38000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e64000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e74000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff0e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a55a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01076000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030049, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030047, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CHDCAndSF1MetricSet::CHDCAndSF1MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CHDCAndSF1MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Poly0DataReady", "Polygon (Slice0) Data Ready",
                          "The percentage of time in which geometry pipeline output is ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Poly1DataReady", "Polygon (Slice1) Data Ready",
                          "The percentage of time in which geometry pipeline output is ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Poly2DataReady", "Polygon (Slice2) Data Ready",
                          "The percentage of time in which geometry pipeline output is ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Poly3DataReady", "Polygon (Slice3) Data Ready",
                          "The percentage of time in which geometry pipeline output is ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Poly4DataReady", "Polygon (Slice4) Data Ready",
                          "The percentage of time in which geometry pipeline output is ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Poly5DataReady", "Polygon (Slice5) Data Ready",
                          "The percentage of time in which geometry pipeline output is ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Poly6DataReady", "Polygon (Slice6) Data Ready",
                          "The percentage of time in which geometry pipeline output is ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Poly7DataReady", "Polygon (Slice7) Data Ready",
                          "The percentage of time in which geometry pipeline output is ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GTRequestQueue00Full", "SQ00 is full",
                          "The percentage of time when IDI0 SQ00 is filled above a threshold (usually 48 entries)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GTRequestQueue10Full", "SQ10 is full",
                          "The percentage of time when IDI0 SQ10 is filled above a threshold (usually 48 entries)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GTRequestQueue20Full", "SQ20 is full",
                          "The percentage of time when IDI0 SQ20 is filled above a threshold (usually 48 entries)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GTRequestQueue30Full", "SQ30 is full",
                          "The percentage of time when IDI0 SQ30 is filled above a threshold (usually 48 entries)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GTRequestQueue40Full", "SQ40 is full",
                          "The percentage of time when IDI0 SQ40 is filled above a threshold (usually 48 entries)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GTRequestQueue50Full", "SQ50 is full",
                          "The percentage of time when IDI0 SQ50 is filled above a threshold (usually 48 entries)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GTRequestQueue60Full", "SQ60 is full",
                          "The percentage of time when IDI0 SQ60 is filled above a threshold (usually 48 entries)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GTRequestQueue70Full", "SQ70 is full",
                          "The percentage of time when IDI0 SQ70 is filled above a threshold (usually 48 entries)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12056400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13056400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0205001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01050002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03050700, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01060002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12056400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13056400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04050007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01050002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050501c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01060008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12056400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13056400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06050007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01050002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070501c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01060020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12056400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13056400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08050007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008d000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b8000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01050002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090501c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01060080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c017000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c217000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c417000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c617000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c817000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca17000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc17000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce17000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16010006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02210010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14210180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02410010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14410006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00410000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02610010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12610180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00610000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12810006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a10180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c10006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee10180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002a500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02034849, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04034924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02093800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0409000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040a2489, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060a0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b2700, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e0314c9, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032424, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46031060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48031e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030de6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1603f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031084, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2003f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3_Slice01MetricSet::CL3_Slice01MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3_Slice01MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L30Bank0InputAvailable", "Quad0 L3 Bank0 Input Available",
                          "The percentage of time in which Quad0 L3 bank0 has input available",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L30Bank1InputAvailable", "Quad0 L3 Bank1 Input Available",
                          "The percentage of time in which Quad0 L3 bank1 has input available",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L30Bank2InputAvailable", "Quad0 L3 Bank2 Input Available",
                          "The percentage of time in which Quad0 L3 bank2 has input available",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L30Bank3InputAvailable", "Quad0 L3 Bank3 Input Available",
                          "The percentage of time in which Quad0 L3 bank3 has input available",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L30Bank4InputAvailable", "Quad0 L3 Bank4 Input Available",
                          "The percentage of time in which Quad0 L3 bank4 has input available",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L30Bank5InputAvailable", "Quad0 L3 Bank5 Input Available",
                          "The percentage of time in which Quad0 L3 bank5 has input available",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L30Bank6InputAvailable", "Quad0 L3 Bank6 Input Available",
                          "The percentage of time in which Quad0 L3 bank6 has input available",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L30Bank7InputAvailable", "Quad0 L3 Bank7 Input Available",
                          "The percentage of time in which Quad0 L3 bank7 has input available",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L30Bank0OutputReady", "Quad0 L3 Bank0 Output Ready",
                          "The percentage of time in which quad0 L3 bank0 output is ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L30Bank1OutputReady", "Quad0 L3 Bank1 Output Ready",
                          "The percentage of time in which quad0 L3 bank1 output is ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L30Bank2OutputReady", "Quad0 L3 Bank2 Output Ready",
                          "The percentage of time in which quad0 L3 bank2 output is ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L30Bank3OutputReady", "Quad0 L3 Bank3 Output Ready",
                          "The percentage of time in which quad0 L3 bank3 output is ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L30Bank4OutputReady", "Quad0 L3 Bank4 Output Ready",
                          "The percentage of time in which quad0 L3 bank4 output is ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L30Bank5OutputReady", "Quad0 L3 Bank5 Output Ready",
                          "The percentage of time in which quad0 L3 bank5 output is ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L30Bank6OutputReady", "Quad0 L3 Bank6 Output Ready",
                          "The percentage of time in which quad0 L3 bank6 output is ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L30Bank7OutputReady", "Quad0 L3 Bank7 Output Ready",
                          "The percentage of time in which quad0 L3 bank7 output is ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b1006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c1180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030e01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3_Slice23MetricSet::CL3_Slice23MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3_Slice23MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L31Bank0InputAvailable", "Quad1 L3 Bank0 Input Available",
                          "The percentage of time in which Quad1 L3 bank0 has input available",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L31Bank1InputAvailable", "Quad1 L3 Bank1 Input Available",
                          "The percentage of time in which Quad1 L3 bank1 has input available",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L31Bank2InputAvailable", "Quad1 L3 Bank2 Input Available",
                          "The percentage of time in which Quad1 L3 bank2 has input available",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L31Bank3InputAvailable", "Quad1 L3 Bank3 Input Available",
                          "The percentage of time in which Quad1 L3 bank3 has input available",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L31Bank4InputAvailable", "Quad1 L3 Bank4 Input Available",
                          "The percentage of time in which Quad1 L3 bank4 has input available",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L31Bank5InputAvailable", "Quad1 L3 Bank5 Input Available",
                          "The percentage of time in which Quad1 L3 bank5 has input available",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L31Bank6InputAvailable", "Quad1 L3 Bank6 Input Available",
                          "The percentage of time in which Quad1 L3 bank6 has input available",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L31Bank7InputAvailable", "Quad1 L3 Bank7 Input Available",
                          "The percentage of time in which Quad1 L3 bank7 has input available",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L31Bank0OutputReady", "Quad1 L3 Bank0 Output Ready",
                          "The percentage of time in which quad1 L3 bank0 output is ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L31Bank1OutputReady", "Quad1 L3 Bank1 Output Ready",
                          "The percentage of time in which quad1 L3 bank1 output is ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L31Bank2OutputReady", "Quad1 L3 Bank2 Output Ready",
                          "The percentage of time in which quad1 L3 bank2 output is ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L31Bank3OutputReady", "Quad1 L3 Bank3 Output Ready",
                          "The percentage of time in which quad1 L3 bank3 output is ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L31Bank4OutputReady", "Quad1 L3 Bank4 Output Ready",
                          "The percentage of time in which quad1 L3 bank4 output is ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L31Bank5OutputReady", "Quad1 L3 Bank5 Output Ready",
                          "The percentage of time in which quad1 L3 bank5 output is ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L31Bank6OutputReady", "Quad1 L3 Bank6 Output Ready",
                          "The percentage of time in which quad1 L3 bank6 output is ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L31Bank7OutputReady", "Quad1 L3 Bank7 Output Ready",
                          "The percentage of time in which quad1 L3 bank7 output is ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b1006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c1180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030e01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3_Slice45MetricSet::CL3_Slice45MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3_Slice45MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L32Bank0InputAvailable", "Quad2 L3 Bank0 Input Available",
                          "The percentage of time in which Quad2 L3 bank0 has input available",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L32Bank1InputAvailable", "Quad2 L3 Bank1 Input Available",
                          "The percentage of time in which Quad2 L3 bank1 has input available",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L32Bank2InputAvailable", "Quad2 L3 Bank2 Input Available",
                          "The percentage of time in which Quad2 L3 bank2 has input available",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L32Bank3InputAvailable", "Quad2 L3 Bank3 Input Available",
                          "The percentage of time in which Quad2 L3 bank3 has input available",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L32Bank4InputAvailable", "Quad2 L3 Bank4 Input Available",
                          "The percentage of time in which Quad2 L3 bank4 has input available",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L32Bank5InputAvailable", "Quad2 L3 Bank5 Input Available",
                          "The percentage of time in which Quad2 L3 bank5 has input available",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L32Bank6InputAvailable", "Quad2 L3 Bank6 Input Available",
                          "The percentage of time in which Quad2 L3 bank6 has input available",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L32Bank7InputAvailable", "Quad2 L3 Bank7 Input Available",
                          "The percentage of time in which Quad2 L3 bank7 has input available",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L32Bank0OutputReady", "Quad2 L3 Bank0 Output Ready",
                          "The percentage of time in which quad2 L3 bank0 output is ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L32Bank1OutputReady", "Quad2 L3 Bank1 Output Ready",
                          "The percentage of time in which quad2 L3 bank1 output is ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L32Bank2OutputReady", "Quad2 L3 Bank2 Output Ready",
                          "The percentage of time in which quad2 L3 bank2 output is ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L32Bank3OutputReady", "Quad2 L3 Bank3 Output Ready",
                          "The percentage of time in which quad2 L3 bank3 output is ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L32Bank4OutputReady", "Quad2 L3 Bank4 Output Ready",
                          "The percentage of time in which quad2 L3 bank4 output is ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L32Bank5OutputReady", "Quad2 L3 Bank5 Output Ready",
                          "The percentage of time in which quad2 L3 bank5 output is ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L32Bank6OutputReady", "Quad2 L3 Bank6 Output Ready",
                          "The percentage of time in which quad2 L3 bank6 output is ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L32Bank7OutputReady", "Quad2 L3 Bank7 Output Ready",
                          "The percentage of time in which quad2 L3 bank7 output is ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b1006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c1180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030e01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL3_Slice67MetricSet::CL3_Slice67MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL3_Slice67MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L33Bank0InputAvailable", "Quad3 L3 Bank0 Input Available",
                          "The percentage of time in which Quad3 L3 bank0 has input available",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L33Bank1InputAvailable", "Quad3 L3 Bank1 Input Available",
                          "The percentage of time in which Quad3 L3 bank1 has input available",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L33Bank2InputAvailable", "Quad3 L3 Bank2 Input Available",
                          "The percentage of time in which Quad3 L3 bank2 has input available",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L33Bank3InputAvailable", "Quad3 L3 Bank3 Input Available",
                          "The percentage of time in which Quad3 L3 bank3 has input available",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L33Bank4InputAvailable", "Quad3 L3 Bank4 Input Available",
                          "The percentage of time in which Quad3 L3 bank4 has input available",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L33Bank5InputAvailable", "Quad3 L3 Bank5 Input Available",
                          "The percentage of time in which Quad3 L3 bank5 has input available",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L33Bank6InputAvailable", "Quad3 L3 Bank6 Input Available",
                          "The percentage of time in which Quad3 L3 bank6 has input available",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L33Bank7InputAvailable", "Quad3 L3 Bank7 Input Available",
                          "The percentage of time in which Quad3 L3 bank7 has input available",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L33Bank0OutputReady", "Quad3 L3 Bank0 Output Ready",
                          "The percentage of time in which quad3 L3 bank0 output is ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L33Bank1OutputReady", "Quad3 L3 Bank1 Output Ready",
                          "The percentage of time in which quad3 L3 bank1 output is ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L33Bank2OutputReady", "Quad3 L3 Bank2 Output Ready",
                          "The percentage of time in which quad3 L3 bank2 output is ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L33Bank3OutputReady", "Quad3 L3 Bank3 Output Ready",
                          "The percentage of time in which quad3 L3 bank3 output is ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L33Bank4OutputReady", "Quad3 L3 Bank4 Output Ready",
                          "The percentage of time in which quad3 L3 bank4 output is ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L33Bank5OutputReady", "Quad3 L3 Bank5 Output Ready",
                          "The percentage of time in which quad3 L3 bank5 output is ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L33Bank6OutputReady", "Quad3 L3 Bank6 Output Ready",
                          "The percentage of time in which quad3 L3 bank6 output is ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L33Bank7OutputReady", "Quad3 L3 Bank7 Output Ready",
                          "The percentage of time in which quad3 L3 bank7 output is ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b1006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c1180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030e01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRasterizerAndPixelBackend1MetricSet::CRasterizerAndPixelBackend1MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRasterizerAndPixelBackend1MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "Rasterizer0InputAvailable", "Slice0 Rasterizer Input Available",
                          "The percentage of time in which slice0 rasterizer input is available",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "Rasterizer1OutputReady", "Slice1 Rasterizer Output Ready",
                          "The percentage of time in which slice1 rasterizer output is ready",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PixelData00Ready", "Slice0 Pipe0 Post-EarlyZ Pixel Data Ready",
                          "The percentage of time in which slice0  pipe0 post-EarlyZ pixel data is ready (after early Z tests have been applied)",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "Pixel|Fragment,pixel|fragment", nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PixelData01Ready", "Slice0 Pipe1 Post-EarlyZ Pixel Data Ready",
                          "The percentage of time in which slice0  pipe1 post-EarlyZ pixel data is ready (after early Z tests have been applied)",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "Pixel|Fragment,pixel|fragment", nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "Rasterizer2InputAvailable", "Slice2 Rasterizer Input Available",
                          "The percentage of time in which slice2 rasterizer input is available",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "Rasterizer3OutputReady", "Slice3 Rasterizer Output Ready",
                          "The percentage of time in which slice3 rasterizer output is ready",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PixelData20Ready", "Slice2 Pipe0 Post-EarlyZ Pixel Data Ready",
                          "The percentage of time in which slice2  pipe0 post-EarlyZ pixel data is ready (after early Z tests have been applied)",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "Pixel|Fragment,pixel|fragment", nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PixelData21Ready", "Slice2 Pipe1 Post-EarlyZ Pixel Data Ready",
                          "The percentage of time in which slice2  pipe1 post-EarlyZ pixel data is ready (after early Z tests have been applied)",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "Pixel|Fragment,pixel|fragment", nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a056000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0c701f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b057000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00038000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020535d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0405003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00072800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000803d5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a2955, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00018018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0b001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b8000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11050dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01068000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a056000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0c7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b057000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00034000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08050d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a050fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020830f5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00093000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b07d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00023000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120c07d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11050037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01064000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008eaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208bfff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e0314a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030ca5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030462, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030683, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001807f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02024000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02044000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02054000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02088000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017f80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00024000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00044000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00054000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00088000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000038, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x000000c0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffe7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000300, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ff9f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00001c00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fc7f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00006000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00018000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000cfff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRasterizerAndPixelBackend2MetricSet::CRasterizerAndPixelBackend2MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRasterizerAndPixelBackend2MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "Rasterizer1InputAvailable", "Slice1 Rasterizer Input Available",
                          "The percentage of time in which slice1 rasterizer input is available",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "Rasterizer0OutputReady", "Slice0 Rasterizer Output Ready",
                          "The percentage of time in which slice0 rasterizer output is ready",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PixelData10Ready", "Slice1 Pipe0 Post-EarlyZ Pixel Data Ready",
                          "The percentage of time in which slice1  pipe0 post-EarlyZ pixel data is ready (after early Z tests have been applied)",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "Pixel|Fragment,pixel|fragment", nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PixelData11Ready", "Slice1 Pipe1 Post-EarlyZ Pixel Data Ready",
                          "The percentage of time in which slice1  pipe1 post-EarlyZ pixel data is ready (after early Z tests have been applied)",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "Pixel|Fragment,pixel|fragment", nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "Rasterizer3InputAvailable", "Slice3 Rasterizer Input Available",
                          "The percentage of time in which slice3 rasterizer input is available",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "Rasterizer2OutputReady", "Slice2 Rasterizer Output Ready",
                          "The percentage of time in which slice2 rasterizer output is ready",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PixelData30Ready", "Slice3 Pipe0 Post-EarlyZ Pixel Data Ready",
                          "The percentage of time in which slice3  pipe0 post-EarlyZ pixel data is ready (after early Z tests have been applied)",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "Pixel|Fragment,pixel|fragment", nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PixelData31Ready", "Slice3 Pipe1 Post-EarlyZ Pixel Data Ready",
                          "The percentage of time in which slice3  pipe1 post-EarlyZ pixel data is ready (after early Z tests have been applied)",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "Pixel|Fragment,pixel|fragment", nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a057000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b056000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0b701f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0c7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003007f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10050dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00068000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00083fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a1555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001007f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b2aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030535d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0505003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01060007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070280, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01083c15, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a1695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a057000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b056000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0c7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00033f80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10050037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02081fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00013f80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b8000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03050002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09050d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b050fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01060380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800f5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01093000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b07d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01023000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c07d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008eaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208bfff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c66, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x420318c3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030c06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001807f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02024000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02044000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02054000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02088000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017f80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00024000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00044000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00054000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00088000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000038, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x000000c0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffe7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000300, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ff9f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00001c00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fc7f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00006000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00018000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000cfff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRasterizerAndPixelBackend3MetricSet::CRasterizerAndPixelBackend3MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRasterizerAndPixelBackend3MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "Rasterizer4InputAvailable", "Slice4 Rasterizer Input Available",
                          "The percentage of time in which slice4 rasterizer input is available",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "Rasterizer5OutputReady", "Slice5 Rasterizer Output Ready",
                          "The percentage of time in which slice5 rasterizer output is ready",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PixelData40Ready", "Slice4 Pipe0 Post-EarlyZ Pixel Data Ready",
                          "The percentage of time in which slice4  pipe0 post-EarlyZ pixel data is ready (after early Z tests have been applied)",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "Pixel|Fragment,pixel|fragment", nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PixelData41Ready", "Slice4 Pipe1 Post-EarlyZ Pixel Data Ready",
                          "The percentage of time in which slice4  pipe1 post-EarlyZ pixel data is ready (after early Z tests have been applied)",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "Pixel|Fragment,pixel|fragment", nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "Rasterizer6InputAvailable", "Slice6 Rasterizer Input Available",
                          "The percentage of time in which slice6 rasterizer input is available",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "Rasterizer7OutputReady", "Slice7 Rasterizer Output Ready",
                          "The percentage of time in which slice7 rasterizer output is ready",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PixelData60Ready", "Slice6 Pipe0 Post-EarlyZ Pixel Data Ready",
                          "The percentage of time in which slice6  pipe0 post-EarlyZ pixel data is ready (after early Z tests have been applied)",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "Pixel|Fragment,pixel|fragment", nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PixelData61Ready", "Slice6 Pipe1 Post-EarlyZ Pixel Data Ready",
                          "The percentage of time in which slice6  pipe1 post-EarlyZ pixel data is ready (after early Z tests have been applied)",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "Pixel|Fragment,pixel|fragment", nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a056000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0c701f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b057000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00038000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020535d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0405003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00072800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000803d5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a2955, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00018018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0b001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b8000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11050dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01068000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a056000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0c7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b057000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00034000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08050d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a050fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020830f5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00093000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b07d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00023000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120c07d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11050037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01064000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00029555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02026aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e0314a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030ca5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030462, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030683, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001807f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02024000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02044000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02054000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02088000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017f80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00024000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00044000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00054000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00088000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000038, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x000000c0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffe7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000300, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ff9f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00001c00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fc7f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00006000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00018000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000cfff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRasterizerAndPixelBackend4MetricSet::CRasterizerAndPixelBackend4MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRasterizerAndPixelBackend4MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "Rasterizer5InputAvailable", "Slice5 Rasterizer Input Available",
                          "The percentage of time in which slice5 rasterizer input is available",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "Rasterizer4OutputReady", "Slice4 Rasterizer Output Ready",
                          "The percentage of time in which slice4 rasterizer output is ready",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PixelData50Ready", "Slice5 Pipe0 Post-EarlyZ Pixel Data Ready",
                          "The percentage of time in which slice5  pipe0 post-EarlyZ pixel data is ready (after early Z tests have been applied)",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "Pixel|Fragment,pixel|fragment", nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PixelData51Ready", "Slice5 Pipe1 Post-EarlyZ Pixel Data Ready",
                          "The percentage of time in which slice5  pipe1 post-EarlyZ pixel data is ready (after early Z tests have been applied)",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "Pixel|Fragment,pixel|fragment", nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "Rasterizer7InputAvailable", "Slice7 Rasterizer Input Available",
                          "The percentage of time in which slice7 rasterizer input is available",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "Rasterizer6OutputReady", "Slice6 Rasterizer Output Ready",
                          "The percentage of time in which slice6 rasterizer output is ready",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PixelData70Ready", "Slice7 Pipe0 Post-EarlyZ Pixel Data Ready",
                          "The percentage of time in which slice7  pipe0 post-EarlyZ pixel data is ready (after early Z tests have been applied)",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "Pixel|Fragment,pixel|fragment", nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PixelData71Ready", "Slice7 Pipe1 Post-EarlyZ Pixel Data Ready",
                          "The percentage of time in which slice7  pipe1 post-EarlyZ pixel data is ready (after early Z tests have been applied)",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "Pixel|Fragment,pixel|fragment", nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a057000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b056000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0b701f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0c7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003007f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10050dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00068000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00083fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a1555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001007f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b2aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030535d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0505003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01060007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070280, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01083c15, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a1695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a057000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b056000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0b7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0c7000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00033f80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10050037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02081fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00013f80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b8000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03050002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09050d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b050fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01060380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800f5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01093000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b07d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01023000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c07d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00029555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02026aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c66, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x420318c3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030c06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001807f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02024000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02044000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02054000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02088000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017f80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00024000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00044000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00054000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00088000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000038, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x000000c0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffe7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000300, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ff9f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00001c00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fc7f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00006000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00018000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000cfff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRasterizerAndPixelBackend5MetricSet::CRasterizerAndPixelBackend5MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRasterizerAndPixelBackend5MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PSOutput00Available", "PS00 Output Available",
                          "The percentage of time in which PS00 output is available",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "PS|FS", nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PSOutput01Available", "PS01 Output Available",
                          "The percentage of time in which PS01 output is available",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "PS|FS", nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PSOutput10Available", "PS10 Output Available",
                          "The percentage of time in which PS10 output is available",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "PS|FS", nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PSOutput11Available", "PS11 Output Available",
                          "The percentage of time in which PS11 output is available",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "PS|FS", nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PSOutput20Available", "PS20 Output Available",
                          "The percentage of time in which PS20 output is available",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "PS|FS", nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PSOutput21Available", "PS21 Output Available",
                          "The percentage of time in which PS21 output is available",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "PS|FS", nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PSOutput30Available", "PS30 Output Available",
                          "The percentage of time in which PS30 output is available",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "PS|FS", nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PSOutput31Available", "PS31 Output Available",
                          "The percentage of time in which PS31 output is available",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "PS|FS", nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PixelValues00Ready", "Pixel Values 00 Ready",
                          "The percentage of time in which pixel values 00 are ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "Pixel|Fragment,pixel|fragment", nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PixelValues01Ready", "Pixel Values 01 Ready",
                          "The percentage of time in which pixel values 01 are ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "Pixel|Fragment,pixel|fragment", nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PixelValues10Ready", "Pixel Values 10 Ready",
                          "The percentage of time in which pixel values 10 are ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "Pixel|Fragment,pixel|fragment", nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PixelValues11Ready", "Pixel Values 11 Ready",
                          "The percentage of time in which pixel values 11 are ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "Pixel|Fragment,pixel|fragment", nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PixelValues20Ready", "Pixel Values 20 Ready",
                          "The percentage of time in which pixel values 20 are ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "Pixel|Fragment,pixel|fragment", nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PixelValues21Ready", "Pixel Values 21 Ready",
                          "The percentage of time in which pixel values 21 are ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "Pixel|Fragment,pixel|fragment", nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PixelValues30Ready", "Pixel Values 30 Ready",
                          "The percentage of time in which pixel values 30 are ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "Pixel|Fragment,pixel|fragment", nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PixelValues31Ready", "Pixel Values 31 Ready",
                          "The percentage of time in which pixel values 31 are ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "Pixel|Fragment,pixel|fragment", nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030126, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080126, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c030038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030126, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080126, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e030038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030126, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080126, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10030038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030126, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080126, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a030c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00048000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02042000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00054000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00088000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208803e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002a500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02022940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032449, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0403124a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032820, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030141, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRenderPipeProfile_Slice0MetricSet::CRenderPipeProfile_Slice0MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRenderPipeProfile_Slice0MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Vf0Bottleneck", "VF0 Bottleneck",
                          "The percentage of time in which vertex fetch pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Vs0Bottleneck", "VS0 Bottleneck",
                          "The percentage of time in which VS0 pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 10, 30, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Cl0Bottleneck", "Clipper0 Bottleneck",
                          "The percentage of time in which clipper pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 10, 30, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Hs0Bottleneck", "HS0 Bottleneck",
                          "The percentage of time in which hull shader pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 3, 9, HW_UNIT_SLICE, availabilityEquation, "hull|control,HS|TCS", nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Ds0Bottleneck", "DS0 Bottleneck",
                          "The percentage of time in which domain shader pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_SLICE, availabilityEquation, "domain|evaluation,DS|TES", nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Gs0Bottleneck", "GS0 Bottleneck",
                          "The percentage of time in which geometry shader pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Sf0Bottleneck", "SF0 Bottleneck",
                          "The percentage of time in which strip-fans pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 10, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "So0Bottleneck", "SO0 Bottleneck",
                          "The percentage of time in which stream output pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Cl0Stall", "CL0 Stall",
                          "The percentage of time in which clipper pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Hs0Stall", "HS0 Stall",
                          "The percentage of time in which hull stall pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "hull|control,HS|TCS", nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Ds0Stall", "DS0 Stall",
                          "The percentage of time in which domain shader pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "domain|evaluation,DS|TES", nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Sf0Stall", "SF0 Stall",
                          "The percentage of time in which strip-fans pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "So0Stall", "SO0 Stall",
                          "The percentage of time in which stream-output pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "HiDepth00Bottleneck", "Hi-Depth00 Bottleneck",
                          "The percentage of time in which early hierarchical depth test pipeline stage was slowing down the 3D pipeline.",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Bc00Bottleneck", "BC00 Bottleneck",
                          "The percentage of time in which barycentric coordinates calculation pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x168607c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1603001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12040640, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08040021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0903c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a01f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b7c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06860400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0301c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c040080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e040022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04074000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a070021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0708c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00083032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02094003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08090880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c090001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e090023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12090003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090d28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040a0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140a0940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a9a91, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a19aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00015044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020c20, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c00a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaa2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032482, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203180a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x440300c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030261, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030c22, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x400304c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fffd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025551, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045551, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055551, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaa2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRenderPipeProfile_Slice1MetricSet::CRenderPipeProfile_Slice1MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRenderPipeProfile_Slice1MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Vf1Bottleneck", "VF1 Bottleneck",
                          "The percentage of time in which vertex fetch pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Vs1Bottleneck", "VS1 Bottleneck",
                          "The percentage of time in which VS1 pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 10, 30, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Cl1Bottleneck", "Clipper1 Bottleneck",
                          "The percentage of time in which clipper pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 10, 30, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Hs1Bottleneck", "HS1 Bottleneck",
                          "The percentage of time in which hull shader pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 3, 9, HW_UNIT_SLICE, availabilityEquation, "hull|control,HS|TCS", nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Ds1Bottleneck", "DS1 Bottleneck",
                          "The percentage of time in which domain shader pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_SLICE, availabilityEquation, "domain|evaluation,DS|TES", nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Gs1Bottleneck", "GS1 Bottleneck",
                          "The percentage of time in which geometry shader pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Sf1Bottleneck", "SF1 Bottleneck",
                          "The percentage of time in which strip-fans pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 10, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "So1Bottleneck", "SO1 Bottleneck",
                          "The percentage of time in which stream output pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Cl1Stall", "CL1 Stall",
                          "The percentage of time in which clipper pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Hs1Stall", "HS1 Stall",
                          "The percentage of time in which hull stall pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "hull|control,HS|TCS", nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Ds1Stall", "DS1 Stall",
                          "The percentage of time in which domain shader pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "domain|evaluation,DS|TES", nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Sf1Stall", "SF1 Stall",
                          "The percentage of time in which strip-fans pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "So1Stall", "SO1 Stall",
                          "The percentage of time in which stream-output pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "HiDepth10Bottleneck", "Hi-Depth10 Bottleneck",
                          "The percentage of time in which early hierarchical depth test pipeline stage was slowing down the 3D pipeline.",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Bc10Bottleneck", "BC10 Bottleneck",
                          "The percentage of time in which barycentric coordinates calculation pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x178607c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1703001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13040640, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09040021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0903c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a01f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b7c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07860400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003fffd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008fff3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5551, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fffd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaa2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0301c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13030c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01040000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d040080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f040022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05074000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b070021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0708c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01083032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03083300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03094003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09090880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d090001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f090023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13090003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090d28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050a0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150a0940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a9a91, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a19aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01015044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b2200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020c20, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c00a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaa2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032482, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203180a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x440300c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030261, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030c22, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x400304c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fffd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025551, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045551, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055551, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaa2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRenderPipeProfile_Slice2MetricSet::CRenderPipeProfile_Slice2MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRenderPipeProfile_Slice2MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Vf2Bottleneck", "VF2 Bottleneck",
                          "The percentage of time in which vertex fetch pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Vs2Bottleneck", "VS2 Bottleneck",
                          "The percentage of time in which VS2 pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 10, 30, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Cl2Bottleneck", "Clipper2 Bottleneck",
                          "The percentage of time in which clipper pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 10, 30, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Hs2Bottleneck", "HS2 Bottleneck",
                          "The percentage of time in which hull shader pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 3, 9, HW_UNIT_SLICE, availabilityEquation, "hull|control,HS|TCS", nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Ds2Bottleneck", "DS2 Bottleneck",
                          "The percentage of time in which domain shader pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_SLICE, availabilityEquation, "domain|evaluation,DS|TES", nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Gs2Bottleneck", "GS2 Bottleneck",
                          "The percentage of time in which geometry shader pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Sf2Bottleneck", "SF2 Bottleneck",
                          "The percentage of time in which strip-fans pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 10, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "So2Bottleneck", "SO2 Bottleneck",
                          "The percentage of time in which stream output pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Cl2Stall", "CL2 Stall",
                          "The percentage of time in which clipper pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Hs2Stall", "HS2 Stall",
                          "The percentage of time in which hull stall pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "hull|control,HS|TCS", nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Ds2Stall", "DS2 Stall",
                          "The percentage of time in which domain shader pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "domain|evaluation,DS|TES", nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Sf2Stall", "SF2 Stall",
                          "The percentage of time in which strip-fans pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "So2Stall", "SO2 Stall",
                          "The percentage of time in which stream-output pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "HiDepth20Bottleneck", "Hi-Depth20 Bottleneck",
                          "The percentage of time in which early hierarchical depth test pipeline stage was slowing down the 3D pipeline.",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Bc20Bottleneck", "BC20 Bottleneck",
                          "The percentage of time in which barycentric coordinates calculation pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x168607c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1603001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12040640, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08040021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0903c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a01f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b7c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06860400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0301c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c040080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e040022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04074000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a070021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0708c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00083032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02094003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08090880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c090001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e090023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12090003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090d28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040a0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140a0940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a9a91, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a19aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00015044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020c20, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c00a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008fff3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032482, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203180a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x440300c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030261, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030c22, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x400304c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fffd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025551, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045551, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055551, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaa2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRenderPipeProfile_Slice3MetricSet::CRenderPipeProfile_Slice3MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRenderPipeProfile_Slice3MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Vf3Bottleneck", "VF3 Bottleneck",
                          "The percentage of time in which vertex fetch pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Vs3Bottleneck", "VS3 Bottleneck",
                          "The percentage of time in which VS3 pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 10, 30, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Cl3Bottleneck", "Clipper3 Bottleneck",
                          "The percentage of time in which clipper pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 10, 30, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Hs3Bottleneck", "HS3 Bottleneck",
                          "The percentage of time in which hull shader pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 3, 9, HW_UNIT_SLICE, availabilityEquation, "hull|control,HS|TCS", nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Ds3Bottleneck", "DS3 Bottleneck",
                          "The percentage of time in which domain shader pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_SLICE, availabilityEquation, "domain|evaluation,DS|TES", nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Gs3Bottleneck", "GS3 Bottleneck",
                          "The percentage of time in which geometry shader pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Sf3Bottleneck", "SF3 Bottleneck",
                          "The percentage of time in which strip-fans pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 10, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "So3Bottleneck", "SO3 Bottleneck",
                          "The percentage of time in which stream output pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Cl3Stall", "CL3 Stall",
                          "The percentage of time in which clipper pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Hs3Stall", "HS3 Stall",
                          "The percentage of time in which hull stall pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "hull|control,HS|TCS", nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Ds3Stall", "DS3 Stall",
                          "The percentage of time in which domain shader pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "domain|evaluation,DS|TES", nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Sf3Stall", "SF3 Stall",
                          "The percentage of time in which strip-fans pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "So3Stall", "SO3 Stall",
                          "The percentage of time in which stream-output pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "HiDepth30Bottleneck", "Hi-Depth30 Bottleneck",
                          "The percentage of time in which early hierarchical depth test pipeline stage was slowing down the 3D pipeline.",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Bc30Bottleneck", "BC30 Bottleneck",
                          "The percentage of time in which barycentric coordinates calculation pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x178607c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1703001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13040640, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09040021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0903c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a01f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b7c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07860400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003fffd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008fff3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5551, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fffd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaa2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0301c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13030c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01040000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d040080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f040022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05074000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b070021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0708c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01083032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03083300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03094003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09090880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d090001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f090023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13090003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090d28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050a0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150a0940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a9a91, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a19aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01015044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b2200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020c20, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c00a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008fff3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032482, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203180a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x440300c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030261, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030c22, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x400304c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fffd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025551, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045551, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055551, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaa2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRenderPipeProfile_Slice4MetricSet::CRenderPipeProfile_Slice4MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRenderPipeProfile_Slice4MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Vf4Bottleneck", "VF4 Bottleneck",
                          "The percentage of time in which vertex fetch pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Vs4Bottleneck", "VS4 Bottleneck",
                          "The percentage of time in which VS4 pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 10, 30, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Cl4Bottleneck", "Clipper4 Bottleneck",
                          "The percentage of time in which clipper pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 10, 30, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Hs4Bottleneck", "HS4 Bottleneck",
                          "The percentage of time in which hull shader pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 3, 9, HW_UNIT_SLICE, availabilityEquation, "hull|control,HS|TCS", nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Ds4Bottleneck", "DS4 Bottleneck",
                          "The percentage of time in which domain shader pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_SLICE, availabilityEquation, "domain|evaluation,DS|TES", nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Gs4Bottleneck", "GS4 Bottleneck",
                          "The percentage of time in which geometry shader pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Sf4Bottleneck", "SF4 Bottleneck",
                          "The percentage of time in which strip-fans pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 10, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "So4Bottleneck", "SO4 Bottleneck",
                          "The percentage of time in which stream output pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Cl4Stall", "CL4 Stall",
                          "The percentage of time in which clipper pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Hs4Stall", "HS4 Stall",
                          "The percentage of time in which hull stall pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "hull|control,HS|TCS", nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Ds4Stall", "DS4 Stall",
                          "The percentage of time in which domain shader pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "domain|evaluation,DS|TES", nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Sf4Stall", "SF4 Stall",
                          "The percentage of time in which strip-fans pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "So4Stall", "SO4 Stall",
                          "The percentage of time in which stream-output pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "HiDepth40Bottleneck", "Hi-Depth40 Bottleneck",
                          "The percentage of time in which early hierarchical depth test pipeline stage was slowing down the 3D pipeline.",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Bc40Bottleneck", "BC40 Bottleneck",
                          "The percentage of time in which barycentric coordinates calculation pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x168607c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1603001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12040640, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08040021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0903c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a01f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b7c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06860400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0301c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c040080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e040022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04074000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a070021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0708c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00083032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02094003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08090880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c090001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e090023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12090003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090d28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040a0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140a0940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a9a91, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a19aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00015044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020c20, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c00a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025551, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031241, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203180a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x440300c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030261, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030c22, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x400304c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fffd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025551, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045551, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055551, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaa2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRenderPipeProfile_Slice5MetricSet::CRenderPipeProfile_Slice5MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRenderPipeProfile_Slice5MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Vf5Bottleneck", "VF5 Bottleneck",
                          "The percentage of time in which vertex fetch pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Vs5Bottleneck", "VS5 Bottleneck",
                          "The percentage of time in which VS5 pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 10, 30, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Cl5Bottleneck", "Clipper5 Bottleneck",
                          "The percentage of time in which clipper pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 10, 30, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Hs5Bottleneck", "HS5 Bottleneck",
                          "The percentage of time in which hull shader pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 3, 9, HW_UNIT_SLICE, availabilityEquation, "hull|control,HS|TCS", nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Ds5Bottleneck", "DS5 Bottleneck",
                          "The percentage of time in which domain shader pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_SLICE, availabilityEquation, "domain|evaluation,DS|TES", nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Gs5Bottleneck", "GS5 Bottleneck",
                          "The percentage of time in which geometry shader pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Sf5Bottleneck", "SF5 Bottleneck",
                          "The percentage of time in which strip-fans pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 10, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "So5Bottleneck", "SO5 Bottleneck",
                          "The percentage of time in which stream output pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Cl5Stall", "CL5 Stall",
                          "The percentage of time in which clipper pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Hs5Stall", "HS5 Stall",
                          "The percentage of time in which hull stall pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "hull|control,HS|TCS", nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Ds5Stall", "DS5 Stall",
                          "The percentage of time in which domain shader pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "domain|evaluation,DS|TES", nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Sf5Stall", "SF5 Stall",
                          "The percentage of time in which strip-fans pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "So5Stall", "SO5 Stall",
                          "The percentage of time in which stream-output pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "HiDepth50Bottleneck", "Hi-Depth50 Bottleneck",
                          "The percentage of time in which early hierarchical depth test pipeline stage was slowing down the 3D pipeline.",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Bc50Bottleneck", "BC50 Bottleneck",
                          "The percentage of time in which barycentric coordinates calculation pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x178607c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1703001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13040640, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09040021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0903c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a01f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b7c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07860400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003fffd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008fff3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5551, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fffd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaa2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0301c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13030c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01040000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d040080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f040022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05074000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b070021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0708c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01083032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03083300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03094003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09090880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d090001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f090023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13090003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090d28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050a0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150a0940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a9a91, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a19aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01015044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b2200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020c20, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c00a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025551, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031241, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203180a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x440300c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030261, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030c22, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x400304c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fffd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025551, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045551, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055551, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaa2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRenderPipeProfile_Slice6MetricSet::CRenderPipeProfile_Slice6MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRenderPipeProfile_Slice6MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Vf6Bottleneck", "VF6 Bottleneck",
                          "The percentage of time in which vertex fetch pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Vs6Bottleneck", "VS6 Bottleneck",
                          "The percentage of time in which VS6 pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 10, 30, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Cl6Bottleneck", "Clipper6 Bottleneck",
                          "The percentage of time in which clipper pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 10, 30, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Hs6Bottleneck", "HS6 Bottleneck",
                          "The percentage of time in which hull shader pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 3, 9, HW_UNIT_SLICE, availabilityEquation, "hull|control,HS|TCS", nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Ds6Bottleneck", "DS6 Bottleneck",
                          "The percentage of time in which domain shader pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_SLICE, availabilityEquation, "domain|evaluation,DS|TES", nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Gs6Bottleneck", "GS6 Bottleneck",
                          "The percentage of time in which geometry shader pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Sf6Bottleneck", "SF6 Bottleneck",
                          "The percentage of time in which strip-fans pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 10, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "So6Bottleneck", "SO6 Bottleneck",
                          "The percentage of time in which stream output pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Cl6Stall", "CL6 Stall",
                          "The percentage of time in which clipper pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Hs6Stall", "HS6 Stall",
                          "The percentage of time in which hull stall pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "hull|control,HS|TCS", nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Ds6Stall", "DS6 Stall",
                          "The percentage of time in which domain shader pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "domain|evaluation,DS|TES", nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Sf6Stall", "SF6 Stall",
                          "The percentage of time in which strip-fans pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "So6Stall", "SO6 Stall",
                          "The percentage of time in which stream-output pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "HiDepth60Bottleneck", "Hi-Depth60 Bottleneck",
                          "The percentage of time in which early hierarchical depth test pipeline stage was slowing down the 3D pipeline.",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Bc60Bottleneck", "BC60 Bottleneck",
                          "The percentage of time in which barycentric coordinates calculation pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x168607c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1603001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12040640, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08040021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0903c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a01f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b7c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06860400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0301c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c040080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e040022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04074000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a070021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0708c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00083032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02094003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08090880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c090001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e090023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12090003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090d28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040a0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140a0940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a9a91, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a19aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00015044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020c20, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c00a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaa2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031241, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203180a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x440300c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030261, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030c22, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x400304c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fffd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025551, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045551, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055551, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaa2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CRenderPipeProfile_Slice7MetricSet::CRenderPipeProfile_Slice7MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CRenderPipeProfile_Slice7MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Vf7Bottleneck", "VF7 Bottleneck",
                          "The percentage of time in which vertex fetch pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Vs7Bottleneck", "VS7 Bottleneck",
                          "The percentage of time in which VS7 pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 10, 30, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Cl7Bottleneck", "Clipper7 Bottleneck",
                          "The percentage of time in which clipper pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 10, 30, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Hs7Bottleneck", "HS7 Bottleneck",
                          "The percentage of time in which hull shader pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 3, 9, HW_UNIT_SLICE, availabilityEquation, "hull|control,HS|TCS", nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Ds7Bottleneck", "DS7 Bottleneck",
                          "The percentage of time in which domain shader pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_SLICE, availabilityEquation, "domain|evaluation,DS|TES", nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Gs7Bottleneck", "GS7 Bottleneck",
                          "The percentage of time in which geometry shader pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Sf7Bottleneck", "SF7 Bottleneck",
                          "The percentage of time in which strip-fans pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 10, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "So7Bottleneck", "SO7 Bottleneck",
                          "The percentage of time in which stream output pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Cl7Stall", "CL7 Stall",
                          "The percentage of time in which clipper pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Hs7Stall", "HS7 Stall",
                          "The percentage of time in which hull stall pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "hull|control,HS|TCS", nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Ds7Stall", "DS7 Stall",
                          "The percentage of time in which domain shader pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "domain|evaluation,DS|TES", nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Sf7Stall", "SF7 Stall",
                          "The percentage of time in which strip-fans pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "So7Stall", "SO7 Stall",
                          "The percentage of time in which stream-output pipeline stage was stalled.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_CORRELATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "HiDepth70Bottleneck", "Hi-Depth70 Bottleneck",
                          "The percentage of time in which early hierarchical depth test pipeline stage was slowing down the 3D pipeline.",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "Bc70Bottleneck", "BC70 Bottleneck",
                          "The percentage of time in which barycentric coordinates calculation pipeline stage was slowing down the 3D pipeline.",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_INDICATE | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 5, 15, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x178607c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1703001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13040640, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09040021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0903c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a01f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b7c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07860400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003fffd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008fff3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5551, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fffd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaa2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0301c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13030c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01040000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d040080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f040022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05074000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b070021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0708c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01083032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03083300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03094003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09090880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d090001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f090023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13090003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090d28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050a0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150a0940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a9a91, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a19aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01015044, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b2200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020c20, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c00a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaa2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031241, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203180a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x440300c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030261, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030c22, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x400304c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fffd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025551, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045551, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055551, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaa2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CSampler_Slice01MetricSet::CSampler_Slice01MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CSampler_Slice01MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "Sampler00InputAvailable", "Slice0 Xe Core0 Input Available",
                          "The percentage of time in which slice0 Xe core0 sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "Sampler01InputAvailable", "Slice0 Xe Core1 Input Available",
                          "The percentage of time in which slice0 Xe core1 sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "Sampler02InputAvailable", "Slice0 Xe Core2 Input Available",
                          "The percentage of time in which slice0 Xe core2 sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "Sampler03InputAvailable", "Slice0 Xe Core3 Input Available",
                          "The percentage of time in which slice0 Xe core3 sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "Sampler10InputAvailable", "Slice1 Xe Core0 Input Available",
                          "The percentage of time in which slice1 Xe core0 sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "Sampler11InputAvailable", "Slice1 Xe Core1 Input Available",
                          "The percentage of time in which slice1 Xe core1 sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "Sampler12InputAvailable", "Slice1 Xe Core2 Input Available",
                          "The percentage of time in which slice1 Xe core2 sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "Sampler13InputAvailable", "Slice1 Xe Core3 Input Available",
                          "The percentage of time in which slice1 Xe core3 sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "Sampler00OutputReady", "Slice0 Xe Core0 Sampler Output Ready",
                          "The percentage of time in which slice0 Xe core0 sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "Sampler01OutputReady", "Slice0 Xe Core1 Sampler Output Ready",
                          "The percentage of time in which slice0 Xe core1 sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "Sampler02OutputReady", "Slice0 Xe Core2 Sampler Output Ready",
                          "The percentage of time in which slice0 Xe core2 sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "Sampler03OutputReady", "Slice0 Xe Core3 Sampler Output Ready",
                          "The percentage of time in which slice0 Xe core3 sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "Sampler10OutputReady", "Slice1 Xe Core0 Sampler Output Ready",
                          "The percentage of time in which slice1 Xe core0 sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "Sampler11OutputReady", "Slice1 Xe Core1 Sampler Output Ready",
                          "The percentage of time in which slice1 Xe core1 sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "Sampler12OutputReady", "Slice1 Xe Core2 Sampler Output Ready",
                          "The percentage of time in which slice1 Xe core2 sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "Sampler13OutputReady", "Slice1 Xe Core3 Sampler Output Ready",
                          "The percentage of time in which slice1 Xe core3 sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c824c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14832c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ca24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a32c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c32c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ce24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e32c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d824c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15832c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1da24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a32c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c32c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1de24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e32c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04824000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16820024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a830580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02834000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa30016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c20024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c30580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e30016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05824000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13820024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07830580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840808, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a30016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c20024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c30580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e30016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030f0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00093030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014f4f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090303, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030863, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42031c8a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44031c06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x460308e1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4803003f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CSampler_Slice23MetricSet::CSampler_Slice23MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CSampler_Slice23MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "Sampler20InputAvailable", "Slice2 Xe Core0 Input Available",
                          "The percentage of time in which slice2 Xe core0 sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "Sampler21InputAvailable", "Slice2 Xe Core1 Input Available",
                          "The percentage of time in which slice2 Xe core1 sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "Sampler22InputAvailable", "Slice2 Xe Core2 Input Available",
                          "The percentage of time in which slice2 Xe core2 sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "Sampler23InputAvailable", "Slice2 Xe Core3 Input Available",
                          "The percentage of time in which slice2 Xe core3 sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "Sampler30InputAvailable", "Slice3 Xe Core0 Input Available",
                          "The percentage of time in which slice3 Xe core0 sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "Sampler31InputAvailable", "Slice3 Xe Core1 Input Available",
                          "The percentage of time in which slice3 Xe core1 sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "Sampler32InputAvailable", "Slice3 Xe Core2 Input Available",
                          "The percentage of time in which slice3 Xe core2 sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "Sampler33InputAvailable", "Slice3 Xe Core3 Input Available",
                          "The percentage of time in which slice3 Xe core3 sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "Sampler20OutputReady", "Slice2 Xe Core0 Sampler Output Ready",
                          "The percentage of time in which slice2 Xe core0 sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "Sampler21OutputReady", "Slice2 Xe Core1 Sampler Output Ready",
                          "The percentage of time in which slice2 Xe core1 sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "Sampler22OutputReady", "Slice2 Xe Core2 Sampler Output Ready",
                          "The percentage of time in which slice2 Xe core2 sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "Sampler23OutputReady", "Slice2 Xe Core3 Sampler Output Ready",
                          "The percentage of time in which slice2 Xe core3 sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "Sampler30OutputReady", "Slice3 Xe Core0 Sampler Output Ready",
                          "The percentage of time in which slice3 Xe core0 sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "Sampler31OutputReady", "Slice3 Xe Core1 Sampler Output Ready",
                          "The percentage of time in which slice3 Xe core1 sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "Sampler32OutputReady", "Slice3 Xe Core2 Sampler Output Ready",
                          "The percentage of time in which slice3 Xe core2 sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "Sampler33OutputReady", "Slice3 Xe Core3 Sampler Output Ready",
                          "The percentage of time in which slice3 Xe core3 sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c824c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14832c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ca24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a32c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c32c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ce24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e32c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d824c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15832c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1da24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a32c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c32c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1de24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e32c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04824000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16820024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a830580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02834000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa30016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c20024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c30580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e30016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05824000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13820024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07830580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840808, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a30016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c20024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c30580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e30016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030f0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00093030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014f4f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090303, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030863, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42031c8a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44031c06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x460308e1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4803003f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CSampler_Slice45MetricSet::CSampler_Slice45MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CSampler_Slice45MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "Sampler40InputAvailable", "Slice4 Xe Core0 Input Available",
                          "The percentage of time in which slice4 Xe core0 sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "Sampler41InputAvailable", "Slice4 Xe Core1 Input Available",
                          "The percentage of time in which slice4 Xe core1 sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "Sampler42InputAvailable", "Slice4 Xe Core2 Input Available",
                          "The percentage of time in which slice4 Xe core2 sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "Sampler43InputAvailable", "Slice4 Xe Core3 Input Available",
                          "The percentage of time in which slice4 Xe core3 sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "Sampler50InputAvailable", "Slice5 Xe Core0 Input Available",
                          "The percentage of time in which slice5 Xe core0 sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "Sampler51InputAvailable", "Slice5 Xe Core1 Input Available",
                          "The percentage of time in which slice5 Xe core1 sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "Sampler52InputAvailable", "Slice5 Xe Core2 Input Available",
                          "The percentage of time in which slice5 Xe core2 sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "Sampler53InputAvailable", "Slice5 Xe Core3 Input Available",
                          "The percentage of time in which slice5 Xe core3 sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "Sampler40OutputReady", "Slice4 Xe Core0 Sampler Output Ready",
                          "The percentage of time in which slice4 Xe core0 sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "Sampler41OutputReady", "Slice4 Xe Core1 Sampler Output Ready",
                          "The percentage of time in which slice4 Xe core1 sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "Sampler42OutputReady", "Slice4 Xe Core2 Sampler Output Ready",
                          "The percentage of time in which slice4 Xe core2 sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "Sampler43OutputReady", "Slice4 Xe Core3 Sampler Output Ready",
                          "The percentage of time in which slice4 Xe core3 sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "Sampler50OutputReady", "Slice5 Xe Core0 Sampler Output Ready",
                          "The percentage of time in which slice5 Xe core0 sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "Sampler51OutputReady", "Slice5 Xe Core1 Sampler Output Ready",
                          "The percentage of time in which slice5 Xe core1 sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "Sampler52OutputReady", "Slice5 Xe Core2 Sampler Output Ready",
                          "The percentage of time in which slice5 Xe core2 sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "Sampler53OutputReady", "Slice5 Xe Core3 Sampler Output Ready",
                          "The percentage of time in which slice5 Xe core3 sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c824c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14832c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ca24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a32c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c32c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ce24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e32c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d824c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15832c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1da24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a32c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c32c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1de24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e32c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04824000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16820024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a830580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02834000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa30016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c20024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c30580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e30016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05824000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13820024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07830580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840808, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a30016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c20024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c30580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e30016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030f0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00093030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014f4f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090303, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030863, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42031c8a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44031c06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x460308e1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4803003f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CSampler_Slice67MetricSet::CSampler_Slice67MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CSampler_Slice67MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "Sampler60InputAvailable", "Slice6 Xe Core0 Input Available",
                          "The percentage of time in which slice6 Xe core0 sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "Sampler61InputAvailable", "Slice6 Xe Core1 Input Available",
                          "The percentage of time in which slice6 Xe core1 sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "Sampler62InputAvailable", "Slice6 Xe Core2 Input Available",
                          "The percentage of time in which slice6 Xe core2 sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "Sampler63InputAvailable", "Slice6 Xe Core3 Input Available",
                          "The percentage of time in which slice6 Xe core3 sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "Sampler70InputAvailable", "Slice7 Xe Core0 Input Available",
                          "The percentage of time in which slice7 Xe core0 sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "Sampler71InputAvailable", "Slice7 Xe Core1 Input Available",
                          "The percentage of time in which slice7 Xe core1 sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "Sampler72InputAvailable", "Slice7 Xe Core2 Input Available",
                          "The percentage of time in which slice7 Xe core2 sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "Sampler73InputAvailable", "Slice7 Xe Core3 Input Available",
                          "The percentage of time in which slice7 Xe core3 sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "Sampler60OutputReady", "Slice6 Xe Core0 Sampler Output Ready",
                          "The percentage of time in which slice6 Xe core0 sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "Sampler61OutputReady", "Slice6 Xe Core1 Sampler Output Ready",
                          "The percentage of time in which slice6 Xe core1 sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "Sampler62OutputReady", "Slice6 Xe Core2 Sampler Output Ready",
                          "The percentage of time in which slice6 Xe core2 sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "Sampler63OutputReady", "Slice6 Xe Core3 Sampler Output Ready",
                          "The percentage of time in which slice6 Xe core3 sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "Sampler70OutputReady", "Slice7 Xe Core0 Sampler Output Ready",
                          "The percentage of time in which slice7 Xe core0 sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "Sampler71OutputReady", "Slice7 Xe Core1 Sampler Output Ready",
                          "The percentage of time in which slice7 Xe core1 sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "Sampler72OutputReady", "Slice7 Xe Core2 Sampler Output Ready",
                          "The percentage of time in which slice7 Xe core2 sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "Sampler73OutputReady", "Slice7 Xe Core3 Sampler Output Ready",
                          "The percentage of time in which slice7 Xe core3 sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c824c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14832c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ca24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a32c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c32c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ce24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e32c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d824c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15832c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1da24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a32c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c32c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1de24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e32c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04824000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16820024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a830580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02834000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa30016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c20024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c30580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e30016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05824000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13820024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07830580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840808, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a30016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c20024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c30580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e30016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030f0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00093030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014f4f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090303, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030863, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42031c8a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44031c06, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x460308e1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4803003f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CTDL_Slice01_1MetricSet::CTDL_Slice01_1MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CTDL_Slice01_1MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "NonPSThread00ReadyForDispatch", "Non-PS Thread Ready For Dispatch on Slice0 Xe Core0 Thread Dispatcher",
                          "The percentage of time in which non-PS thread is ready for dispatch on slice0 Xe core0 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "NonPSThread01ReadyForDispatch", "Non-PS Thread Ready For Dispatch on Slice0 Xe Core1 Thread Dispatcher",
                          "The percentage of time in which non-PS thread is ready for dispatch on slice0 Xe core1 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "NonPSThread02ReadyForDispatch", "Non-PS Thread Ready For Dispatch on Slice0 Xe Core2 Thread Dispatcher",
                          "The percentage of time in which non-PS thread is ready for dispatch on slice0 Xe core2 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "NonPSThread03ReadyForDispatch", "Non-PS Thread Ready For Dispatch on Slice0 Xe Core3 Thread Dispatcher",
                          "The percentage of time in which non-PS thread is ready for dispatch on slice0 Xe core3 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "NonPSThread10ReadyForDispatch", "Non-PS Thread Ready For Dispatch on Slice1 Xe Core0 Thread Dispatcher",
                          "The percentage of time in which non-PS thread is ready for dispatch on slice1 Xe core0 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "NonPSThread11ReadyForDispatch", "Non-PS Thread Ready For Dispatch on Slice1 Xe Core1 Thread Dispatcher",
                          "The percentage of time in which non-PS thread is ready for dispatch on slice1 Xe core1 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "NonPSThread12ReadyForDispatch", "Non-PS Thread Ready For Dispatch on Slice1 Xe Core2 Thread Dispatcher",
                          "The percentage of time in which non-PS thread is ready for dispatch on slice1 Xe core2 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "NonPSThread13ReadyForDispatch", "Non-PS Thread Ready For Dispatch on Slice1 Xe Core3 Thread Dispatcher",
                          "The percentage of time in which non-PS thread is ready for dispatch on slice1 Xe core3 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "ThreadHeader03ReadyPort0", "Thread Header Ready on Slice0 Xe Core3 Thread Dispatcher Port 0",
                          "The percentage of time in which thread header is ready on slice0 Xe core3 thread dispatcher port 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "ThreadHeader03ReadyPort1", "Thread Header Ready on Slice0 Xe Core3 Thread Dispatcher Port 1",
                          "The percentage of time in which thread header is ready on slice0 Xe core3 thread dispatcher port 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "ThreadHeader03ReadyPort2", "Thread Header Ready on Slice0 Xe Core3 Thread Dispatcher Port 2",
                          "The percentage of time in which thread header is ready on slice0 Xe core3 thread dispatcher port 2",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "ThreadHeader03ReadyPort3", "Thread Header Ready on Slice0 Xe Core3 Thread Dispatcher Port 3",
                          "The percentage of time in which thread header is ready on slice0 Xe core3 thread dispatcher port 3",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "ThreadHeader13ReadyPort0", "Thread Header Ready on Slice1 Xe Core3 Thread Dispatcher Port 0",
                          "The percentage of time in which thread header is ready on slice1 Xe core3 thread dispatcher port 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "ThreadHeader13ReadyPort1", "Thread Header Ready on Slice1 Xe Core3 Thread Dispatcher Port 1",
                          "The percentage of time in which thread header is ready on slice1 Xe core3 thread dispatcher port 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "ThreadHeader13ReadyPort2", "Thread Header Ready on Slice1 Xe Core3 Thread Dispatcher Port 2",
                          "The percentage of time in which thread header is ready on slice1 Xe core3 thread dispatcher port 2",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "ThreadHeader13ReadyPort3", "Thread Header Ready on Slice1 Xe Core3 Thread Dispatcher Port 3",
                          "The percentage of time in which thread header is ready on slice1 Xe core3 thread dispatcher port 3",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a81001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b81001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac10030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e10cf4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e10c72, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4f008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10cf4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e10c72, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e38000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40f80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e64000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e74000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff0e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009f00c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a55a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010ff2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01076000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030047, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031ce7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CTDL_Slice01_2MetricSet::CTDL_Slice01_2MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CTDL_Slice01_2MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "PSThread00ReadyForDispatch", "PS Thread Ready For Dispatch on Slice0 Xe Core0 Thread Dispatcher",
                          "The percentage of time in which PS thread is ready for dispatch on slice0 Xe core0 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "PSThread01ReadyForDispatch", "PS Thread Ready For Dispatch on Slice0 Xe Core1 Thread Dispatcher",
                          "The percentage of time in which PS thread is ready for dispatch on slice0 Xe core1 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "PSThread02ReadyForDispatch", "PS Thread Ready For Dispatch on Slice0 Xe Core2 Thread Dispatcher",
                          "The percentage of time in which PS thread is ready for dispatch on slice0 Xe core2 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "PSThread03ReadyForDispatch", "PS Thread Ready For Dispatch on Slice0 Xe Core3 Thread Dispatcher",
                          "The percentage of time in which PS thread is ready for dispatch on slice0 Xe core3 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "PSThread10ReadyForDispatch", "PS Thread Ready For Dispatch on Slice1 Xe Core0 Thread Dispatcher",
                          "The percentage of time in which PS thread is ready for dispatch on slice1 Xe core0 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "PSThread11ReadyForDispatch", "PS Thread Ready For Dispatch on Slice1 Xe Core1 Thread Dispatcher",
                          "The percentage of time in which PS thread is ready for dispatch on slice1 Xe core1 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "PSThread12ReadyForDispatch", "PS Thread Ready For Dispatch on Slice1 Xe Core2 Thread Dispatcher",
                          "The percentage of time in which PS thread is ready for dispatch on slice1 Xe core2 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "PSThread13ReadyForDispatch", "PS Thread Ready For Dispatch on Slice1 Xe Core3 Thread Dispatcher",
                          "The percentage of time in which PS thread is ready for dispatch on slice1 Xe core3 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28810340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28a10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28c10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28e10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29810340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29a10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29c10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29e10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e400c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11810c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c43000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff0c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01023000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030ee8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030277, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CTDL_Slice01_3MetricSet::CTDL_Slice01_3MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CTDL_Slice01_3MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "ThreadHeader00Ready", "Thread Header Ready on Slice0 Xe Core0 Thread Dispatcher",
                          "The percentage of time in which thread header is ready on slice0 Xe core0 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "ThreadHeader00ReadyPort0", "Thread Header Ready on Slice0 Xe Core0 Thread Dispatcher Port 0",
                          "The percentage of time in which thread header is ready on slice0 Xe core0 thread dispatcher port 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "ThreadHeader00ReadyPort1", "Thread Header Ready on Slice0 Xe Core0 Thread Dispatcher Port 1",
                          "The percentage of time in which thread header is ready on slice0 Xe core0 thread dispatcher port 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "ThreadHeader00ReadyPort2", "Thread Header Ready on Slice0 Xe Core0 Thread Dispatcher Port 2",
                          "The percentage of time in which thread header is ready on slice0 Xe core0 thread dispatcher port 2",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "ThreadHeader00ReadyPort3", "Thread Header Ready on Slice0 Xe Core0 Thread Dispatcher Port 3",
                          "The percentage of time in which thread header is ready on slice0 Xe core0 thread dispatcher port 3",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "ThreadHeader01Ready", "Thread Header Ready on Slice0 Xe Core1 Thread Dispatcher",
                          "The percentage of time in which thread header is ready on slice0 Xe core1 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "ThreadHeader01ReadyPort0", "Thread Header Ready on Slice0 Xe Core1 Thread Dispatcher Port 0",
                          "The percentage of time in which thread header is ready on slice0 Xe core1 thread dispatcher port 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "ThreadHeader01ReadyPort1", "Thread Header Ready on Slice0 Xe Core1 Thread Dispatcher Port 1",
                          "The percentage of time in which thread header is ready on slice0 Xe core1 thread dispatcher port 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "ThreadHeader01ReadyPort2", "Thread Header Ready on Slice0 Xe Core1 Thread Dispatcher Port 2",
                          "The percentage of time in which thread header is ready on slice0 Xe core1 thread dispatcher port 2",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "ThreadHeader01ReadyPort3", "Thread Header Ready on Slice0 Xe Core1 Thread Dispatcher Port 3",
                          "The percentage of time in which thread header is ready on slice0 Xe core1 thread dispatcher port 3",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "ThreadHeader02Ready", "Thread Header Ready on Slice0 Xe Core2 Thread Dispatcher",
                          "The percentage of time in which thread header is ready on slice0 Xe core2 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "ThreadHeader02ReadyPort0", "Thread Header Ready on Slice0 Xe Core2 Thread Dispatcher Port 0",
                          "The percentage of time in which thread header is ready on slice0 Xe core2 thread dispatcher port 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "ThreadHeader02ReadyPort1", "Thread Header Ready on Slice0 Xe Core2 Thread Dispatcher Port 1",
                          "The percentage of time in which thread header is ready on slice0 Xe core2 thread dispatcher port 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "ThreadHeader02ReadyPort2", "Thread Header Ready on Slice0 Xe Core2 Thread Dispatcher Port 2",
                          "The percentage of time in which thread header is ready on slice0 Xe core2 thread dispatcher port 2",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "ThreadHeader02ReadyPort3", "Thread Header Ready on Slice0 Xe Core2 Thread Dispatcher Port 3",
                          "The percentage of time in which thread header is ready on slice0 Xe core2 thread dispatcher port 3",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "ThreadHeader03Ready", "Thread Header Ready on Slice0 Xe Core3 Thread Dispatcher",
                          "The percentage of time in which thread header is ready on slice0 Xe core3 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a81001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14810cf4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16810c72, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02875500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a10cf4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a10c72, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10cf4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec10c72, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae10d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00078000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00007800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000780, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000078, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fff0, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CTDL_Slice01_4MetricSet::CTDL_Slice01_4MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CTDL_Slice01_4MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "ThreadHeader10Ready", "Thread Header Ready on Slice1 Xe Core0 Thread Dispatcher",
                          "The percentage of time in which thread header is ready on slice1 Xe core0 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "ThreadHeader10ReadyPort0", "Thread Header Ready on Slice1 Xe Core0 Thread Dispatcher Port 0",
                          "The percentage of time in which thread header is ready on slice1 Xe core0 thread dispatcher port 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "ThreadHeader10ReadyPort1", "Thread Header Ready on Slice1 Xe Core0 Thread Dispatcher Port 1",
                          "The percentage of time in which thread header is ready on slice1 Xe core0 thread dispatcher port 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "ThreadHeader10ReadyPort2", "Thread Header Ready on Slice1 Xe Core0 Thread Dispatcher Port 2",
                          "The percentage of time in which thread header is ready on slice1 Xe core0 thread dispatcher port 2",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "ThreadHeader10ReadyPort3", "Thread Header Ready on Slice1 Xe Core0 Thread Dispatcher Port 3",
                          "The percentage of time in which thread header is ready on slice1 Xe core0 thread dispatcher port 3",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "ThreadHeader11Ready", "Thread Header Ready on Slice1 Xe Core1 Thread Dispatcher",
                          "The percentage of time in which thread header is ready on slice1 Xe core1 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "ThreadHeader11ReadyPort0", "Thread Header Ready on Slice1 Xe Core1 Thread Dispatcher Port 0",
                          "The percentage of time in which thread header is ready on slice1 Xe core1 thread dispatcher port 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "ThreadHeader11ReadyPort1", "Thread Header Ready on Slice1 Xe Core1 Thread Dispatcher Port 1",
                          "The percentage of time in which thread header is ready on slice1 Xe core1 thread dispatcher port 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "ThreadHeader11ReadyPort2", "Thread Header Ready on Slice1 Xe Core1 Thread Dispatcher Port 2",
                          "The percentage of time in which thread header is ready on slice1 Xe core1 thread dispatcher port 2",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "ThreadHeader11ReadyPort3", "Thread Header Ready on Slice1 Xe Core1 Thread Dispatcher Port 3",
                          "The percentage of time in which thread header is ready on slice1 Xe core1 thread dispatcher port 3",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "ThreadHeader12Ready", "Thread Header Ready on Slice1 Xe Core2 Thread Dispatcher",
                          "The percentage of time in which thread header is ready on slice1 Xe core2 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "ThreadHeader12ReadyPort0", "Thread Header Ready on Slice1 Xe Core2 Thread Dispatcher Port 0",
                          "The percentage of time in which thread header is ready on slice1 Xe core2 thread dispatcher port 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "ThreadHeader12ReadyPort1", "Thread Header Ready on Slice1 Xe Core2 Thread Dispatcher Port 1",
                          "The percentage of time in which thread header is ready on slice1 Xe core2 thread dispatcher port 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "ThreadHeader12ReadyPort2", "Thread Header Ready on Slice1 Xe Core2 Thread Dispatcher Port 2",
                          "The percentage of time in which thread header is ready on slice1 Xe core2 thread dispatcher port 2",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "ThreadHeader12ReadyPort3", "Thread Header Ready on Slice1 Xe Core2 Thread Dispatcher Port 3",
                          "The percentage of time in which thread header is ready on slice1 Xe core2 thread dispatcher port 3",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "ThreadHeader13Ready", "Thread Header Ready on Slice1 Xe Core3 Thread Dispatcher",
                          "The percentage of time in which thread header is ready on slice1 Xe core3 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b81001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15810cf4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17810c72, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03875500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a10cf4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10c72, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc10cf4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10c72, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be10d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00078000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00007800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000780, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000078, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fff0, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CTDL_Slice23_1MetricSet::CTDL_Slice23_1MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CTDL_Slice23_1MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "NonPSThread20ReadyForDispatch", "Non-PS Thread Ready For Dispatch on Slice2 Xe Core0 Thread Dispatcher",
                          "The percentage of time in which non-PS thread is ready for dispatch on slice2 Xe core0 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "NonPSThread21ReadyForDispatch", "Non-PS Thread Ready For Dispatch on Slice2 Xe Core1 Thread Dispatcher",
                          "The percentage of time in which non-PS thread is ready for dispatch on slice2 Xe core1 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "NonPSThread22ReadyForDispatch", "Non-PS Thread Ready For Dispatch on Slice2 Xe Core2 Thread Dispatcher",
                          "The percentage of time in which non-PS thread is ready for dispatch on slice2 Xe core2 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "NonPSThread23ReadyForDispatch", "Non-PS Thread Ready For Dispatch on Slice2 Xe Core3 Thread Dispatcher",
                          "The percentage of time in which non-PS thread is ready for dispatch on slice2 Xe core3 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "NonPSThread30ReadyForDispatch", "Non-PS Thread Ready For Dispatch on Slice3 Xe Core0 Thread Dispatcher",
                          "The percentage of time in which non-PS thread is ready for dispatch on slice3 Xe core0 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "NonPSThread31ReadyForDispatch", "Non-PS Thread Ready For Dispatch on Slice3 Xe Core1 Thread Dispatcher",
                          "The percentage of time in which non-PS thread is ready for dispatch on slice3 Xe core1 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "NonPSThread32ReadyForDispatch", "Non-PS Thread Ready For Dispatch on Slice3 Xe Core2 Thread Dispatcher",
                          "The percentage of time in which non-PS thread is ready for dispatch on slice3 Xe core2 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "NonPSThread33ReadyForDispatch", "Non-PS Thread Ready For Dispatch on Slice3 Xe Core3 Thread Dispatcher",
                          "The percentage of time in which non-PS thread is ready for dispatch on slice3 Xe core3 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "ThreadHeader23ReadyPort0", "Thread Header Ready on Slice2 Xe Core3 Thread Dispatcher Port 0",
                          "The percentage of time in which thread header is ready on slice2 Xe core3 thread dispatcher port 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "ThreadHeader23ReadyPort1", "Thread Header Ready on Slice2 Xe Core3 Thread Dispatcher Port 1",
                          "The percentage of time in which thread header is ready on slice2 Xe core3 thread dispatcher port 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "ThreadHeader23ReadyPort2", "Thread Header Ready on Slice2 Xe Core3 Thread Dispatcher Port 2",
                          "The percentage of time in which thread header is ready on slice2 Xe core3 thread dispatcher port 2",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "ThreadHeader23ReadyPort3", "Thread Header Ready on Slice2 Xe Core3 Thread Dispatcher Port 3",
                          "The percentage of time in which thread header is ready on slice2 Xe core3 thread dispatcher port 3",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "ThreadHeader33ReadyPort0", "Thread Header Ready on Slice3 Xe Core3 Thread Dispatcher Port 0",
                          "The percentage of time in which thread header is ready on slice3 Xe core3 thread dispatcher port 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "ThreadHeader33ReadyPort1", "Thread Header Ready on Slice3 Xe Core3 Thread Dispatcher Port 1",
                          "The percentage of time in which thread header is ready on slice3 Xe core3 thread dispatcher port 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "ThreadHeader33ReadyPort2", "Thread Header Ready on Slice3 Xe Core3 Thread Dispatcher Port 2",
                          "The percentage of time in which thread header is ready on slice3 Xe core3 thread dispatcher port 2",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "ThreadHeader33ReadyPort3", "Thread Header Ready on Slice3 Xe Core3 Thread Dispatcher Port 3",
                          "The percentage of time in which thread header is ready on slice3 Xe core3 thread dispatcher port 3",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a81001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b81001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac10030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e10cf4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e10c72, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4f008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10cf4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e10c72, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e38000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40f80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e64000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e74000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff0e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009f00c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a55a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010ff2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01076000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030047, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031ce7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CTDL_Slice23_2MetricSet::CTDL_Slice23_2MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CTDL_Slice23_2MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "PSThread20ReadyForDispatch", "PS Thread Ready For Dispatch on Slice2 Xe Core0 Thread Dispatcher",
                          "The percentage of time in which PS thread is ready for dispatch on slice2 Xe core0 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "PSThread21ReadyForDispatch", "PS Thread Ready For Dispatch on Slice2 Xe Core1 Thread Dispatcher",
                          "The percentage of time in which PS thread is ready for dispatch on slice2 Xe core1 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "PSThread22ReadyForDispatch", "PS Thread Ready For Dispatch on Slice2 Xe Core2 Thread Dispatcher",
                          "The percentage of time in which PS thread is ready for dispatch on slice2 Xe core2 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "PSThread23ReadyForDispatch", "PS Thread Ready For Dispatch on Slice2 Xe Core3 Thread Dispatcher",
                          "The percentage of time in which PS thread is ready for dispatch on slice2 Xe core3 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "PSThread30ReadyForDispatch", "PS Thread Ready For Dispatch on Slice3 Xe Core0 Thread Dispatcher",
                          "The percentage of time in which PS thread is ready for dispatch on slice3 Xe core0 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "PSThread31ReadyForDispatch", "PS Thread Ready For Dispatch on Slice3 Xe Core1 Thread Dispatcher",
                          "The percentage of time in which PS thread is ready for dispatch on slice3 Xe core1 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "PSThread32ReadyForDispatch", "PS Thread Ready For Dispatch on Slice3 Xe Core2 Thread Dispatcher",
                          "The percentage of time in which PS thread is ready for dispatch on slice3 Xe core2 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "PSThread33ReadyForDispatch", "PS Thread Ready For Dispatch on Slice3 Xe Core3 Thread Dispatcher",
                          "The percentage of time in which PS thread is ready for dispatch on slice3 Xe core3 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28810340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28a10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28c10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28e10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29810340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29a10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29c10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29e10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e400c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11810c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c43000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff0c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01023000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030ee8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030277, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CTDL_Slice23_3MetricSet::CTDL_Slice23_3MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CTDL_Slice23_3MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "ThreadHeader20Ready", "Thread Header Ready on Slice2 Xe Core0 Thread Dispatcher",
                          "The percentage of time in which thread header is ready on slice2 Xe core0 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "ThreadHeader20ReadyPort0", "Thread Header Ready on Slice2 Xe Core0 Thread Dispatcher Port 0",
                          "The percentage of time in which thread header is ready on slice2 Xe core0 thread dispatcher port 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "ThreadHeader20ReadyPort1", "Thread Header Ready on Slice2 Xe Core0 Thread Dispatcher Port 1",
                          "The percentage of time in which thread header is ready on slice2 Xe core0 thread dispatcher port 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "ThreadHeader20ReadyPort2", "Thread Header Ready on Slice2 Xe Core0 Thread Dispatcher Port 2",
                          "The percentage of time in which thread header is ready on slice2 Xe core0 thread dispatcher port 2",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "ThreadHeader20ReadyPort3", "Thread Header Ready on Slice2 Xe Core0 Thread Dispatcher Port 3",
                          "The percentage of time in which thread header is ready on slice2 Xe core0 thread dispatcher port 3",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "ThreadHeader21Ready", "Thread Header Ready on Slice2 Xe Core1 Thread Dispatcher",
                          "The percentage of time in which thread header is ready on slice2 Xe core1 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "ThreadHeader21ReadyPort0", "Thread Header Ready on Slice2 Xe Core1 Thread Dispatcher Port 0",
                          "The percentage of time in which thread header is ready on slice2 Xe core1 thread dispatcher port 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "ThreadHeader21ReadyPort1", "Thread Header Ready on Slice2 Xe Core1 Thread Dispatcher Port 1",
                          "The percentage of time in which thread header is ready on slice2 Xe core1 thread dispatcher port 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "ThreadHeader21ReadyPort2", "Thread Header Ready on Slice2 Xe Core1 Thread Dispatcher Port 2",
                          "The percentage of time in which thread header is ready on slice2 Xe core1 thread dispatcher port 2",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "ThreadHeader21ReadyPort3", "Thread Header Ready on Slice2 Xe Core1 Thread Dispatcher Port 3",
                          "The percentage of time in which thread header is ready on slice2 Xe core1 thread dispatcher port 3",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "ThreadHeader22Ready", "Thread Header Ready on Slice2 Xe Core2 Thread Dispatcher",
                          "The percentage of time in which thread header is ready on slice2 Xe core2 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "ThreadHeader22ReadyPort0", "Thread Header Ready on Slice2 Xe Core2 Thread Dispatcher Port 0",
                          "The percentage of time in which thread header is ready on slice2 Xe core2 thread dispatcher port 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "ThreadHeader22ReadyPort1", "Thread Header Ready on Slice2 Xe Core2 Thread Dispatcher Port 1",
                          "The percentage of time in which thread header is ready on slice2 Xe core2 thread dispatcher port 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "ThreadHeader22ReadyPort2", "Thread Header Ready on Slice2 Xe Core2 Thread Dispatcher Port 2",
                          "The percentage of time in which thread header is ready on slice2 Xe core2 thread dispatcher port 2",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "ThreadHeader22ReadyPort3", "Thread Header Ready on Slice2 Xe Core2 Thread Dispatcher Port 3",
                          "The percentage of time in which thread header is ready on slice2 Xe core2 thread dispatcher port 3",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "ThreadHeader23Ready", "Thread Header Ready on Slice2 Xe Core3 Thread Dispatcher",
                          "The percentage of time in which thread header is ready on slice2 Xe core3 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a81001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14810cf4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16810c72, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02875500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a10cf4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a10c72, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10cf4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec10c72, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae10d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00078000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00007800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000780, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000078, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fff0, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CTDL_Slice23_4MetricSet::CTDL_Slice23_4MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CTDL_Slice23_4MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "ThreadHeader30Ready", "Thread Header Ready on Slice3 Xe Core0 Thread Dispatcher",
                          "The percentage of time in which thread header is ready on slice3 Xe core0 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "ThreadHeader30ReadyPort0", "Thread Header Ready on Slice3 Xe Core0 Thread Dispatcher Port 0",
                          "The percentage of time in which thread header is ready on slice3 Xe core0 thread dispatcher port 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "ThreadHeader30ReadyPort1", "Thread Header Ready on Slice3 Xe Core0 Thread Dispatcher Port 1",
                          "The percentage of time in which thread header is ready on slice3 Xe core0 thread dispatcher port 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "ThreadHeader30ReadyPort2", "Thread Header Ready on Slice3 Xe Core0 Thread Dispatcher Port 2",
                          "The percentage of time in which thread header is ready on slice3 Xe core0 thread dispatcher port 2",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "ThreadHeader30ReadyPort3", "Thread Header Ready on Slice3 Xe Core0 Thread Dispatcher Port 3",
                          "The percentage of time in which thread header is ready on slice3 Xe core0 thread dispatcher port 3",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "ThreadHeader31Ready", "Thread Header Ready on Slice3 Xe Core1 Thread Dispatcher",
                          "The percentage of time in which thread header is ready on slice3 Xe core1 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "ThreadHeader31ReadyPort0", "Thread Header Ready on Slice3 Xe Core1 Thread Dispatcher Port 0",
                          "The percentage of time in which thread header is ready on slice3 Xe core1 thread dispatcher port 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "ThreadHeader31ReadyPort1", "Thread Header Ready on Slice3 Xe Core1 Thread Dispatcher Port 1",
                          "The percentage of time in which thread header is ready on slice3 Xe core1 thread dispatcher port 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "ThreadHeader31ReadyPort2", "Thread Header Ready on Slice3 Xe Core1 Thread Dispatcher Port 2",
                          "The percentage of time in which thread header is ready on slice3 Xe core1 thread dispatcher port 2",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "ThreadHeader31ReadyPort3", "Thread Header Ready on Slice3 Xe Core1 Thread Dispatcher Port 3",
                          "The percentage of time in which thread header is ready on slice3 Xe core1 thread dispatcher port 3",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "ThreadHeader32Ready", "Thread Header Ready on Slice3 Xe Core2 Thread Dispatcher",
                          "The percentage of time in which thread header is ready on slice3 Xe core2 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "ThreadHeader32ReadyPort0", "Thread Header Ready on Slice3 Xe Core2 Thread Dispatcher Port 0",
                          "The percentage of time in which thread header is ready on slice3 Xe core2 thread dispatcher port 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "ThreadHeader32ReadyPort1", "Thread Header Ready on Slice3 Xe Core2 Thread Dispatcher Port 1",
                          "The percentage of time in which thread header is ready on slice3 Xe core2 thread dispatcher port 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "ThreadHeader32ReadyPort2", "Thread Header Ready on Slice3 Xe Core2 Thread Dispatcher Port 2",
                          "The percentage of time in which thread header is ready on slice3 Xe core2 thread dispatcher port 2",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "ThreadHeader32ReadyPort3", "Thread Header Ready on Slice3 Xe Core2 Thread Dispatcher Port 3",
                          "The percentage of time in which thread header is ready on slice3 Xe core2 thread dispatcher port 3",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "ThreadHeader33Ready", "Thread Header Ready on Slice3 Xe Core3 Thread Dispatcher",
                          "The percentage of time in which thread header is ready on slice3 Xe core3 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b81001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15810cf4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17810c72, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03875500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a10cf4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10c72, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc10cf4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10c72, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be10d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00078000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00007800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000780, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000078, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fff0, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CTDL_Slice45_1MetricSet::CTDL_Slice45_1MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CTDL_Slice45_1MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "NonPSThread40ReadyForDispatch", "Non-PS Thread Ready For Dispatch on Slice4 Xe Core0 Thread Dispatcher",
                          "The percentage of time in which non-PS thread is ready for dispatch on slice4 Xe core0 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "NonPSThread41ReadyForDispatch", "Non-PS Thread Ready For Dispatch on Slice4 Xe Core1 Thread Dispatcher",
                          "The percentage of time in which non-PS thread is ready for dispatch on slice4 Xe core1 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "NonPSThread42ReadyForDispatch", "Non-PS Thread Ready For Dispatch on Slice4 Xe Core2 Thread Dispatcher",
                          "The percentage of time in which non-PS thread is ready for dispatch on slice4 Xe core2 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "NonPSThread43ReadyForDispatch", "Non-PS Thread Ready For Dispatch on Slice4 Xe Core3 Thread Dispatcher",
                          "The percentage of time in which non-PS thread is ready for dispatch on slice4 Xe core3 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "NonPSThread50ReadyForDispatch", "Non-PS Thread Ready For Dispatch on Slice5 Xe Core0 Thread Dispatcher",
                          "The percentage of time in which non-PS thread is ready for dispatch on slice5 Xe core0 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "NonPSThread51ReadyForDispatch", "Non-PS Thread Ready For Dispatch on Slice5 Xe Core1 Thread Dispatcher",
                          "The percentage of time in which non-PS thread is ready for dispatch on slice5 Xe core1 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "NonPSThread52ReadyForDispatch", "Non-PS Thread Ready For Dispatch on Slice5 Xe Core2 Thread Dispatcher",
                          "The percentage of time in which non-PS thread is ready for dispatch on slice5 Xe core2 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "NonPSThread53ReadyForDispatch", "Non-PS Thread Ready For Dispatch on Slice5 Xe Core3 Thread Dispatcher",
                          "The percentage of time in which non-PS thread is ready for dispatch on slice5 Xe core3 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "ThreadHeader43ReadyPort0", "Thread Header Ready on Slice4 Xe Core3 Thread Dispatcher Port 0",
                          "The percentage of time in which thread header is ready on slice4 Xe core3 thread dispatcher port 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "ThreadHeader43ReadyPort1", "Thread Header Ready on Slice4 Xe Core3 Thread Dispatcher Port 1",
                          "The percentage of time in which thread header is ready on slice4 Xe core3 thread dispatcher port 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "ThreadHeader43ReadyPort2", "Thread Header Ready on Slice4 Xe Core3 Thread Dispatcher Port 2",
                          "The percentage of time in which thread header is ready on slice4 Xe core3 thread dispatcher port 2",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "ThreadHeader43ReadyPort3", "Thread Header Ready on Slice4 Xe Core3 Thread Dispatcher Port 3",
                          "The percentage of time in which thread header is ready on slice4 Xe core3 thread dispatcher port 3",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "ThreadHeader53ReadyPort0", "Thread Header Ready on Slice5 Xe Core3 Thread Dispatcher Port 0",
                          "The percentage of time in which thread header is ready on slice5 Xe core3 thread dispatcher port 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "ThreadHeader53ReadyPort1", "Thread Header Ready on Slice5 Xe Core3 Thread Dispatcher Port 1",
                          "The percentage of time in which thread header is ready on slice5 Xe core3 thread dispatcher port 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "ThreadHeader53ReadyPort2", "Thread Header Ready on Slice5 Xe Core3 Thread Dispatcher Port 2",
                          "The percentage of time in which thread header is ready on slice5 Xe core3 thread dispatcher port 2",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "ThreadHeader53ReadyPort3", "Thread Header Ready on Slice5 Xe Core3 Thread Dispatcher Port 3",
                          "The percentage of time in which thread header is ready on slice5 Xe core3 thread dispatcher port 3",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a81001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b81001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac10030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e10cf4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e10c72, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4f008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10cf4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e10c72, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e38000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40f80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e64000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e74000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff0e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009f00c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a55a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010ff2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01076000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030047, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031ce7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CTDL_Slice45_2MetricSet::CTDL_Slice45_2MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CTDL_Slice45_2MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "PSThread40ReadyForDispatch", "PS Thread Ready For Dispatch on Slice4 Xe Core0 Thread Dispatcher",
                          "The percentage of time in which PS thread is ready for dispatch on slice4 Xe core0 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "PSThread41ReadyForDispatch", "PS Thread Ready For Dispatch on Slice4 Xe Core1 Thread Dispatcher",
                          "The percentage of time in which PS thread is ready for dispatch on slice4 Xe core1 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "PSThread42ReadyForDispatch", "PS Thread Ready For Dispatch on Slice4 Xe Core2 Thread Dispatcher",
                          "The percentage of time in which PS thread is ready for dispatch on slice4 Xe core2 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "PSThread43ReadyForDispatch", "PS Thread Ready For Dispatch on Slice4 Xe Core3 Thread Dispatcher",
                          "The percentage of time in which PS thread is ready for dispatch on slice4 Xe core3 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "PSThread50ReadyForDispatch", "PS Thread Ready For Dispatch on Slice5 Xe Core0 Thread Dispatcher",
                          "The percentage of time in which PS thread is ready for dispatch on slice5 Xe core0 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "PSThread51ReadyForDispatch", "PS Thread Ready For Dispatch on Slice5 Xe Core1 Thread Dispatcher",
                          "The percentage of time in which PS thread is ready for dispatch on slice5 Xe core1 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "PSThread52ReadyForDispatch", "PS Thread Ready For Dispatch on Slice5 Xe Core2 Thread Dispatcher",
                          "The percentage of time in which PS thread is ready for dispatch on slice5 Xe core2 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "PSThread53ReadyForDispatch", "PS Thread Ready For Dispatch on Slice5 Xe Core3 Thread Dispatcher",
                          "The percentage of time in which PS thread is ready for dispatch on slice5 Xe core3 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28810340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28a10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28c10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28e10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29810340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29a10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29c10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29e10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e400c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11810c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c43000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff0c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01023000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030ee8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030277, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CTDL_Slice45_3MetricSet::CTDL_Slice45_3MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CTDL_Slice45_3MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "ThreadHeader40Ready", "Thread Header Ready on Slice4 Xe Core0 Thread Dispatcher",
                          "The percentage of time in which thread header is ready on slice4 Xe core0 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "ThreadHeader40ReadyPort0", "Thread Header Ready on Slice4 Xe Core0 Thread Dispatcher Port 0",
                          "The percentage of time in which thread header is ready on slice4 Xe core0 thread dispatcher port 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "ThreadHeader40ReadyPort1", "Thread Header Ready on Slice4 Xe Core0 Thread Dispatcher Port 1",
                          "The percentage of time in which thread header is ready on slice4 Xe core0 thread dispatcher port 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "ThreadHeader40ReadyPort2", "Thread Header Ready on Slice4 Xe Core0 Thread Dispatcher Port 2",
                          "The percentage of time in which thread header is ready on slice4 Xe core0 thread dispatcher port 2",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "ThreadHeader40ReadyPort3", "Thread Header Ready on Slice4 Xe Core0 Thread Dispatcher Port 3",
                          "The percentage of time in which thread header is ready on slice4 Xe core0 thread dispatcher port 3",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "ThreadHeader41Ready", "Thread Header Ready on Slice4 Xe Core1 Thread Dispatcher",
                          "The percentage of time in which thread header is ready on slice4 Xe core1 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "ThreadHeader41ReadyPort0", "Thread Header Ready on Slice4 Xe Core1 Thread Dispatcher Port 0",
                          "The percentage of time in which thread header is ready on slice4 Xe core1 thread dispatcher port 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "ThreadHeader41ReadyPort1", "Thread Header Ready on Slice4 Xe Core1 Thread Dispatcher Port 1",
                          "The percentage of time in which thread header is ready on slice4 Xe core1 thread dispatcher port 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "ThreadHeader41ReadyPort2", "Thread Header Ready on Slice4 Xe Core1 Thread Dispatcher Port 2",
                          "The percentage of time in which thread header is ready on slice4 Xe core1 thread dispatcher port 2",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "ThreadHeader41ReadyPort3", "Thread Header Ready on Slice4 Xe Core1 Thread Dispatcher Port 3",
                          "The percentage of time in which thread header is ready on slice4 Xe core1 thread dispatcher port 3",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "ThreadHeader42Ready", "Thread Header Ready on Slice4 Xe Core2 Thread Dispatcher",
                          "The percentage of time in which thread header is ready on slice4 Xe core2 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "ThreadHeader42ReadyPort0", "Thread Header Ready on Slice4 Xe Core2 Thread Dispatcher Port 0",
                          "The percentage of time in which thread header is ready on slice4 Xe core2 thread dispatcher port 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "ThreadHeader42ReadyPort1", "Thread Header Ready on Slice4 Xe Core2 Thread Dispatcher Port 1",
                          "The percentage of time in which thread header is ready on slice4 Xe core2 thread dispatcher port 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "ThreadHeader42ReadyPort2", "Thread Header Ready on Slice4 Xe Core2 Thread Dispatcher Port 2",
                          "The percentage of time in which thread header is ready on slice4 Xe core2 thread dispatcher port 2",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "ThreadHeader42ReadyPort3", "Thread Header Ready on Slice4 Xe Core2 Thread Dispatcher Port 3",
                          "The percentage of time in which thread header is ready on slice4 Xe core2 thread dispatcher port 3",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "ThreadHeader43Ready", "Thread Header Ready on Slice4 Xe Core3 Thread Dispatcher",
                          "The percentage of time in which thread header is ready on slice4 Xe core3 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a81001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14810cf4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16810c72, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02875500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a10cf4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a10c72, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10cf4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec10c72, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae10d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00078000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00007800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000780, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000078, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fff0, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CTDL_Slice45_4MetricSet::CTDL_Slice45_4MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CTDL_Slice45_4MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "ThreadHeader50Ready", "Thread Header Ready on Slice5 Xe Core0 Thread Dispatcher",
                          "The percentage of time in which thread header is ready on slice5 Xe core0 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "ThreadHeader50ReadyPort0", "Thread Header Ready on Slice5 Xe Core0 Thread Dispatcher Port 0",
                          "The percentage of time in which thread header is ready on slice5 Xe core0 thread dispatcher port 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "ThreadHeader50ReadyPort1", "Thread Header Ready on Slice5 Xe Core0 Thread Dispatcher Port 1",
                          "The percentage of time in which thread header is ready on slice5 Xe core0 thread dispatcher port 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "ThreadHeader50ReadyPort2", "Thread Header Ready on Slice5 Xe Core0 Thread Dispatcher Port 2",
                          "The percentage of time in which thread header is ready on slice5 Xe core0 thread dispatcher port 2",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "ThreadHeader50ReadyPort3", "Thread Header Ready on Slice5 Xe Core0 Thread Dispatcher Port 3",
                          "The percentage of time in which thread header is ready on slice5 Xe core0 thread dispatcher port 3",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "ThreadHeader51Ready", "Thread Header Ready on Slice5 Xe Core1 Thread Dispatcher",
                          "The percentage of time in which thread header is ready on slice5 Xe core1 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "ThreadHeader51ReadyPort0", "Thread Header Ready on Slice5 Xe Core1 Thread Dispatcher Port 0",
                          "The percentage of time in which thread header is ready on slice5 Xe core1 thread dispatcher port 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "ThreadHeader51ReadyPort1", "Thread Header Ready on Slice5 Xe Core1 Thread Dispatcher Port 1",
                          "The percentage of time in which thread header is ready on slice5 Xe core1 thread dispatcher port 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "ThreadHeader51ReadyPort2", "Thread Header Ready on Slice5 Xe Core1 Thread Dispatcher Port 2",
                          "The percentage of time in which thread header is ready on slice5 Xe core1 thread dispatcher port 2",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "ThreadHeader51ReadyPort3", "Thread Header Ready on Slice5 Xe Core1 Thread Dispatcher Port 3",
                          "The percentage of time in which thread header is ready on slice5 Xe core1 thread dispatcher port 3",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "ThreadHeader52Ready", "Thread Header Ready on Slice5 Xe Core2 Thread Dispatcher",
                          "The percentage of time in which thread header is ready on slice5 Xe core2 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "ThreadHeader52ReadyPort0", "Thread Header Ready on Slice5 Xe Core2 Thread Dispatcher Port 0",
                          "The percentage of time in which thread header is ready on slice5 Xe core2 thread dispatcher port 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "ThreadHeader52ReadyPort1", "Thread Header Ready on Slice5 Xe Core2 Thread Dispatcher Port 1",
                          "The percentage of time in which thread header is ready on slice5 Xe core2 thread dispatcher port 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "ThreadHeader52ReadyPort2", "Thread Header Ready on Slice5 Xe Core2 Thread Dispatcher Port 2",
                          "The percentage of time in which thread header is ready on slice5 Xe core2 thread dispatcher port 2",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "ThreadHeader52ReadyPort3", "Thread Header Ready on Slice5 Xe Core2 Thread Dispatcher Port 3",
                          "The percentage of time in which thread header is ready on slice5 Xe core2 thread dispatcher port 3",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "ThreadHeader53Ready", "Thread Header Ready on Slice5 Xe Core3 Thread Dispatcher",
                          "The percentage of time in which thread header is ready on slice5 Xe core3 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b81001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15810cf4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17810c72, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03875500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a10cf4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10c72, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc10cf4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10c72, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be10d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00078000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00007800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000780, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000078, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fff0, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CTDL_Slice67_1MetricSet::CTDL_Slice67_1MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CTDL_Slice67_1MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "NonPSThread60ReadyForDispatch", "Non-PS Thread Ready For Dispatch on Slice6 Xe Core0 Thread Dispatcher",
                          "The percentage of time in which non-PS thread is ready for dispatch on slice6 Xe core0 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "NonPSThread61ReadyForDispatch", "Non-PS Thread Ready For Dispatch on Slice6 Xe Core1 Thread Dispatcher",
                          "The percentage of time in which non-PS thread is ready for dispatch on slice6 Xe core1 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "NonPSThread62ReadyForDispatch", "Non-PS Thread Ready For Dispatch on Slice6 Xe Core2 Thread Dispatcher",
                          "The percentage of time in which non-PS thread is ready for dispatch on slice6 Xe core2 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "NonPSThread63ReadyForDispatch", "Non-PS Thread Ready For Dispatch on Slice6 Xe Core3 Thread Dispatcher",
                          "The percentage of time in which non-PS thread is ready for dispatch on slice6 Xe core3 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "NonPSThread70ReadyForDispatch", "Non-PS Thread Ready For Dispatch on Slice7 Xe Core0 Thread Dispatcher",
                          "The percentage of time in which non-PS thread is ready for dispatch on slice7 Xe core0 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "NonPSThread71ReadyForDispatch", "Non-PS Thread Ready For Dispatch on Slice7 Xe Core1 Thread Dispatcher",
                          "The percentage of time in which non-PS thread is ready for dispatch on slice7 Xe core1 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "NonPSThread72ReadyForDispatch", "Non-PS Thread Ready For Dispatch on Slice7 Xe Core2 Thread Dispatcher",
                          "The percentage of time in which non-PS thread is ready for dispatch on slice7 Xe core2 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "NonPSThread73ReadyForDispatch", "Non-PS Thread Ready For Dispatch on Slice7 Xe Core3 Thread Dispatcher",
                          "The percentage of time in which non-PS thread is ready for dispatch on slice7 Xe core3 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "ThreadHeader63ReadyPort0", "Thread Header Ready on Slice6 Xe Core3 Thread Dispatcher Port 0",
                          "The percentage of time in which thread header is ready on slice6 Xe core3 thread dispatcher port 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "ThreadHeader63ReadyPort1", "Thread Header Ready on Slice6 Xe Core3 Thread Dispatcher Port 1",
                          "The percentage of time in which thread header is ready on slice6 Xe core3 thread dispatcher port 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "ThreadHeader63ReadyPort2", "Thread Header Ready on Slice6 Xe Core3 Thread Dispatcher Port 2",
                          "The percentage of time in which thread header is ready on slice6 Xe core3 thread dispatcher port 2",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "ThreadHeader63ReadyPort3", "Thread Header Ready on Slice6 Xe Core3 Thread Dispatcher Port 3",
                          "The percentage of time in which thread header is ready on slice6 Xe core3 thread dispatcher port 3",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "ThreadHeader73ReadyPort0", "Thread Header Ready on Slice7 Xe Core3 Thread Dispatcher Port 0",
                          "The percentage of time in which thread header is ready on slice7 Xe core3 thread dispatcher port 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "ThreadHeader73ReadyPort1", "Thread Header Ready on Slice7 Xe Core3 Thread Dispatcher Port 1",
                          "The percentage of time in which thread header is ready on slice7 Xe core3 thread dispatcher port 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "ThreadHeader73ReadyPort2", "Thread Header Ready on Slice7 Xe Core3 Thread Dispatcher Port 2",
                          "The percentage of time in which thread header is ready on slice7 Xe core3 thread dispatcher port 2",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "ThreadHeader73ReadyPort3", "Thread Header Ready on Slice7 Xe Core3 Thread Dispatcher Port 3",
                          "The percentage of time in which thread header is ready on slice7 Xe core3 thread dispatcher port 3",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a81001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b81001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac10030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e10cf4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e10c72, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4f008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10cf4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e10c72, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e38000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40f80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e64000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e74000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff0e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009f00c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a55a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010ff2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01076000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030047, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031ce7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CTDL_Slice67_2MetricSet::CTDL_Slice67_2MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CTDL_Slice67_2MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "PSThread60ReadyForDispatch", "PS Thread Ready For Dispatch on Slice6 Xe Core0 Thread Dispatcher",
                          "The percentage of time in which PS thread is ready for dispatch on slice6 Xe core0 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "PSThread61ReadyForDispatch", "PS Thread Ready For Dispatch on Slice6 Xe Core1 Thread Dispatcher",
                          "The percentage of time in which PS thread is ready for dispatch on slice6 Xe core1 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "PSThread62ReadyForDispatch", "PS Thread Ready For Dispatch on Slice6 Xe Core2 Thread Dispatcher",
                          "The percentage of time in which PS thread is ready for dispatch on slice6 Xe core2 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "PSThread63ReadyForDispatch", "PS Thread Ready For Dispatch on Slice6 Xe Core3 Thread Dispatcher",
                          "The percentage of time in which PS thread is ready for dispatch on slice6 Xe core3 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "PSThread70ReadyForDispatch", "PS Thread Ready For Dispatch on Slice7 Xe Core0 Thread Dispatcher",
                          "The percentage of time in which PS thread is ready for dispatch on slice7 Xe core0 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "PSThread71ReadyForDispatch", "PS Thread Ready For Dispatch on Slice7 Xe Core1 Thread Dispatcher",
                          "The percentage of time in which PS thread is ready for dispatch on slice7 Xe core1 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "PSThread72ReadyForDispatch", "PS Thread Ready For Dispatch on Slice7 Xe Core2 Thread Dispatcher",
                          "The percentage of time in which PS thread is ready for dispatch on slice7 Xe core2 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "PSThread73ReadyForDispatch", "PS Thread Ready For Dispatch on Slice7 Xe Core3 Thread Dispatcher",
                          "The percentage of time in which PS thread is ready for dispatch on slice7 Xe core3 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "PS|FS", nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28810340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28a10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28c10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28e10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29810340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29a10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29c10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29e10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e400c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11810c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c43000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff0c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01023000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030ee8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030277, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CTDL_Slice67_3MetricSet::CTDL_Slice67_3MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CTDL_Slice67_3MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "ThreadHeader60Ready", "Thread Header Ready on Slice6 Xe Core0 Thread Dispatcher",
                          "The percentage of time in which thread header is ready on slice6 Xe core0 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "ThreadHeader60ReadyPort0", "Thread Header Ready on Slice6 Xe Core0 Thread Dispatcher Port 0",
                          "The percentage of time in which thread header is ready on slice6 Xe core0 thread dispatcher port 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "ThreadHeader60ReadyPort1", "Thread Header Ready on Slice6 Xe Core0 Thread Dispatcher Port 1",
                          "The percentage of time in which thread header is ready on slice6 Xe core0 thread dispatcher port 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "ThreadHeader60ReadyPort2", "Thread Header Ready on Slice6 Xe Core0 Thread Dispatcher Port 2",
                          "The percentage of time in which thread header is ready on slice6 Xe core0 thread dispatcher port 2",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "ThreadHeader60ReadyPort3", "Thread Header Ready on Slice6 Xe Core0 Thread Dispatcher Port 3",
                          "The percentage of time in which thread header is ready on slice6 Xe core0 thread dispatcher port 3",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "ThreadHeader61Ready", "Thread Header Ready on Slice6 Xe Core1 Thread Dispatcher",
                          "The percentage of time in which thread header is ready on slice6 Xe core1 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "ThreadHeader61ReadyPort0", "Thread Header Ready on Slice6 Xe Core1 Thread Dispatcher Port 0",
                          "The percentage of time in which thread header is ready on slice6 Xe core1 thread dispatcher port 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "ThreadHeader61ReadyPort1", "Thread Header Ready on Slice6 Xe Core1 Thread Dispatcher Port 1",
                          "The percentage of time in which thread header is ready on slice6 Xe core1 thread dispatcher port 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "ThreadHeader61ReadyPort2", "Thread Header Ready on Slice6 Xe Core1 Thread Dispatcher Port 2",
                          "The percentage of time in which thread header is ready on slice6 Xe core1 thread dispatcher port 2",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "ThreadHeader61ReadyPort3", "Thread Header Ready on Slice6 Xe Core1 Thread Dispatcher Port 3",
                          "The percentage of time in which thread header is ready on slice6 Xe core1 thread dispatcher port 3",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "ThreadHeader62Ready", "Thread Header Ready on Slice6 Xe Core2 Thread Dispatcher",
                          "The percentage of time in which thread header is ready on slice6 Xe core2 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "ThreadHeader62ReadyPort0", "Thread Header Ready on Slice6 Xe Core2 Thread Dispatcher Port 0",
                          "The percentage of time in which thread header is ready on slice6 Xe core2 thread dispatcher port 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "ThreadHeader62ReadyPort1", "Thread Header Ready on Slice6 Xe Core2 Thread Dispatcher Port 1",
                          "The percentage of time in which thread header is ready on slice6 Xe core2 thread dispatcher port 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "ThreadHeader62ReadyPort2", "Thread Header Ready on Slice6 Xe Core2 Thread Dispatcher Port 2",
                          "The percentage of time in which thread header is ready on slice6 Xe core2 thread dispatcher port 2",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "ThreadHeader62ReadyPort3", "Thread Header Ready on Slice6 Xe Core2 Thread Dispatcher Port 3",
                          "The percentage of time in which thread header is ready on slice6 Xe core2 thread dispatcher port 3",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "ThreadHeader63Ready", "Thread Header Ready on Slice6 Xe Core3 Thread Dispatcher",
                          "The percentage of time in which thread header is ready on slice6 Xe core3 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a81001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14810cf4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16810c72, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02875500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a10cf4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a10c72, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10cf4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec10c72, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae10d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00078000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00007800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000780, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000078, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fff0, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CTDL_Slice67_4MetricSet::CTDL_Slice67_4MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CTDL_Slice67_4MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuBusy", "GPU Busy",
                          "The percentage of time in which the GPU has been processing GPU commands.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x10" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "ThreadHeader70Ready", "Thread Header Ready on Slice7 Xe Core0 Thread Dispatcher",
                          "The percentage of time in which thread header is ready on slice7 Xe core0 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "ThreadHeader70ReadyPort0", "Thread Header Ready on Slice7 Xe Core0 Thread Dispatcher Port 0",
                          "The percentage of time in which thread header is ready on slice7 Xe core0 thread dispatcher port 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "ThreadHeader70ReadyPort1", "Thread Header Ready on Slice7 Xe Core0 Thread Dispatcher Port 1",
                          "The percentage of time in which thread header is ready on slice7 Xe core0 thread dispatcher port 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "ThreadHeader70ReadyPort2", "Thread Header Ready on Slice7 Xe Core0 Thread Dispatcher Port 2",
                          "The percentage of time in which thread header is ready on slice7 Xe core0 thread dispatcher port 2",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "ThreadHeader70ReadyPort3", "Thread Header Ready on Slice7 Xe Core0 Thread Dispatcher Port 3",
                          "The percentage of time in which thread header is ready on slice7 Xe core0 thread dispatcher port 3",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "ThreadHeader71Ready", "Thread Header Ready on Slice7 Xe Core1 Thread Dispatcher",
                          "The percentage of time in which thread header is ready on slice7 Xe core1 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "ThreadHeader71ReadyPort0", "Thread Header Ready on Slice7 Xe Core1 Thread Dispatcher Port 0",
                          "The percentage of time in which thread header is ready on slice7 Xe core1 thread dispatcher port 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "ThreadHeader71ReadyPort1", "Thread Header Ready on Slice7 Xe Core1 Thread Dispatcher Port 1",
                          "The percentage of time in which thread header is ready on slice7 Xe core1 thread dispatcher port 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "ThreadHeader71ReadyPort2", "Thread Header Ready on Slice7 Xe Core1 Thread Dispatcher Port 2",
                          "The percentage of time in which thread header is ready on slice7 Xe core1 thread dispatcher port 2",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "ThreadHeader71ReadyPort3", "Thread Header Ready on Slice7 Xe Core1 Thread Dispatcher Port 3",
                          "The percentage of time in which thread header is ready on slice7 Xe core1 thread dispatcher port 3",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "ThreadHeader72Ready", "Thread Header Ready on Slice7 Xe Core2 Thread Dispatcher",
                          "The percentage of time in which thread header is ready on slice7 Xe core2 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "ThreadHeader72ReadyPort0", "Thread Header Ready on Slice7 Xe Core2 Thread Dispatcher Port 0",
                          "The percentage of time in which thread header is ready on slice7 Xe core2 thread dispatcher port 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "ThreadHeader72ReadyPort1", "Thread Header Ready on Slice7 Xe Core2 Thread Dispatcher Port 1",
                          "The percentage of time in which thread header is ready on slice7 Xe core2 thread dispatcher port 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "ThreadHeader72ReadyPort2", "Thread Header Ready on Slice7 Xe Core2 Thread Dispatcher Port 2",
                          "The percentage of time in which thread header is ready on slice7 Xe core2 thread dispatcher port 2",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "ThreadHeader72ReadyPort3", "Thread Header Ready on Slice7 Xe Core2 Thread Dispatcher Port 3",
                          "The percentage of time in which thread header is ready on slice7 Xe core2 thread dispatcher port 3",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "ThreadHeader73Ready", "Thread Header Ready on Slice7 Xe Core3 Thread Dispatcher",
                          "The percentage of time in which thread header is ready on slice7 Xe core3 thread dispatcher",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_MEDIA | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b81001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be1001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15810cf4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17810c72, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03875500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a10cf4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10c72, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc10cf4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10c72, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be10d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00078000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00007800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000780, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000078, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fff0, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CComputeOverviewMetricSet::CComputeOverviewMetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CComputeOverviewMetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L3_BYTE_READ", "L3 BYTE READ",
                          "Number of bytes read from L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD dw@0xcc UADD dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD qw@0x158 UADD qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "256 $SliceTotalCount UMUL $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L3_BYTE_WRITE", "L3 BYTE WRITE",
                          "Number of bytes written to L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD dw@0xec UADD dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD qw@0x198 UADD qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "256 $SliceTotalCount UMUL $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ", "GPU MEMORY BYTE READ",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) read bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xa0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x130" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "64 $SliceTotalCount UMUL $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE", "GPU MEMORY BYTE WRITE",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) write bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xb8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x138" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "64 $SliceTotalCount UMUL $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_ACTIVE", "XVE ACTIVE",
                          "Percentage of time in which at least one pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x2c:0xa7" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x48" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL", "XVE STALL",
                          "Percentage of time in which any threads are loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x30:0xa8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x50" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_BUSY", "XVE BUSY",
                          "Any XVE thread loaded.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x34:0xa9" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x58" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 0 UGT" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "1" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_THREADS_OCCUPANCY_ALL", "XVE THREADS OCCUPANCY ALL",
                          "Percentage of thread slots occupied",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "DS|TES", nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "8 rd40@0x34:0xa9 FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "8 qw@0x58 FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_COMPUTE_THREAD_COUNT", "XVE COMPUTE THREAD COUNT",
                          "Number of compute shader hardware threads dispatched",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x20:0xa4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x30" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_ATOMIC_ACCESS_COUNT", "XVE ATOMIC ACCESS COUNT",
                          "Number of shader atomic memory accesses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "messages", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x98" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x120" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_BARRIER_MESSAGE_COUNT", "XVE BARRIER MESSAGE COUNT",
                          "Number of shader barrier messages",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "messages", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x9c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x128" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_ALL", "XVE INST EXECUTED ALU0 ALL",
                          "Number of execution slots taken by instructions executed on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x38:0xaa" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x60" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_ALL", "XVE INST EXECUTED ALU1 ALL",
                          "Number of execution slots taken by instructions executed on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x3c:0xab" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x68" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_ALL", "XVE INST EXECUTED XMX ALL",
                          "Number of execution slots taken by instructions executed in XMX pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x40:0xac" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x70" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_ALL", "XVE INST EXECUTED SEND ALL",
                          "Number of instructions executed on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x44:0xad" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x78" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_CONTROL_ALL", "XVE INST EXECUTED CONTROL ALL",
                          "Number of instructions executed on Jump Pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x48:0xae" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x80" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_PIPE_ALU0_AND_ALU1_ACTIVE", "XVE PIPE ALU0 AND ALU1 ACTIVE",
                          "Percentage of time in which ALU0 and ALU1 pipes are both actively executing a Gen ISA instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x4c:0xaf" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x88" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_PIPE_ALU0_AND_XMX_ACTIVE", "XVE PIPE ALU0 AND XMX ACTIVE",
                          "Percentage of time in which ALU0 and XMX pipes are both actively executing a Gen ISA instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 20 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x50:0xb0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x90" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_ALL_UTILIZATION", "XVE INST EXECUTED ALU0 ALL UTILIZATION",
                          "Percentage of execution slots taken by instructions executed on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 21 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x38:0xaa" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x60" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_ALL_UTILIZATION", "XVE INST EXECUTED ALU1 ALL UTILIZATION",
                          "Percentage of execution slots taken by instructions executed on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 22 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x3c:0xab" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x68" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_ALL_UTILIZATION", "XVE INST EXECUTED SEND ALL UTILIZATION",
                          "Percentage of time taken by instructions executed on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 23 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x44:0xad" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x78" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_CONTROL_ALL_UTILIZATION", "XVE INST EXECUTED CONTROL ALL UTILIZATION",
                          "Percentage of time taken by instructions executed on Jump Pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 24 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x48:0xae" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x80" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_ALL_UTILIZATION", "XVE INST EXECUTED XMX ALL UTILIZATION",
                          "Percentage of execution slots taken by instructions executed in XMX pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 25 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x40:0xac" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x70" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x280a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x290a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x280a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x290a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x280a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x290a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x280a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x290a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b1005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b6005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b4b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b6b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c1140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c6140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b4c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b6c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20081c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0804e1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c0340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c0340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c0340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20101000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a101c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100804, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22102801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24100e04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20101000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a101c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100804, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22102801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24100e04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20081c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0804e1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20081c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0804e1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20081c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0804e1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0228, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0228, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0087, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0087, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0228, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0228, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0087, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0087, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0228, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0228, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0087, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0087, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0228, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0228, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0087, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0087, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26080001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b1005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b6005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b4b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b6b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c1140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c6140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b4c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b6c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20081c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0804e1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c0340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c0340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c0340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20101000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a101c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100804, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22102801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24100e04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20101000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a101c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100804, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22102801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24100e04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20081c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0804e1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20081c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0804e1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20081c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0804e1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0228, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0228, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0087, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0087, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0228, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0228, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0087, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0087, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0228, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0228, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0087, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0087, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0228, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0228, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0087, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0087, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26080001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b1005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b6005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b4b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b6b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c1140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c6140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b4c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b6c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20081c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0804e1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c0340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c0340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c0340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20101000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a101c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100804, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22102801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24100e04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20101000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a101c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100804, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22102801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24100e04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20081c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0804e1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20081c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0804e1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20081c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0804e1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0228, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0228, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0087, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0087, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0228, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0228, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0087, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0087, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0228, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0228, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0087, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0087, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0228, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0228, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0087, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0087, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26080001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b1005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b6005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b4b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b6b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c1140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c6140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b4c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b6c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20081c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0804e1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c0340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c0340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c0340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a0a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20101000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a101c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100804, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22102801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24100e04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20101000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a101c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100804, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22102801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24100e04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20081c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0804e1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20081c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0804e1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20081c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0804e1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0228, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0228, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0087, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0087, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0228, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0228, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0087, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0087, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0228, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0228, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0087, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0087, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0228, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0228, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0087, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0087, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26080001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x0000ffff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xe458, 0x00005004, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe558, 0x00000008, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe658, 0x00009001, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe758, 0x02001002, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe45c, 0x0000a003, REGISTER_TYPE_FLEX );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1ProfileReadsMetricSet_XeCore0::CL1ProfileReadsMetricSet_XeCore0( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1ProfileReadsMetricSet_XeCore0::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_READ", "LOAD STORE CACHE BYTE READ",
                          "Number of bytes read out of the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "4 $XeCoreTotalCount UMUL dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD UMUL $GtSlice0XeCore0 $GtSlice1XeCore0 UADD $GtSlice2XeCore0 UADD $GtSlice3XeCore0 UADD $GtSlice4XeCore0 UADD $GtSlice5XeCore0 UADD $GtSlice6XeCore0 UADD $GtSlice7XeCore0 UADD UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "4 $XeCoreTotalCount UMUL qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD UMUL $GtSlice0XeCore0 $GtSlice1XeCore0 UADD $GtSlice2XeCore0 UADD $GtSlice3XeCore0 UADD $GtSlice4XeCore0 UADD $GtSlice5XeCore0 UADD $GtSlice6XeCore0 UADD $GtSlice7XeCore0 UADD UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "256  $XeCoreTotalCount UMUL $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SLM_BYTE_READ", "SLM BYTE READ",
                          "Number of bytes read from SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "4 $XeCoreTotalCount UMUL dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD UMUL $GtSlice0XeCore0 $GtSlice1XeCore0 UADD $GtSlice2XeCore0 UADD $GtSlice3XeCore0 UADD $GtSlice4XeCore0 UADD $GtSlice5XeCore0 UADD $GtSlice6XeCore0 UADD $GtSlice7XeCore0 UADD UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "4 $XeCoreTotalCount UMUL qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD UMUL $GtSlice0XeCore0 $GtSlice1XeCore0 UADD $GtSlice2XeCore0 UADD $GtSlice3XeCore0 UADD $GtSlice4XeCore0 UADD $GtSlice5XeCore0 UADD $GtSlice6XeCore0 UADD $GtSlice7XeCore0 UADD UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "256  $XeCoreTotalCount UMUL $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ", "GPU MEMORY BYTE READ",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) read bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xa0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x130" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "64 $SliceTotalCount UMUL $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE", "GPU MEMORY BYTE WRITE",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) write bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xb8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x138" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "64 $SliceTotalCount UMUL $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_ACTIVE", "XVE ACTIVE",
                          "Percentage of time in which at least one pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x2c:0xa7" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x48" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL", "XVE STALL",
                          "Percentage of time in which any threads are loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x30:0xa8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x50" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_THREADS_OCCUPANCY_ALL", "XVE THREADS OCCUPANCY ALL",
                          "Percentage of thread slots occupied",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "DS|TES", nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "8 rd40@0x34:0xa9 FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "8 qw@0x58 FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_BUSY", "XVE BUSY",
                          "Any XVE thread loaded.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x34:0xa9" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x58" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 0 UGT" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "1" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16870253, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18891060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e870140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x108700c4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12870042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x148703c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890387, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a8902ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c89034c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x280a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17870253, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19891060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f870140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x118700c4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13870042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x158703c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890387, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09890248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b8902ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d89034c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x290a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16870253, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18891060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e870140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x108700c4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12870042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x148703c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890387, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a8902ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c89034c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x280a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17870253, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19891060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f870140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x118700c4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13870042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x158703c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890387, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09890248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b8902ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d89034c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x290a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16870253, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18891060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e870140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x108700c4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12870042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x148703c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890387, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a8902ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c89034c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x280a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17870253, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19891060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f870140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x118700c4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13870042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x158703c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890387, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09890248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b8902ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d89034c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x290a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16870253, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18891060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e870140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x108700c4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12870042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x148703c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890387, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a8902ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c89034c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x280a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17870253, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19891060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f870140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x118700c4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13870042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x158703c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890387, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09890248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b8902ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d89034c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x290a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x007f0000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x0000fe7f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc00, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc04, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc08, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc0c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc10, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc14, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc18, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc1c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc20, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc24, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc28, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc2c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc30, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc34, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xe458, 0x00005004, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe558, 0x00000008, REGISTER_TYPE_FLEX );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1ProfileReadsMetricSet_XeCore3::CL1ProfileReadsMetricSet_XeCore3( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1ProfileReadsMetricSet_XeCore3::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_READ", "LOAD STORE CACHE BYTE READ",
                          "Number of bytes read out of the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "4 $XeCoreTotalCount UMUL dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD UMUL $GtSlice0XeCore3 $GtSlice1XeCore3 UADD $GtSlice2XeCore3 UADD $GtSlice3XeCore3 UADD $GtSlice4XeCore3 UADD $GtSlice5XeCore3 UADD $GtSlice6XeCore3 UADD $GtSlice7XeCore3 UADD UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "4 $XeCoreTotalCount UMUL qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD UMUL $GtSlice0XeCore3 $GtSlice1XeCore3 UADD $GtSlice2XeCore3 UADD $GtSlice3XeCore3 UADD $GtSlice4XeCore3 UADD $GtSlice5XeCore3 UADD $GtSlice6XeCore3 UADD $GtSlice7XeCore3 UADD UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "256  $XeCoreTotalCount UMUL $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SLM_BYTE_READ", "SLM BYTE READ",
                          "Number of bytes read from SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "4 $XeCoreTotalCount UMUL dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD UMUL $GtSlice0XeCore3 $GtSlice1XeCore3 UADD $GtSlice2XeCore3 UADD $GtSlice3XeCore3 UADD $GtSlice4XeCore3 UADD $GtSlice5XeCore3 UADD $GtSlice6XeCore3 UADD $GtSlice7XeCore3 UADD UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "4 $XeCoreTotalCount UMUL qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD UMUL $GtSlice0XeCore3 $GtSlice1XeCore3 UADD $GtSlice2XeCore3 UADD $GtSlice3XeCore3 UADD $GtSlice4XeCore3 UADD $GtSlice5XeCore3 UADD $GtSlice6XeCore3 UADD $GtSlice7XeCore3 UADD UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "256  $XeCoreTotalCount UMUL $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ", "GPU MEMORY BYTE READ",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) read bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xa0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x130" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "64 $SliceTotalCount UMUL $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE", "GPU MEMORY BYTE WRITE",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) write bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xb8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x138" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "64 $SliceTotalCount UMUL $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_ACTIVE", "XVE ACTIVE",
                          "Percentage of time in which at least one pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x2c:0xa7" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x48" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL", "XVE STALL",
                          "Percentage of time in which any threads are loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x30:0xa8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x50" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_THREADS_OCCUPANCY_ALL", "XVE THREADS OCCUPANCY ALL",
                          "Percentage of thread slots occupied",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "DS|TES", nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "8 rd40@0x34:0xa9 FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "8 qw@0x58 FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_BUSY", "XVE BUSY",
                          "Any XVE thread loaded.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x34:0xa9" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x58" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 0 UGT" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "1" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e70253, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e91060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee70140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e700c4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e70042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e703c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90387, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e90248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae902ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce9034c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x280a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e70253, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e91060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe70140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e700c4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e70042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e703c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90387, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e90248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be902ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de9034c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x290a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e70253, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e91060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee70140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e700c4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e70042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e703c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90387, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e90248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae902ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce9034c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x280a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e70253, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e91060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe70140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e700c4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e70042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e703c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90387, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e90248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be902ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de9034c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x290a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e70253, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e91060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee70140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e700c4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e70042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e703c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90387, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e90248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae902ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce9034c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x280a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e70253, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e91060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe70140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e700c4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e70042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e703c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90387, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e90248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be902ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de9034c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x290a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e70253, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e91060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee70140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e700c4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e70042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e703c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90387, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e90248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae902ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce9034c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x280a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e70253, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e91060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe70140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e700c4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e70042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e703c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90387, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e90248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be902ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de9034c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x290a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x007f0000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x0000fe7f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc00, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc04, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc08, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc0c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc10, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc14, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc18, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc1c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc20, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc24, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc28, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc2c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc30, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc34, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xe458, 0x00005004, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe558, 0x00000008, REGISTER_TYPE_FLEX );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1ProfileSlmBankConflictsMetricSet_XeCore0::CL1ProfileSlmBankConflictsMetricSet_XeCore0( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1ProfileSlmBankConflictsMetricSet_XeCore0::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT", "SLM BANK CONFLICT COUNT",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD dw@0xec 2 dw@0xe8 UMUL UADD 4 dw@0xe4 UMUL UADD 8 dw@0xe0 UMUL UADD UADD dw@0xdc 2 dw@0xd8 UMUL UADD 4 dw@0xd4 UMUL UADD 8 dw@0xd0 UMUL UADD UADD dw@0xcc 2 dw@0xc8 UMUL UADD 4 dw@0xc4 UMUL UADD 8 dw@0xc0 UMUL UADD UADD $XeCoreTotalCount UMUL $GtSlice0XeCore0 $GtSlice1XeCore0 UADD $GtSlice2XeCore0 UADD $GtSlice3XeCore0 UADD $GtSlice4XeCore0 UADD $GtSlice5XeCore0 UADD $GtSlice6XeCore0 UADD $GtSlice7XeCore0 UADD UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD qw@0x198 2 qw@0x190 UMUL UADD 4 qw@0x188 UMUL UADD 8 qw@0x180 UMUL UADD UADD qw@0x178 2 qw@0x170 UMUL UADD 4 qw@0x168 UMUL UADD 8 qw@0x160 UMUL UADD UADD qw@0x158 2 qw@0x150 UMUL UADD 4 qw@0x148 UMUL UADD 8 qw@0x140 UMUL UADD UADD $XeCoreTotalCount UMUL $GtSlice0XeCore0 $GtSlice1XeCore0 UADD $GtSlice2XeCore0 UADD $GtSlice3XeCore0 UADD $GtSlice4XeCore0 UADD $GtSlice5XeCore0 UADD $GtSlice6XeCore0 UADD $GtSlice7XeCore0 UADD UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ", "GPU MEMORY BYTE READ",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) read bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xa0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x130" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "64 $SliceTotalCount UMUL $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE", "GPU MEMORY BYTE WRITE",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) write bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xb8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x138" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "64 $SliceTotalCount UMUL $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_ACTIVE", "XVE ACTIVE",
                          "Percentage of time in which at least one pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x2c:0xa7" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x48" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL", "XVE STALL",
                          "Percentage of time in which any threads are loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x30:0xa8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x50" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_THREADS_OCCUPANCY_ALL", "XVE THREADS OCCUPANCY ALL",
                          "Percentage of thread slots occupied",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "DS|TES", nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "8 rd40@0x34:0xa9 FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "8 qw@0x58 FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_BUSY", "XVE BUSY",
                          "Any XVE thread loaded.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x34:0xa9" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x58" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 0 UGT" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "1" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x188914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e8900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22891800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x288914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02893254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e890411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1089079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1489038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x280a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x198914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f8900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23891800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x298914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0387aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03893254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09890fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f890411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1189079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1589038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x290a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x188914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e8900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22891800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x288914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02893254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e890411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1089079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1489038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x280a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x198914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f8900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23891800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x298914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0387aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03893254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09890fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f890411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1189079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1589038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x290a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x188914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e8900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22891800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x288914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02893254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e890411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1089079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1489038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x280a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x198914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f8900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23891800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x298914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0387aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03893254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09890fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f890411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1189079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1589038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x290a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x188914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e8900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22891800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x288914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02893254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e890411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1089079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1489038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x280a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x198914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f8900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23891800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x298914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0387aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03893254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09890fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f890411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1189079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1589038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x290a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x0000ffff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xe458, 0x00005004, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe558, 0x00000008, REGISTER_TYPE_FLEX );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1ProfileSlmBankConflictsMetricSet_XeCore3::CL1ProfileSlmBankConflictsMetricSet_XeCore3( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1ProfileSlmBankConflictsMetricSet_XeCore3::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT", "SLM BANK CONFLICT COUNT",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD dw@0xec 2 dw@0xe8 UMUL UADD 4 dw@0xe4 UMUL UADD 8 dw@0xe0 UMUL UADD UADD dw@0xdc 2 dw@0xd8 UMUL UADD 4 dw@0xd4 UMUL UADD 8 dw@0xd0 UMUL UADD UADD dw@0xcc 2 dw@0xc8 UMUL UADD 4 dw@0xc4 UMUL UADD 8 dw@0xc0 UMUL UADD UADD $XeCoreTotalCount UMUL $GtSlice0XeCore3 $GtSlice1XeCore3 UADD $GtSlice2XeCore3 UADD $GtSlice3XeCore3 UADD $GtSlice4XeCore3 UADD $GtSlice5XeCore3 UADD $GtSlice6XeCore3 UADD $GtSlice7XeCore3 UADD UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD qw@0x198 2 qw@0x190 UMUL UADD 4 qw@0x188 UMUL UADD 8 qw@0x180 UMUL UADD UADD qw@0x178 2 qw@0x170 UMUL UADD 4 qw@0x168 UMUL UADD 8 qw@0x160 UMUL UADD UADD qw@0x158 2 qw@0x150 UMUL UADD 4 qw@0x148 UMUL UADD 8 qw@0x140 UMUL UADD UADD $XeCoreTotalCount UMUL $GtSlice0XeCore3 $GtSlice1XeCore3 UADD $GtSlice2XeCore3 UADD $GtSlice3XeCore3 UADD $GtSlice4XeCore3 UADD $GtSlice5XeCore3 UADD $GtSlice6XeCore3 UADD $GtSlice7XeCore3 UADD UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ", "GPU MEMORY BYTE READ",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) read bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xa0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x130" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "64 $SliceTotalCount UMUL $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE", "GPU MEMORY BYTE WRITE",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) write bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xb8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x138" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "64 $SliceTotalCount UMUL $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_ACTIVE", "XVE ACTIVE",
                          "Percentage of time in which at least one pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x2c:0xa7" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x48" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL", "XVE STALL",
                          "Percentage of time in which any threads are loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x30:0xa8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x50" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_THREADS_OCCUPANCY_ALL", "XVE THREADS OCCUPANCY ALL",
                          "Percentage of thread slots occupied",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "DS|TES", nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "8 rd40@0x34:0xa9 FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "8 qw@0x58 FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_BUSY", "XVE BUSY",
                          "Any XVE thread loaded.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x34:0xa9" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x58" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 0 UGT" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "1" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22e91800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28e914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e90fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae90821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce90baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e9079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e9038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x280a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23e91800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29e914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e90fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be90821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de90baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe90411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e9079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e9038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x290a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22e91800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28e914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e90fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae90821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce90baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e9079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e9038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x280a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23e91800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29e914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e90fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be90821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de90baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe90411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e9079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e9038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x290a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22e91800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28e914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e90fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae90821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce90baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e9079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e9038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x280a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23e91800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29e914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e90fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be90821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de90baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe90411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e9079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e9038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x290a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22e91800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28e914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e90fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae90821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce90baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e9079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e9038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x280a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23e91800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29e914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e90fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be90821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de90baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe90411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e9079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e9038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x290a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x0000ffff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xe458, 0x00005004, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe558, 0x00000008, REGISTER_TYPE_FLEX );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1ProfileWritesMetricSet_XeCore0::CL1ProfileWritesMetricSet_XeCore0( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1ProfileWritesMetricSet_XeCore0::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_WRITE", "LOAD STORE CACHE BYTE WRITE",
                          "Number of bytes written to the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "4 $XeCoreTotalCount UMUL dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD UMUL $GtSlice0XeCore0 $GtSlice1XeCore0 UADD $GtSlice2XeCore0 UADD $GtSlice3XeCore0 UADD $GtSlice4XeCore0 UADD $GtSlice5XeCore0 UADD $GtSlice6XeCore0 UADD $GtSlice7XeCore0 UADD UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "4 $XeCoreTotalCount UMUL qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD UMUL $GtSlice0XeCore0 $GtSlice1XeCore0 UADD $GtSlice2XeCore0 UADD $GtSlice3XeCore0 UADD $GtSlice4XeCore0 UADD $GtSlice5XeCore0 UADD $GtSlice6XeCore0 UADD $GtSlice7XeCore0 UADD UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "128  $XeCoreTotalCount UMUL $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SLM_BYTE_WRITE", "SLM BYTE WRITE",
                          "Number of bytes written to SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "4 $XeCoreTotalCount UMUL dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD UMUL $GtSlice0XeCore0 $GtSlice1XeCore0 UADD $GtSlice2XeCore0 UADD $GtSlice3XeCore0 UADD $GtSlice4XeCore0 UADD $GtSlice5XeCore0 UADD $GtSlice6XeCore0 UADD $GtSlice7XeCore0 UADD UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "4 $XeCoreTotalCount UMUL qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD UMUL $GtSlice0XeCore0 $GtSlice1XeCore0 UADD $GtSlice2XeCore0 UADD $GtSlice3XeCore0 UADD $GtSlice4XeCore0 UADD $GtSlice5XeCore0 UADD $GtSlice6XeCore0 UADD $GtSlice7XeCore0 UADD UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "128  $XeCoreTotalCount UMUL $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ", "GPU MEMORY BYTE READ",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) read bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xa0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x130" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "64 $SliceTotalCount UMUL $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE", "GPU MEMORY BYTE WRITE",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) write bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xb8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x138" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "64 $SliceTotalCount UMUL $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_ACTIVE", "XVE ACTIVE",
                          "Percentage of time in which at least one pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x2c:0xa7" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x48" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL", "XVE STALL",
                          "Percentage of time in which any threads are loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x30:0xa8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x50" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_THREADS_OCCUPANCY_ALL", "XVE THREADS OCCUPANCY ALL",
                          "Percentage of thread slots occupied",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "DS|TES", nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "8 rd40@0x34:0xa9 FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "8 qw@0x58 FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_BUSY", "XVE BUSY",
                          "Any XVE thread loaded.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x34:0xa9" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x58" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 0 UGT" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "1" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16870012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18891060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04870000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e870180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10870105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12870083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14870001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x280a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17870012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19891060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05870000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f870180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11870105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13870083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15870001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09890081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x290a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16870012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18891060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04870000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e870180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10870105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12870083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14870001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x280a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17870012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19891060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05870000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f870180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11870105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13870083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15870001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09890081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x290a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16870012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18891060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04870000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e870180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10870105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12870083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14870001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x280a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17870012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19891060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05870000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f870180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11870105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13870083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15870001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09890081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x290a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16870012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18891060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04870000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e870180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10870105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12870083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14870001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x280a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17870012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19891060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05870000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f870180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11870105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13870083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15870001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09890081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x290a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x007f0000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x0000fe7f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc00, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc04, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc08, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc0c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc10, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc14, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc18, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc1c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc20, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc24, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc28, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc2c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc30, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc34, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xe458, 0x00005004, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe558, 0x00000008, REGISTER_TYPE_FLEX );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CL1ProfileWritesMetricSet_XeCore3::CL1ProfileWritesMetricSet_XeCore3( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CL1ProfileWritesMetricSet_XeCore3::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_WRITE", "LOAD STORE CACHE BYTE WRITE",
                          "Number of bytes written to the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "4 $XeCoreTotalCount UMUL dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD UMUL $GtSlice0XeCore3 $GtSlice1XeCore3 UADD $GtSlice2XeCore3 UADD $GtSlice3XeCore3 UADD $GtSlice4XeCore3 UADD $GtSlice5XeCore3 UADD $GtSlice6XeCore3 UADD $GtSlice7XeCore3 UADD UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "4 $XeCoreTotalCount UMUL qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD UMUL $GtSlice0XeCore3 $GtSlice1XeCore3 UADD $GtSlice2XeCore3 UADD $GtSlice3XeCore3 UADD $GtSlice4XeCore3 UADD $GtSlice5XeCore3 UADD $GtSlice6XeCore3 UADD $GtSlice7XeCore3 UADD UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "128  $XeCoreTotalCount UMUL $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SLM_BYTE_WRITE", "SLM BYTE WRITE",
                          "Number of bytes written to SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "4 $XeCoreTotalCount UMUL dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD UMUL $GtSlice0XeCore3 $GtSlice1XeCore3 UADD $GtSlice2XeCore3 UADD $GtSlice3XeCore3 UADD $GtSlice4XeCore3 UADD $GtSlice5XeCore3 UADD $GtSlice6XeCore3 UADD $GtSlice7XeCore3 UADD UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "4 $XeCoreTotalCount UMUL qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD UMUL $GtSlice0XeCore3 $GtSlice1XeCore3 UADD $GtSlice2XeCore3 UADD $GtSlice3XeCore3 UADD $GtSlice4XeCore3 UADD $GtSlice5XeCore3 UADD $GtSlice6XeCore3 UADD $GtSlice7XeCore3 UADD UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "128  $XeCoreTotalCount UMUL $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ", "GPU MEMORY BYTE READ",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) read bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xa0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x130" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "64 $SliceTotalCount UMUL $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE", "GPU MEMORY BYTE WRITE",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) write bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xb8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x138" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "64 $SliceTotalCount UMUL $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_ACTIVE", "XVE ACTIVE",
                          "Percentage of time in which at least one pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x2c:0xa7" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x48" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL", "XVE STALL",
                          "Percentage of time in which any threads are loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x30:0xa8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x50" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_THREADS_OCCUPANCY_ALL", "XVE THREADS OCCUPANCY ALL",
                          "Percentage of thread slots occupied",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "DS|TES", nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "8 rd40@0x34:0xa9 FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "8 qw@0x58 FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_BUSY", "XVE BUSY",
                          "Any XVE thread loaded.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x34:0xa9" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x58" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 0 UGT" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "1" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e70012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e91060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e70000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee70180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e70105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e70083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e90081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae90103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce90185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x280a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e70012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e91060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e70000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe70180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e70105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e70083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e90081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be90103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de90185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x290a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e70012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e91060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e70000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee70180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e70105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e70083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e90081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae90103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce90185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x280a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e70012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e91060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e70000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe70180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e70105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e70083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e90081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be90103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de90185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x290a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e70012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e91060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e70000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee70180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e70105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e70083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e90081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae90103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce90185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x280a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e70012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e91060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e70000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe70180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e70105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e70083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e90081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be90103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de90185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x290a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e70012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e91060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e70000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee70180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e70105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e70083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e90081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae90103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce90185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x280a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e70012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e91060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e70000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe70180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e70105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e70083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e90081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be90103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de90185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2410060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c080c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x290a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x007f0000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x0000fe7f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc00, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc04, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc08, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc0c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc10, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc14, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc18, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc1c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc20, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc24, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc28, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc2c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc30, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc34, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xe458, 0x00005004, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe558, 0x00000008, REGISTER_TYPE_FLEX );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataportReadsMetricSet::CDataportReadsMetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataportReadsMetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "DATAPORT_BYTE_READ", "DATAPORT BYTE READ",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "64 2 UMUL dw@0xd0 dw@0xc0 UADD dw@0xd4 UADD dw@0xc4 UADD dw@0xc8 UADD dw@0xd8 UADD dw@0xcc UADD dw@0xdc UADD UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "64 2 UMUL qw@0x160 qw@0x140 UADD qw@0x168 UADD qw@0x148 UADD qw@0x150 UADD qw@0x170 UADD qw@0x158 UADD qw@0x178 UADD UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "64  $XeCoreTotalCount UMUL $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "HOST_TO_GPUMEM_BYTE_READ", "HOST TO GPUMEM BYTE READ",
                          "Number of bytes read by host from GPU local (HBM) memory (downstream)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "64 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "64 $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "HOST_TO_GPUMEM_BYTE_WRITE", "HOST TO GPUMEM BYTE WRITE",
                          "Number of bytes written by host to GPU local (HBM) memory (downstream)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "64 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "64 $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ", "GPU MEMORY BYTE READ",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) read bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xa0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x130" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "64 $SliceTotalCount UMUL $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE", "GPU MEMORY BYTE WRITE",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) write bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xb8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x138" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "64 $SliceTotalCount UMUL $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_ACTIVE", "XVE ACTIVE",
                          "Percentage of time in which at least one pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x2c:0xa7" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x48" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL", "XVE STALL",
                          "Percentage of time in which any threads are loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x30:0xa8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x50" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_BUSY", "XVE BUSY",
                          "Any XVE thread loaded.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x34:0xa9" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x58" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 0 UGT" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "1" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_THREADS_OCCUPANCY_ALL", "XVE THREADS OCCUPANCY ALL",
                          "Percentage of thread slots occupied",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "DS|TES", nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "8 rd40@0x34:0xa9 FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "8 qw@0x58 FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_COMPUTE_THREAD_COUNT", "XVE COMPUTE THREAD COUNT",
                          "Number of compute shader hardware threads dispatched",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x20:0xa4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x30" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12091940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04034000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100903d6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040a1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1281a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1481b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a1a656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a1b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c1a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c1b695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e1a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e1b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04813200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c810695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10810617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840330, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a70050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c43003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae10656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4c00c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008fa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009f00f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a55aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00023003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2610000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2810154a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c10408c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24101400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2610000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2810154a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c10408c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24101400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080403, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080403, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080403, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080403, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x280a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1381a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1581b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a1a656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a1b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c1a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c1b695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e1a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e1b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05813200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11810617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840330, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c43003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be10656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4c00c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e70050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108fa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109f00f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a55aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01023003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2610000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2810154a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c10408c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24101400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2610000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2810154a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c10408c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24101400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080403, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080403, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080403, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080403, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x290a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1281a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1481b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a1a656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a1b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c1a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c1b695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e1a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e1b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04813200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c810695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10810617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840330, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a70050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c43003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae10656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4c00c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008fa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009f00f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a55aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00023003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2610000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2810154a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c10408c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24101400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2610000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2810154a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c10408c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24101400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080403, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080403, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080403, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080403, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x280a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1381a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1581b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a1a656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a1b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c1a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c1b695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e1a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e1b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05813200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11810617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840330, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c43003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be10656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4c00c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e70050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108fa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109f00f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a55aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01023003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2610000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2810154a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c10408c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24101400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2610000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2810154a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c10408c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24101400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080403, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080403, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080403, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080403, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x290a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1281a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1481b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a1a656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a1b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c1a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c1b695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e1a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e1b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04813200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c810695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10810617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840330, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a70050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c43003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae10656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4c00c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008fa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009f00f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a55aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00023003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2610000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2810154a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c10408c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24101400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2610000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2810154a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c10408c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24101400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080403, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080403, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080403, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080403, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x280a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1381a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1581b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a1a656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a1b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c1a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c1b695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e1a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e1b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05813200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11810617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840330, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c43003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be10656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4c00c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e70050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108fa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109f00f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a55aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01023003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2610000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2810154a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c10408c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24101400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2610000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2810154a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c10408c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24101400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080403, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080403, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080403, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080403, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x290a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1281a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1481b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a1a656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a1b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c1a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c1b695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e1a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e1b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04813200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c810695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10810617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840330, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a70050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c43003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae10656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4c00c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008fa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009f00f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a55aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00023003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2610000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2810154a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c10408c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24101400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2610000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2810154a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c10408c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24101400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080403, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080403, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080403, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080403, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x280a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1381a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1581b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a1a656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a1b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c1a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c1b695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e1a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e1b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05813200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11810617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840330, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c43003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be10656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4c00c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e70050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108fa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109f00f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a55aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01023003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2610000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2810154a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c10408c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24101400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2610000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2810154a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c10408c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22100063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24101400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080403, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080403, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080403, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080403, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a060c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x290a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xdc00, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc04, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc08, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc0c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc10, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc14, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc18, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc1c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc20, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc24, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc28, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc2c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc30, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc34, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc38, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc3c, 0x00003fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00ff0000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x000000ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xe458, 0x00005004, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe558, 0x00000008, REGISTER_TYPE_FLEX );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CDataportWritesMetricSet::CDataportWritesMetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CDataportWritesMetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "DATAPORT_BYTE_WRITE", "DATAPORT BYTE WRITE",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "32 dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "32 qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "32 $XeCoreTotalCount UMUL $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SAMPLER_L3_READ", "SAMPLER L3 READ",
                          "Number of L3 read requests resulting from sampler local cache miss",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD dw@0xec UADD dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD qw@0x198 UADD qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SYSMEM_BYTE_READ", "SYSMEM BYTE READ",
                          "Number of system memory bytes read (upstream)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "64 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "64 $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SYSMEM_BYTE_WRITE", "SYSMEM BYTE WRITE",
                          "Number of system memory bytes written (upstream)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "64 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "64 $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ", "GPU MEMORY BYTE READ",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) read bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xa0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x130" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "64 $SliceTotalCount UMUL $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE", "GPU MEMORY BYTE WRITE",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) write bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xb8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x138" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "64 $SliceTotalCount UMUL $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_ACTIVE", "XVE ACTIVE",
                          "Percentage of time in which at least one pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x2c:0xa7" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x48" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL", "XVE STALL",
                          "Percentage of time in which any threads are loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x30:0xa8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x50" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_BUSY", "XVE BUSY",
                          "Any XVE thread loaded.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x34:0xa9" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x58" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 0 UGT" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "1" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_THREADS_OCCUPANCY_ALL", "XVE THREADS OCCUPANCY ALL",
                          "Percentage of thread slots occupied",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "DS|TES", nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "8 rd40@0x34:0xa9 FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "8 qw@0x58 FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_COMPUTE_THREAD_COUNT", "XVE COMPUTE THREAD COUNT",
                          "Number of compute shader hardware threads dispatched",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "threads", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x20:0xa4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x30" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120900a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06091490, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e810340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030019, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c810016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca10580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec10016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee10580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e38000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e64000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e74000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00076000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080eff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aa555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff2f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b04aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12105000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20102c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x261055ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2810056b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c1056a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e10000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22102d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14105000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x241056ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12105000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20102c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x261055ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2810056b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c1056a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e10000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22102d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14105000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x241056ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04082000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18082c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2208056a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2408000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04082000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18082c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2208056a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2408000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04082000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18082c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2208056a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2408000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04082000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18082c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2208056a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2408000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x280a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f810340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17030019, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da10580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe10580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e38000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e64000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e74000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01076000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080eff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff2f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b04aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12105000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20102c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x261055ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2810056b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c1056a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e10000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22102d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14105000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x241056ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12105000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20102c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x261055ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2810056b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c1056a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e10000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22102d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14105000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x241056ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04082000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18082c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2208056a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2408000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04082000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18082c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2208056a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2408000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04082000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18082c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2208056a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2408000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04082000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18082c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2208056a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2408000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x290a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e810340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030019, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c810016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca10580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec10016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee10580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e38000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e64000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e74000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00076000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080eff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aa555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff2f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b04aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12105000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20102c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x261055ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2810056b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c1056a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e10000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22102d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14105000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x241056ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12105000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20102c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x261055ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2810056b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c1056a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e10000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22102d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14105000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x241056ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04082000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18082c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2208056a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2408000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04082000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18082c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2208056a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2408000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04082000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18082c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2208056a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2408000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04082000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18082c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2208056a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2408000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x280a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f810340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17030019, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da10580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe10580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e38000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e64000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e74000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01076000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080eff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff2f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b04aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12105000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20102c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x261055ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2810056b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c1056a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e10000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22102d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14105000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x241056ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12105000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20102c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x261055ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2810056b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c1056a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e10000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22102d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14105000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x241056ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04082000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18082c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2208056a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2408000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04082000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18082c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2208056a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2408000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04082000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18082c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2208056a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2408000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04082000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18082c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2208056a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2408000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x290a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e810340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030019, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c810016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca10580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec10016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee10580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e38000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e64000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e74000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00076000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080eff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aa555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff2f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b04aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12105000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20102c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x261055ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2810056b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c1056a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e10000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22102d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14105000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x241056ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12105000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20102c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x261055ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2810056b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c1056a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e10000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22102d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14105000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x241056ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04082000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18082c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2208056a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2408000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04082000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18082c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2208056a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2408000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04082000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18082c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2208056a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2408000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04082000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18082c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2208056a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2408000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x280a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f810340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17030019, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da10580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe10580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e38000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e64000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e74000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01076000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080eff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff2f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b04aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12105000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20102c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x261055ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2810056b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c1056a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e10000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22102d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14105000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x241056ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12105000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20102c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x261055ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2810056b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c1056a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e10000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22102d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14105000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x241056ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04082000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18082c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2208056a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2408000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04082000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18082c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2208056a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2408000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04082000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18082c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2208056a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2408000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04082000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18082c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2208056a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2408000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x290a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e810340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030019, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c810016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca10580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec10016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee10580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e38000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e64000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e74000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00076000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080eff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aa555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff2f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b04aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12105000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20102c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x261055ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2810056b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c1056a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e10000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22102d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14105000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x241056ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12105000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20102c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x261055ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2810056b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c1056a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e10000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22102d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14105000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x241056ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04082000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18082c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2208056a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2408000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04082000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18082c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2208056a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2408000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04082000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18082c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2208056a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2408000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04082000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18082c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2208056a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2408000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x280a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f810340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17030019, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da10580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe10580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e38000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e64000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e74000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01076000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080eff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff2f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b04aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12105000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20102c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x261055ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2810056b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c1056a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e10000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22102d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14105000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x241056ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12105000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20102c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x261055ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2810056b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c1056a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e10000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22102d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14105000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x241056ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04082000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18082c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2208056a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2408000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04082000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18082c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2208056a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2408000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04082000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18082c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2208056a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2408000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04082000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18082c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12084000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2208056a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2408000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c082d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a556b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a2d6b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0601, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a016b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a56ad, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a55ab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x290a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0804e1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00065555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00085555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100804, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22102801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24100e04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100804, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22102801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24100e04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0804e1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0804e1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0804e1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26080001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0804e1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00065555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00085555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100804, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22102801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24100e04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100804, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22102801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24100e04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0804e1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0804e1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0804e1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26080001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0804e1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00065555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00085555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100804, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22102801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24100e04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100804, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22102801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24100e04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0804e1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0804e1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0804e1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26080001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c3000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0804e1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00065555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00085555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100804, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22102801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24100e04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20100400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26100081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28100021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a100421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c100804, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22102801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14100000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24100e04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0804e1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0804e1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e080421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20080421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22080081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a082801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0804e1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x200a0421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x210a0421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x220a0204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x230a0204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x240a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x250a0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x260a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x270a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b0a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0a008a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26080001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xe458, 0x00005004, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe558, 0x00000008, REGISTER_TYPE_FLEX );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt1MetricSet::CExt1MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt1MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_READ_SQIDI0", "GPU MEMORY READ SQIDI0",
                          "Number of GTI memory reads",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_READ_SQIDI1", "GPU MEMORY READ SQIDI1",
                          "Number of GTI memory reads",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_READ_SQIDI2", "GPU MEMORY READ SQIDI2",
                          "Number of GTI memory reads",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_READ_SQIDI3", "GPU MEMORY READ SQIDI3",
                          "Number of GTI memory reads",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_READ_SQIDI4", "GPU MEMORY READ SQIDI4",
                          "Number of GTI memory reads",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_READ_SQIDI5", "GPU MEMORY READ SQIDI5",
                          "Number of GTI memory reads",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4 dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168 qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_READ_SQIDI6", "GPU MEMORY READ SQIDI6",
                          "Number of GTI memory reads",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_READ_SQIDI7", "GPU MEMORY READ SQIDI7",
                          "Number of GTI memory reads",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_READ", "GPU MEMORY READ",
                          "Number of GTI memory reads",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$$GPU_MEMORY_READ_SQIDI2 $$GPU_MEMORY_READ_SQIDI0 UADD $$GPU_MEMORY_READ_SQIDI1 UADD $$GPU_MEMORY_READ_SQIDI3 UADD $$GPU_MEMORY_READ_SQIDI4 UADD $$GPU_MEMORY_READ_SQIDI5 UADD $$GPU_MEMORY_READ_SQIDI6 UADD $$GPU_MEMORY_READ_SQIDI7 UADD" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18013800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a010140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18213800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a210140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18413800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a410140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18613800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a610140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18813800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a810140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a13800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa10140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c13800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac10140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e13800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae10140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010106, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14010180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1601000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02210106, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12210180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1421000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02410106, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10410180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1241000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00410000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02610106, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e610180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1061000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00610000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810106, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c810180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e81000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10106, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa10180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca1000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10106, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac1000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10106, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e11800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e1000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00034924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02034924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04034924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000926e4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0209004a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a1249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2449, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040a2492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060a0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b4800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b149b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt2MetricSet::CExt2MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt2MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ_SQIDI0", "GPU MEMORY BYTE READ SQIDI0",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) read bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ_SQIDI1", "GPU MEMORY BYTE READ SQIDI1",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) read bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ_SQIDI2", "GPU MEMORY BYTE READ SQIDI2",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) read bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ_SQIDI3", "GPU MEMORY BYTE READ SQIDI3",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) read bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ_SQIDI4", "GPU MEMORY BYTE READ SQIDI4",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) read bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ_SQIDI5", "GPU MEMORY BYTE READ SQIDI5",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) read bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ_SQIDI6", "GPU MEMORY BYTE READ SQIDI6",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) read bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ_SQIDI7", "GPU MEMORY BYTE READ SQIDI7",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) read bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ", "GPU MEMORY BYTE READ",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) read bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GPU_MEMORY_BYTE_READ_SQIDI0 $GPU_MEMORY_BYTE_READ_SQIDI1 UADD $GPU_MEMORY_BYTE_READ_SQIDI2 UADD $GPU_MEMORY_BYTE_READ_SQIDI3 UADD $GPU_MEMORY_BYTE_READ_SQIDI4 UADD $GPU_MEMORY_BYTE_READ_SQIDI5 UADD $GPU_MEMORY_BYTE_READ_SQIDI6 UADD $GPU_MEMORY_BYTE_READ_SQIDI7 UADD 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "64 $SliceTotalCount UMUL $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE_SQIDI0", "GPU MEMORY BYTE WRITE SQIDI0",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) write bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE_SQIDI1", "GPU MEMORY BYTE WRITE SQIDI1",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) write bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE_SQIDI2", "GPU MEMORY BYTE WRITE SQIDI2",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) write bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE_SQIDI3", "GPU MEMORY BYTE WRITE SQIDI3",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) write bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE_SQIDI4", "GPU MEMORY BYTE WRITE SQIDI4",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) write bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE_SQIDI5", "GPU MEMORY BYTE WRITE SQIDI5",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) write bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE_SQIDI6", "GPU MEMORY BYTE WRITE SQIDI6",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) write bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE_SQIDI7", "GPU MEMORY BYTE WRITE SQIDI7",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) write bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE", "GPU MEMORY BYTE WRITE",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) write bytes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 20 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GPU_MEMORY_BYTE_WRITE_SQIDI0 $GPU_MEMORY_BYTE_WRITE_SQIDI1 UADD $GPU_MEMORY_BYTE_WRITE_SQIDI2 UADD $GPU_MEMORY_BYTE_WRITE_SQIDI3 UADD $GPU_MEMORY_BYTE_WRITE_SQIDI4 UADD $GPU_MEMORY_BYTE_WRITE_SQIDI5 UADD $GPU_MEMORY_BYTE_WRITE_SQIDI6 UADD $GPU_MEMORY_BYTE_WRITE_SQIDI7 UADD 128 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "64 $SliceTotalCount UMUL $GpuCoreClocks UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ_BW_SQIDI0", "GPU MEMORY BYTE READ BW SQIDI0",
                          "Device local memory (HBM, GDDR, LPDDR, etc.) read bandwidth",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_FLOAT, "GBpS", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 21 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$$GPU_MEMORY_BYTE_READ_SQIDI0 $$GpuTime FDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ_BW_SQIDI1", "GPU MEMORY BYTE READ BW SQIDI1",
                          "Device local memory (HBM, GDDR, LPDDR, etc.) read bandwidth",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_FLOAT, "GBpS", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 22 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$$GPU_MEMORY_BYTE_READ_SQIDI1 $$GpuTime FDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ_BW_SQIDI2", "GPU MEMORY BYTE READ BW SQIDI2",
                          "Device local memory (HBM, GDDR, LPDDR, etc.) read bandwidth",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_FLOAT, "GBpS", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 23 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$$GPU_MEMORY_BYTE_READ_SQIDI2 $$GpuTime FDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ_BW_SQIDI3", "GPU MEMORY BYTE READ BW SQIDI3",
                          "Device local memory (HBM, GDDR, LPDDR, etc.) read bandwidth",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_FLOAT, "GBpS", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 24 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$$GPU_MEMORY_BYTE_READ_SQIDI3 $$GpuTime FDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ_BW_SQIDI4", "GPU MEMORY BYTE READ BW SQIDI4",
                          "Device local memory (HBM, GDDR, LPDDR, etc.) read bandwidth",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_FLOAT, "GBpS", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 25 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$$GPU_MEMORY_BYTE_READ_SQIDI4 $$GpuTime FDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ_BW_SQIDI5", "GPU MEMORY BYTE READ BW SQIDI5",
                          "Device local memory (HBM, GDDR, LPDDR, etc.) read bandwidth",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_FLOAT, "GBpS", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 26 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$$GPU_MEMORY_BYTE_READ_SQIDI5 $$GpuTime FDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ_BW_SQIDI6", "GPU MEMORY BYTE READ BW SQIDI6",
                          "Device local memory (HBM, GDDR, LPDDR, etc.) read bandwidth",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_FLOAT, "GBpS", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 27 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$$GPU_MEMORY_BYTE_READ_SQIDI6 $$GpuTime FDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ_BW_SQIDI7", "GPU MEMORY BYTE READ BW SQIDI7",
                          "Device local memory (HBM, GDDR, LPDDR, etc.) read bandwidth",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_FLOAT, "GBpS", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 28 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$$GPU_MEMORY_BYTE_READ_SQIDI7 $$GpuTime FDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_READ_BW", "GPU MEMORY BYTE READ BW",
                          "Device local memory (HBM, GDDR, LPDDR, etc.) read bandwidth",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_FLOAT, "GBPS", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 29 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$$GPU_MEMORY_BYTE_READ $$GpuTime FDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE_BW_SQIDI0", "GPU MEMORY BYTE WRITE BW SQIDI0",
                          "Device local memory (HBM, GDDR, LPDDR, etc.) write bandwidth",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_FLOAT, "GBpS", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 30 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$$GPU_MEMORY_BYTE_WRITE_SQIDI0 $$GpuTime FDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE_BW_SQIDI1", "GPU MEMORY BYTE WRITE BW SQIDI1",
                          "Device local memory (HBM, GDDR, LPDDR, etc.) write bandwidth",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_FLOAT, "GBpS", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 31 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$$GPU_MEMORY_BYTE_WRITE_SQIDI1 $$GpuTime FDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE_BW_SQIDI2", "GPU MEMORY BYTE WRITE BW SQIDI2",
                          "Device local memory (HBM, GDDR, LPDDR, etc.) write bandwidth",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_FLOAT, "GBpS", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 32 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$$GPU_MEMORY_BYTE_WRITE_SQIDI2 $$GpuTime FDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE_BW_SQIDI3", "GPU MEMORY BYTE WRITE BW SQIDI3",
                          "Device local memory (HBM, GDDR, LPDDR, etc.) write bandwidth",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_FLOAT, "GBpS", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 33 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$$GPU_MEMORY_BYTE_WRITE_SQIDI3 $$GpuTime FDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE_BW_SQIDI4", "GPU MEMORY BYTE WRITE BW SQIDI4",
                          "Device local memory (HBM, GDDR, LPDDR, etc.) write bandwidth",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_FLOAT, "GBpS", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 34 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$$GPU_MEMORY_BYTE_WRITE_SQIDI4 $$GpuTime FDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE_BW_SQIDI5", "GPU MEMORY BYTE WRITE BW SQIDI5",
                          "Device local memory (HBM, GDDR, LPDDR, etc.) write bandwidth",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_FLOAT, "GBpS", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 35 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$$GPU_MEMORY_BYTE_WRITE_SQIDI5 $$GpuTime FDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE_BW_SQIDI6", "GPU MEMORY BYTE WRITE BW SQIDI6",
                          "Device local memory (HBM, GDDR, LPDDR, etc.) write bandwidth",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_FLOAT, "GBpS", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 36 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$$GPU_MEMORY_BYTE_WRITE_SQIDI6 $$GpuTime FDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE_BW_SQIDI7", "GPU MEMORY BYTE WRITE BW SQIDI7",
                          "Device local memory (HBM, GDDR, LPDDR, etc.) write bandwidth",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_FLOAT, "GBpS", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 37 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$$GPU_MEMORY_BYTE_WRITE_SQIDI7 $$GpuTime FDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_BYTE_WRITE_BW", "GPU MEMORY BYTE WRITE BW",
                          "Device local memory (HBM, GDDR, LPDDR, etc.) write bandwidth",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_FLOAT, "GBPS", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 38 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$$GPU_MEMORY_BYTE_WRITE $$GpuTime FDIV" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18013800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18213800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18413800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18613800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18813800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a13800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c13800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e13800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e010004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16010005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02210006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c210100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14210140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02410006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c410004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14410005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00410000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02610006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a610100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12610140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00610000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a810004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12810005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a10140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c10005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e11000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee10140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00034924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02034924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04034924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009029c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02093800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0409000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a2249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1292, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040a2489, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060a0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0053, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b2700, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030442, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt3MetricSet::CExt3MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt3MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_32B_TRANSACTION_READ_SQIDI0", "GPU MEMORY 32B TRANSACTION READ SQIDI0",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) reads (32B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xfc UMUL dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x1b8 UMUL qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_32B_TRANSACTION_READ_SQIDI1", "GPU MEMORY 32B TRANSACTION READ SQIDI1",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) reads (32B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xf4 UMUL dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x1a8 UMUL qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_32B_TRANSACTION_READ_SQIDI2", "GPU MEMORY 32B TRANSACTION READ SQIDI2",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) reads (32B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xec UMUL dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x198 UMUL qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_32B_TRANSACTION_READ_SQIDI3", "GPU MEMORY 32B TRANSACTION READ SQIDI3",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) reads (32B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xe4 UMUL dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x188 UMUL qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_32B_TRANSACTION_READ_SQIDI4", "GPU MEMORY 32B TRANSACTION READ SQIDI4",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) reads (32B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xdc UMUL dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x178 UMUL qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_32B_TRANSACTION_READ_SQIDI5", "GPU MEMORY 32B TRANSACTION READ SQIDI5",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) reads (32B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xd4 UMUL dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x168 UMUL qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_32B_TRANSACTION_READ_SQIDI6", "GPU MEMORY 32B TRANSACTION READ SQIDI6",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) reads (32B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xcc UMUL dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x158 UMUL qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_32B_TRANSACTION_READ_SQIDI7", "GPU MEMORY 32B TRANSACTION READ SQIDI7",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) reads (32B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xc4 UMUL dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x148 UMUL qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10020011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10220011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10420011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10620011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10820011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a20011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c20011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e20011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e020185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00213000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c220185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00220000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00410c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a420185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00420000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00610300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08620185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00620000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008100c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06820185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a20185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e20185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00034924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02034924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04034924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000926e4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0209004a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a1249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2449, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040a2492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060a0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b4800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b149b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt4MetricSet::CExt4MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt4MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_64B_TRANSACTION_READ_SQIDI0", "GPU MEMORY 64B TRANSACTION READ SQIDI0",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) reads (64B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xfc UMUL dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x1b8 UMUL qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_64B_TRANSACTION_READ_SQIDI1", "GPU MEMORY 64B TRANSACTION READ SQIDI1",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) reads (64B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xf4 UMUL dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x1a8 UMUL qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_64B_TRANSACTION_READ_SQIDI2", "GPU MEMORY 64B TRANSACTION READ SQIDI2",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) reads (64B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xec UMUL dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x198 UMUL qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_64B_TRANSACTION_READ_SQIDI3", "GPU MEMORY 64B TRANSACTION READ SQIDI3",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) reads (64B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xe4 UMUL dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x188 UMUL qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_64B_TRANSACTION_READ_SQIDI4", "GPU MEMORY 64B TRANSACTION READ SQIDI4",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) reads (64B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xdc UMUL dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x178 UMUL qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_64B_TRANSACTION_READ_SQIDI5", "GPU MEMORY 64B TRANSACTION READ SQIDI5",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) reads (64B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xd4 UMUL dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x168 UMUL qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_64B_TRANSACTION_READ_SQIDI6", "GPU MEMORY 64B TRANSACTION READ SQIDI6",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) reads (64B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xcc UMUL dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x158 UMUL qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_64B_TRANSACTION_READ_SQIDI7", "GPU MEMORY 64B TRANSACTION READ SQIDI7",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) reads (64B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "2 dw@0xc4 UMUL dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "2 qw@0x148 UMUL qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10020251, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10220251, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10420251, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10620251, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10820251, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a20251, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c20251, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e20251, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e020207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00213000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c220207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00220000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00410c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a420207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00420000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00610300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08620207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00620000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008100c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06820207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a20207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c1000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e20207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00034924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02034924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04034924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000926e4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0209004a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a1249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2449, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040a2492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060a0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b4800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b149b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt5MetricSet::CExt5MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt5MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_32B_TRANSACTION_WRITE_SQIDI0", "GPU MEMORY 32B TRANSACTION WRITE SQIDI0",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) writes (32B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_32B_TRANSACTION_WRITE_SQIDI1", "GPU MEMORY 32B TRANSACTION WRITE SQIDI1",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) writes (32B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_32B_TRANSACTION_WRITE_SQIDI2", "GPU MEMORY 32B TRANSACTION WRITE SQIDI2",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) writes (32B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_32B_TRANSACTION_WRITE_SQIDI3", "GPU MEMORY 32B TRANSACTION WRITE SQIDI3",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) writes (32B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_32B_TRANSACTION_WRITE_SQIDI4", "GPU MEMORY 32B TRANSACTION WRITE SQIDI4",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) writes (32B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_32B_TRANSACTION_WRITE_SQIDI5", "GPU MEMORY 32B TRANSACTION WRITE SQIDI5",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) writes (32B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_32B_TRANSACTION_WRITE_SQIDI6", "GPU MEMORY 32B TRANSACTION WRITE SQIDI6",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) writes (32B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_32B_TRANSACTION_WRITE_SQIDI7", "GPU MEMORY 32B TRANSACTION WRITE SQIDI7",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) writes (32B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_64B_TRANSACTION_WRITE_SQIDI0", "GPU MEMORY 64B TRANSACTION WRITE SQIDI0",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) writes (64B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_64B_TRANSACTION_WRITE_SQIDI1", "GPU MEMORY 64B TRANSACTION WRITE SQIDI1",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) writes (64B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_64B_TRANSACTION_WRITE_SQIDI2", "GPU MEMORY 64B TRANSACTION WRITE SQIDI2",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) writes (64B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_64B_TRANSACTION_WRITE_SQIDI3", "GPU MEMORY 64B TRANSACTION WRITE SQIDI3",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) writes (64B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_64B_TRANSACTION_WRITE_SQIDI4", "GPU MEMORY 64B TRANSACTION WRITE SQIDI4",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) writes (64B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_64B_TRANSACTION_WRITE_SQIDI5", "GPU MEMORY 64B TRANSACTION WRITE SQIDI5",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) writes (64B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_64B_TRANSACTION_WRITE_SQIDI6", "GPU MEMORY 64B TRANSACTION WRITE SQIDI6",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) writes (64B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_64B_TRANSACTION_WRITE_SQIDI7", "GPU MEMORY 64B TRANSACTION WRITE SQIDI7",
                          "Number of device local memory (HBM, GDDR, LPDDR, etc.) writes (64B)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1002000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1022000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1042000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1062000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1082000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a2000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c2000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e2000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00018080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06020100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e020080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00214040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06220004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e220002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00220000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00412020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04420100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c420080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00420000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00611010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04620004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c620002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00620000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810808, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02820100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a820080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a20004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c20080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e20004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00034924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02034924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04034924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009029c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02093800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0409000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a2249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1292, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040a2489, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060a0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0053, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b2700, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030442, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt6MetricSet::CExt6MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt6MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_ACTIVE_SQIDI0", "GPU MEMORY ACTIVE SQIDI0",
                          "Percentage of time in which device local memory (HBM, GDDR, LPDDR, etc.) is active",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_ACTIVE_SQIDI1", "GPU MEMORY ACTIVE SQIDI1",
                          "Percentage of time in which device local memory (HBM, GDDR, LPDDR, etc.) is active",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_ACTIVE_SQIDI2", "GPU MEMORY ACTIVE SQIDI2",
                          "Percentage of time in which device local memory (HBM, GDDR, LPDDR, etc.) is active",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_ACTIVE_SQIDI3", "GPU MEMORY ACTIVE SQIDI3",
                          "Percentage of time in which device local memory (HBM, GDDR, LPDDR, etc.) is active",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_ACTIVE_SQIDI4", "GPU MEMORY ACTIVE SQIDI4",
                          "Percentage of time in which device local memory (HBM, GDDR, LPDDR, etc.) is active",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_ACTIVE_SQIDI5", "GPU MEMORY ACTIVE SQIDI5",
                          "Percentage of time in which device local memory (HBM, GDDR, LPDDR, etc.) is active",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_ACTIVE_SQIDI6", "GPU MEMORY ACTIVE SQIDI6",
                          "Percentage of time in which device local memory (HBM, GDDR, LPDDR, etc.) is active",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_ACTIVE_SQIDI7", "GPU MEMORY ACTIVE SQIDI7",
                          "Percentage of time in which device local memory (HBM, GDDR, LPDDR, etc.) is active",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_REQUEST_QUEUE_FULL_SQIDI0", "GPU MEMORY REQUEST QUEUE FULL SQIDI0",
                          "Percentage of time in which SQ is filled above a threshold (usually 48 entries)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_REQUEST_QUEUE_FULL_SQIDI1", "GPU MEMORY REQUEST QUEUE FULL SQIDI1",
                          "Percentage of time in which SQ is filled above a threshold (usually 48 entries)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_REQUEST_QUEUE_FULL_SQIDI2", "GPU MEMORY REQUEST QUEUE FULL SQIDI2",
                          "Percentage of time in which SQ is filled above a threshold (usually 48 entries)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_REQUEST_QUEUE_FULL_SQIDI3", "GPU MEMORY REQUEST QUEUE FULL SQIDI3",
                          "Percentage of time in which SQ is filled above a threshold (usually 48 entries)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_REQUEST_QUEUE_FULL_SQIDI4", "GPU MEMORY REQUEST QUEUE FULL SQIDI4",
                          "Percentage of time in which SQ is filled above a threshold (usually 48 entries)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_REQUEST_QUEUE_FULL_SQIDI5", "GPU MEMORY REQUEST QUEUE FULL SQIDI5",
                          "Percentage of time in which SQ is filled above a threshold (usually 48 entries)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_REQUEST_QUEUE_FULL_SQIDI6", "GPU MEMORY REQUEST QUEUE FULL SQIDI6",
                          "Percentage of time in which SQ is filled above a threshold (usually 48 entries)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_REQUEST_QUEUE_FULL_SQIDI7", "GPU MEMORY REQUEST QUEUE FULL SQIDI7",
                          "Percentage of time in which SQ is filled above a threshold (usually 48 entries)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_ACTIVE", "GPU MEMORY ACTIVE",
                          "Percentage of time in which device local memory (HBM, GDDR, LPDDR, etc.) is active",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GPU_MEMORY_ACTIVE_SQIDI2 $GPU_MEMORY_ACTIVE_SQIDI0 FADD $GPU_MEMORY_ACTIVE_SQIDI1 FADD $GPU_MEMORY_ACTIVE_SQIDI3 FADD $GPU_MEMORY_ACTIVE_SQIDI4 FADD $GPU_MEMORY_ACTIVE_SQIDI5 FADD $GPU_MEMORY_ACTIVE_SQIDI6 FADD $GPU_MEMORY_ACTIVE_SQIDI7 FADD 8 FDIV $GpuCoreClocks FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_REQUEST_QUEUE_FULL", "GPU MEMORY REQUEST QUEUE FULL",
                          "Percentage of time in which SQ is filled above a threshold (usually 48 entries)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 20 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GPU_MEMORY_REQUEST_QUEUE_FULL_SQIDI2 $GPU_MEMORY_REQUEST_QUEUE_FULL_SQIDI0 FADD $GPU_MEMORY_REQUEST_QUEUE_FULL_SQIDI1 FADD $GPU_MEMORY_REQUEST_QUEUE_FULL_SQIDI3 FADD $GPU_MEMORY_REQUEST_QUEUE_FULL_SQIDI4 FADD $GPU_MEMORY_REQUEST_QUEUE_FULL_SQIDI5 FADD $GPU_MEMORY_REQUEST_QUEUE_FULL_SQIDI6 FADD $GPU_MEMORY_REQUEST_QUEUE_FULL_SQIDI7 FADD 8 FDIV $GpuCoreClocks FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1601034e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a010140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16210340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a210140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16410340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a410140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16610340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a610140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16810340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a810140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa10140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac10140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae10140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e010002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02210100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c210080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14210380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02410100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c410002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1441000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00410000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02610100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a610080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12610380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00610000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a810002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1281000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a10380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c1000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee10380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00034924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02034924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04034924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009029c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02093800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0409000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a2249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1292, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040a2489, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060a0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0053, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b2700, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030442, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt7MetricSet::CExt7MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt7MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L3_HIT_L3BANK0", "L3 HIT L3BANK0",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L3_HIT_L3BANK1", "L3 HIT L3BANK1",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L3_HIT_L3BANK2", "L3 HIT L3BANK2",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L3_HIT_L3BANK3", "L3 HIT L3BANK3",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L3_HIT_L3BANK4", "L3 HIT L3BANK4",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L3_HIT_L3BANK5", "L3 HIT L3BANK5",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L3_HIT_L3BANK6", "L3 HIT L3BANK6",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L3_HIT_L3BANK7", "L3 HIT L3BANK7",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L3_HIT_L3BANK8", "L3 HIT L3BANK8",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L3_HIT_L3BANK9", "L3 HIT L3BANK9",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L3_HIT_L3BANK10", "L3 HIT L3BANK10",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L3_HIT_L3BANK11", "L3 HIT L3BANK11",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L3_HIT_L3BANK12", "L3 HIT L3BANK12",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L3_HIT_L3BANK13", "L3 HIT L3BANK13",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L3_HIT_L3BANK14", "L3 HIT L3BANK14",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L3_HIT_L3BANK15", "L3 HIT L3BANK15",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114b2040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114c2001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116c2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0b0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f2b0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x136b0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f2c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x136c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204e600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055508, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02060021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aad9, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114c2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116c2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x072b0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b6b0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x072c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b6c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004e600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055508, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aad9, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x420304e4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030e01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt8MetricSet::CExt8MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt8MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L3_HIT_L3BANK16", "L3 HIT L3BANK16",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L3_HIT_L3BANK17", "L3 HIT L3BANK17",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L3_HIT_L3BANK18", "L3 HIT L3BANK18",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L3_HIT_L3BANK19", "L3 HIT L3BANK19",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L3_HIT_L3BANK20", "L3 HIT L3BANK20",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L3_HIT_L3BANK21", "L3 HIT L3BANK21",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L3_HIT_L3BANK22", "L3 HIT L3BANK22",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L3_HIT_L3BANK23", "L3 HIT L3BANK23",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L3_HIT_L3BANK24", "L3 HIT L3BANK24",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L3_HIT_L3BANK25", "L3 HIT L3BANK25",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L3_HIT_L3BANK26", "L3 HIT L3BANK26",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L3_HIT_L3BANK27", "L3 HIT L3BANK27",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L3_HIT_L3BANK28", "L3 HIT L3BANK28",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L3_HIT_L3BANK29", "L3 HIT L3BANK29",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L3_HIT_L3BANK30", "L3 HIT L3BANK30",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "L3_HIT_L3BANK31", "L3 HIT L3BANK31",
                          "Number of L3 accesses which hits in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114c2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116c2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x072b0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b6b0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x072c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b6c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004e600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055508, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aad9, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114b2040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114c2001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116c2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0b0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f2b0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x136b0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f2c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x136c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204e600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055508, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02060021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aad9, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x420304e4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030e01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt9MetricSet::CExt9MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt9MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK0", "L3 BANK INPUT AVAILABLE L3BANK0",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK1", "L3 BANK INPUT AVAILABLE L3BANK1",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK2", "L3 BANK INPUT AVAILABLE L3BANK2",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK3", "L3 BANK INPUT AVAILABLE L3BANK3",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK4", "L3 BANK INPUT AVAILABLE L3BANK4",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK5", "L3 BANK INPUT AVAILABLE L3BANK5",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK6", "L3 BANK INPUT AVAILABLE L3BANK6",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK7", "L3 BANK INPUT AVAILABLE L3BANK7",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK8", "L3 BANK INPUT AVAILABLE L3BANK8",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK9", "L3 BANK INPUT AVAILABLE L3BANK9",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK10", "L3 BANK INPUT AVAILABLE L3BANK10",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK11", "L3 BANK INPUT AVAILABLE L3BANK11",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK12", "L3 BANK INPUT AVAILABLE L3BANK12",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK13", "L3 BANK INPUT AVAILABLE L3BANK13",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK14", "L3 BANK INPUT AVAILABLE L3BANK14",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK15", "L3 BANK INPUT AVAILABLE L3BANK15",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b1007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c11c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030e01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt10MetricSet::CExt10MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt10MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK16", "L3 BANK INPUT AVAILABLE L3BANK16",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK17", "L3 BANK INPUT AVAILABLE L3BANK17",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK18", "L3 BANK INPUT AVAILABLE L3BANK18",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK19", "L3 BANK INPUT AVAILABLE L3BANK19",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK20", "L3 BANK INPUT AVAILABLE L3BANK20",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK21", "L3 BANK INPUT AVAILABLE L3BANK21",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK22", "L3 BANK INPUT AVAILABLE L3BANK22",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK23", "L3 BANK INPUT AVAILABLE L3BANK23",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK24", "L3 BANK INPUT AVAILABLE L3BANK24",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK25", "L3 BANK INPUT AVAILABLE L3BANK25",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK26", "L3 BANK INPUT AVAILABLE L3BANK26",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK27", "L3 BANK INPUT AVAILABLE L3BANK27",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK28", "L3 BANK INPUT AVAILABLE L3BANK28",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK29", "L3 BANK INPUT AVAILABLE L3BANK29",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK30", "L3 BANK INPUT AVAILABLE L3BANK30",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_INPUT_AVAILABLE_L3BANK31", "L3 BANK INPUT AVAILABLE L3BANK31",
                          "Percentage of time in which L3 bank has input requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b1007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c11c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030e01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt11MetricSet::CExt11MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt11MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK0", "L3 OUTPUT READY L3BANK0",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK1", "L3 OUTPUT READY L3BANK1",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK2", "L3 OUTPUT READY L3BANK2",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK3", "L3 OUTPUT READY L3BANK3",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK4", "L3 OUTPUT READY L3BANK4",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK5", "L3 OUTPUT READY L3BANK5",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK6", "L3 OUTPUT READY L3BANK6",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK7", "L3 OUTPUT READY L3BANK7",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK8", "L3 OUTPUT READY L3BANK8",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK9", "L3 OUTPUT READY L3BANK9",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK10", "L3 OUTPUT READY L3BANK10",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK11", "L3 OUTPUT READY L3BANK11",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK12", "L3 OUTPUT READY L3BANK12",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK13", "L3 OUTPUT READY L3BANK13",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK14", "L3 OUTPUT READY L3BANK14",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK15", "L3 OUTPUT READY L3BANK15",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b1006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c1180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030e01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt12MetricSet::CExt12MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt12MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK16", "L3 OUTPUT READY L3BANK16",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK17", "L3 OUTPUT READY L3BANK17",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK18", "L3 OUTPUT READY L3BANK18",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK19", "L3 OUTPUT READY L3BANK19",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK20", "L3 OUTPUT READY L3BANK20",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK21", "L3 OUTPUT READY L3BANK21",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK22", "L3 OUTPUT READY L3BANK22",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK23", "L3 OUTPUT READY L3BANK23",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK24", "L3 OUTPUT READY L3BANK24",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK25", "L3 OUTPUT READY L3BANK25",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK26", "L3 OUTPUT READY L3BANK26",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK27", "L3 OUTPUT READY L3BANK27",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK28", "L3 OUTPUT READY L3BANK28",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK29", "L3 OUTPUT READY L3BANK29",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK30", "L3 OUTPUT READY L3BANK30",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_OUTPUT_READY_L3BANK31", "L3 OUTPUT READY L3BANK31",
                          "Percentage of time in which L3 bank has output ready",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b1006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c1180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030e01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt13MetricSet::CExt13MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt13MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_BUSY_L3BANK0", "L3 BANK ACTIVE L3BANK0",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_BUSY_L3BANK1", "L3 BANK ACTIVE L3BANK1",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_BUSY_L3BANK2", "L3 BANK ACTIVE L3BANK2",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_BUSY_L3BANK3", "L3 BANK ACTIVE L3BANK3",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_BUSY_L3BANK4", "L3 BANK ACTIVE L3BANK4",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_BUSY_L3BANK5", "L3 BANK ACTIVE L3BANK5",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_BUSY_L3BANK6", "L3 BANK ACTIVE L3BANK6",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_BUSY_L3BANK7", "L3 BANK ACTIVE L3BANK7",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_BUSY_L3BANK8", "L3 BANK ACTIVE L3BANK8",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_BUSY_L3BANK9", "L3 BANK ACTIVE L3BANK9",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_BUSY_L3BANK10", "L3 BANK ACTIVE L3BANK10",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_BUSY_L3BANK11", "L3 BANK ACTIVE L3BANK11",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_BUSY_L3BANK12", "L3 BANK ACTIVE L3BANK12",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_BUSY_L3BANK13", "L3 BANK ACTIVE L3BANK13",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_BUSY_L3BANK14", "L3 BANK ACTIVE L3BANK14",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_BUSY_L3BANK15", "L3 BANK ACTIVE L3BANK15",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030e01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt14MetricSet::CExt14MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt14MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_BUSY_L3BANK16", "L3 BANK ACTIVE L3BANK16",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_BUSY_L3BANK17", "L3 BANK ACTIVE L3BANK17",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_BUSY_L3BANK18", "L3 BANK ACTIVE L3BANK18",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_BUSY_L3BANK19", "L3 BANK ACTIVE L3BANK19",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_BUSY_L3BANK20", "L3 BANK ACTIVE L3BANK20",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_BUSY_L3BANK21", "L3 BANK ACTIVE L3BANK21",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_BUSY_L3BANK22", "L3 BANK ACTIVE L3BANK22",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_BUSY_L3BANK23", "L3 BANK ACTIVE L3BANK23",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_BUSY_L3BANK24", "L3 BANK ACTIVE L3BANK24",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_BUSY_L3BANK25", "L3 BANK ACTIVE L3BANK25",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_BUSY_L3BANK26", "L3 BANK ACTIVE L3BANK26",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_BUSY_L3BANK27", "L3 BANK ACTIVE L3BANK27",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_BUSY_L3BANK28", "L3 BANK ACTIVE L3BANK28",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_BUSY_L3BANK29", "L3 BANK ACTIVE L3BANK29",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_BUSY_L3BANK30", "L3 BANK ACTIVE L3BANK30",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_BUSY_L3BANK31", "L3 BANK ACTIVE L3BANK31",
                          "Percentage of time in which L3 request queue has one or more requests pending",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030e01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt15MetricSet::CExt15MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt15MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_STALL_L3BANK0", "L3 BANK STALL L3BANK0",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_STALL_L3BANK1", "L3 BANK STALL L3BANK1",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_STALL_L3BANK2", "L3 BANK STALL L3BANK2",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_STALL_L3BANK3", "L3 BANK STALL L3BANK3",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_STALL_L3BANK4", "L3 BANK STALL L3BANK4",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b1001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d2b0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f2b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c0042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2c0042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d2c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114c0042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x134c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02042a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0006a015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02060002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000701c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00085a95, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082afd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000901c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032941, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x440300e7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x10800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000038, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x000001c0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000e00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00038000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00008fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt16MetricSet::CExt16MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt16MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_STALL_L3BANK5", "L3 BANK STALL L3BANK5",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_STALL_L3BANK6", "L3 BANK STALL L3BANK6",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_STALL_L3BANK7", "L3 BANK STALL L3BANK7",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_STALL_L3BANK8", "L3 BANK STALL L3BANK8",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_STALL_L3BANK9", "L3 BANK STALL L3BANK9",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c1001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x054b0042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b6b0042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x076c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002003f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004fa95, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b0042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02060054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082a54, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083ffe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030204, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031ce7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x10800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000038, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x000001c0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000e00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00038000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00008fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt17MetricSet::CExt17MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt17MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_STALL_L3BANK10", "L3 BANK STALL L3BANK10",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_STALL_L3BANK11", "L3 BANK STALL L3BANK11",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_STALL_L3BANK12", "L3 BANK STALL L3BANK12",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_STALL_L3BANK13", "L3 BANK STALL L3BANK13",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_STALL_L3BANK14", "L3 BANK STALL L3BANK14",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b1001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x072b0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d4b0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x052c0042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x072c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b4c0042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d4c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116c0042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x136c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020200fc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00035000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032a01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02042a56, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0006002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008afd5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x10800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000038, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x000001c0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000e00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00038000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00008fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt18MetricSet::CExt18MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt18MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_STALL_L3BANK15", "L3 BANK STALL L3BANK15",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_STALL_L3BANK16", "L3 BANK STALL L3BANK16",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_STALL_L3BANK17", "L3 BANK STALL L3BANK17",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_STALL_L3BANK18", "L3 BANK STALL L3BANK18",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_STALL_L3BANK19", "L3 BANK STALL L3BANK19",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x076b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004003f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c1001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x132b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d2c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f2c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0005a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020600a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070e38, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083f56, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090e38, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008003f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031292, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42031080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032529, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x10800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000038, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x000001c0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000e00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00038000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00008fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt19MetricSet::CExt19MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt19MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_STALL_L3BANK20", "L3 BANK STALL L3BANK20",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_STALL_L3BANK21", "L3 BANK STALL L3BANK21",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_STALL_L3BANK22", "L3 BANK STALL L3BANK22",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_STALL_L3BANK23", "L3 BANK STALL L3BANK23",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_STALL_L3BANK24", "L3 BANK STALL L3BANK24",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b1001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f6b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x054c0042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b6c0042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003a015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004a56a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020400fe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c0042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02061500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00077000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02081500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00097000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02022a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x10800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000038, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x000001c0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000e00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00038000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00008fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt20MetricSet::CExt20MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt20MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_STALL_L3BANK25", "L3 BANK STALL L3BANK25",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_STALL_L3BANK26", "L3 BANK STALL L3BANK26",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_STALL_L3BANK27", "L3 BANK STALL L3BANK27",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_STALL_L3BANK28", "L3 BANK STALL L3BANK28",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_STALL_L3BANK29", "L3 BANK STALL L3BANK29",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c1001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d2b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114b0042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x134b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x072c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d4c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02023f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020415a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0005002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008f56a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02022aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42031ce0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46031401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x10800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000038, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x000001c0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000e00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00038000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00008fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt21MetricSet::CExt21MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt21MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_READ_L3BANK0", "L3 READ L3BANK0",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_READ_L3BANK1", "L3 READ L3BANK1",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_READ_L3BANK2", "L3 READ L3BANK2",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_READ_L3BANK3", "L3 READ L3BANK3",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_READ_L3BANK4", "L3 READ L3BANK4",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_READ_L3BANK5", "L3 READ L3BANK5",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_READ_L3BANK6", "L3 READ L3BANK6",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_READ_L3BANK7", "L3 READ L3BANK7",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_READ_L3BANK8", "L3 READ L3BANK8",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_READ_L3BANK9", "L3 READ L3BANK9",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_READ_L3BANK10", "L3 READ L3BANK10",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_READ_L3BANK11", "L3 READ L3BANK11",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_READ_L3BANK12", "L3 READ L3BANK12",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_READ_L3BANK13", "L3 READ L3BANK13",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_READ_L3BANK14", "L3 READ L3BANK14",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_READ_L3BANK15", "L3 READ L3BANK15",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b6005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c6140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030e01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt22MetricSet::CExt22MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt22MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_READ_L3BANK16", "L3 READ L3BANK16",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_READ_L3BANK17", "L3 READ L3BANK17",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_READ_L3BANK18", "L3 READ L3BANK18",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_READ_L3BANK19", "L3 READ L3BANK19",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_READ_L3BANK20", "L3 READ L3BANK20",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_READ_L3BANK21", "L3 READ L3BANK21",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_READ_L3BANK22", "L3 READ L3BANK22",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_READ_L3BANK23", "L3 READ L3BANK23",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_READ_L3BANK24", "L3 READ L3BANK24",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_READ_L3BANK25", "L3 READ L3BANK25",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_READ_L3BANK26", "L3 READ L3BANK26",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_READ_L3BANK27", "L3 READ L3BANK27",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_READ_L3BANK28", "L3 READ L3BANK28",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_READ_L3BANK29", "L3 READ L3BANK29",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_READ_L3BANK30", "L3 READ L3BANK30",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_READ_L3BANK31", "L3 READ L3BANK31",
                          "Number of L3 read requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b6005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c6140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030e01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt23MetricSet::CExt23MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt23MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_WRITE_L3BANK0", "L3 WRITE L3BANK0",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_WRITE_L3BANK1", "L3 WRITE L3BANK1",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_WRITE_L3BANK2", "L3 WRITE L3BANK2",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_WRITE_L3BANK3", "L3 WRITE L3BANK3",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_WRITE_L3BANK4", "L3 WRITE L3BANK4",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_WRITE_L3BANK5", "L3 WRITE L3BANK5",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_WRITE_L3BANK6", "L3 WRITE L3BANK6",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_WRITE_L3BANK7", "L3 WRITE L3BANK7",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_WRITE_L3BANK8", "L3 WRITE L3BANK8",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_WRITE_L3BANK9", "L3 WRITE L3BANK9",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_WRITE_L3BANK10", "L3 WRITE L3BANK10",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_WRITE_L3BANK11", "L3 WRITE L3BANK11",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_WRITE_L3BANK12", "L3 WRITE L3BANK12",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_WRITE_L3BANK13", "L3 WRITE L3BANK13",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_WRITE_L3BANK14", "L3 WRITE L3BANK14",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_WRITE_L3BANK15", "L3 WRITE L3BANK15",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b1005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c1140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030e01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt24MetricSet::CExt24MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt24MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_WRITE_L3BANK16", "L3 WRITE L3BANK16",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_WRITE_L3BANK17", "L3 WRITE L3BANK17",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_WRITE_L3BANK18", "L3 WRITE L3BANK18",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_WRITE_L3BANK19", "L3 WRITE L3BANK19",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_WRITE_L3BANK20", "L3 WRITE L3BANK20",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_WRITE_L3BANK21", "L3 WRITE L3BANK21",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_WRITE_L3BANK22", "L3 WRITE L3BANK22",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_WRITE_L3BANK23", "L3 WRITE L3BANK23",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_WRITE_L3BANK24", "L3 WRITE L3BANK24",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_WRITE_L3BANK25", "L3 WRITE L3BANK25",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_WRITE_L3BANK26", "L3 WRITE L3BANK26",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_WRITE_L3BANK27", "L3 WRITE L3BANK27",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_WRITE_L3BANK28", "L3 WRITE L3BANK28",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_WRITE_L3BANK29", "L3 WRITE L3BANK29",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_WRITE_L3BANK30", "L3 WRITE L3BANK30",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_WRITE_L3BANK31", "L3 WRITE L3BANK31",
                          "Number of L3 write requests",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b1005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c1140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030e01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt27MetricSet::CExt27MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt27MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_MISS_L3BANK0", "L3 MISS L3BANK0",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_MISS_L3BANK1", "L3 MISS L3BANK1",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_MISS_L3BANK2", "L3 MISS L3BANK2",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_MISS_L3BANK3", "L3 MISS L3BANK3",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_MISS_L3BANK4", "L3 MISS L3BANK4",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_MISS_L3BANK5", "L3 MISS L3BANK5",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_MISS_L3BANK6", "L3 MISS L3BANK6",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_MISS_L3BANK7", "L3 MISS L3BANK7",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_MISS_L3BANK8", "L3 MISS L3BANK8",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_MISS_L3BANK9", "L3 MISS L3BANK9",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_MISS_L3BANK10", "L3 MISS L3BANK10",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_MISS_L3BANK11", "L3 MISS L3BANK11",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_MISS_L3BANK12", "L3 MISS L3BANK12",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_MISS_L3BANK13", "L3 MISS L3BANK13",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_MISS_L3BANK14", "L3 MISS L3BANK14",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_MISS_L3BANK15", "L3 MISS L3BANK15",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b2002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c2080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114c2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116c2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114c2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116c2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030e01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt28MetricSet::CExt28MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt28MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_MISS_L3BANK16", "L3 MISS L3BANK16",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_MISS_L3BANK17", "L3 MISS L3BANK17",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_MISS_L3BANK18", "L3 MISS L3BANK18",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_MISS_L3BANK19", "L3 MISS L3BANK19",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_MISS_L3BANK20", "L3 MISS L3BANK20",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_MISS_L3BANK21", "L3 MISS L3BANK21",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_MISS_L3BANK22", "L3 MISS L3BANK22",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_MISS_L3BANK23", "L3 MISS L3BANK23",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_MISS_L3BANK24", "L3 MISS L3BANK24",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_MISS_L3BANK25", "L3 MISS L3BANK25",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_MISS_L3BANK26", "L3 MISS L3BANK26",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_MISS_L3BANK27", "L3 MISS L3BANK27",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_MISS_L3BANK28", "L3 MISS L3BANK28",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_MISS_L3BANK29", "L3 MISS L3BANK29",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_MISS_L3BANK30", "L3 MISS L3BANK30",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_MISS_L3BANK31", "L3 MISS L3BANK31",
                          "Number of L3 accesses which miss in the L3 cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b2002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c2080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114c2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116c2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114c2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116c2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030e01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt29MetricSet::CExt29MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt29MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK0", "DATAPORT L3 READ L3BANK0",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK1", "DATAPORT L3 READ L3BANK1",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK2", "DATAPORT L3 READ L3BANK2",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK3", "DATAPORT L3 READ L3BANK3",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK4", "DATAPORT L3 READ L3BANK4",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK5", "DATAPORT L3 READ L3BANK5",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK6", "DATAPORT L3 READ L3BANK6",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK7", "DATAPORT L3 READ L3BANK7",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK8", "DATAPORT L3 READ L3BANK8",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK9", "DATAPORT L3 READ L3BANK9",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK10", "DATAPORT L3 READ L3BANK10",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK11", "DATAPORT L3 READ L3BANK11",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK12", "DATAPORT L3 READ L3BANK12",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK13", "DATAPORT L3 READ L3BANK13",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK14", "DATAPORT L3 READ L3BANK14",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK15", "DATAPORT L3 READ L3BANK15",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030e01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt30MetricSet::CExt30MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt30MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK16", "DATAPORT L3 READ L3BANK16",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK17", "DATAPORT L3 READ L3BANK17",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK18", "DATAPORT L3 READ L3BANK18",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK19", "DATAPORT L3 READ L3BANK19",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK20", "DATAPORT L3 READ L3BANK20",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK21", "DATAPORT L3 READ L3BANK21",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK22", "DATAPORT L3 READ L3BANK22",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK23", "DATAPORT L3 READ L3BANK23",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK24", "DATAPORT L3 READ L3BANK24",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK25", "DATAPORT L3 READ L3BANK25",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK26", "DATAPORT L3 READ L3BANK26",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK27", "DATAPORT L3 READ L3BANK27",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK28", "DATAPORT L3 READ L3BANK28",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK29", "DATAPORT L3 READ L3BANK29",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK30", "DATAPORT L3 READ L3BANK30",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_READ_L3BANK31", "DATAPORT L3 READ L3BANK31",
                          "Number of L3 read requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030e01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt31MetricSet::CExt31MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt31MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK0", "DATAPORT L3 WRITE L3BANK0",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK1", "DATAPORT L3 WRITE L3BANK1",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK2", "DATAPORT L3 WRITE L3BANK2",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK3", "DATAPORT L3 WRITE L3BANK3",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK4", "DATAPORT L3 WRITE L3BANK4",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK5", "DATAPORT L3 WRITE L3BANK5",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK6", "DATAPORT L3 WRITE L3BANK6",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK7", "DATAPORT L3 WRITE L3BANK7",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK8", "DATAPORT L3 WRITE L3BANK8",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK9", "DATAPORT L3 WRITE L3BANK9",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK10", "DATAPORT L3 WRITE L3BANK10",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK11", "DATAPORT L3 WRITE L3BANK11",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK12", "DATAPORT L3 WRITE L3BANK12",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK13", "DATAPORT L3 WRITE L3BANK13",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK14", "DATAPORT L3 WRITE L3BANK14",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK15", "DATAPORT L3 WRITE L3BANK15",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c00c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c00c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c00c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c00c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c00c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c00c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c00c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c00c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030e01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt32MetricSet::CExt32MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt32MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK16", "DATAPORT L3 WRITE L3BANK16",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK17", "DATAPORT L3 WRITE L3BANK17",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK18", "DATAPORT L3 WRITE L3BANK18",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK19", "DATAPORT L3 WRITE L3BANK19",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK20", "DATAPORT L3 WRITE L3BANK20",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK21", "DATAPORT L3 WRITE L3BANK21",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK22", "DATAPORT L3 WRITE L3BANK22",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK23", "DATAPORT L3 WRITE L3BANK23",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK24", "DATAPORT L3 WRITE L3BANK24",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK25", "DATAPORT L3 WRITE L3BANK25",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK26", "DATAPORT L3 WRITE L3BANK26",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK27", "DATAPORT L3 WRITE L3BANK27",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK28", "DATAPORT L3 WRITE L3BANK28",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK29", "DATAPORT L3 WRITE L3BANK29",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK30", "DATAPORT L3 WRITE L3BANK30",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_WRITE_L3BANK31", "DATAPORT L3 WRITE L3BANK31",
                          "Number of L3 write requests coming from XVE via Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c00c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c00c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c00c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c00c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c00c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c00c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c00c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c00c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030e01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt33MetricSet::CExt33MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt33MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK0", "ICACHE L3 READ L3BANK0",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK1", "ICACHE L3 READ L3BANK1",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK2", "ICACHE L3 READ L3BANK2",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK3", "ICACHE L3 READ L3BANK3",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK4", "ICACHE L3 READ L3BANK4",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK5", "ICACHE L3 READ L3BANK5",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK6", "ICACHE L3 READ L3BANK6",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK7", "ICACHE L3 READ L3BANK7",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK8", "ICACHE L3 READ L3BANK8",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK9", "ICACHE L3 READ L3BANK9",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK10", "ICACHE L3 READ L3BANK10",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK11", "ICACHE L3 READ L3BANK11",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK12", "ICACHE L3 READ L3BANK12",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK13", "ICACHE L3 READ L3BANK13",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK14", "ICACHE L3 READ L3BANK14",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK15", "ICACHE L3 READ L3BANK15",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030e01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt34MetricSet::CExt34MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt34MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK16", "ICACHE L3 READ L3BANK16",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK17", "ICACHE L3 READ L3BANK17",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK18", "ICACHE L3 READ L3BANK18",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK19", "ICACHE L3 READ L3BANK19",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK20", "ICACHE L3 READ L3BANK20",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK21", "ICACHE L3 READ L3BANK21",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK22", "ICACHE L3 READ L3BANK22",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK23", "ICACHE L3 READ L3BANK23",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK24", "ICACHE L3 READ L3BANK24",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK25", "ICACHE L3 READ L3BANK25",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK26", "ICACHE L3 READ L3BANK26",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK27", "ICACHE L3 READ L3BANK27",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK28", "ICACHE L3 READ L3BANK28",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK29", "ICACHE L3 READ L3BANK29",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK30", "ICACHE L3 READ L3BANK30",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_READ_L3BANK31", "ICACHE L3 READ L3BANK31",
                          "Number of L3 read requests coming from XVE Instruction Cache",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c01c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030e01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt35MetricSet::CExt35MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt35MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK0", "L3 ATOMIC ACCESS L3BANK0",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK1", "L3 ATOMIC ACCESS L3BANK1",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK2", "L3 ATOMIC ACCESS L3BANK2",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK3", "L3 ATOMIC ACCESS L3BANK3",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK4", "L3 ATOMIC ACCESS L3BANK4",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK5", "L3 ATOMIC ACCESS L3BANK5",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK6", "L3 ATOMIC ACCESS L3BANK6",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK7", "L3 ATOMIC ACCESS L3BANK7",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK8", "L3 ATOMIC ACCESS L3BANK8",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK9", "L3 ATOMIC ACCESS L3BANK9",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK10", "L3 ATOMIC ACCESS L3BANK10",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK11", "L3 ATOMIC ACCESS L3BANK11",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK12", "L3 ATOMIC ACCESS L3BANK12",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK13", "L3 ATOMIC ACCESS L3BANK13",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK14", "L3 ATOMIC ACCESS L3BANK14",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK15", "L3 ATOMIC ACCESS L3BANK15",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b1004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c1100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030e01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt36MetricSet::CExt36MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt36MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK16", "L3 ATOMIC ACCESS L3BANK16",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK17", "L3 ATOMIC ACCESS L3BANK17",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK18", "L3 ATOMIC ACCESS L3BANK18",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK19", "L3 ATOMIC ACCESS L3BANK19",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK20", "L3 ATOMIC ACCESS L3BANK20",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK21", "L3 ATOMIC ACCESS L3BANK21",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK22", "L3 ATOMIC ACCESS L3BANK22",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK23", "L3 ATOMIC ACCESS L3BANK23",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK24", "L3 ATOMIC ACCESS L3BANK24",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK25", "L3 ATOMIC ACCESS L3BANK25",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK26", "L3 ATOMIC ACCESS L3BANK26",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK27", "L3 ATOMIC ACCESS L3BANK27",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK28", "L3 ATOMIC ACCESS L3BANK28",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK29", "L3 ATOMIC ACCESS L3BANK29",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK30", "L3 ATOMIC ACCESS L3BANK30",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_ATOMIC_ACCESS_L3BANK31", "L3 ATOMIC ACCESS L3BANK31",
                          "Number of atomic accesses to L3 bank",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b1004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c1100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030e01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt37MetricSet::CExt37MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt37MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_READ_L3BANK0", "SAMPLER L3 READ L3BANK0",
                          "Number of L3 read requests resulting from sampler local cache miss",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_READ_L3BANK1", "SAMPLER L3 READ L3BANK1",
                          "Number of L3 read requests resulting from sampler local cache miss",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_READ_L3BANK2", "SAMPLER L3 READ L3BANK2",
                          "Number of L3 read requests resulting from sampler local cache miss",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_READ_L3BANK3", "SAMPLER L3 READ L3BANK3",
                          "Number of L3 read requests resulting from sampler local cache miss",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_READ_L3BANK4", "SAMPLER L3 READ L3BANK4",
                          "Number of L3 read requests resulting from sampler local cache miss",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_READ_L3BANK5", "SAMPLER L3 READ L3BANK5",
                          "Number of L3 read requests resulting from sampler local cache miss",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_READ_L3BANK6", "SAMPLER L3 READ L3BANK6",
                          "Number of L3 read requests resulting from sampler local cache miss",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_READ_L3BANK7", "SAMPLER L3 READ L3BANK7",
                          "Number of L3 read requests resulting from sampler local cache miss",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_READ_L3BANK8", "SAMPLER L3 READ L3BANK8",
                          "Number of L3 read requests resulting from sampler local cache miss",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_READ_L3BANK9", "SAMPLER L3 READ L3BANK9",
                          "Number of L3 read requests resulting from sampler local cache miss",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_READ_L3BANK10", "SAMPLER L3 READ L3BANK10",
                          "Number of L3 read requests resulting from sampler local cache miss",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_READ_L3BANK11", "SAMPLER L3 READ L3BANK11",
                          "Number of L3 read requests resulting from sampler local cache miss",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_READ_L3BANK12", "SAMPLER L3 READ L3BANK12",
                          "Number of L3 read requests resulting from sampler local cache miss",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_READ_L3BANK13", "SAMPLER L3 READ L3BANK13",
                          "Number of L3 read requests resulting from sampler local cache miss",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_READ_L3BANK14", "SAMPLER L3 READ L3BANK14",
                          "Number of L3 read requests resulting from sampler local cache miss",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_READ_L3BANK15", "SAMPLER L3 READ L3BANK15",
                          "Number of L3 read requests resulting from sampler local cache miss",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030e01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt38MetricSet::CExt38MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt38MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_READ_L3BANK16", "SAMPLER L3 READ L3BANK16",
                          "Number of L3 read requests resulting from sampler local cache miss",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_READ_L3BANK17", "SAMPLER L3 READ L3BANK17",
                          "Number of L3 read requests resulting from sampler local cache miss",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_READ_L3BANK18", "SAMPLER L3 READ L3BANK18",
                          "Number of L3 read requests resulting from sampler local cache miss",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_READ_L3BANK19", "SAMPLER L3 READ L3BANK19",
                          "Number of L3 read requests resulting from sampler local cache miss",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_READ_L3BANK20", "SAMPLER L3 READ L3BANK20",
                          "Number of L3 read requests resulting from sampler local cache miss",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_READ_L3BANK21", "SAMPLER L3 READ L3BANK21",
                          "Number of L3 read requests resulting from sampler local cache miss",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_READ_L3BANK22", "SAMPLER L3 READ L3BANK22",
                          "Number of L3 read requests resulting from sampler local cache miss",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_READ_L3BANK23", "SAMPLER L3 READ L3BANK23",
                          "Number of L3 read requests resulting from sampler local cache miss",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_READ_L3BANK24", "SAMPLER L3 READ L3BANK24",
                          "Number of L3 read requests resulting from sampler local cache miss",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_READ_L3BANK25", "SAMPLER L3 READ L3BANK25",
                          "Number of L3 read requests resulting from sampler local cache miss",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_READ_L3BANK26", "SAMPLER L3 READ L3BANK26",
                          "Number of L3 read requests resulting from sampler local cache miss",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_READ_L3BANK27", "SAMPLER L3 READ L3BANK27",
                          "Number of L3 read requests resulting from sampler local cache miss",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_READ_L3BANK28", "SAMPLER L3 READ L3BANK28",
                          "Number of L3 read requests resulting from sampler local cache miss",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_READ_L3BANK29", "SAMPLER L3 READ L3BANK29",
                          "Number of L3 read requests resulting from sampler local cache miss",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_READ_L3BANK30", "SAMPLER L3 READ L3BANK30",
                          "Number of L3 read requests resulting from sampler local cache miss",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_READ_L3BANK31", "SAMPLER L3 READ L3BANK31",
                          "Number of L3 read requests resulting from sampler local cache miss",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x094c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c0180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030e01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt39MetricSet::CExt39MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt39MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "COLOR_L3_HIT_L3BANK0", "COLOR L3 HIT L3BANK0",
                          "Number of L3 read requests resulting from color local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "COLOR_L3_HIT_L3BANK1", "COLOR L3 HIT L3BANK1",
                          "Number of L3 read requests resulting from color local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "COLOR_L3_HIT_L3BANK2", "COLOR L3 HIT L3BANK2",
                          "Number of L3 read requests resulting from color local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "COLOR_L3_HIT_L3BANK3", "COLOR L3 HIT L3BANK3",
                          "Number of L3 read requests resulting from color local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "COLOR_L3_HIT_L3BANK4", "COLOR L3 HIT L3BANK4",
                          "Number of L3 read requests resulting from color local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "COLOR_L3_HIT_L3BANK5", "COLOR L3 HIT L3BANK5",
                          "Number of L3 read requests resulting from color local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "COLOR_L3_HIT_L3BANK6", "COLOR L3 HIT L3BANK6",
                          "Number of L3 read requests resulting from color local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "COLOR_L3_HIT_L3BANK7", "COLOR L3 HIT L3BANK7",
                          "Number of L3 read requests resulting from color local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "COLOR_L3_HIT_L3BANK8", "COLOR L3 HIT L3BANK8",
                          "Number of L3 read requests resulting from color local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "COLOR_L3_HIT_L3BANK9", "COLOR L3 HIT L3BANK9",
                          "Number of L3 read requests resulting from color local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "COLOR_L3_HIT_L3BANK10", "COLOR L3 HIT L3BANK10",
                          "Number of L3 read requests resulting from color local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "COLOR_L3_HIT_L3BANK11", "COLOR L3 HIT L3BANK11",
                          "Number of L3 read requests resulting from color local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "COLOR_L3_HIT_L3BANK12", "COLOR L3 HIT L3BANK12",
                          "Number of L3 read requests resulting from color local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "COLOR_L3_HIT_L3BANK13", "COLOR L3 HIT L3BANK13",
                          "Number of L3 read requests resulting from color local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "COLOR_L3_HIT_L3BANK14", "COLOR L3 HIT L3BANK14",
                          "Number of L3 read requests resulting from color local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "COLOR_L3_HIT_L3BANK15", "COLOR L3 HIT L3BANK15",
                          "Number of L3 read requests resulting from color local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030e01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt40MetricSet::CExt40MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt40MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "COLOR_L3_HIT_L3BANK16", "COLOR L3 HIT L3BANK16",
                          "Number of L3 read requests resulting from color local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "COLOR_L3_HIT_L3BANK17", "COLOR L3 HIT L3BANK17",
                          "Number of L3 read requests resulting from color local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "COLOR_L3_HIT_L3BANK18", "COLOR L3 HIT L3BANK18",
                          "Number of L3 read requests resulting from color local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "COLOR_L3_HIT_L3BANK19", "COLOR L3 HIT L3BANK19",
                          "Number of L3 read requests resulting from color local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "COLOR_L3_HIT_L3BANK20", "COLOR L3 HIT L3BANK20",
                          "Number of L3 read requests resulting from color local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "COLOR_L3_HIT_L3BANK21", "COLOR L3 HIT L3BANK21",
                          "Number of L3 read requests resulting from color local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "COLOR_L3_HIT_L3BANK22", "COLOR L3 HIT L3BANK22",
                          "Number of L3 read requests resulting from color local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "COLOR_L3_HIT_L3BANK23", "COLOR L3 HIT L3BANK23",
                          "Number of L3 read requests resulting from color local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "COLOR_L3_HIT_L3BANK24", "COLOR L3 HIT L3BANK24",
                          "Number of L3 read requests resulting from color local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "COLOR_L3_HIT_L3BANK25", "COLOR L3 HIT L3BANK25",
                          "Number of L3 read requests resulting from color local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "COLOR_L3_HIT_L3BANK26", "COLOR L3 HIT L3BANK26",
                          "Number of L3 read requests resulting from color local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "COLOR_L3_HIT_L3BANK27", "COLOR L3 HIT L3BANK27",
                          "Number of L3 read requests resulting from color local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "COLOR_L3_HIT_L3BANK28", "COLOR L3 HIT L3BANK28",
                          "Number of L3 read requests resulting from color local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "COLOR_L3_HIT_L3BANK29", "COLOR L3 HIT L3BANK29",
                          "Number of L3 read requests resulting from color local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "COLOR_L3_HIT_L3BANK30", "COLOR L3 HIT L3BANK30",
                          "Number of L3 read requests resulting from color local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "COLOR_L3_HIT_L3BANK31", "COLOR L3 HIT L3BANK31",
                          "Number of L3 read requests resulting from color local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030e01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt41MetricSet::CExt41MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt41MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK0", "DATAPORT L3 HIT L3BANK0",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK1", "DATAPORT L3 HIT L3BANK1",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK2", "DATAPORT L3 HIT L3BANK2",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK3", "DATAPORT L3 HIT L3BANK3",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK4", "DATAPORT L3 HIT L3BANK4",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK5", "DATAPORT L3 HIT L3BANK5",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK6", "DATAPORT L3 HIT L3BANK6",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK7", "DATAPORT L3 HIT L3BANK7",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK8", "DATAPORT L3 HIT L3BANK8",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK9", "DATAPORT L3 HIT L3BANK9",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK10", "DATAPORT L3 HIT L3BANK10",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK11", "DATAPORT L3 HIT L3BANK11",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK12", "DATAPORT L3 HIT L3BANK12",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK13", "DATAPORT L3 HIT L3BANK13",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK14", "DATAPORT L3 HIT L3BANK14",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK15", "DATAPORT L3 HIT L3BANK15",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030e01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt42MetricSet::CExt42MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt42MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK16", "DATAPORT L3 HIT L3BANK16",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK17", "DATAPORT L3 HIT L3BANK17",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK18", "DATAPORT L3 HIT L3BANK18",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK19", "DATAPORT L3 HIT L3BANK19",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK20", "DATAPORT L3 HIT L3BANK20",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK21", "DATAPORT L3 HIT L3BANK21",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK22", "DATAPORT L3 HIT L3BANK22",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK23", "DATAPORT L3 HIT L3BANK23",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK24", "DATAPORT L3 HIT L3BANK24",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK25", "DATAPORT L3 HIT L3BANK25",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK26", "DATAPORT L3 HIT L3BANK26",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK27", "DATAPORT L3 HIT L3BANK27",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK28", "DATAPORT L3 HIT L3BANK28",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK29", "DATAPORT L3 HIT L3BANK29",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK30", "DATAPORT L3 HIT L3BANK30",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "DATAPORT_L3_HIT_L3BANK31", "DATAPORT L3 HIT L3BANK31",
                          "Number of L3 hits for requests coming from the Dataport",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030e01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt43MetricSet::CExt43MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt43MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK0", "ICACHE L3 HIT L3BANK0",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK1", "ICACHE L3 HIT L3BANK1",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK2", "ICACHE L3 HIT L3BANK2",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK3", "ICACHE L3 HIT L3BANK3",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK4", "ICACHE L3 HIT L3BANK4",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK5", "ICACHE L3 HIT L3BANK5",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK6", "ICACHE L3 HIT L3BANK6",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK7", "ICACHE L3 HIT L3BANK7",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK8", "ICACHE L3 HIT L3BANK8",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK9", "ICACHE L3 HIT L3BANK9",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK10", "ICACHE L3 HIT L3BANK10",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK11", "ICACHE L3 HIT L3BANK11",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK12", "ICACHE L3 HIT L3BANK12",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK13", "ICACHE L3 HIT L3BANK13",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK14", "ICACHE L3 HIT L3BANK14",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK15", "ICACHE L3 HIT L3BANK15",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030e01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt44MetricSet::CExt44MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt44MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK16", "ICACHE L3 HIT L3BANK16",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK17", "ICACHE L3 HIT L3BANK17",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK18", "ICACHE L3 HIT L3BANK18",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK19", "ICACHE L3 HIT L3BANK19",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK20", "ICACHE L3 HIT L3BANK20",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK21", "ICACHE L3 HIT L3BANK21",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK22", "ICACHE L3 HIT L3BANK22",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK23", "ICACHE L3 HIT L3BANK23",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK24", "ICACHE L3 HIT L3BANK24",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK25", "ICACHE L3 HIT L3BANK25",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK26", "ICACHE L3 HIT L3BANK26",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK27", "ICACHE L3 HIT L3BANK27",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK28", "ICACHE L3 HIT L3BANK28",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK29", "ICACHE L3 HIT L3BANK29",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK30", "ICACHE L3 HIT L3BANK30",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "ICACHE_L3_HIT_L3BANK31", "ICACHE L3 HIT L3BANK31",
                          "Number of XVE instruction cache requests that hit the L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030e01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt45MetricSet::CExt45MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt45MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_HIT_L3BANK0", "SAMPLER L3 HIT L3BANK0",
                          "Number of L3 hit requests resulting from sampler local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_HIT_L3BANK1", "SAMPLER L3 HIT L3BANK1",
                          "Number of L3 hit requests resulting from sampler local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_HIT_L3BANK2", "SAMPLER L3 HIT L3BANK2",
                          "Number of L3 hit requests resulting from sampler local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_HIT_L3BANK3", "SAMPLER L3 HIT L3BANK3",
                          "Number of L3 hit requests resulting from sampler local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_HIT_L3BANK4", "SAMPLER L3 HIT L3BANK4",
                          "Number of L3 hit requests resulting from sampler local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_HIT_L3BANK5", "SAMPLER L3 HIT L3BANK5",
                          "Number of L3 hit requests resulting from sampler local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_HIT_L3BANK6", "SAMPLER L3 HIT L3BANK6",
                          "Number of L3 hit requests resulting from sampler local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_HIT_L3BANK7", "SAMPLER L3 HIT L3BANK7",
                          "Number of L3 hit requests resulting from sampler local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_HIT_L3BANK8", "SAMPLER L3 HIT L3BANK8",
                          "Number of L3 hit requests resulting from sampler local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_HIT_L3BANK9", "SAMPLER L3 HIT L3BANK9",
                          "Number of L3 hit requests resulting from sampler local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_HIT_L3BANK10", "SAMPLER L3 HIT L3BANK10",
                          "Number of L3 hit requests resulting from sampler local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_HIT_L3BANK11", "SAMPLER L3 HIT L3BANK11",
                          "Number of L3 hit requests resulting from sampler local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_HIT_L3BANK12", "SAMPLER L3 HIT L3BANK12",
                          "Number of L3 hit requests resulting from sampler local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_HIT_L3BANK13", "SAMPLER L3 HIT L3BANK13",
                          "Number of L3 hit requests resulting from sampler local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_HIT_L3BANK14", "SAMPLER L3 HIT L3BANK14",
                          "Number of L3 hit requests resulting from sampler local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_HIT_L3BANK15", "SAMPLER L3 HIT L3BANK15",
                          "Number of L3 hit requests resulting from sampler local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030e01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt46MetricSet::CExt46MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt46MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_HIT_L3BANK16", "SAMPLER L3 HIT L3BANK16",
                          "Number of L3 hit requests resulting from sampler local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_HIT_L3BANK17", "SAMPLER L3 HIT L3BANK17",
                          "Number of L3 hit requests resulting from sampler local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_HIT_L3BANK18", "SAMPLER L3 HIT L3BANK18",
                          "Number of L3 hit requests resulting from sampler local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_HIT_L3BANK19", "SAMPLER L3 HIT L3BANK19",
                          "Number of L3 hit requests resulting from sampler local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_HIT_L3BANK20", "SAMPLER L3 HIT L3BANK20",
                          "Number of L3 hit requests resulting from sampler local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_HIT_L3BANK21", "SAMPLER L3 HIT L3BANK21",
                          "Number of L3 hit requests resulting from sampler local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_HIT_L3BANK22", "SAMPLER L3 HIT L3BANK22",
                          "Number of L3 hit requests resulting from sampler local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_HIT_L3BANK23", "SAMPLER L3 HIT L3BANK23",
                          "Number of L3 hit requests resulting from sampler local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_HIT_L3BANK24", "SAMPLER L3 HIT L3BANK24",
                          "Number of L3 hit requests resulting from sampler local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_HIT_L3BANK25", "SAMPLER L3 HIT L3BANK25",
                          "Number of L3 hit requests resulting from sampler local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_HIT_L3BANK26", "SAMPLER L3 HIT L3BANK26",
                          "Number of L3 hit requests resulting from sampler local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_HIT_L3BANK27", "SAMPLER L3 HIT L3BANK27",
                          "Number of L3 hit requests resulting from sampler local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_HIT_L3BANK28", "SAMPLER L3 HIT L3BANK28",
                          "Number of L3 hit requests resulting from sampler local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_HIT_L3BANK29", "SAMPLER L3 HIT L3BANK29",
                          "Number of L3 hit requests resulting from sampler local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_HIT_L3BANK30", "SAMPLER L3 HIT L3BANK30",
                          "Number of L3 hit requests resulting from sampler local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "SAMPLER_L3_HIT_L3BANK31", "SAMPLER L3 HIT L3BANK31",
                          "Number of L3 hit requests resulting from sampler local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030e01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt47MetricSet::CExt47MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt47MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "Z_L3_HIT_L3BANK0", "Z L3 HIT L3BANK0",
                          "Number of L3 read requests resulting from Z local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "Z_L3_HIT_L3BANK1", "Z L3 HIT L3BANK1",
                          "Number of L3 read requests resulting from Z local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "Z_L3_HIT_L3BANK2", "Z L3 HIT L3BANK2",
                          "Number of L3 read requests resulting from Z local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "Z_L3_HIT_L3BANK3", "Z L3 HIT L3BANK3",
                          "Number of L3 read requests resulting from Z local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "Z_L3_HIT_L3BANK4", "Z L3 HIT L3BANK4",
                          "Number of L3 read requests resulting from Z local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "Z_L3_HIT_L3BANK5", "Z L3 HIT L3BANK5",
                          "Number of L3 read requests resulting from Z local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "Z_L3_HIT_L3BANK6", "Z L3 HIT L3BANK6",
                          "Number of L3 read requests resulting from Z local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "Z_L3_HIT_L3BANK7", "Z L3 HIT L3BANK7",
                          "Number of L3 read requests resulting from Z local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "Z_L3_HIT_L3BANK8", "Z L3 HIT L3BANK8",
                          "Number of L3 read requests resulting from Z local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "Z_L3_HIT_L3BANK9", "Z L3 HIT L3BANK9",
                          "Number of L3 read requests resulting from Z local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "Z_L3_HIT_L3BANK10", "Z L3 HIT L3BANK10",
                          "Number of L3 read requests resulting from Z local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "Z_L3_HIT_L3BANK11", "Z L3 HIT L3BANK11",
                          "Number of L3 read requests resulting from Z local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "Z_L3_HIT_L3BANK12", "Z L3 HIT L3BANK12",
                          "Number of L3 read requests resulting from Z local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "Z_L3_HIT_L3BANK13", "Z L3 HIT L3BANK13",
                          "Number of L3 read requests resulting from Z local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "Z_L3_HIT_L3BANK14", "Z L3 HIT L3BANK14",
                          "Number of L3 read requests resulting from Z local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "Z_L3_HIT_L3BANK15", "Z L3 HIT L3BANK15",
                          "Number of L3 read requests resulting from Z local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030e01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt48MetricSet::CExt48MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt48MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "Z_L3_HIT_L3BANK16", "Z L3 HIT L3BANK16",
                          "Number of L3 read requests resulting from Z local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "Z_L3_HIT_L3BANK17", "Z L3 HIT L3BANK17",
                          "Number of L3 read requests resulting from Z local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "Z_L3_HIT_L3BANK18", "Z L3 HIT L3BANK18",
                          "Number of L3 read requests resulting from Z local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "Z_L3_HIT_L3BANK19", "Z L3 HIT L3BANK19",
                          "Number of L3 read requests resulting from Z local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "Z_L3_HIT_L3BANK20", "Z L3 HIT L3BANK20",
                          "Number of L3 read requests resulting from Z local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "Z_L3_HIT_L3BANK21", "Z L3 HIT L3BANK21",
                          "Number of L3 read requests resulting from Z local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "Z_L3_HIT_L3BANK22", "Z L3 HIT L3BANK22",
                          "Number of L3 read requests resulting from Z local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "Z_L3_HIT_L3BANK23", "Z L3 HIT L3BANK23",
                          "Number of L3 read requests resulting from Z local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "Z_L3_HIT_L3BANK24", "Z L3 HIT L3BANK24",
                          "Number of L3 read requests resulting from Z local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "Z_L3_HIT_L3BANK25", "Z L3 HIT L3BANK25",
                          "Number of L3 read requests resulting from Z local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "Z_L3_HIT_L3BANK26", "Z L3 HIT L3BANK26",
                          "Number of L3 read requests resulting from Z local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "Z_L3_HIT_L3BANK27", "Z L3 HIT L3BANK27",
                          "Number of L3 read requests resulting from Z local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "Z_L3_HIT_L3BANK28", "Z L3 HIT L3BANK28",
                          "Number of L3 read requests resulting from Z local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "Z_L3_HIT_L3BANK29", "Z L3 HIT L3BANK29",
                          "Number of L3 read requests resulting from Z local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "Z_L3_HIT_L3BANK30", "Z L3 HIT L3BANK30",
                          "Number of L3 read requests resulting from Z local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "Z_L3_HIT_L3BANK31", "Z L3 HIT L3BANK31",
                          "Number of L3 read requests resulting from Z local cache miss which hits in L3",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d6c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x074c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c0140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030048, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004009b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00052055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00064800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000867aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030024, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030e01, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031c2a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt49MetricSet::CExt49MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt49MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK0", "L3 SUPERQ FULL L3BANK0",
                          "Percentage of time in which all slots in L3 request queue are waiting for data return / response",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK1", "L3 SUPERQ FULL L3BANK1",
                          "Percentage of time in which all slots in L3 request queue are waiting for data return / response",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK2", "L3 SUPERQ FULL L3BANK2",
                          "Percentage of time in which all slots in L3 request queue are waiting for data return / response",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK3", "L3 SUPERQ FULL L3BANK3",
                          "Percentage of time in which all slots in L3 request queue are waiting for data return / response",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK4", "L3 SUPERQ FULL L3BANK4",
                          "Percentage of time in which all slots in L3 request queue are waiting for data return / response",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK5", "L3 SUPERQ FULL L3BANK5",
                          "Percentage of time in which all slots in L3 request queue are waiting for data return / response",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK6", "L3 SUPERQ FULL L3BANK6",
                          "Percentage of time in which all slots in L3 request queue are waiting for data return / response",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK7", "L3 SUPERQ FULL L3BANK7",
                          "Percentage of time in which all slots in L3 request queue are waiting for data return / response",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116c1183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x136b0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d4c0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030a05, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204fa5a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000500a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060a05, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008f5a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42031c24, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46031401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000060, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000180, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000600, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt50MetricSet::CExt50MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt50MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK8", "L3 SUPERQ FULL L3BANK8",
                          "Percentage of time in which all slots in L3 request queue are waiting for data return / response",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK9", "L3 SUPERQ FULL L3BANK9",
                          "Percentage of time in which all slots in L3 request queue are waiting for data return / response",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK10", "L3 SUPERQ FULL L3BANK10",
                          "Percentage of time in which all slots in L3 request queue are waiting for data return / response",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK11", "L3 SUPERQ FULL L3BANK11",
                          "Percentage of time in which all slots in L3 request queue are waiting for data return / response",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK12", "L3 SUPERQ FULL L3BANK12",
                          "Percentage of time in which all slots in L3 request queue are waiting for data return / response",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK13", "L3 SUPERQ FULL L3BANK13",
                          "Percentage of time in which all slots in L3 request queue are waiting for data return / response",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK14", "L3 SUPERQ FULL L3BANK14",
                          "Percentage of time in which all slots in L3 request queue are waiting for data return / response",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK15", "L3 SUPERQ FULL L3BANK15",
                          "Percentage of time in which all slots in L3 request queue are waiting for data return / response",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116c1183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x136b0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d4c0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030a05, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204fa5a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000500a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060a05, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008f5a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42031c24, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46031401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000060, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000180, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000600, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt51MetricSet::CExt51MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt51MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK16", "L3 SUPERQ FULL L3BANK16",
                          "Percentage of time in which all slots in L3 request queue are waiting for data return / response",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK17", "L3 SUPERQ FULL L3BANK17",
                          "Percentage of time in which all slots in L3 request queue are waiting for data return / response",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK18", "L3 SUPERQ FULL L3BANK18",
                          "Percentage of time in which all slots in L3 request queue are waiting for data return / response",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK19", "L3 SUPERQ FULL L3BANK19",
                          "Percentage of time in which all slots in L3 request queue are waiting for data return / response",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK20", "L3 SUPERQ FULL L3BANK20",
                          "Percentage of time in which all slots in L3 request queue are waiting for data return / response",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK21", "L3 SUPERQ FULL L3BANK21",
                          "Percentage of time in which all slots in L3 request queue are waiting for data return / response",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK22", "L3 SUPERQ FULL L3BANK22",
                          "Percentage of time in which all slots in L3 request queue are waiting for data return / response",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK23", "L3 SUPERQ FULL L3BANK23",
                          "Percentage of time in which all slots in L3 request queue are waiting for data return / response",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116c1183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x136b0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d4c0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030a05, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204fa5a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000500a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060a05, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008f5a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42031c24, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46031401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000060, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000180, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000600, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt52MetricSet::CExt52MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt52MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK24", "L3 SUPERQ FULL L3BANK24",
                          "Percentage of time in which all slots in L3 request queue are waiting for data return / response",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK25", "L3 SUPERQ FULL L3BANK25",
                          "Percentage of time in which all slots in L3 request queue are waiting for data return / response",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK26", "L3 SUPERQ FULL L3BANK26",
                          "Percentage of time in which all slots in L3 request queue are waiting for data return / response",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK27", "L3 SUPERQ FULL L3BANK27",
                          "Percentage of time in which all slots in L3 request queue are waiting for data return / response",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK28", "L3 SUPERQ FULL L3BANK28",
                          "Percentage of time in which all slots in L3 request queue are waiting for data return / response",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK29", "L3 SUPERQ FULL L3BANK29",
                          "Percentage of time in which all slots in L3 request queue are waiting for data return / response",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK30", "L3 SUPERQ FULL L3BANK30",
                          "Percentage of time in which all slots in L3 request queue are waiting for data return / response",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_SUPERQ_FULL_L3BANK31", "L3 SUPERQ FULL L3BANK31",
                          "Percentage of time in which all slots in L3 request queue are waiting for data return / response",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116b1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x112c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x114c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x116c1183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b2b0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f4b0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x136b0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x012c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x092c0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x032c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x014c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d4c0183, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x034c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030a05, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204fa5a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000500a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060a05, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008f5a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42031c24, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46031401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000060, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000180, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000600, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt53MetricSet::CExt53MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt53MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE0", "XVE LOAD STORE CACHE READ MESSAGE COUNT XECORE0",
                          "Number of read messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE1", "XVE LOAD STORE CACHE READ MESSAGE COUNT XECORE1",
                          "Number of read messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt54MetricSet::CExt54MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt54MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE2", "XVE LOAD STORE CACHE READ MESSAGE COUNT XECORE2",
                          "Number of read messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE3", "XVE LOAD STORE CACHE READ MESSAGE COUNT XECORE3",
                          "Number of read messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt55MetricSet::CExt55MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt55MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE4", "XVE LOAD STORE CACHE READ MESSAGE COUNT XECORE4",
                          "Number of read messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE5", "XVE LOAD STORE CACHE READ MESSAGE COUNT XECORE5",
                          "Number of read messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09890414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt56MetricSet::CExt56MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt56MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE6", "XVE LOAD STORE CACHE READ MESSAGE COUNT XECORE6",
                          "Number of read messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE7", "XVE LOAD STORE CACHE READ MESSAGE COUNT XECORE7",
                          "Number of read messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt57MetricSet::CExt57MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt57MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE8", "XVE LOAD STORE CACHE READ MESSAGE COUNT XECORE8",
                          "Number of read messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE9", "XVE LOAD STORE CACHE READ MESSAGE COUNT XECORE9",
                          "Number of read messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt58MetricSet::CExt58MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt58MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE10", "XVE LOAD STORE CACHE READ MESSAGE COUNT XECORE10",
                          "Number of read messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE11", "XVE LOAD STORE CACHE READ MESSAGE COUNT XECORE11",
                          "Number of read messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt59MetricSet::CExt59MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt59MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE12", "XVE LOAD STORE CACHE READ MESSAGE COUNT XECORE12",
                          "Number of read messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE13", "XVE LOAD STORE CACHE READ MESSAGE COUNT XECORE13",
                          "Number of read messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09890414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt60MetricSet::CExt60MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt60MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE14", "XVE LOAD STORE CACHE READ MESSAGE COUNT XECORE14",
                          "Number of read messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE15", "XVE LOAD STORE CACHE READ MESSAGE COUNT XECORE15",
                          "Number of read messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt61MetricSet::CExt61MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt61MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE16", "XVE LOAD STORE CACHE READ MESSAGE COUNT XECORE16",
                          "Number of read messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE17", "XVE LOAD STORE CACHE READ MESSAGE COUNT XECORE17",
                          "Number of read messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt62MetricSet::CExt62MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt62MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE18", "XVE LOAD STORE CACHE READ MESSAGE COUNT XECORE18",
                          "Number of read messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE19", "XVE LOAD STORE CACHE READ MESSAGE COUNT XECORE19",
                          "Number of read messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt63MetricSet::CExt63MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt63MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE20", "XVE LOAD STORE CACHE READ MESSAGE COUNT XECORE20",
                          "Number of read messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE21", "XVE LOAD STORE CACHE READ MESSAGE COUNT XECORE21",
                          "Number of read messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09890414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt64MetricSet::CExt64MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt64MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE22", "XVE LOAD STORE CACHE READ MESSAGE COUNT XECORE22",
                          "Number of read messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE23", "XVE LOAD STORE CACHE READ MESSAGE COUNT XECORE23",
                          "Number of read messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt65MetricSet::CExt65MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt65MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE24", "XVE LOAD STORE CACHE READ MESSAGE COUNT XECORE24",
                          "Number of read messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE25", "XVE LOAD STORE CACHE READ MESSAGE COUNT XECORE25",
                          "Number of read messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt66MetricSet::CExt66MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt66MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE26", "XVE LOAD STORE CACHE READ MESSAGE COUNT XECORE26",
                          "Number of read messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE27", "XVE LOAD STORE CACHE READ MESSAGE COUNT XECORE27",
                          "Number of read messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt67MetricSet::CExt67MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt67MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE28", "XVE LOAD STORE CACHE READ MESSAGE COUNT XECORE28",
                          "Number of read messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE29", "XVE LOAD STORE CACHE READ MESSAGE COUNT XECORE29",
                          "Number of read messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09890414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt68MetricSet::CExt68MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt68MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE30", "XVE LOAD STORE CACHE READ MESSAGE COUNT XECORE30",
                          "Number of read messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE31", "XVE LOAD STORE CACHE READ MESSAGE COUNT XECORE31",
                          "Number of read messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt69MetricSet::CExt69MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt69MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_WRITE_MESSAGE_COUNT_XECORE0", "XVE LOAD STORE CACHE WRITE MESSAGE COUNT XECORE0",
                          "Number of write messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_WRITE_MESSAGE_COUNT_XECORE1", "XVE LOAD STORE CACHE WRITE MESSAGE COUNT XECORE1",
                          "Number of write messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt70MetricSet::CExt70MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt70MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_WRITE_MESSAGE_COUNT_XECORE2", "XVE LOAD STORE CACHE WRITE MESSAGE COUNT XECORE2",
                          "Number of write messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_WRITE_MESSAGE_COUNT_XECORE3", "XVE LOAD STORE CACHE WRITE MESSAGE COUNT XECORE3",
                          "Number of write messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt71MetricSet::CExt71MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt71MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_WRITE_MESSAGE_COUNT_XECORE4", "XVE LOAD STORE CACHE WRITE MESSAGE COUNT XECORE4",
                          "Number of write messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_WRITE_MESSAGE_COUNT_XECORE5", "XVE LOAD STORE CACHE WRITE MESSAGE COUNT XECORE5",
                          "Number of write messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09890413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt72MetricSet::CExt72MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt72MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_WRITE_MESSAGE_COUNT_XECORE6", "XVE LOAD STORE CACHE WRITE MESSAGE COUNT XECORE6",
                          "Number of write messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_WRITE_MESSAGE_COUNT_XECORE7", "XVE LOAD STORE CACHE WRITE MESSAGE COUNT XECORE7",
                          "Number of write messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt73MetricSet::CExt73MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt73MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_WRITE_MESSAGE_COUNT_XECORE8", "XVE LOAD STORE CACHE WRITE MESSAGE COUNT XECORE8",
                          "Number of write messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_WRITE_MESSAGE_COUNT_XECORE9", "XVE LOAD STORE CACHE WRITE MESSAGE COUNT XECORE9",
                          "Number of write messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt74MetricSet::CExt74MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt74MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_WRITE_MESSAGE_COUNT_XECORE10", "XVE LOAD STORE CACHE WRITE MESSAGE COUNT XECORE10",
                          "Number of write messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_WRITE_MESSAGE_COUNT_XECORE11", "XVE LOAD STORE CACHE WRITE MESSAGE COUNT XECORE11",
                          "Number of write messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt75MetricSet::CExt75MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt75MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_WRITE_MESSAGE_COUNT_XECORE12", "XVE LOAD STORE CACHE WRITE MESSAGE COUNT XECORE12",
                          "Number of write messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_WRITE_MESSAGE_COUNT_XECORE13", "XVE LOAD STORE CACHE WRITE MESSAGE COUNT XECORE13",
                          "Number of write messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09890413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt76MetricSet::CExt76MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt76MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_WRITE_MESSAGE_COUNT_XECORE14", "XVE LOAD STORE CACHE WRITE MESSAGE COUNT XECORE14",
                          "Number of write messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_WRITE_MESSAGE_COUNT_XECORE15", "XVE LOAD STORE CACHE WRITE MESSAGE COUNT XECORE15",
                          "Number of write messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt77MetricSet::CExt77MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt77MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_WRITE_MESSAGE_COUNT_XECORE16", "XVE LOAD STORE CACHE WRITE MESSAGE COUNT XECORE16",
                          "Number of write messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_WRITE_MESSAGE_COUNT_XECORE17", "XVE LOAD STORE CACHE WRITE MESSAGE COUNT XECORE17",
                          "Number of write messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt78MetricSet::CExt78MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt78MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_WRITE_MESSAGE_COUNT_XECORE18", "XVE LOAD STORE CACHE WRITE MESSAGE COUNT XECORE18",
                          "Number of write messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_WRITE_MESSAGE_COUNT_XECORE19", "XVE LOAD STORE CACHE WRITE MESSAGE COUNT XECORE19",
                          "Number of write messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt79MetricSet::CExt79MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt79MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_WRITE_MESSAGE_COUNT_XECORE20", "XVE LOAD STORE CACHE WRITE MESSAGE COUNT XECORE20",
                          "Number of write messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_WRITE_MESSAGE_COUNT_XECORE21", "XVE LOAD STORE CACHE WRITE MESSAGE COUNT XECORE21",
                          "Number of write messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09890413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt80MetricSet::CExt80MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt80MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_WRITE_MESSAGE_COUNT_XECORE22", "XVE LOAD STORE CACHE WRITE MESSAGE COUNT XECORE22",
                          "Number of write messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_WRITE_MESSAGE_COUNT_XECORE23", "XVE LOAD STORE CACHE WRITE MESSAGE COUNT XECORE23",
                          "Number of write messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt81MetricSet::CExt81MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt81MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_WRITE_MESSAGE_COUNT_XECORE24", "XVE LOAD STORE CACHE WRITE MESSAGE COUNT XECORE24",
                          "Number of write messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_WRITE_MESSAGE_COUNT_XECORE25", "XVE LOAD STORE CACHE WRITE MESSAGE COUNT XECORE25",
                          "Number of write messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt82MetricSet::CExt82MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt82MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_WRITE_MESSAGE_COUNT_XECORE26", "XVE LOAD STORE CACHE WRITE MESSAGE COUNT XECORE26",
                          "Number of write messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_WRITE_MESSAGE_COUNT_XECORE27", "XVE LOAD STORE CACHE WRITE MESSAGE COUNT XECORE27",
                          "Number of write messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt83MetricSet::CExt83MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt83MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_WRITE_MESSAGE_COUNT_XECORE28", "XVE LOAD STORE CACHE WRITE MESSAGE COUNT XECORE28",
                          "Number of write messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_WRITE_MESSAGE_COUNT_XECORE29", "XVE LOAD STORE CACHE WRITE MESSAGE COUNT XECORE29",
                          "Number of write messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09890413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt84MetricSet::CExt84MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt84MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_WRITE_MESSAGE_COUNT_XECORE30", "XVE LOAD STORE CACHE WRITE MESSAGE COUNT XECORE30",
                          "Number of write messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_WRITE_MESSAGE_COUNT_XECORE31", "XVE LOAD STORE CACHE WRITE MESSAGE COUNT XECORE31",
                          "Number of write messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt85MetricSet::CExt85MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt85MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_ATOMIC_MESSAGE_COUNT_XECORE0", "XVE LOAD STORE CACHE ATOMIC MESSAGE COUNT XECORE0",
                          "Number of atomic operations sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x028300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02860055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x028700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02895476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0489069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x088904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c8908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e890ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10890e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt86MetricSet::CExt86MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt86MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_ATOMIC_MESSAGE_COUNT_XECORE1", "XVE LOAD STORE CACHE ATOMIC MESSAGE COUNT XECORE1",
                          "Number of atomic operations sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt87MetricSet::CExt87MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt87MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_ATOMIC_MESSAGE_COUNT_XECORE2", "XVE LOAD STORE CACHE ATOMIC MESSAGE COUNT XECORE2",
                          "Number of atomic operations sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt88MetricSet::CExt88MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt88MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_ATOMIC_MESSAGE_COUNT_XECORE3", "XVE LOAD STORE CACHE ATOMIC MESSAGE COUNT XECORE3",
                          "Number of atomic operations sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt89MetricSet::CExt89MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt89MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_ATOMIC_MESSAGE_COUNT_XECORE4", "XVE LOAD STORE CACHE ATOMIC MESSAGE COUNT XECORE4",
                          "Number of atomic operations sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f890400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x038300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x038700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03895476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0589069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x098904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d8908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f890ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11890e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt90MetricSet::CExt90MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt90MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_ATOMIC_MESSAGE_COUNT_XECORE5", "XVE LOAD STORE CACHE ATOMIC MESSAGE COUNT XECORE5",
                          "Number of atomic operations sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt91MetricSet::CExt91MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt91MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_ATOMIC_MESSAGE_COUNT_XECORE6", "XVE LOAD STORE CACHE ATOMIC MESSAGE COUNT XECORE6",
                          "Number of atomic operations sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt92MetricSet::CExt92MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt92MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_ATOMIC_MESSAGE_COUNT_XECORE7", "XVE LOAD STORE CACHE ATOMIC MESSAGE COUNT XECORE7",
                          "Number of atomic operations sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt93MetricSet::CExt93MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt93MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_ATOMIC_MESSAGE_COUNT_XECORE8", "XVE LOAD STORE CACHE ATOMIC MESSAGE COUNT XECORE8",
                          "Number of atomic operations sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x028300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02860055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x028700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02895476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0489069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x088904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c8908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e890ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10890e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt94MetricSet::CExt94MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt94MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_ATOMIC_MESSAGE_COUNT_XECORE9", "XVE LOAD STORE CACHE ATOMIC MESSAGE COUNT XECORE9",
                          "Number of atomic operations sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt95MetricSet::CExt95MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt95MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_ATOMIC_MESSAGE_COUNT_XECORE10", "XVE LOAD STORE CACHE ATOMIC MESSAGE COUNT XECORE10",
                          "Number of atomic operations sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt96MetricSet::CExt96MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt96MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_ATOMIC_MESSAGE_COUNT_XECORE11", "XVE LOAD STORE CACHE ATOMIC MESSAGE COUNT XECORE11",
                          "Number of atomic operations sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt97MetricSet::CExt97MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt97MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_ATOMIC_MESSAGE_COUNT_XECORE12", "XVE LOAD STORE CACHE ATOMIC MESSAGE COUNT XECORE12",
                          "Number of atomic operations sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f890400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x038300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x038700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03895476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0589069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x098904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d8908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f890ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11890e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt98MetricSet::CExt98MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt98MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_ATOMIC_MESSAGE_COUNT_XECORE13", "XVE LOAD STORE CACHE ATOMIC MESSAGE COUNT XECORE13",
                          "Number of atomic operations sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt99MetricSet::CExt99MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt99MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_ATOMIC_MESSAGE_COUNT_XECORE14", "XVE LOAD STORE CACHE ATOMIC MESSAGE COUNT XECORE14",
                          "Number of atomic operations sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt100MetricSet::CExt100MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt100MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_ATOMIC_MESSAGE_COUNT_XECORE15", "XVE LOAD STORE CACHE ATOMIC MESSAGE COUNT XECORE15",
                          "Number of atomic operations sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt101MetricSet::CExt101MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt101MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_ATOMIC_MESSAGE_COUNT_XECORE16", "XVE LOAD STORE CACHE ATOMIC MESSAGE COUNT XECORE16",
                          "Number of atomic operations sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x028300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02860055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x028700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02895476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0489069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x088904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c8908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e890ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10890e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt102MetricSet::CExt102MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt102MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_ATOMIC_MESSAGE_COUNT_XECORE17", "XVE LOAD STORE CACHE ATOMIC MESSAGE COUNT XECORE17",
                          "Number of atomic operations sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt103MetricSet::CExt103MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt103MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_ATOMIC_MESSAGE_COUNT_XECORE18", "XVE LOAD STORE CACHE ATOMIC MESSAGE COUNT XECORE18",
                          "Number of atomic operations sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt104MetricSet::CExt104MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt104MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_ATOMIC_MESSAGE_COUNT_XECORE19", "XVE LOAD STORE CACHE ATOMIC MESSAGE COUNT XECORE19",
                          "Number of atomic operations sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt105MetricSet::CExt105MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt105MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_ATOMIC_MESSAGE_COUNT_XECORE20", "XVE LOAD STORE CACHE ATOMIC MESSAGE COUNT XECORE20",
                          "Number of atomic operations sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f890400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x038300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x038700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03895476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0589069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x098904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d8908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f890ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11890e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt106MetricSet::CExt106MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt106MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_ATOMIC_MESSAGE_COUNT_XECORE21", "XVE LOAD STORE CACHE ATOMIC MESSAGE COUNT XECORE21",
                          "Number of atomic operations sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt107MetricSet::CExt107MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt107MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_ATOMIC_MESSAGE_COUNT_XECORE22", "XVE LOAD STORE CACHE ATOMIC MESSAGE COUNT XECORE22",
                          "Number of atomic operations sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt108MetricSet::CExt108MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt108MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_ATOMIC_MESSAGE_COUNT_XECORE23", "XVE LOAD STORE CACHE ATOMIC MESSAGE COUNT XECORE23",
                          "Number of atomic operations sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt109MetricSet::CExt109MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt109MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_ATOMIC_MESSAGE_COUNT_XECORE24", "XVE LOAD STORE CACHE ATOMIC MESSAGE COUNT XECORE24",
                          "Number of atomic operations sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x028300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02860055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x028700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02895476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0489069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x088904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c8908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e890ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10890e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020200aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt110MetricSet::CExt110MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt110MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_ATOMIC_MESSAGE_COUNT_XECORE25", "XVE LOAD STORE CACHE ATOMIC MESSAGE COUNT XECORE25",
                          "Number of atomic operations sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020200aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt111MetricSet::CExt111MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt111MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_ATOMIC_MESSAGE_COUNT_XECORE26", "XVE LOAD STORE CACHE ATOMIC MESSAGE COUNT XECORE26",
                          "Number of atomic operations sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020200aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt112MetricSet::CExt112MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt112MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_ATOMIC_MESSAGE_COUNT_XECORE27", "XVE LOAD STORE CACHE ATOMIC MESSAGE COUNT XECORE27",
                          "Number of atomic operations sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020200aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt113MetricSet::CExt113MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt113MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_ATOMIC_MESSAGE_COUNT_XECORE28", "XVE LOAD STORE CACHE ATOMIC MESSAGE COUNT XECORE28",
                          "Number of atomic operations sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f890400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x038300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x038700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03895476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0589069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x098904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d8908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f890ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11890e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020200aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt114MetricSet::CExt114MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt114MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_ATOMIC_MESSAGE_COUNT_XECORE29", "XVE LOAD STORE CACHE ATOMIC MESSAGE COUNT XECORE29",
                          "Number of atomic operations sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020200aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt115MetricSet::CExt115MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt115MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_ATOMIC_MESSAGE_COUNT_XECORE30", "XVE LOAD STORE CACHE ATOMIC MESSAGE COUNT XECORE30",
                          "Number of atomic operations sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020200aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt116MetricSet::CExt116MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt116MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_ATOMIC_MESSAGE_COUNT_XECORE31", "XVE LOAD STORE CACHE ATOMIC MESSAGE COUNT XECORE31",
                          "Number of atomic operations sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020200aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt117MetricSet::CExt117MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt117MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_FENCE_MESSAGE_COUNT_XECORE0", "XVE LOAD STORE CACHE FENCE MESSAGE COUNT XECORE0",
                          "Number of fence messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_FENCE_MESSAGE_COUNT_XECORE1", "XVE LOAD STORE CACHE FENCE MESSAGE COUNT XECORE1",
                          "Number of fence messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02895476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0489069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a90a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a90e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt118MetricSet::CExt118MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt118MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_FENCE_MESSAGE_COUNT_XECORE2", "XVE LOAD STORE CACHE FENCE MESSAGE COUNT XECORE2",
                          "Number of fence messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_FENCE_MESSAGE_COUNT_XECORE3", "XVE LOAD STORE CACHE FENCE MESSAGE COUNT XECORE3",
                          "Number of fence messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c90617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e90617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e90a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e90e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt119MetricSet::CExt119MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt119MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_FENCE_MESSAGE_COUNT_XECORE4", "XVE LOAD STORE CACHE FENCE MESSAGE COUNT XECORE4",
                          "Number of fence messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_FENCE_MESSAGE_COUNT_XECORE5", "XVE LOAD STORE CACHE FENCE MESSAGE COUNT XECORE5",
                          "Number of fence messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f890400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03895476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0589069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09890617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a90a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a90e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt120MetricSet::CExt120MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt120MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_FENCE_MESSAGE_COUNT_XECORE6", "XVE LOAD STORE CACHE FENCE MESSAGE COUNT XECORE6",
                          "Number of fence messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_FENCE_MESSAGE_COUNT_XECORE7", "XVE LOAD STORE CACHE FENCE MESSAGE COUNT XECORE7",
                          "Number of fence messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c90207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c90617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe90207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e90617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e90a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e90e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt121MetricSet::CExt121MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt121MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_FENCE_MESSAGE_COUNT_XECORE8", "XVE LOAD STORE CACHE FENCE MESSAGE COUNT XECORE8",
                          "Number of fence messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_FENCE_MESSAGE_COUNT_XECORE9", "XVE LOAD STORE CACHE FENCE MESSAGE COUNT XECORE9",
                          "Number of fence messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02895476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0489069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a90a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a90e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt122MetricSet::CExt122MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt122MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_FENCE_MESSAGE_COUNT_XECORE10", "XVE LOAD STORE CACHE FENCE MESSAGE COUNT XECORE10",
                          "Number of fence messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_FENCE_MESSAGE_COUNT_XECORE11", "XVE LOAD STORE CACHE FENCE MESSAGE COUNT XECORE11",
                          "Number of fence messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c90617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e90617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e90a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e90e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt123MetricSet::CExt123MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt123MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_FENCE_MESSAGE_COUNT_XECORE12", "XVE LOAD STORE CACHE FENCE MESSAGE COUNT XECORE12",
                          "Number of fence messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_FENCE_MESSAGE_COUNT_XECORE13", "XVE LOAD STORE CACHE FENCE MESSAGE COUNT XECORE13",
                          "Number of fence messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f890400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03895476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0589069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09890617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a90a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a90e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt124MetricSet::CExt124MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt124MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_FENCE_MESSAGE_COUNT_XECORE14", "XVE LOAD STORE CACHE FENCE MESSAGE COUNT XECORE14",
                          "Number of fence messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_FENCE_MESSAGE_COUNT_XECORE15", "XVE LOAD STORE CACHE FENCE MESSAGE COUNT XECORE15",
                          "Number of fence messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c90207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c90617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe90207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e90617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e90a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e90e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt125MetricSet::CExt125MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt125MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_FENCE_MESSAGE_COUNT_XECORE16", "XVE LOAD STORE CACHE FENCE MESSAGE COUNT XECORE16",
                          "Number of fence messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_FENCE_MESSAGE_COUNT_XECORE17", "XVE LOAD STORE CACHE FENCE MESSAGE COUNT XECORE17",
                          "Number of fence messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02895476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0489069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a90a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a90e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt126MetricSet::CExt126MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt126MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_FENCE_MESSAGE_COUNT_XECORE18", "XVE LOAD STORE CACHE FENCE MESSAGE COUNT XECORE18",
                          "Number of fence messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_FENCE_MESSAGE_COUNT_XECORE19", "XVE LOAD STORE CACHE FENCE MESSAGE COUNT XECORE19",
                          "Number of fence messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c90617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e90617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e90a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e90e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt127MetricSet::CExt127MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt127MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_FENCE_MESSAGE_COUNT_XECORE20", "XVE LOAD STORE CACHE FENCE MESSAGE COUNT XECORE20",
                          "Number of fence messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_FENCE_MESSAGE_COUNT_XECORE21", "XVE LOAD STORE CACHE FENCE MESSAGE COUNT XECORE21",
                          "Number of fence messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f890400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03895476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0589069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09890617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a90a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a90e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt128MetricSet::CExt128MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt128MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_FENCE_MESSAGE_COUNT_XECORE22", "XVE LOAD STORE CACHE FENCE MESSAGE COUNT XECORE22",
                          "Number of fence messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_FENCE_MESSAGE_COUNT_XECORE23", "XVE LOAD STORE CACHE FENCE MESSAGE COUNT XECORE23",
                          "Number of fence messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c90207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c90617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe90207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e90617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e90a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e90e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt129MetricSet::CExt129MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt129MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_FENCE_MESSAGE_COUNT_XECORE24", "XVE LOAD STORE CACHE FENCE MESSAGE COUNT XECORE24",
                          "Number of fence messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_FENCE_MESSAGE_COUNT_XECORE25", "XVE LOAD STORE CACHE FENCE MESSAGE COUNT XECORE25",
                          "Number of fence messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02895476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0489069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a90a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a90e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt130MetricSet::CExt130MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt130MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_FENCE_MESSAGE_COUNT_XECORE26", "XVE LOAD STORE CACHE FENCE MESSAGE COUNT XECORE26",
                          "Number of fence messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_FENCE_MESSAGE_COUNT_XECORE27", "XVE LOAD STORE CACHE FENCE MESSAGE COUNT XECORE27",
                          "Number of fence messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c90617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e90617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e90a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e90e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt131MetricSet::CExt131MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt131MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_FENCE_MESSAGE_COUNT_XECORE28", "XVE LOAD STORE CACHE FENCE MESSAGE COUNT XECORE28",
                          "Number of fence messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_FENCE_MESSAGE_COUNT_XECORE29", "XVE LOAD STORE CACHE FENCE MESSAGE COUNT XECORE29",
                          "Number of fence messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f890400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03895476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0589069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09890617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a90a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a90e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt132MetricSet::CExt132MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt132MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_FENCE_MESSAGE_COUNT_XECORE30", "XVE LOAD STORE CACHE FENCE MESSAGE COUNT XECORE30",
                          "Number of fence messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_FENCE_MESSAGE_COUNT_XECORE31", "XVE LOAD STORE CACHE FENCE MESSAGE COUNT XECORE31",
                          "Number of fence messages sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c90207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c90617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe90207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e90617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e90a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e90e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt133MetricSet::CExt133MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt133MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_SLM_READ_MESSAGE_COUNT_XECORE0", "XVE SLM READ MESSAGE COUNT XECORE0",
                          "Number of SLM read messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "XVE_SLM_READ_MESSAGE_COUNT_XECORE1", "XVE SLM READ MESSAGE COUNT XECORE1",
                          "Number of SLM read messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt134MetricSet::CExt134MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt134MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "XVE_SLM_READ_MESSAGE_COUNT_XECORE2", "XVE SLM READ MESSAGE COUNT XECORE2",
                          "Number of SLM read messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "XVE_SLM_READ_MESSAGE_COUNT_XECORE3", "XVE SLM READ MESSAGE COUNT XECORE3",
                          "Number of SLM read messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt135MetricSet::CExt135MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt135MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "XVE_SLM_READ_MESSAGE_COUNT_XECORE4", "XVE SLM READ MESSAGE COUNT XECORE4",
                          "Number of SLM read messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "XVE_SLM_READ_MESSAGE_COUNT_XECORE5", "XVE SLM READ MESSAGE COUNT XECORE5",
                          "Number of SLM read messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09890414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt136MetricSet::CExt136MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt136MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "XVE_SLM_READ_MESSAGE_COUNT_XECORE6", "XVE SLM READ MESSAGE COUNT XECORE6",
                          "Number of SLM read messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "XVE_SLM_READ_MESSAGE_COUNT_XECORE7", "XVE SLM READ MESSAGE COUNT XECORE7",
                          "Number of SLM read messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt137MetricSet::CExt137MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt137MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_SLM_READ_MESSAGE_COUNT_XECORE8", "XVE SLM READ MESSAGE COUNT XECORE8",
                          "Number of SLM read messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_SLM_READ_MESSAGE_COUNT_XECORE9", "XVE SLM READ MESSAGE COUNT XECORE9",
                          "Number of SLM read messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt138MetricSet::CExt138MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt138MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_SLM_READ_MESSAGE_COUNT_XECORE10", "XVE SLM READ MESSAGE COUNT XECORE10",
                          "Number of SLM read messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_SLM_READ_MESSAGE_COUNT_XECORE11", "XVE SLM READ MESSAGE COUNT XECORE11",
                          "Number of SLM read messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt139MetricSet::CExt139MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt139MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_SLM_READ_MESSAGE_COUNT_XECORE12", "XVE SLM READ MESSAGE COUNT XECORE12",
                          "Number of SLM read messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_SLM_READ_MESSAGE_COUNT_XECORE13", "XVE SLM READ MESSAGE COUNT XECORE13",
                          "Number of SLM read messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09890414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt140MetricSet::CExt140MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt140MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_SLM_READ_MESSAGE_COUNT_XECORE14", "XVE SLM READ MESSAGE COUNT XECORE14",
                          "Number of SLM read messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_SLM_READ_MESSAGE_COUNT_XECORE15", "XVE SLM READ MESSAGE COUNT XECORE15",
                          "Number of SLM read messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt141MetricSet::CExt141MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt141MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_SLM_READ_MESSAGE_COUNT_XECORE16", "XVE SLM READ MESSAGE COUNT XECORE16",
                          "Number of SLM read messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_SLM_READ_MESSAGE_COUNT_XECORE17", "XVE SLM READ MESSAGE COUNT XECORE17",
                          "Number of SLM read messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt142MetricSet::CExt142MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt142MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_SLM_READ_MESSAGE_COUNT_XECORE18", "XVE SLM READ MESSAGE COUNT XECORE18",
                          "Number of SLM read messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_SLM_READ_MESSAGE_COUNT_XECORE19", "XVE SLM READ MESSAGE COUNT XECORE19",
                          "Number of SLM read messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt143MetricSet::CExt143MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt143MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_SLM_READ_MESSAGE_COUNT_XECORE20", "XVE SLM READ MESSAGE COUNT XECORE20",
                          "Number of SLM read messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_SLM_READ_MESSAGE_COUNT_XECORE21", "XVE SLM READ MESSAGE COUNT XECORE21",
                          "Number of SLM read messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09890414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt144MetricSet::CExt144MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt144MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_SLM_READ_MESSAGE_COUNT_XECORE22", "XVE SLM READ MESSAGE COUNT XECORE22",
                          "Number of SLM read messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_SLM_READ_MESSAGE_COUNT_XECORE23", "XVE SLM READ MESSAGE COUNT XECORE23",
                          "Number of SLM read messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt145MetricSet::CExt145MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt145MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "XVE_SLM_READ_MESSAGE_COUNT_XECORE24", "XVE SLM READ MESSAGE COUNT XECORE24",
                          "Number of SLM read messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "XVE_SLM_READ_MESSAGE_COUNT_XECORE25", "XVE SLM READ MESSAGE COUNT XECORE25",
                          "Number of SLM read messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt146MetricSet::CExt146MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt146MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "XVE_SLM_READ_MESSAGE_COUNT_XECORE26", "XVE SLM READ MESSAGE COUNT XECORE26",
                          "Number of SLM read messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "XVE_SLM_READ_MESSAGE_COUNT_XECORE27", "XVE SLM READ MESSAGE COUNT XECORE27",
                          "Number of SLM read messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt147MetricSet::CExt147MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt147MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "XVE_SLM_READ_MESSAGE_COUNT_XECORE28", "XVE SLM READ MESSAGE COUNT XECORE28",
                          "Number of SLM read messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "XVE_SLM_READ_MESSAGE_COUNT_XECORE29", "XVE SLM READ MESSAGE COUNT XECORE29",
                          "Number of SLM read messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09890414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt148MetricSet::CExt148MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt148MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "XVE_SLM_READ_MESSAGE_COUNT_XECORE30", "XVE SLM READ MESSAGE COUNT XECORE30",
                          "Number of SLM read messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "XVE_SLM_READ_MESSAGE_COUNT_XECORE31", "XVE SLM READ MESSAGE COUNT XECORE31",
                          "Number of SLM read messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e90414, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e90824, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e90c34, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt149MetricSet::CExt149MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt149MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_SLM_WRITE_MESSAGE_COUNT_XECORE0", "XVE SLM WRITE MESSAGE COUNT XECORE0",
                          "Number of SLM write messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "XVE_SLM_WRITE_MESSAGE_COUNT_XECORE1", "XVE SLM WRITE MESSAGE COUNT XECORE1",
                          "Number of SLM write messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt150MetricSet::CExt150MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt150MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "XVE_SLM_WRITE_MESSAGE_COUNT_XECORE2", "XVE SLM WRITE MESSAGE COUNT XECORE2",
                          "Number of SLM write messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "XVE_SLM_WRITE_MESSAGE_COUNT_XECORE3", "XVE SLM WRITE MESSAGE COUNT XECORE3",
                          "Number of SLM write messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt151MetricSet::CExt151MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt151MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "XVE_SLM_WRITE_MESSAGE_COUNT_XECORE4", "XVE SLM WRITE MESSAGE COUNT XECORE4",
                          "Number of SLM write messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "XVE_SLM_WRITE_MESSAGE_COUNT_XECORE5", "XVE SLM WRITE MESSAGE COUNT XECORE5",
                          "Number of SLM write messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09890413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt152MetricSet::CExt152MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt152MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "XVE_SLM_WRITE_MESSAGE_COUNT_XECORE6", "XVE SLM WRITE MESSAGE COUNT XECORE6",
                          "Number of SLM write messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "XVE_SLM_WRITE_MESSAGE_COUNT_XECORE7", "XVE SLM WRITE MESSAGE COUNT XECORE7",
                          "Number of SLM write messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt153MetricSet::CExt153MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt153MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_SLM_WRITE_MESSAGE_COUNT_XECORE8", "XVE SLM WRITE MESSAGE COUNT XECORE8",
                          "Number of SLM write messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_SLM_WRITE_MESSAGE_COUNT_XECORE9", "XVE SLM WRITE MESSAGE COUNT XECORE9",
                          "Number of SLM write messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt154MetricSet::CExt154MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt154MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_SLM_WRITE_MESSAGE_COUNT_XECORE10", "XVE SLM WRITE MESSAGE COUNT XECORE10",
                          "Number of SLM write messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_SLM_WRITE_MESSAGE_COUNT_XECORE11", "XVE SLM WRITE MESSAGE COUNT XECORE11",
                          "Number of SLM write messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt155MetricSet::CExt155MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt155MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_SLM_WRITE_MESSAGE_COUNT_XECORE12", "XVE SLM WRITE MESSAGE COUNT XECORE12",
                          "Number of SLM write messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_SLM_WRITE_MESSAGE_COUNT_XECORE13", "XVE SLM WRITE MESSAGE COUNT XECORE13",
                          "Number of SLM write messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09890413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt156MetricSet::CExt156MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt156MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_SLM_WRITE_MESSAGE_COUNT_XECORE14", "XVE SLM WRITE MESSAGE COUNT XECORE14",
                          "Number of SLM write messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_SLM_WRITE_MESSAGE_COUNT_XECORE15", "XVE SLM WRITE MESSAGE COUNT XECORE15",
                          "Number of SLM write messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt157MetricSet::CExt157MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt157MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_SLM_WRITE_MESSAGE_COUNT_XECORE16", "XVE SLM WRITE MESSAGE COUNT XECORE16",
                          "Number of SLM write messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_SLM_WRITE_MESSAGE_COUNT_XECORE17", "XVE SLM WRITE MESSAGE COUNT XECORE17",
                          "Number of SLM write messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt158MetricSet::CExt158MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt158MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_SLM_WRITE_MESSAGE_COUNT_XECORE18", "XVE SLM WRITE MESSAGE COUNT XECORE18",
                          "Number of SLM write messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_SLM_WRITE_MESSAGE_COUNT_XECORE19", "XVE SLM WRITE MESSAGE COUNT XECORE19",
                          "Number of SLM write messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt159MetricSet::CExt159MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt159MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_SLM_WRITE_MESSAGE_COUNT_XECORE20", "XVE SLM WRITE MESSAGE COUNT XECORE20",
                          "Number of SLM write messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_SLM_WRITE_MESSAGE_COUNT_XECORE21", "XVE SLM WRITE MESSAGE COUNT XECORE21",
                          "Number of SLM write messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09890413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt160MetricSet::CExt160MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt160MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_SLM_WRITE_MESSAGE_COUNT_XECORE22", "XVE SLM WRITE MESSAGE COUNT XECORE22",
                          "Number of SLM write messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_SLM_WRITE_MESSAGE_COUNT_XECORE23", "XVE SLM WRITE MESSAGE COUNT XECORE23",
                          "Number of SLM write messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt161MetricSet::CExt161MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt161MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "XVE_SLM_WRITE_MESSAGE_COUNT_XECORE24", "XVE SLM WRITE MESSAGE COUNT XECORE24",
                          "Number of SLM write messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "XVE_SLM_WRITE_MESSAGE_COUNT_XECORE25", "XVE SLM WRITE MESSAGE COUNT XECORE25",
                          "Number of SLM write messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt162MetricSet::CExt162MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt162MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "XVE_SLM_WRITE_MESSAGE_COUNT_XECORE26", "XVE SLM WRITE MESSAGE COUNT XECORE26",
                          "Number of SLM write messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "XVE_SLM_WRITE_MESSAGE_COUNT_XECORE27", "XVE SLM WRITE MESSAGE COUNT XECORE27",
                          "Number of SLM write messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt163MetricSet::CExt163MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt163MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "XVE_SLM_WRITE_MESSAGE_COUNT_XECORE28", "XVE SLM WRITE MESSAGE COUNT XECORE28",
                          "Number of SLM write messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "XVE_SLM_WRITE_MESSAGE_COUNT_XECORE29", "XVE SLM WRITE MESSAGE COUNT XECORE29",
                          "Number of SLM write messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09890413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt164MetricSet::CExt164MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt164MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "XVE_SLM_WRITE_MESSAGE_COUNT_XECORE30", "XVE SLM WRITE MESSAGE COUNT XECORE30",
                          "Number of SLM write messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "XVE_SLM_WRITE_MESSAGE_COUNT_XECORE31", "XVE SLM WRITE MESSAGE COUNT XECORE31",
                          "Number of SLM write messages sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e90413, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e90823, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e90c33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt165MetricSet::CExt165MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt165MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_SLM_ATOMIC_MESSAGE_COUNT_XECORE0", "XVE SLM ATOMIC MESSAGE COUNT XECORE0",
                          "Number of SLM atomic operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x028300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02860055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x028700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02895476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0489069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x088904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c8908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e890ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10890e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt166MetricSet::CExt166MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt166MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "XVE_SLM_ATOMIC_MESSAGE_COUNT_XECORE1", "XVE SLM ATOMIC MESSAGE COUNT XECORE1",
                          "Number of SLM atomic operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt167MetricSet::CExt167MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt167MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "XVE_SLM_ATOMIC_MESSAGE_COUNT_XECORE2", "XVE SLM ATOMIC MESSAGE COUNT XECORE2",
                          "Number of SLM atomic operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt168MetricSet::CExt168MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt168MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "XVE_SLM_ATOMIC_MESSAGE_COUNT_XECORE3", "XVE SLM ATOMIC MESSAGE COUNT XECORE3",
                          "Number of SLM atomic operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt169MetricSet::CExt169MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt169MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "XVE_SLM_ATOMIC_MESSAGE_COUNT_XECORE4", "XVE SLM ATOMIC MESSAGE COUNT XECORE4",
                          "Number of SLM atomic operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f890400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x038300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x038700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03895476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0589069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x098904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d8908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f890ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11890e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt170MetricSet::CExt170MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt170MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "XVE_SLM_ATOMIC_MESSAGE_COUNT_XECORE5", "XVE SLM ATOMIC MESSAGE COUNT XECORE5",
                          "Number of SLM atomic operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt171MetricSet::CExt171MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt171MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "XVE_SLM_ATOMIC_MESSAGE_COUNT_XECORE6", "XVE SLM ATOMIC MESSAGE COUNT XECORE6",
                          "Number of SLM atomic operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt172MetricSet::CExt172MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt172MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "XVE_SLM_ATOMIC_MESSAGE_COUNT_XECORE7", "XVE SLM ATOMIC MESSAGE COUNT XECORE7",
                          "Number of SLM atomic operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt173MetricSet::CExt173MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt173MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_SLM_ATOMIC_MESSAGE_COUNT_XECORE8", "XVE SLM ATOMIC MESSAGE COUNT XECORE8",
                          "Number of SLM atomic operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x028300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02860055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x028700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02895476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0489069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x088904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c8908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e890ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10890e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt174MetricSet::CExt174MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt174MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_SLM_ATOMIC_MESSAGE_COUNT_XECORE9", "XVE SLM ATOMIC MESSAGE COUNT XECORE9",
                          "Number of SLM atomic operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt175MetricSet::CExt175MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt175MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_SLM_ATOMIC_MESSAGE_COUNT_XECORE10", "XVE SLM ATOMIC MESSAGE COUNT XECORE10",
                          "Number of SLM atomic operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt176MetricSet::CExt176MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt176MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_SLM_ATOMIC_MESSAGE_COUNT_XECORE11", "XVE SLM ATOMIC MESSAGE COUNT XECORE11",
                          "Number of SLM atomic operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt177MetricSet::CExt177MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt177MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_SLM_ATOMIC_MESSAGE_COUNT_XECORE12", "XVE SLM ATOMIC MESSAGE COUNT XECORE12",
                          "Number of SLM atomic operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f890400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x038300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x038700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03895476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0589069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x098904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d8908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f890ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11890e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt178MetricSet::CExt178MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt178MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_SLM_ATOMIC_MESSAGE_COUNT_XECORE13", "XVE SLM ATOMIC MESSAGE COUNT XECORE13",
                          "Number of SLM atomic operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt179MetricSet::CExt179MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt179MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_SLM_ATOMIC_MESSAGE_COUNT_XECORE14", "XVE SLM ATOMIC MESSAGE COUNT XECORE14",
                          "Number of SLM atomic operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt180MetricSet::CExt180MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt180MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_SLM_ATOMIC_MESSAGE_COUNT_XECORE15", "XVE SLM ATOMIC MESSAGE COUNT XECORE15",
                          "Number of SLM atomic operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt181MetricSet::CExt181MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt181MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_SLM_ATOMIC_MESSAGE_COUNT_XECORE16", "XVE SLM ATOMIC MESSAGE COUNT XECORE16",
                          "Number of SLM atomic operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x028300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02860055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x028700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02895476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0489069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x088904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c8908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e890ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10890e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt182MetricSet::CExt182MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt182MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_SLM_ATOMIC_MESSAGE_COUNT_XECORE17", "XVE SLM ATOMIC MESSAGE COUNT XECORE17",
                          "Number of SLM atomic operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt183MetricSet::CExt183MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt183MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_SLM_ATOMIC_MESSAGE_COUNT_XECORE18", "XVE SLM ATOMIC MESSAGE COUNT XECORE18",
                          "Number of SLM atomic operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt184MetricSet::CExt184MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt184MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_SLM_ATOMIC_MESSAGE_COUNT_XECORE19", "XVE SLM ATOMIC MESSAGE COUNT XECORE19",
                          "Number of SLM atomic operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt185MetricSet::CExt185MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt185MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_SLM_ATOMIC_MESSAGE_COUNT_XECORE20", "XVE SLM ATOMIC MESSAGE COUNT XECORE20",
                          "Number of SLM atomic operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f890400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x038300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x038700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03895476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0589069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x098904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d8908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f890ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11890e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt186MetricSet::CExt186MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt186MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_SLM_ATOMIC_MESSAGE_COUNT_XECORE21", "XVE SLM ATOMIC MESSAGE COUNT XECORE21",
                          "Number of SLM atomic operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt187MetricSet::CExt187MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt187MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_SLM_ATOMIC_MESSAGE_COUNT_XECORE22", "XVE SLM ATOMIC MESSAGE COUNT XECORE22",
                          "Number of SLM atomic operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt188MetricSet::CExt188MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt188MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_SLM_ATOMIC_MESSAGE_COUNT_XECORE23", "XVE SLM ATOMIC MESSAGE COUNT XECORE23",
                          "Number of SLM atomic operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt189MetricSet::CExt189MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt189MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "XVE_SLM_ATOMIC_MESSAGE_COUNT_XECORE24", "XVE SLM ATOMIC MESSAGE COUNT XECORE24",
                          "Number of SLM atomic operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x028300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02860055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x028700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02895476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0489069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x088904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c8908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e890ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10890e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020200aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt190MetricSet::CExt190MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt190MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "XVE_SLM_ATOMIC_MESSAGE_COUNT_XECORE25", "XVE SLM ATOMIC MESSAGE COUNT XECORE25",
                          "Number of SLM atomic operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020200aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt191MetricSet::CExt191MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt191MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "XVE_SLM_ATOMIC_MESSAGE_COUNT_XECORE26", "XVE SLM ATOMIC MESSAGE COUNT XECORE26",
                          "Number of SLM atomic operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020200aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt192MetricSet::CExt192MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt192MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "XVE_SLM_ATOMIC_MESSAGE_COUNT_XECORE27", "XVE SLM ATOMIC MESSAGE COUNT XECORE27",
                          "Number of SLM atomic operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020200aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt193MetricSet::CExt193MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt193MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "XVE_SLM_ATOMIC_MESSAGE_COUNT_XECORE28", "XVE SLM ATOMIC MESSAGE COUNT XECORE28",
                          "Number of SLM atomic operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f890400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x038300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x038700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03895476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0589069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x098904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d8908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f890ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11890e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020200aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt194MetricSet::CExt194MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt194MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "XVE_SLM_ATOMIC_MESSAGE_COUNT_XECORE29", "XVE SLM ATOMIC MESSAGE COUNT XECORE29",
                          "Number of SLM atomic operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020200aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt195MetricSet::CExt195MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt195MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "XVE_SLM_ATOMIC_MESSAGE_COUNT_XECORE30", "XVE SLM ATOMIC MESSAGE COUNT XECORE30",
                          "Number of SLM atomic operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020200aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt196MetricSet::CExt196MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt196MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "XVE_SLM_ATOMIC_MESSAGE_COUNT_XECORE31", "XVE SLM ATOMIC MESSAGE COUNT XECORE31",
                          "Number of SLM atomic operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e904c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be90612, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de908a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe90ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e90e32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020200aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt197MetricSet::CExt197MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt197MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_SLM_FENCE_MESSAGE_COUNT_XECORE0", "XVE SLM FENCE MESSAGE COUNT XECORE0",
                          "Number of SLM fence operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "XVE_SLM_FENCE_MESSAGE_COUNT_XECORE1", "XVE SLM FENCE MESSAGE COUNT XECORE1",
                          "Number of SLM fence operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02895476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0489069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a90a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a90e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt198MetricSet::CExt198MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt198MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "XVE_SLM_FENCE_MESSAGE_COUNT_XECORE2", "XVE SLM FENCE MESSAGE COUNT XECORE2",
                          "Number of SLM fence operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "XVE_SLM_FENCE_MESSAGE_COUNT_XECORE3", "XVE SLM FENCE MESSAGE COUNT XECORE3",
                          "Number of SLM fence operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c90617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e90617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e90a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e90e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt199MetricSet::CExt199MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt199MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "XVE_SLM_FENCE_MESSAGE_COUNT_XECORE4", "XVE SLM FENCE MESSAGE COUNT XECORE4",
                          "Number of SLM fence operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "XVE_SLM_FENCE_MESSAGE_COUNT_XECORE5", "XVE SLM FENCE MESSAGE COUNT XECORE5",
                          "Number of SLM fence operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f890400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03895476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0589069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09890617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a90a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a90e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt200MetricSet::CExt200MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt200MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "XVE_SLM_FENCE_MESSAGE_COUNT_XECORE6", "XVE SLM FENCE MESSAGE COUNT XECORE6",
                          "Number of SLM fence operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "XVE_SLM_FENCE_MESSAGE_COUNT_XECORE7", "XVE SLM FENCE MESSAGE COUNT XECORE7",
                          "Number of SLM fence operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c90207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c90617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe90207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e90617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e90a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e90e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt201MetricSet::CExt201MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt201MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_SLM_FENCE_MESSAGE_COUNT_XECORE8", "XVE SLM FENCE MESSAGE COUNT XECORE8",
                          "Number of SLM fence operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_SLM_FENCE_MESSAGE_COUNT_XECORE9", "XVE SLM FENCE MESSAGE COUNT XECORE9",
                          "Number of SLM fence operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02895476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0489069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a90a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a90e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt202MetricSet::CExt202MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt202MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_SLM_FENCE_MESSAGE_COUNT_XECORE10", "XVE SLM FENCE MESSAGE COUNT XECORE10",
                          "Number of SLM fence operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_SLM_FENCE_MESSAGE_COUNT_XECORE11", "XVE SLM FENCE MESSAGE COUNT XECORE11",
                          "Number of SLM fence operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c90617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e90617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e90a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e90e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt203MetricSet::CExt203MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt203MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_SLM_FENCE_MESSAGE_COUNT_XECORE12", "XVE SLM FENCE MESSAGE COUNT XECORE12",
                          "Number of SLM fence operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_SLM_FENCE_MESSAGE_COUNT_XECORE13", "XVE SLM FENCE MESSAGE COUNT XECORE13",
                          "Number of SLM fence operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f890400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03895476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0589069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09890617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a90a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a90e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt204MetricSet::CExt204MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt204MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_SLM_FENCE_MESSAGE_COUNT_XECORE14", "XVE SLM FENCE MESSAGE COUNT XECORE14",
                          "Number of SLM fence operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_SLM_FENCE_MESSAGE_COUNT_XECORE15", "XVE SLM FENCE MESSAGE COUNT XECORE15",
                          "Number of SLM fence operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c90207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c90617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe90207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e90617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e90a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e90e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt205MetricSet::CExt205MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt205MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_SLM_FENCE_MESSAGE_COUNT_XECORE16", "XVE SLM FENCE MESSAGE COUNT XECORE16",
                          "Number of SLM fence operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_SLM_FENCE_MESSAGE_COUNT_XECORE17", "XVE SLM FENCE MESSAGE COUNT XECORE17",
                          "Number of SLM fence operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02895476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0489069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a90a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a90e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt206MetricSet::CExt206MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt206MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_SLM_FENCE_MESSAGE_COUNT_XECORE18", "XVE SLM FENCE MESSAGE COUNT XECORE18",
                          "Number of SLM fence operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_SLM_FENCE_MESSAGE_COUNT_XECORE19", "XVE SLM FENCE MESSAGE COUNT XECORE19",
                          "Number of SLM fence operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c90617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e90617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e90a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e90e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt207MetricSet::CExt207MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt207MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_SLM_FENCE_MESSAGE_COUNT_XECORE20", "XVE SLM FENCE MESSAGE COUNT XECORE20",
                          "Number of SLM fence operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_SLM_FENCE_MESSAGE_COUNT_XECORE21", "XVE SLM FENCE MESSAGE COUNT XECORE21",
                          "Number of SLM fence operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f890400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03895476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0589069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09890617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a90a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a90e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt208MetricSet::CExt208MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt208MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_SLM_FENCE_MESSAGE_COUNT_XECORE22", "XVE SLM FENCE MESSAGE COUNT XECORE22",
                          "Number of SLM fence operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_SLM_FENCE_MESSAGE_COUNT_XECORE23", "XVE SLM FENCE MESSAGE COUNT XECORE23",
                          "Number of SLM fence operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c90207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c90617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe90207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e90617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e90a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e90e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt209MetricSet::CExt209MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt209MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "XVE_SLM_FENCE_MESSAGE_COUNT_XECORE24", "XVE SLM FENCE MESSAGE COUNT XECORE24",
                          "Number of SLM fence operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "XVE_SLM_FENCE_MESSAGE_COUNT_XECORE25", "XVE SLM FENCE MESSAGE COUNT XECORE25",
                          "Number of SLM fence operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02895476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0489069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a90a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a90e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt210MetricSet::CExt210MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt210MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "XVE_SLM_FENCE_MESSAGE_COUNT_XECORE26", "XVE SLM FENCE MESSAGE COUNT XECORE26",
                          "Number of SLM fence operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "XVE_SLM_FENCE_MESSAGE_COUNT_XECORE27", "XVE SLM FENCE MESSAGE COUNT XECORE27",
                          "Number of SLM fence operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c90617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e90617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e90a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e90e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt211MetricSet::CExt211MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt211MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "XVE_SLM_FENCE_MESSAGE_COUNT_XECORE28", "XVE SLM FENCE MESSAGE COUNT XECORE28",
                          "Number of SLM fence operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "XVE_SLM_FENCE_MESSAGE_COUNT_XECORE29", "XVE SLM FENCE MESSAGE COUNT XECORE29",
                          "Number of SLM fence operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f890400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03895476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0589069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09890617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a90a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a90e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt212MetricSet::CExt212MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt212MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "XVE_SLM_FENCE_MESSAGE_COUNT_XECORE30", "XVE SLM FENCE MESSAGE COUNT XECORE30",
                          "Number of SLM fence operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "XVE_SLM_FENCE_MESSAGE_COUNT_XECORE31", "XVE SLM FENCE MESSAGE COUNT XECORE31",
                          "Number of SLM fence operations sent by XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe90400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c90207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c90617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e95476, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e9069a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe90207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e90617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e90a27, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e90e37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt213MetricSet::CExt213MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt213MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_ACCESS_XECORE0", "LOAD STORE CACHE ACCESS XECORE0",
                          "Number of Load Store Cache accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_ACCESS_XECORE1", "LOAD STORE CACHE ACCESS XECORE1",
                          "Number of Load Store Cache accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_ACCESS_XECORE2", "LOAD STORE CACHE ACCESS XECORE2",
                          "Number of Load Store Cache accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_ACCESS_XECORE3", "LOAD STORE CACHE ACCESS XECORE3",
                          "Number of Load Store Cache accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14870010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e880010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00893000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031cea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030d46, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt214MetricSet::CExt214MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt214MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_ACCESS_XECORE4", "LOAD STORE CACHE ACCESS XECORE4",
                          "Number of Load Store Cache accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_ACCESS_XECORE5", "LOAD STORE CACHE ACCESS XECORE5",
                          "Number of Load Store Cache accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_ACCESS_XECORE6", "LOAD STORE CACHE ACCESS XECORE6",
                          "Number of Load Store Cache accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_ACCESS_XECORE7", "LOAD STORE CACHE ACCESS XECORE7",
                          "Number of Load Store Cache accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15870010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f880010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01893000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031cea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030d46, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt215MetricSet::CExt215MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt215MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_ACCESS_XECORE8", "LOAD STORE CACHE ACCESS XECORE8",
                          "Number of Load Store Cache accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_ACCESS_XECORE9", "LOAD STORE CACHE ACCESS XECORE9",
                          "Number of Load Store Cache accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_ACCESS_XECORE10", "LOAD STORE CACHE ACCESS XECORE10",
                          "Number of Load Store Cache accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_ACCESS_XECORE11", "LOAD STORE CACHE ACCESS XECORE11",
                          "Number of Load Store Cache accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14870010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e880010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00893000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031cea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030d46, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt216MetricSet::CExt216MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt216MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_ACCESS_XECORE12", "LOAD STORE CACHE ACCESS XECORE12",
                          "Number of Load Store Cache accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_ACCESS_XECORE13", "LOAD STORE CACHE ACCESS XECORE13",
                          "Number of Load Store Cache accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_ACCESS_XECORE14", "LOAD STORE CACHE ACCESS XECORE14",
                          "Number of Load Store Cache accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_ACCESS_XECORE15", "LOAD STORE CACHE ACCESS XECORE15",
                          "Number of Load Store Cache accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15870010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f880010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01893000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031cea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030d46, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt217MetricSet::CExt217MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt217MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_ACCESS_XECORE16", "LOAD STORE CACHE ACCESS XECORE16",
                          "Number of Load Store Cache accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_ACCESS_XECORE17", "LOAD STORE CACHE ACCESS XECORE17",
                          "Number of Load Store Cache accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_ACCESS_XECORE18", "LOAD STORE CACHE ACCESS XECORE18",
                          "Number of Load Store Cache accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_ACCESS_XECORE19", "LOAD STORE CACHE ACCESS XECORE19",
                          "Number of Load Store Cache accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14870010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e880010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00893000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031cea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030d46, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt218MetricSet::CExt218MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt218MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_ACCESS_XECORE20", "LOAD STORE CACHE ACCESS XECORE20",
                          "Number of Load Store Cache accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_ACCESS_XECORE21", "LOAD STORE CACHE ACCESS XECORE21",
                          "Number of Load Store Cache accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_ACCESS_XECORE22", "LOAD STORE CACHE ACCESS XECORE22",
                          "Number of Load Store Cache accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_ACCESS_XECORE23", "LOAD STORE CACHE ACCESS XECORE23",
                          "Number of Load Store Cache accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15870010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f880010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01893000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031cea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030d46, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt219MetricSet::CExt219MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt219MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_ACCESS_XECORE24", "LOAD STORE CACHE ACCESS XECORE24",
                          "Number of Load Store Cache accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_ACCESS_XECORE25", "LOAD STORE CACHE ACCESS XECORE25",
                          "Number of Load Store Cache accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_ACCESS_XECORE26", "LOAD STORE CACHE ACCESS XECORE26",
                          "Number of Load Store Cache accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_ACCESS_XECORE27", "LOAD STORE CACHE ACCESS XECORE27",
                          "Number of Load Store Cache accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14870010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e880010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00893000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031cea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030d46, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt220MetricSet::CExt220MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt220MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_ACCESS_XECORE28", "LOAD STORE CACHE ACCESS XECORE28",
                          "Number of Load Store Cache accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_ACCESS_XECORE29", "LOAD STORE CACHE ACCESS XECORE29",
                          "Number of Load Store Cache accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_ACCESS_XECORE30", "LOAD STORE CACHE ACCESS XECORE30",
                          "Number of Load Store Cache accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_ACCESS_XECORE31", "LOAD STORE CACHE ACCESS XECORE31",
                          "Number of Load Store Cache accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15870010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f880010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01893000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031cea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030d46, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt221MetricSet::CExt221MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt221MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_HIT_XECORE0", "LOAD STORE CACHE HIT XECORE0",
                          "Number of Load Store Cache hits.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_HIT_XECORE1", "LOAD STORE CACHE HIT XECORE1",
                          "Number of Load Store Cache hits.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06870143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08870553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06880143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08880553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008900f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea70143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a70553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea80143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a80553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a9f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030c60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030804, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000060, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000180, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000600, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt222MetricSet::CExt222MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt222MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_HIT_XECORE2", "LOAD STORE CACHE HIT XECORE2",
                          "Number of Load Store Cache hits.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_HIT_XECORE3", "LOAD STORE CACHE HIT XECORE3",
                          "Number of Load Store Cache hits.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c70143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c70553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c80143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c80553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c900f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee70143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e70553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee80143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e80553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e9f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c64, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203108a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030623, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000060, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000180, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000600, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt223MetricSet::CExt223MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt223MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_HIT_XECORE4", "LOAD STORE CACHE HIT XECORE4",
                          "Number of Load Store Cache hits.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_HIT_XECORE5", "LOAD STORE CACHE HIT XECORE5",
                          "Number of Load Store Cache hits.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07870143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09870553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07880143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09880553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018900f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa70143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a70553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa80143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a80553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a9f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030c60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030804, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000060, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000180, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000600, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt224MetricSet::CExt224MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt224MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_HIT_XECORE6", "LOAD STORE CACHE HIT XECORE6",
                          "Number of Load Store Cache hits.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_HIT_XECORE7", "LOAD STORE CACHE HIT XECORE7",
                          "Number of Load Store Cache hits.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c70143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c70553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c80143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c80553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c900f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe70143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e70553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe80143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e80553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e9f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c64, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203108a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030623, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000060, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000180, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000600, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt225MetricSet::CExt225MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt225MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_HIT_XECORE8", "LOAD STORE CACHE HIT XECORE8",
                          "Number of Load Store Cache hits.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_HIT_XECORE9", "LOAD STORE CACHE HIT XECORE9",
                          "Number of Load Store Cache hits.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06870143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08870553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06880143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08880553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008900f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea70143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a70553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea80143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a80553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a9f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030c60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030804, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000060, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000180, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000600, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt226MetricSet::CExt226MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt226MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_HIT_XECORE10", "LOAD STORE CACHE HIT XECORE10",
                          "Number of Load Store Cache hits.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_HIT_XECORE11", "LOAD STORE CACHE HIT XECORE11",
                          "Number of Load Store Cache hits.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c70143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c70553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c80143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c80553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c900f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee70143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e70553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee80143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e80553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e9f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c64, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203108a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030623, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000060, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000180, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000600, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt227MetricSet::CExt227MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt227MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_HIT_XECORE12", "LOAD STORE CACHE HIT XECORE12",
                          "Number of Load Store Cache hits.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_HIT_XECORE13", "LOAD STORE CACHE HIT XECORE13",
                          "Number of Load Store Cache hits.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07870143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09870553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07880143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09880553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018900f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa70143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a70553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa80143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a80553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a9f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030c60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030804, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000060, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000180, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000600, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt228MetricSet::CExt228MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt228MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_HIT_XECORE14", "LOAD STORE CACHE HIT XECORE14",
                          "Number of Load Store Cache hits.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_HIT_XECORE15", "LOAD STORE CACHE HIT XECORE15",
                          "Number of Load Store Cache hits.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c70143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c70553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c80143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c80553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c900f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe70143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e70553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe80143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e80553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e9f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c64, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203108a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030623, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000060, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000180, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000600, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt229MetricSet::CExt229MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt229MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_HIT_XECORE16", "LOAD STORE CACHE HIT XECORE16",
                          "Number of Load Store Cache hits.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_HIT_XECORE17", "LOAD STORE CACHE HIT XECORE17",
                          "Number of Load Store Cache hits.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06870143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08870553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06880143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08880553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008900f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea70143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a70553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea80143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a80553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a9f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030c60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030804, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000060, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000180, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000600, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt230MetricSet::CExt230MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt230MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_HIT_XECORE18", "LOAD STORE CACHE HIT XECORE18",
                          "Number of Load Store Cache hits.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_HIT_XECORE19", "LOAD STORE CACHE HIT XECORE19",
                          "Number of Load Store Cache hits.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c70143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c70553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c80143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c80553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c900f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee70143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e70553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee80143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e80553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e9f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c64, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203108a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030623, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000060, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000180, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000600, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt231MetricSet::CExt231MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt231MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_HIT_XECORE20", "LOAD STORE CACHE HIT XECORE20",
                          "Number of Load Store Cache hits.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_HIT_XECORE21", "LOAD STORE CACHE HIT XECORE21",
                          "Number of Load Store Cache hits.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07870143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09870553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07880143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09880553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018900f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa70143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a70553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa80143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a80553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a9f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030c60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030804, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000060, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000180, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000600, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt232MetricSet::CExt232MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt232MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_HIT_XECORE22", "LOAD STORE CACHE HIT XECORE22",
                          "Number of Load Store Cache hits.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_HIT_XECORE23", "LOAD STORE CACHE HIT XECORE23",
                          "Number of Load Store Cache hits.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c70143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c70553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c80143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c80553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c900f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe70143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e70553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe80143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e80553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e9f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c64, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203108a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030623, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000060, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000180, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000600, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt233MetricSet::CExt233MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt233MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_HIT_XECORE24", "LOAD STORE CACHE HIT XECORE24",
                          "Number of Load Store Cache hits.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_HIT_XECORE25", "LOAD STORE CACHE HIT XECORE25",
                          "Number of Load Store Cache hits.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06870143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08870553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06880143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08880553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008900f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea70143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a70553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea80143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a80553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a9f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030c60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030804, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000060, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000180, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000600, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt234MetricSet::CExt234MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt234MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_HIT_XECORE26", "LOAD STORE CACHE HIT XECORE26",
                          "Number of Load Store Cache hits.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_HIT_XECORE27", "LOAD STORE CACHE HIT XECORE27",
                          "Number of Load Store Cache hits.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c70143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c70553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c80143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c80553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c900f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee70143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e70553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee80143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e80553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e9f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c64, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203108a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030623, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000060, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000180, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000600, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt235MetricSet::CExt235MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt235MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_HIT_XECORE28", "LOAD STORE CACHE HIT XECORE28",
                          "Number of Load Store Cache hits.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_HIT_XECORE29", "LOAD STORE CACHE HIT XECORE29",
                          "Number of Load Store Cache hits.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07870143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09870553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07880143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09880553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018900f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa70143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a70553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa80143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a80553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a9f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030c60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030804, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000060, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000180, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000600, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt236MetricSet::CExt236MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt236MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_HIT_XECORE30", "LOAD STORE CACHE HIT XECORE30",
                          "Number of Load Store Cache hits.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_HIT_XECORE31", "LOAD STORE CACHE HIT XECORE31",
                          "Number of Load Store Cache hits.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c70143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c70553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c80143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c80553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c900f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe70143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e70553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe80143, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e80553, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e9f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c64, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203108a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030623, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000060, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000180, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000600, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt237MetricSet::CExt237MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt237MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE0", "LOAD STORE CACHE L3 READ XECORE0",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE1", "LOAD STORE CACHE L3 READ XECORE1",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE2", "LOAD STORE CACHE L3 READ XECORE2",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE3", "LOAD STORE CACHE L3 READ XECORE3",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE4", "LOAD STORE CACHE L3 READ XECORE4",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE5", "LOAD STORE CACHE L3 READ XECORE5",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4 dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168 qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE6", "LOAD STORE CACHE L3 READ XECORE6",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE7", "LOAD STORE CACHE L3 READ XECORE7",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1689001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1789001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14890083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a43000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000300ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020700a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208af00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a55aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000130ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010700a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108af00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a55aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03210a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030423, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030e21, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030ee7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt238MetricSet::CExt238MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt238MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE8", "LOAD STORE CACHE L3 READ XECORE8",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE9", "LOAD STORE CACHE L3 READ XECORE9",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE10", "LOAD STORE CACHE L3 READ XECORE10",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE11", "LOAD STORE CACHE L3 READ XECORE11",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE12", "LOAD STORE CACHE L3 READ XECORE12",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE13", "LOAD STORE CACHE L3 READ XECORE13",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4 dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168 qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE14", "LOAD STORE CACHE L3 READ XECORE14",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE15", "LOAD STORE CACHE L3 READ XECORE15",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1689001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1789001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14890083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a43000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000300ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020700a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208af00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a55aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000130ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010700a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108af00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a55aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03210a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030423, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030e21, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030ee7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt239MetricSet::CExt239MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt239MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE16", "LOAD STORE CACHE L3 READ XECORE16",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE17", "LOAD STORE CACHE L3 READ XECORE17",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE18", "LOAD STORE CACHE L3 READ XECORE18",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE19", "LOAD STORE CACHE L3 READ XECORE19",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE20", "LOAD STORE CACHE L3 READ XECORE20",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE21", "LOAD STORE CACHE L3 READ XECORE21",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4 dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168 qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE22", "LOAD STORE CACHE L3 READ XECORE22",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE23", "LOAD STORE CACHE L3 READ XECORE23",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1689001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1789001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14890083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a43000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000300ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020700a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208af00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a55aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000130ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010700a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108af00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a55aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03210a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030423, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030e21, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030ee7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt240MetricSet::CExt240MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt240MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE24", "LOAD STORE CACHE L3 READ XECORE24",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE25", "LOAD STORE CACHE L3 READ XECORE25",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE26", "LOAD STORE CACHE L3 READ XECORE26",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE27", "LOAD STORE CACHE L3 READ XECORE27",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE28", "LOAD STORE CACHE L3 READ XECORE28",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE29", "LOAD STORE CACHE L3 READ XECORE29",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4 dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168 qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE30", "LOAD STORE CACHE L3 READ XECORE30",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_READ_XECORE31", "LOAD STORE CACHE L3 READ XECORE31",
                          "Number of cacheline read requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1689001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1789001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14890083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a43000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000300ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020700a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208af00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a55aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000130ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010700a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108af00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a55aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03210a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030423, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030e21, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030ee7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt241MetricSet::CExt241MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt241MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE0", "LOAD STORE CACHE L3 WRITE XECORE0",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE1", "LOAD STORE CACHE L3 WRITE XECORE1",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE2", "LOAD STORE CACHE L3 WRITE XECORE2",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE3", "LOAD STORE CACHE L3 WRITE XECORE3",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE4", "LOAD STORE CACHE L3 WRITE XECORE4",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE5", "LOAD STORE CACHE L3 WRITE XECORE5",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4 dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168 qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE6", "LOAD STORE CACHE L3 WRITE XECORE6",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE7", "LOAD STORE CACHE L3 WRITE XECORE7",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1689001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1789001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14890105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a43000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a90105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c90105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba90105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c90105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000300ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020700a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208af00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a55aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000130ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010700a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108af00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a55aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03210a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030423, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030e21, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030ee7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt242MetricSet::CExt242MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt242MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE8", "LOAD STORE CACHE L3 WRITE XECORE8",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE9", "LOAD STORE CACHE L3 WRITE XECORE9",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE10", "LOAD STORE CACHE L3 WRITE XECORE10",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE11", "LOAD STORE CACHE L3 WRITE XECORE11",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE12", "LOAD STORE CACHE L3 WRITE XECORE12",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE13", "LOAD STORE CACHE L3 WRITE XECORE13",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4 dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168 qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE14", "LOAD STORE CACHE L3 WRITE XECORE14",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE15", "LOAD STORE CACHE L3 WRITE XECORE15",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1689001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1789001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14890105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a43000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a90105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c90105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba90105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c90105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000300ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020700a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208af00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a55aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000130ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010700a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108af00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a55aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03210a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030423, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030e21, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030ee7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt243MetricSet::CExt243MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt243MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE16", "LOAD STORE CACHE L3 WRITE XECORE16",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE17", "LOAD STORE CACHE L3 WRITE XECORE17",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE18", "LOAD STORE CACHE L3 WRITE XECORE18",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE19", "LOAD STORE CACHE L3 WRITE XECORE19",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE20", "LOAD STORE CACHE L3 WRITE XECORE20",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE21", "LOAD STORE CACHE L3 WRITE XECORE21",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4 dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168 qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE22", "LOAD STORE CACHE L3 WRITE XECORE22",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE23", "LOAD STORE CACHE L3 WRITE XECORE23",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1689001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1789001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14890105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a43000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a90105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c90105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba90105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c90105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000300ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020700a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208af00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a55aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000130ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010700a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108af00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a55aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03210a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030423, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030e21, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030ee7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt244MetricSet::CExt244MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt244MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE24", "LOAD STORE CACHE L3 WRITE XECORE24",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE25", "LOAD STORE CACHE L3 WRITE XECORE25",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE26", "LOAD STORE CACHE L3 WRITE XECORE26",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE27", "LOAD STORE CACHE L3 WRITE XECORE27",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE28", "LOAD STORE CACHE L3 WRITE XECORE28",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE29", "LOAD STORE CACHE L3 WRITE XECORE29",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4 dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168 qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE30", "LOAD STORE CACHE L3 WRITE XECORE30",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_L3_WRITE_XECORE31", "LOAD STORE CACHE L3 WRITE XECORE31",
                          "Number of cacheline write requests from the Load Store Cache to L3",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1689001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1789001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e9001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14890105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a43000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a90105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c90105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba90105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c90105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000300ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020700a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208af00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a55aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000130ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010700a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108af00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a55aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03210a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030423, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030e21, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030ee7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt245MetricSet::CExt245MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt245MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_PARTIAL_WRITE_COUNT_XECORE0", "LOAD STORE CACHE PARTIAL WRITE COUNT XECORE0",
                          "Number of writes to the Load Store Cache that don't fill a subsector",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_PARTIAL_WRITE_COUNT_XECORE1", "LOAD STORE CACHE PARTIAL WRITE COUNT XECORE1",
                          "Number of writes to the Load Store Cache that don't fill a subsector",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_PARTIAL_WRITE_COUNT_XECORE2", "LOAD STORE CACHE PARTIAL WRITE COUNT XECORE2",
                          "Number of writes to the Load Store Cache that don't fill a subsector",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_PARTIAL_WRITE_COUNT_XECORE3", "LOAD STORE CACHE PARTIAL WRITE COUNT XECORE3",
                          "Number of writes to the Load Store Cache that don't fill a subsector",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12880005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16880005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x148701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e8801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00893000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031cea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030d46, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt246MetricSet::CExt246MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt246MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_PARTIAL_WRITE_COUNT_XECORE4", "LOAD STORE CACHE PARTIAL WRITE COUNT XECORE4",
                          "Number of writes to the Load Store Cache that don't fill a subsector",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_PARTIAL_WRITE_COUNT_XECORE5", "LOAD STORE CACHE PARTIAL WRITE COUNT XECORE5",
                          "Number of writes to the Load Store Cache that don't fill a subsector",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_PARTIAL_WRITE_COUNT_XECORE6", "LOAD STORE CACHE PARTIAL WRITE COUNT XECORE6",
                          "Number of writes to the Load Store Cache that don't fill a subsector",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_PARTIAL_WRITE_COUNT_XECORE7", "LOAD STORE CACHE PARTIAL WRITE COUNT XECORE7",
                          "Number of writes to the Load Store Cache that don't fill a subsector",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13880005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17880005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x158701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f8801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01893000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031cea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030d46, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt247MetricSet::CExt247MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt247MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_PARTIAL_WRITE_COUNT_XECORE8", "LOAD STORE CACHE PARTIAL WRITE COUNT XECORE8",
                          "Number of writes to the Load Store Cache that don't fill a subsector",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_PARTIAL_WRITE_COUNT_XECORE9", "LOAD STORE CACHE PARTIAL WRITE COUNT XECORE9",
                          "Number of writes to the Load Store Cache that don't fill a subsector",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_PARTIAL_WRITE_COUNT_XECORE10", "LOAD STORE CACHE PARTIAL WRITE COUNT XECORE10",
                          "Number of writes to the Load Store Cache that don't fill a subsector",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_PARTIAL_WRITE_COUNT_XECORE11", "LOAD STORE CACHE PARTIAL WRITE COUNT XECORE11",
                          "Number of writes to the Load Store Cache that don't fill a subsector",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12880005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16880005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x148701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e8801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00893000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031cea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030d46, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt248MetricSet::CExt248MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt248MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_PARTIAL_WRITE_COUNT_XECORE12", "LOAD STORE CACHE PARTIAL WRITE COUNT XECORE12",
                          "Number of writes to the Load Store Cache that don't fill a subsector",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_PARTIAL_WRITE_COUNT_XECORE13", "LOAD STORE CACHE PARTIAL WRITE COUNT XECORE13",
                          "Number of writes to the Load Store Cache that don't fill a subsector",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_PARTIAL_WRITE_COUNT_XECORE14", "LOAD STORE CACHE PARTIAL WRITE COUNT XECORE14",
                          "Number of writes to the Load Store Cache that don't fill a subsector",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_PARTIAL_WRITE_COUNT_XECORE15", "LOAD STORE CACHE PARTIAL WRITE COUNT XECORE15",
                          "Number of writes to the Load Store Cache that don't fill a subsector",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13880005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17880005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x158701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f8801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01893000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031cea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030d46, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt249MetricSet::CExt249MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt249MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_PARTIAL_WRITE_COUNT_XECORE16", "LOAD STORE CACHE PARTIAL WRITE COUNT XECORE16",
                          "Number of writes to the Load Store Cache that don't fill a subsector",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_PARTIAL_WRITE_COUNT_XECORE17", "LOAD STORE CACHE PARTIAL WRITE COUNT XECORE17",
                          "Number of writes to the Load Store Cache that don't fill a subsector",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_PARTIAL_WRITE_COUNT_XECORE18", "LOAD STORE CACHE PARTIAL WRITE COUNT XECORE18",
                          "Number of writes to the Load Store Cache that don't fill a subsector",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_PARTIAL_WRITE_COUNT_XECORE19", "LOAD STORE CACHE PARTIAL WRITE COUNT XECORE19",
                          "Number of writes to the Load Store Cache that don't fill a subsector",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12880005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16880005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x148701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e8801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00893000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031cea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030d46, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt250MetricSet::CExt250MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt250MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_PARTIAL_WRITE_COUNT_XECORE20", "LOAD STORE CACHE PARTIAL WRITE COUNT XECORE20",
                          "Number of writes to the Load Store Cache that don't fill a subsector",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_PARTIAL_WRITE_COUNT_XECORE21", "LOAD STORE CACHE PARTIAL WRITE COUNT XECORE21",
                          "Number of writes to the Load Store Cache that don't fill a subsector",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_PARTIAL_WRITE_COUNT_XECORE22", "LOAD STORE CACHE PARTIAL WRITE COUNT XECORE22",
                          "Number of writes to the Load Store Cache that don't fill a subsector",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_PARTIAL_WRITE_COUNT_XECORE23", "LOAD STORE CACHE PARTIAL WRITE COUNT XECORE23",
                          "Number of writes to the Load Store Cache that don't fill a subsector",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13880005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17880005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x158701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f8801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01893000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031cea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030d46, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt251MetricSet::CExt251MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt251MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_PARTIAL_WRITE_COUNT_XECORE24", "LOAD STORE CACHE PARTIAL WRITE COUNT XECORE24",
                          "Number of writes to the Load Store Cache that don't fill a subsector",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_PARTIAL_WRITE_COUNT_XECORE25", "LOAD STORE CACHE PARTIAL WRITE COUNT XECORE25",
                          "Number of writes to the Load Store Cache that don't fill a subsector",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_PARTIAL_WRITE_COUNT_XECORE26", "LOAD STORE CACHE PARTIAL WRITE COUNT XECORE26",
                          "Number of writes to the Load Store Cache that don't fill a subsector",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_PARTIAL_WRITE_COUNT_XECORE27", "LOAD STORE CACHE PARTIAL WRITE COUNT XECORE27",
                          "Number of writes to the Load Store Cache that don't fill a subsector",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12880005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16880005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x148701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e8801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00893000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031cea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030d46, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt252MetricSet::CExt252MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt252MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_PARTIAL_WRITE_COUNT_XECORE28", "LOAD STORE CACHE PARTIAL WRITE COUNT XECORE28",
                          "Number of writes to the Load Store Cache that don't fill a subsector",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_PARTIAL_WRITE_COUNT_XECORE29", "LOAD STORE CACHE PARTIAL WRITE COUNT XECORE29",
                          "Number of writes to the Load Store Cache that don't fill a subsector",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_PARTIAL_WRITE_COUNT_XECORE30", "LOAD STORE CACHE PARTIAL WRITE COUNT XECORE30",
                          "Number of writes to the Load Store Cache that don't fill a subsector",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_PARTIAL_WRITE_COUNT_XECORE31", "LOAD STORE CACHE PARTIAL WRITE COUNT XECORE31",
                          "Number of writes to the Load Store Cache that don't fill a subsector",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13880005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17880005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e80005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x158701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f8801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01893000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031cea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030d46, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt253MetricSet::CExt253MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt253MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_REQUEST_COUNT_XECORE0", "XVE LOAD STORE CACHE REGISTER REQUEST COUNT XECORE0",
                          "Number of message payload transactions sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_REQUEST_COUNT_XECORE1", "XVE LOAD STORE CACHE REGISTER REQUEST COUNT XECORE1",
                          "Number of message payload transactions sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_REQUEST_COUNT_XECORE2", "XVE LOAD STORE CACHE REGISTER REQUEST COUNT XECORE2",
                          "Number of message payload transactions sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_REQUEST_COUNT_XECORE3", "XVE LOAD STORE CACHE REGISTER REQUEST COUNT XECORE3",
                          "Number of message payload transactions sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12890871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14890051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt254MetricSet::CExt254MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt254MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_REQUEST_COUNT_XECORE4", "XVE LOAD STORE CACHE REGISTER REQUEST COUNT XECORE4",
                          "Number of message payload transactions sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_REQUEST_COUNT_XECORE5", "XVE LOAD STORE CACHE REGISTER REQUEST COUNT XECORE5",
                          "Number of message payload transactions sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_REQUEST_COUNT_XECORE6", "XVE LOAD STORE CACHE REGISTER REQUEST COUNT XECORE6",
                          "Number of message payload transactions sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_REQUEST_COUNT_XECORE7", "XVE LOAD STORE CACHE REGISTER REQUEST COUNT XECORE7",
                          "Number of message payload transactions sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0387aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13890871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15890051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt255MetricSet::CExt255MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt255MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_REQUEST_COUNT_XECORE8", "XVE LOAD STORE CACHE REGISTER REQUEST COUNT XECORE8",
                          "Number of message payload transactions sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_REQUEST_COUNT_XECORE9", "XVE LOAD STORE CACHE REGISTER REQUEST COUNT XECORE9",
                          "Number of message payload transactions sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_REQUEST_COUNT_XECORE10", "XVE LOAD STORE CACHE REGISTER REQUEST COUNT XECORE10",
                          "Number of message payload transactions sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_REQUEST_COUNT_XECORE11", "XVE LOAD STORE CACHE REGISTER REQUEST COUNT XECORE11",
                          "Number of message payload transactions sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12890871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14890051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt256MetricSet::CExt256MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt256MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_REQUEST_COUNT_XECORE12", "XVE LOAD STORE CACHE REGISTER REQUEST COUNT XECORE12",
                          "Number of message payload transactions sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_REQUEST_COUNT_XECORE13", "XVE LOAD STORE CACHE REGISTER REQUEST COUNT XECORE13",
                          "Number of message payload transactions sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_REQUEST_COUNT_XECORE14", "XVE LOAD STORE CACHE REGISTER REQUEST COUNT XECORE14",
                          "Number of message payload transactions sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_REQUEST_COUNT_XECORE15", "XVE LOAD STORE CACHE REGISTER REQUEST COUNT XECORE15",
                          "Number of message payload transactions sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0387aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13890871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15890051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt257MetricSet::CExt257MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt257MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_REQUEST_COUNT_XECORE16", "XVE LOAD STORE CACHE REGISTER REQUEST COUNT XECORE16",
                          "Number of message payload transactions sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_REQUEST_COUNT_XECORE17", "XVE LOAD STORE CACHE REGISTER REQUEST COUNT XECORE17",
                          "Number of message payload transactions sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_REQUEST_COUNT_XECORE18", "XVE LOAD STORE CACHE REGISTER REQUEST COUNT XECORE18",
                          "Number of message payload transactions sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_REQUEST_COUNT_XECORE19", "XVE LOAD STORE CACHE REGISTER REQUEST COUNT XECORE19",
                          "Number of message payload transactions sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12890871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14890051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt258MetricSet::CExt258MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt258MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_REQUEST_COUNT_XECORE20", "XVE LOAD STORE CACHE REGISTER REQUEST COUNT XECORE20",
                          "Number of message payload transactions sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_REQUEST_COUNT_XECORE21", "XVE LOAD STORE CACHE REGISTER REQUEST COUNT XECORE21",
                          "Number of message payload transactions sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_REQUEST_COUNT_XECORE22", "XVE LOAD STORE CACHE REGISTER REQUEST COUNT XECORE22",
                          "Number of message payload transactions sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_REQUEST_COUNT_XECORE23", "XVE LOAD STORE CACHE REGISTER REQUEST COUNT XECORE23",
                          "Number of message payload transactions sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0387aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13890871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15890051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt259MetricSet::CExt259MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt259MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_REQUEST_COUNT_XECORE24", "XVE LOAD STORE CACHE REGISTER REQUEST COUNT XECORE24",
                          "Number of message payload transactions sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_REQUEST_COUNT_XECORE25", "XVE LOAD STORE CACHE REGISTER REQUEST COUNT XECORE25",
                          "Number of message payload transactions sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_REQUEST_COUNT_XECORE26", "XVE LOAD STORE CACHE REGISTER REQUEST COUNT XECORE26",
                          "Number of message payload transactions sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_REQUEST_COUNT_XECORE27", "XVE LOAD STORE CACHE REGISTER REQUEST COUNT XECORE27",
                          "Number of message payload transactions sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12890871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14890051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt260MetricSet::CExt260MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt260MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_REQUEST_COUNT_XECORE28", "XVE LOAD STORE CACHE REGISTER REQUEST COUNT XECORE28",
                          "Number of message payload transactions sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_REQUEST_COUNT_XECORE29", "XVE LOAD STORE CACHE REGISTER REQUEST COUNT XECORE29",
                          "Number of message payload transactions sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_REQUEST_COUNT_XECORE30", "XVE LOAD STORE CACHE REGISTER REQUEST COUNT XECORE30",
                          "Number of message payload transactions sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_REQUEST_COUNT_XECORE31", "XVE LOAD STORE CACHE REGISTER REQUEST COUNT XECORE31",
                          "Number of message payload transactions sent by XVEs to the Load Store Cache",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0387aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13890871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15890051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt261MetricSet::CExt261MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt261MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_RESPONSE_COUNT_XECORE0", "XVE LOAD STORE CACHE REGISTER RESPONSE COUNT XECORE0",
                          "Number of message payload transactions sent from the Load Store Cache back to XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_RESPONSE_COUNT_XECORE1", "XVE LOAD STORE CACHE REGISTER RESPONSE COUNT XECORE1",
                          "Number of message payload transactions sent from the Load Store Cache back to XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_RESPONSE_COUNT_XECORE2", "XVE LOAD STORE CACHE REGISTER RESPONSE COUNT XECORE2",
                          "Number of message payload transactions sent from the Load Store Cache back to XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_RESPONSE_COUNT_XECORE3", "XVE LOAD STORE CACHE REGISTER RESPONSE COUNT XECORE3",
                          "Number of message payload transactions sent from the Load Store Cache back to XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a89001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e897000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a89001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12890871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14890051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt262MetricSet::CExt262MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt262MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_RESPONSE_COUNT_XECORE4", "XVE LOAD STORE CACHE REGISTER RESPONSE COUNT XECORE4",
                          "Number of message payload transactions sent from the Load Store Cache back to XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_RESPONSE_COUNT_XECORE5", "XVE LOAD STORE CACHE REGISTER RESPONSE COUNT XECORE5",
                          "Number of message payload transactions sent from the Load Store Cache back to XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_RESPONSE_COUNT_XECORE6", "XVE LOAD STORE CACHE REGISTER RESPONSE COUNT XECORE6",
                          "Number of message payload transactions sent from the Load Store Cache back to XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_RESPONSE_COUNT_XECORE7", "XVE LOAD STORE CACHE REGISTER RESPONSE COUNT XECORE7",
                          "Number of message payload transactions sent from the Load Store Cache back to XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b89001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f897000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b89001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0387aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13890871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15890051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt263MetricSet::CExt263MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt263MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_RESPONSE_COUNT_XECORE8", "XVE LOAD STORE CACHE REGISTER RESPONSE COUNT XECORE8",
                          "Number of message payload transactions sent from the Load Store Cache back to XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_RESPONSE_COUNT_XECORE9", "XVE LOAD STORE CACHE REGISTER RESPONSE COUNT XECORE9",
                          "Number of message payload transactions sent from the Load Store Cache back to XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_RESPONSE_COUNT_XECORE10", "XVE LOAD STORE CACHE REGISTER RESPONSE COUNT XECORE10",
                          "Number of message payload transactions sent from the Load Store Cache back to XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_RESPONSE_COUNT_XECORE11", "XVE LOAD STORE CACHE REGISTER RESPONSE COUNT XECORE11",
                          "Number of message payload transactions sent from the Load Store Cache back to XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a89001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e897000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a89001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12890871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14890051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt264MetricSet::CExt264MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt264MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_RESPONSE_COUNT_XECORE12", "XVE LOAD STORE CACHE REGISTER RESPONSE COUNT XECORE12",
                          "Number of message payload transactions sent from the Load Store Cache back to XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_RESPONSE_COUNT_XECORE13", "XVE LOAD STORE CACHE REGISTER RESPONSE COUNT XECORE13",
                          "Number of message payload transactions sent from the Load Store Cache back to XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_RESPONSE_COUNT_XECORE14", "XVE LOAD STORE CACHE REGISTER RESPONSE COUNT XECORE14",
                          "Number of message payload transactions sent from the Load Store Cache back to XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_RESPONSE_COUNT_XECORE15", "XVE LOAD STORE CACHE REGISTER RESPONSE COUNT XECORE15",
                          "Number of message payload transactions sent from the Load Store Cache back to XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b89001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f897000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b89001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0387aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13890871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15890051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt265MetricSet::CExt265MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt265MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_RESPONSE_COUNT_XECORE16", "XVE LOAD STORE CACHE REGISTER RESPONSE COUNT XECORE16",
                          "Number of message payload transactions sent from the Load Store Cache back to XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_RESPONSE_COUNT_XECORE17", "XVE LOAD STORE CACHE REGISTER RESPONSE COUNT XECORE17",
                          "Number of message payload transactions sent from the Load Store Cache back to XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_RESPONSE_COUNT_XECORE18", "XVE LOAD STORE CACHE REGISTER RESPONSE COUNT XECORE18",
                          "Number of message payload transactions sent from the Load Store Cache back to XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_RESPONSE_COUNT_XECORE19", "XVE LOAD STORE CACHE REGISTER RESPONSE COUNT XECORE19",
                          "Number of message payload transactions sent from the Load Store Cache back to XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a89001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e897000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a89001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12890871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14890051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt266MetricSet::CExt266MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt266MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_RESPONSE_COUNT_XECORE20", "XVE LOAD STORE CACHE REGISTER RESPONSE COUNT XECORE20",
                          "Number of message payload transactions sent from the Load Store Cache back to XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_RESPONSE_COUNT_XECORE21", "XVE LOAD STORE CACHE REGISTER RESPONSE COUNT XECORE21",
                          "Number of message payload transactions sent from the Load Store Cache back to XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_RESPONSE_COUNT_XECORE22", "XVE LOAD STORE CACHE REGISTER RESPONSE COUNT XECORE22",
                          "Number of message payload transactions sent from the Load Store Cache back to XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_RESPONSE_COUNT_XECORE23", "XVE LOAD STORE CACHE REGISTER RESPONSE COUNT XECORE23",
                          "Number of message payload transactions sent from the Load Store Cache back to XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b89001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f897000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b89001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0387aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13890871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15890051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt267MetricSet::CExt267MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt267MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_RESPONSE_COUNT_XECORE24", "XVE LOAD STORE CACHE REGISTER RESPONSE COUNT XECORE24",
                          "Number of message payload transactions sent from the Load Store Cache back to XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_RESPONSE_COUNT_XECORE25", "XVE LOAD STORE CACHE REGISTER RESPONSE COUNT XECORE25",
                          "Number of message payload transactions sent from the Load Store Cache back to XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_RESPONSE_COUNT_XECORE26", "XVE LOAD STORE CACHE REGISTER RESPONSE COUNT XECORE26",
                          "Number of message payload transactions sent from the Load Store Cache back to XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_RESPONSE_COUNT_XECORE27", "XVE LOAD STORE CACHE REGISTER RESPONSE COUNT XECORE27",
                          "Number of message payload transactions sent from the Load Store Cache back to XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a89001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e897000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a89001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12890871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14890051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt268MetricSet::CExt268MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt268MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_RESPONSE_COUNT_XECORE28", "XVE LOAD STORE CACHE REGISTER RESPONSE COUNT XECORE28",
                          "Number of message payload transactions sent from the Load Store Cache back to XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_RESPONSE_COUNT_XECORE29", "XVE LOAD STORE CACHE REGISTER RESPONSE COUNT XECORE29",
                          "Number of message payload transactions sent from the Load Store Cache back to XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_RESPONSE_COUNT_XECORE30", "XVE LOAD STORE CACHE REGISTER RESPONSE COUNT XECORE30",
                          "Number of message payload transactions sent from the Load Store Cache back to XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "XVE_LOAD_STORE_CACHE_REGISTER_RESPONSE_COUNT_XECORE31", "XVE LOAD STORE CACHE REGISTER RESPONSE COUNT XECORE31",
                          "Number of message payload transactions sent from the Load Store Cache back to XVEs",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b89001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f897000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b89001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0387aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13890871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15890051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90871, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e90051, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt269MetricSet::CExt269MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt269MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE0", "LOAD STORE CACHE INPUT AVAILABLE XECORE0",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE1", "LOAD STORE CACHE INPUT AVAILABLE XECORE1",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE2", "LOAD STORE CACHE INPUT AVAILABLE XECORE2",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE3", "LOAD STORE CACHE INPUT AVAILABLE XECORE3",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a890002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a890002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12890975, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14890155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90975, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90975, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90975, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e90155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt270MetricSet::CExt270MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt270MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE4", "LOAD STORE CACHE INPUT AVAILABLE XECORE4",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE5", "LOAD STORE CACHE INPUT AVAILABLE XECORE5",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE6", "LOAD STORE CACHE INPUT AVAILABLE XECORE6",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE7", "LOAD STORE CACHE INPUT AVAILABLE XECORE7",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b890002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f890800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b890002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa90800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc90800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe90800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0387aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13890975, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15890155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90975, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90975, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90975, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e90155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt271MetricSet::CExt271MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt271MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE8", "LOAD STORE CACHE INPUT AVAILABLE XECORE8",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE9", "LOAD STORE CACHE INPUT AVAILABLE XECORE9",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE10", "LOAD STORE CACHE INPUT AVAILABLE XECORE10",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE11", "LOAD STORE CACHE INPUT AVAILABLE XECORE11",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a890002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a890002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12890975, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14890155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90975, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90975, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90975, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e90155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt272MetricSet::CExt272MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt272MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE12", "LOAD STORE CACHE INPUT AVAILABLE XECORE12",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE13", "LOAD STORE CACHE INPUT AVAILABLE XECORE13",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE14", "LOAD STORE CACHE INPUT AVAILABLE XECORE14",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE15", "LOAD STORE CACHE INPUT AVAILABLE XECORE15",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b890002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f890800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b890002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa90800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc90800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe90800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0387aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13890975, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15890155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90975, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90975, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90975, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e90155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt273MetricSet::CExt273MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt273MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE16", "LOAD STORE CACHE INPUT AVAILABLE XECORE16",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE17", "LOAD STORE CACHE INPUT AVAILABLE XECORE17",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE18", "LOAD STORE CACHE INPUT AVAILABLE XECORE18",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE19", "LOAD STORE CACHE INPUT AVAILABLE XECORE19",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a890002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a890002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12890975, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14890155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90975, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90975, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90975, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e90155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt274MetricSet::CExt274MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt274MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE20", "LOAD STORE CACHE INPUT AVAILABLE XECORE20",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE21", "LOAD STORE CACHE INPUT AVAILABLE XECORE21",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE22", "LOAD STORE CACHE INPUT AVAILABLE XECORE22",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE23", "LOAD STORE CACHE INPUT AVAILABLE XECORE23",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b890002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f890800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b890002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa90800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc90800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe90800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0387aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13890975, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15890155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90975, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90975, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90975, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e90155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt275MetricSet::CExt275MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt275MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE24", "LOAD STORE CACHE INPUT AVAILABLE XECORE24",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE25", "LOAD STORE CACHE INPUT AVAILABLE XECORE25",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE26", "LOAD STORE CACHE INPUT AVAILABLE XECORE26",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE27", "LOAD STORE CACHE INPUT AVAILABLE XECORE27",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a890002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a890002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12890975, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14890155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90975, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90975, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90975, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e90155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt276MetricSet::CExt276MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt276MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE28", "LOAD STORE CACHE INPUT AVAILABLE XECORE28",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE29", "LOAD STORE CACHE INPUT AVAILABLE XECORE29",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE30", "LOAD STORE CACHE INPUT AVAILABLE XECORE30",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_INPUT_AVAILABLE_XECORE31", "LOAD STORE CACHE INPUT AVAILABLE XECORE31",
                          "Percentage of time in which the Load Store Cache has input available",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b890002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f890800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b890002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa90800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc90800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe90800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be90002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0387aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13890975, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15890155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90975, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90975, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90975, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e90155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt277MetricSet::CExt277MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt277MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE0", "LOAD STORE CACHE OUTPUT READY XECORE0",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE1", "LOAD STORE CACHE OUTPUT READY XECORE1",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE2", "LOAD STORE CACHE OUTPUT READY XECORE2",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE3", "LOAD STORE CACHE OUTPUT READY XECORE3",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a89001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e897000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a89001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12890934, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14890114, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90934, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90114, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90934, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90114, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90934, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e90114, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt278MetricSet::CExt278MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt278MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE4", "LOAD STORE CACHE OUTPUT READY XECORE4",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE5", "LOAD STORE CACHE OUTPUT READY XECORE5",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE6", "LOAD STORE CACHE OUTPUT READY XECORE6",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE7", "LOAD STORE CACHE OUTPUT READY XECORE7",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b89001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f897000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b89001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0387aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13890934, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15890114, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90934, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90114, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90934, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90114, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90934, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e90114, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt279MetricSet::CExt279MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt279MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE8", "LOAD STORE CACHE OUTPUT READY XECORE8",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE9", "LOAD STORE CACHE OUTPUT READY XECORE9",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE10", "LOAD STORE CACHE OUTPUT READY XECORE10",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE11", "LOAD STORE CACHE OUTPUT READY XECORE11",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a89001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e897000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a89001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12890934, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14890114, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90934, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90114, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90934, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90114, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90934, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e90114, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt280MetricSet::CExt280MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt280MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE12", "LOAD STORE CACHE OUTPUT READY XECORE12",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE13", "LOAD STORE CACHE OUTPUT READY XECORE13",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE14", "LOAD STORE CACHE OUTPUT READY XECORE14",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE15", "LOAD STORE CACHE OUTPUT READY XECORE15",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b89001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f897000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b89001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0387aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13890934, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15890114, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90934, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90114, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90934, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90114, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90934, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e90114, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt281MetricSet::CExt281MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt281MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE16", "LOAD STORE CACHE OUTPUT READY XECORE16",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE17", "LOAD STORE CACHE OUTPUT READY XECORE17",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE18", "LOAD STORE CACHE OUTPUT READY XECORE18",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE19", "LOAD STORE CACHE OUTPUT READY XECORE19",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a89001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e897000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a89001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12890934, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14890114, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90934, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90114, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90934, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90114, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90934, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e90114, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt282MetricSet::CExt282MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt282MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE20", "LOAD STORE CACHE OUTPUT READY XECORE20",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE21", "LOAD STORE CACHE OUTPUT READY XECORE21",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE22", "LOAD STORE CACHE OUTPUT READY XECORE22",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE23", "LOAD STORE CACHE OUTPUT READY XECORE23",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b89001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f897000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b89001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0387aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13890934, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15890114, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90934, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90114, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90934, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90114, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90934, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e90114, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt283MetricSet::CExt283MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt283MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE24", "LOAD STORE CACHE OUTPUT READY XECORE24",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE25", "LOAD STORE CACHE OUTPUT READY XECORE25",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE26", "LOAD STORE CACHE OUTPUT READY XECORE26",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE27", "LOAD STORE CACHE OUTPUT READY XECORE27",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a89001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e897000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a89001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12890934, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14890114, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90934, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a90114, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90934, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90114, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90934, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e90114, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt284MetricSet::CExt284MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt284MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE28", "LOAD STORE CACHE OUTPUT READY XECORE28",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 FADD dw@0xf4 FADD dw@0xf0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 FADD qw@0x1a8 FADD qw@0x1a0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE29", "LOAD STORE CACHE OUTPUT READY XECORE29",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 FADD dw@0xe4 FADD dw@0xe0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 FADD qw@0x188 FADD qw@0x180 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE30", "LOAD STORE CACHE OUTPUT READY XECORE30",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 FADD dw@0xd4 FADD dw@0xd0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 FADD qw@0x168 FADD qw@0x160 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_OUTPUT_READY_XECORE31", "LOAD STORE CACHE OUTPUT READY XECORE31",
                          "Percentage of time in which the Load Store Cache has output ready",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 FADD dw@0xc4 FADD dw@0xc0 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 FADD qw@0x148 FADD qw@0x140 FADD 4 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b89001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f897000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b89001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe97000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be9001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0387aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03890406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13890934, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15890114, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90934, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a90114, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90934, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90114, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e90406, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90082, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90934, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e90114, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt285MetricSet::CExt285MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt285MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_STALL_L3BANK30", "L3 BANK STALL L3BANK30",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "L3_STALL_L3BANK31", "L3 BANK STALL L3BANK31",
                          "Percentage of time in which L3 bank stalled",
                          "L3Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SUBSLICE_BANK, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096b1001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x096c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x076b0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x016c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x056c0042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x076c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x036c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040fea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030084, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000038, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x000001c0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt286MetricSet::CExt286MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt286MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "COLOR_PIPE_CACHE_LATENCY2_STALL_L3NODE0", "COLOR PIPE CACHE LATENCY2 STALL L3NODE0",
                          "Percentage of time in which Color Pipeline stalled due to Render Cache latency hiding structure full",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "COLOR_PIPE_CACHE_LATENCY2_STALL_L3NODE1", "COLOR PIPE CACHE LATENCY2 STALL L3NODE1",
                          "Percentage of time in which Color Pipeline stalled due to Render Cache latency hiding structure full",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "COLOR_PIPE_CACHE_LATENCY2_STALL_L3NODE2", "COLOR PIPE CACHE LATENCY2 STALL L3NODE2",
                          "Percentage of time in which Color Pipeline stalled due to Render Cache latency hiding structure full",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "COLOR_PIPE_CACHE_LATENCY2_STALL_L3NODE3", "COLOR PIPE CACHE LATENCY2 STALL L3NODE3",
                          "Percentage of time in which Color Pipeline stalled due to Render Cache latency hiding structure full",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "COLOR_PIPE_CACHE_LATENCY2_STALL_L3NODE4", "COLOR PIPE CACHE LATENCY2 STALL L3NODE4",
                          "Percentage of time in which Color Pipeline stalled due to Render Cache latency hiding structure full",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "COLOR_PIPE_CACHE_LATENCY2_STALL_L3NODE5", "COLOR PIPE CACHE LATENCY2 STALL L3NODE5",
                          "Percentage of time in which Color Pipeline stalled due to Render Cache latency hiding structure full",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "COLOR_PIPE_CACHE_LATENCY2_STALL_L3NODE6", "COLOR PIPE CACHE LATENCY2 STALL L3NODE6",
                          "Percentage of time in which Color Pipeline stalled due to Render Cache latency hiding structure full",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "COLOR_PIPE_CACHE_LATENCY2_STALL_L3NODE7", "COLOR PIPE CACHE LATENCY2 STALL L3NODE7",
                          "Percentage of time in which Color Pipeline stalled due to Render Cache latency hiding structure full",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14087800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c030480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14087800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e030480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14087800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10030480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14087800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02048000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02054000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02088000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202a500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003280a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt288MetricSet::CExt288MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt288MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "SAMPLER_OUTPUT_READY_XECORE0", "SAMPLER OUTPUT READY XECORE0",
                          "Percentage of time in which Sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "SAMPLER_OUTPUT_READY_XECORE1", "SAMPLER OUTPUT READY XECORE1",
                          "Percentage of time in which Sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "SAMPLER_OUTPUT_READY_XECORE2", "SAMPLER OUTPUT READY XECORE2",
                          "Percentage of time in which Sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "SAMPLER_OUTPUT_READY_XECORE3", "SAMPLER OUTPUT READY XECORE3",
                          "Percentage of time in which Sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14833000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04830450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x068304d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a30450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa304d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc30450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec304d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e30450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e304d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000078, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000780, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00007800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00078000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt289MetricSet::CExt289MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt289MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "SAMPLER_OUTPUT_READY_XECORE4", "SAMPLER OUTPUT READY XECORE4",
                          "Percentage of time in which Sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "SAMPLER_OUTPUT_READY_XECORE5", "SAMPLER OUTPUT READY XECORE5",
                          "Percentage of time in which Sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "SAMPLER_OUTPUT_READY_XECORE6", "SAMPLER OUTPUT READY XECORE6",
                          "Percentage of time in which Sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "SAMPLER_OUTPUT_READY_XECORE7", "SAMPLER OUTPUT READY XECORE7",
                          "Percentage of time in which Sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15833000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05830450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x078304d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a30450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba304d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc30450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc304d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e30450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e304d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000078, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000780, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00007800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00078000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt290MetricSet::CExt290MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt290MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "SAMPLER_OUTPUT_READY_XECORE8", "SAMPLER OUTPUT READY XECORE8",
                          "Percentage of time in which Sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "SAMPLER_OUTPUT_READY_XECORE9", "SAMPLER OUTPUT READY XECORE9",
                          "Percentage of time in which Sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "SAMPLER_OUTPUT_READY_XECORE10", "SAMPLER OUTPUT READY XECORE10",
                          "Percentage of time in which Sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "SAMPLER_OUTPUT_READY_XECORE11", "SAMPLER OUTPUT READY XECORE11",
                          "Percentage of time in which Sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14833000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04830450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x068304d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a30450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa304d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc30450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec304d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e30450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e304d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000078, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000780, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00007800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00078000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt291MetricSet::CExt291MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt291MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "SAMPLER_OUTPUT_READY_XECORE12", "SAMPLER OUTPUT READY XECORE12",
                          "Percentage of time in which Sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "SAMPLER_OUTPUT_READY_XECORE13", "SAMPLER OUTPUT READY XECORE13",
                          "Percentage of time in which Sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "SAMPLER_OUTPUT_READY_XECORE14", "SAMPLER OUTPUT READY XECORE14",
                          "Percentage of time in which Sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "SAMPLER_OUTPUT_READY_XECORE15", "SAMPLER OUTPUT READY XECORE15",
                          "Percentage of time in which Sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15833000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05830450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x078304d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a30450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba304d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc30450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc304d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e30450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e304d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000078, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000780, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00007800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00078000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt292MetricSet::CExt292MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt292MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "SAMPLER_OUTPUT_READY_XECORE16", "SAMPLER OUTPUT READY XECORE16",
                          "Percentage of time in which Sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "SAMPLER_OUTPUT_READY_XECORE17", "SAMPLER OUTPUT READY XECORE17",
                          "Percentage of time in which Sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "SAMPLER_OUTPUT_READY_XECORE18", "SAMPLER OUTPUT READY XECORE18",
                          "Percentage of time in which Sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "SAMPLER_OUTPUT_READY_XECORE19", "SAMPLER OUTPUT READY XECORE19",
                          "Percentage of time in which Sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14833000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04830450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x068304d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a30450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa304d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc30450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec304d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e30450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e304d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000078, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000780, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00007800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00078000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt293MetricSet::CExt293MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt293MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "SAMPLER_OUTPUT_READY_XECORE20", "SAMPLER OUTPUT READY XECORE20",
                          "Percentage of time in which Sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "SAMPLER_OUTPUT_READY_XECORE21", "SAMPLER OUTPUT READY XECORE21",
                          "Percentage of time in which Sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "SAMPLER_OUTPUT_READY_XECORE22", "SAMPLER OUTPUT READY XECORE22",
                          "Percentage of time in which Sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "SAMPLER_OUTPUT_READY_XECORE23", "SAMPLER OUTPUT READY XECORE23",
                          "Percentage of time in which Sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15833000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05830450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x078304d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a30450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba304d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc30450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc304d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e30450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e304d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000078, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000780, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00007800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00078000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt294MetricSet::CExt294MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt294MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "SAMPLER_OUTPUT_READY_XECORE24", "SAMPLER OUTPUT READY XECORE24",
                          "Percentage of time in which Sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "SAMPLER_OUTPUT_READY_XECORE25", "SAMPLER OUTPUT READY XECORE25",
                          "Percentage of time in which Sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "SAMPLER_OUTPUT_READY_XECORE26", "SAMPLER OUTPUT READY XECORE26",
                          "Percentage of time in which Sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "SAMPLER_OUTPUT_READY_XECORE27", "SAMPLER OUTPUT READY XECORE27",
                          "Percentage of time in which Sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14833000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04830450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x068304d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a30450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa304d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc30450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec304d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e30450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e304d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000078, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000780, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00007800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00078000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt295MetricSet::CExt295MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt295MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "SAMPLER_OUTPUT_READY_XECORE28", "SAMPLER OUTPUT READY XECORE28",
                          "Percentage of time in which Sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "SAMPLER_OUTPUT_READY_XECORE29", "SAMPLER OUTPUT READY XECORE29",
                          "Percentage of time in which Sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "SAMPLER_OUTPUT_READY_XECORE30", "SAMPLER OUTPUT READY XECORE30",
                          "Percentage of time in which Sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "SAMPLER_OUTPUT_READY_XECORE31", "SAMPLER OUTPUT READY XECORE31",
                          "Percentage of time in which Sampler output is ready",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15833000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e33000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05830450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x078304d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a30450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba304d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc30450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc304d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e30450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e304d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000078, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000780, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00007800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00078000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt296MetricSet::CExt296MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt296MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "SAMPLER_BUSY_XECORE0", "SAMPLER BUSY XECORE0",
                          "Percentage of time in which Sampler pipeline active",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "SAMPLER_BUSY_XECORE1", "SAMPLER BUSY XECORE1",
                          "Percentage of time in which Sampler pipeline active",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "SAMPLER_BUSY_XECORE2", "SAMPLER BUSY XECORE2",
                          "Percentage of time in which Sampler pipeline active",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "SAMPLER_BUSY_XECORE3", "SAMPLER BUSY XECORE3",
                          "Percentage of time in which Sampler pipeline active",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "SAMPLER_BUSY_XECORE4", "SAMPLER BUSY XECORE4",
                          "Percentage of time in which Sampler pipeline active",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "SAMPLER_BUSY_XECORE5", "SAMPLER BUSY XECORE5",
                          "Percentage of time in which Sampler pipeline active",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "SAMPLER_BUSY_XECORE6", "SAMPLER BUSY XECORE6",
                          "Percentage of time in which Sampler pipeline active",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "SAMPLER_BUSY_XECORE7", "SAMPLER BUSY XECORE7",
                          "Percentage of time in which Sampler pipeline active",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "SAMPLER_BUSY_XECORE8", "SAMPLER BUSY XECORE8",
                          "Percentage of time in which Sampler pipeline active",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "SAMPLER_BUSY_XECORE9", "SAMPLER BUSY XECORE9",
                          "Percentage of time in which Sampler pipeline active",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "SAMPLER_BUSY_XECORE10", "SAMPLER BUSY XECORE10",
                          "Percentage of time in which Sampler pipeline active",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "SAMPLER_BUSY_XECORE11", "SAMPLER BUSY XECORE11",
                          "Percentage of time in which Sampler pipeline active",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "SAMPLER_BUSY_XECORE12", "SAMPLER BUSY XECORE12",
                          "Percentage of time in which Sampler pipeline active",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "SAMPLER_BUSY_XECORE13", "SAMPLER BUSY XECORE13",
                          "Percentage of time in which Sampler pipeline active",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "SAMPLER_BUSY_XECORE14", "SAMPLER BUSY XECORE14",
                          "Percentage of time in which Sampler pipeline active",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "SAMPLER_BUSY_XECORE15", "SAMPLER BUSY XECORE15",
                          "Percentage of time in which Sampler pipeline active",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18830004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19830004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12830d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a30034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e30034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f830d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa30034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc30d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de30034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00093000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18830004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19830004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a830d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa30034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c30d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e30034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07830d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a30034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c30d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e30034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001004f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03086a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030c0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030ce2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x460300e8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt297MetricSet::CExt297MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt297MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "SAMPLER_BUSY_XECORE16", "SAMPLER BUSY XECORE16",
                          "Percentage of time in which Sampler pipeline active",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "SAMPLER_BUSY_XECORE17", "SAMPLER BUSY XECORE17",
                          "Percentage of time in which Sampler pipeline active",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "SAMPLER_BUSY_XECORE18", "SAMPLER BUSY XECORE18",
                          "Percentage of time in which Sampler pipeline active",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "SAMPLER_BUSY_XECORE19", "SAMPLER BUSY XECORE19",
                          "Percentage of time in which Sampler pipeline active",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "SAMPLER_BUSY_XECORE20", "SAMPLER BUSY XECORE20",
                          "Percentage of time in which Sampler pipeline active",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "SAMPLER_BUSY_XECORE21", "SAMPLER BUSY XECORE21",
                          "Percentage of time in which Sampler pipeline active",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "SAMPLER_BUSY_XECORE22", "SAMPLER BUSY XECORE22",
                          "Percentage of time in which Sampler pipeline active",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "SAMPLER_BUSY_XECORE23", "SAMPLER BUSY XECORE23",
                          "Percentage of time in which Sampler pipeline active",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "SAMPLER_BUSY_XECORE24", "SAMPLER BUSY XECORE24",
                          "Percentage of time in which Sampler pipeline active",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "SAMPLER_BUSY_XECORE25", "SAMPLER BUSY XECORE25",
                          "Percentage of time in which Sampler pipeline active",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "SAMPLER_BUSY_XECORE26", "SAMPLER BUSY XECORE26",
                          "Percentage of time in which Sampler pipeline active",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "SAMPLER_BUSY_XECORE27", "SAMPLER BUSY XECORE27",
                          "Percentage of time in which Sampler pipeline active",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "SAMPLER_BUSY_XECORE28", "SAMPLER BUSY XECORE28",
                          "Percentage of time in which Sampler pipeline active",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "SAMPLER_BUSY_XECORE29", "SAMPLER BUSY XECORE29",
                          "Percentage of time in which Sampler pipeline active",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "SAMPLER_BUSY_XECORE30", "SAMPLER BUSY XECORE30",
                          "Percentage of time in which Sampler pipeline active",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "SAMPLER_BUSY_XECORE31", "SAMPLER BUSY XECORE31",
                          "Percentage of time in which Sampler pipeline active",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18830004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19830004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12830d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a30034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e30034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f830d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa30034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc30d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de30034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00093000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18830004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19830004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a830d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa30034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c30d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e30034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07830d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a30034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c30d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e30034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001004f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03086a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030c0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030ce2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x460300e8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt298MetricSet::CExt298MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt298MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "SAMPLER_MEMORY_LATENCY_STALL_XECORE0", "SAMPLER MEMORY LATENCY STALL XECORE0",
                          "Percentage of time in which Sampler stalled due to latency hiding structure full",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "SAMPLER_MEMORY_LATENCY_STALL_XECORE1", "SAMPLER MEMORY LATENCY STALL XECORE1",
                          "Percentage of time in which Sampler stalled due to latency hiding structure full",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "SAMPLER_MEMORY_LATENCY_STALL_XECORE2", "SAMPLER MEMORY LATENCY STALL XECORE2",
                          "Percentage of time in which Sampler stalled due to latency hiding structure full",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "SAMPLER_MEMORY_LATENCY_STALL_XECORE3", "SAMPLER MEMORY LATENCY STALL XECORE3",
                          "Percentage of time in which Sampler stalled due to latency hiding structure full",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "SAMPLER_MEMORY_LATENCY_STALL_XECORE4", "SAMPLER MEMORY LATENCY STALL XECORE4",
                          "Percentage of time in which Sampler stalled due to latency hiding structure full",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "SAMPLER_MEMORY_LATENCY_STALL_XECORE5", "SAMPLER MEMORY LATENCY STALL XECORE5",
                          "Percentage of time in which Sampler stalled due to latency hiding structure full",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "SAMPLER_MEMORY_LATENCY_STALL_XECORE6", "SAMPLER MEMORY LATENCY STALL XECORE6",
                          "Percentage of time in which Sampler stalled due to latency hiding structure full",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "SAMPLER_MEMORY_LATENCY_STALL_XECORE7", "SAMPLER MEMORY LATENCY STALL XECORE7",
                          "Percentage of time in which Sampler stalled due to latency hiding structure full",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e847400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea47400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec47400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee47400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f847400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa47400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc47400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe47400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04846810, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06840035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02840000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a40d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a40035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c40d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac40035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae40d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce40035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05840010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d840d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f840035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03840000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa40d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a40035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c40d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c40035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e40d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e40035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff0c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01023000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030ee8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030277, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt299MetricSet::CExt299MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt299MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "SAMPLER_MEMORY_LATENCY_STALL_XECORE8", "SAMPLER MEMORY LATENCY STALL XECORE8",
                          "Percentage of time in which Sampler stalled due to latency hiding structure full",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "SAMPLER_MEMORY_LATENCY_STALL_XECORE9", "SAMPLER MEMORY LATENCY STALL XECORE9",
                          "Percentage of time in which Sampler stalled due to latency hiding structure full",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "SAMPLER_MEMORY_LATENCY_STALL_XECORE10", "SAMPLER MEMORY LATENCY STALL XECORE10",
                          "Percentage of time in which Sampler stalled due to latency hiding structure full",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "SAMPLER_MEMORY_LATENCY_STALL_XECORE11", "SAMPLER MEMORY LATENCY STALL XECORE11",
                          "Percentage of time in which Sampler stalled due to latency hiding structure full",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "SAMPLER_MEMORY_LATENCY_STALL_XECORE12", "SAMPLER MEMORY LATENCY STALL XECORE12",
                          "Percentage of time in which Sampler stalled due to latency hiding structure full",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "SAMPLER_MEMORY_LATENCY_STALL_XECORE13", "SAMPLER MEMORY LATENCY STALL XECORE13",
                          "Percentage of time in which Sampler stalled due to latency hiding structure full",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "SAMPLER_MEMORY_LATENCY_STALL_XECORE14", "SAMPLER MEMORY LATENCY STALL XECORE14",
                          "Percentage of time in which Sampler stalled due to latency hiding structure full",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "SAMPLER_MEMORY_LATENCY_STALL_XECORE15", "SAMPLER MEMORY LATENCY STALL XECORE15",
                          "Percentage of time in which Sampler stalled due to latency hiding structure full",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e847400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea47400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec47400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee47400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f847400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa47400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc47400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe47400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04846810, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06840035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02840000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a40d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a40035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c40d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac40035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae40d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce40035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05840010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d840d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f840035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03840000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa40d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a40035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c40d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c40035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e40d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e40035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff0c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01023000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030ee8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030277, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt300MetricSet::CExt300MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt300MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "SAMPLER_MEMORY_LATENCY_STALL_XECORE16", "SAMPLER MEMORY LATENCY STALL XECORE16",
                          "Percentage of time in which Sampler stalled due to latency hiding structure full",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "SAMPLER_MEMORY_LATENCY_STALL_XECORE17", "SAMPLER MEMORY LATENCY STALL XECORE17",
                          "Percentage of time in which Sampler stalled due to latency hiding structure full",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "SAMPLER_MEMORY_LATENCY_STALL_XECORE18", "SAMPLER MEMORY LATENCY STALL XECORE18",
                          "Percentage of time in which Sampler stalled due to latency hiding structure full",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "SAMPLER_MEMORY_LATENCY_STALL_XECORE19", "SAMPLER MEMORY LATENCY STALL XECORE19",
                          "Percentage of time in which Sampler stalled due to latency hiding structure full",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "SAMPLER_MEMORY_LATENCY_STALL_XECORE20", "SAMPLER MEMORY LATENCY STALL XECORE20",
                          "Percentage of time in which Sampler stalled due to latency hiding structure full",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "SAMPLER_MEMORY_LATENCY_STALL_XECORE21", "SAMPLER MEMORY LATENCY STALL XECORE21",
                          "Percentage of time in which Sampler stalled due to latency hiding structure full",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "SAMPLER_MEMORY_LATENCY_STALL_XECORE22", "SAMPLER MEMORY LATENCY STALL XECORE22",
                          "Percentage of time in which Sampler stalled due to latency hiding structure full",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "SAMPLER_MEMORY_LATENCY_STALL_XECORE23", "SAMPLER MEMORY LATENCY STALL XECORE23",
                          "Percentage of time in which Sampler stalled due to latency hiding structure full",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e847400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea47400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec47400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee47400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f847400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa47400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc47400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe47400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04846810, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06840035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02840000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a40d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a40035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c40d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac40035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae40d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce40035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05840010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d840d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f840035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03840000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa40d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a40035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c40d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c40035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e40d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e40035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff0c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01023000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030ee8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030277, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt301MetricSet::CExt301MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt301MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "SAMPLER_MEMORY_LATENCY_STALL_XECORE24", "SAMPLER MEMORY LATENCY STALL XECORE24",
                          "Percentage of time in which Sampler stalled due to latency hiding structure full",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "SAMPLER_MEMORY_LATENCY_STALL_XECORE25", "SAMPLER MEMORY LATENCY STALL XECORE25",
                          "Percentage of time in which Sampler stalled due to latency hiding structure full",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "SAMPLER_MEMORY_LATENCY_STALL_XECORE26", "SAMPLER MEMORY LATENCY STALL XECORE26",
                          "Percentage of time in which Sampler stalled due to latency hiding structure full",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "SAMPLER_MEMORY_LATENCY_STALL_XECORE27", "SAMPLER MEMORY LATENCY STALL XECORE27",
                          "Percentage of time in which Sampler stalled due to latency hiding structure full",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "SAMPLER_MEMORY_LATENCY_STALL_XECORE28", "SAMPLER MEMORY LATENCY STALL XECORE28",
                          "Percentage of time in which Sampler stalled due to latency hiding structure full",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "SAMPLER_MEMORY_LATENCY_STALL_XECORE29", "SAMPLER MEMORY LATENCY STALL XECORE29",
                          "Percentage of time in which Sampler stalled due to latency hiding structure full",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "SAMPLER_MEMORY_LATENCY_STALL_XECORE30", "SAMPLER MEMORY LATENCY STALL XECORE30",
                          "Percentage of time in which Sampler stalled due to latency hiding structure full",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "SAMPLER_MEMORY_LATENCY_STALL_XECORE31", "SAMPLER MEMORY LATENCY STALL XECORE31",
                          "Percentage of time in which Sampler stalled due to latency hiding structure full",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e847400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea47400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec47400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee47400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f847400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa47400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc47400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe47400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04846810, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06840035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02840000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a40d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a40035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c40d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac40035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae40d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce40035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05840010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d840d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f840035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03840000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa40d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a40035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c40d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c40035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e40d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e40035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff0c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01023000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030ee8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030277, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt302MetricSet::CExt302MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt302MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "SAMPLER_INPUT_AVAILABLE_XECORE0", "SAMPLER INPUT AVAILABLE XECORE0",
                          "Percentage of time in which Sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "SAMPLER_INPUT_AVAILABLE_XECORE1", "SAMPLER INPUT AVAILABLE XECORE1",
                          "Percentage of time in which Sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "SAMPLER_INPUT_AVAILABLE_XECORE2", "SAMPLER INPUT AVAILABLE XECORE2",
                          "Percentage of time in which Sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "SAMPLER_INPUT_AVAILABLE_XECORE3", "SAMPLER INPUT AVAILABLE XECORE3",
                          "Percentage of time in which Sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "SAMPLER_INPUT_AVAILABLE_XECORE4", "SAMPLER INPUT AVAILABLE XECORE4",
                          "Percentage of time in which Sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "SAMPLER_INPUT_AVAILABLE_XECORE5", "SAMPLER INPUT AVAILABLE XECORE5",
                          "Percentage of time in which Sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "SAMPLER_INPUT_AVAILABLE_XECORE6", "SAMPLER INPUT AVAILABLE XECORE6",
                          "Percentage of time in which Sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "SAMPLER_INPUT_AVAILABLE_XECORE7", "SAMPLER INPUT AVAILABLE XECORE7",
                          "Percentage of time in which Sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c824c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ca24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ce24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d824c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1da24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1de24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04824000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06824800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08820023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa20023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc20023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee20023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e35000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e400c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05824000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f820900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11820023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a20023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c20023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c43000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e20023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e35000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff0c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01023000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030ee8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030277, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000060, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000180, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000600, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt303MetricSet::CExt303MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt303MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "SAMPLER_INPUT_AVAILABLE_XECORE8", "SAMPLER INPUT AVAILABLE XECORE8",
                          "Percentage of time in which Sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "SAMPLER_INPUT_AVAILABLE_XECORE9", "SAMPLER INPUT AVAILABLE XECORE9",
                          "Percentage of time in which Sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "SAMPLER_INPUT_AVAILABLE_XECORE10", "SAMPLER INPUT AVAILABLE XECORE10",
                          "Percentage of time in which Sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "SAMPLER_INPUT_AVAILABLE_XECORE11", "SAMPLER INPUT AVAILABLE XECORE11",
                          "Percentage of time in which Sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "SAMPLER_INPUT_AVAILABLE_XECORE12", "SAMPLER INPUT AVAILABLE XECORE12",
                          "Percentage of time in which Sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "SAMPLER_INPUT_AVAILABLE_XECORE13", "SAMPLER INPUT AVAILABLE XECORE13",
                          "Percentage of time in which Sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "SAMPLER_INPUT_AVAILABLE_XECORE14", "SAMPLER INPUT AVAILABLE XECORE14",
                          "Percentage of time in which Sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "SAMPLER_INPUT_AVAILABLE_XECORE15", "SAMPLER INPUT AVAILABLE XECORE15",
                          "Percentage of time in which Sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c824c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ca24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ce24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d824c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1da24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1de24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04824000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06824800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08820023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa20023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc20023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee20023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e35000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e400c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05824000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f820900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11820023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a20023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c20023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c43000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e20023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e35000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff0c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01023000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030ee8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030277, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000060, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000180, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000600, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt304MetricSet::CExt304MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt304MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "SAMPLER_INPUT_AVAILABLE_XECORE16", "SAMPLER INPUT AVAILABLE XECORE16",
                          "Percentage of time in which Sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "SAMPLER_INPUT_AVAILABLE_XECORE17", "SAMPLER INPUT AVAILABLE XECORE17",
                          "Percentage of time in which Sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "SAMPLER_INPUT_AVAILABLE_XECORE18", "SAMPLER INPUT AVAILABLE XECORE18",
                          "Percentage of time in which Sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "SAMPLER_INPUT_AVAILABLE_XECORE19", "SAMPLER INPUT AVAILABLE XECORE19",
                          "Percentage of time in which Sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "SAMPLER_INPUT_AVAILABLE_XECORE20", "SAMPLER INPUT AVAILABLE XECORE20",
                          "Percentage of time in which Sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "SAMPLER_INPUT_AVAILABLE_XECORE21", "SAMPLER INPUT AVAILABLE XECORE21",
                          "Percentage of time in which Sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "SAMPLER_INPUT_AVAILABLE_XECORE22", "SAMPLER INPUT AVAILABLE XECORE22",
                          "Percentage of time in which Sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "SAMPLER_INPUT_AVAILABLE_XECORE23", "SAMPLER INPUT AVAILABLE XECORE23",
                          "Percentage of time in which Sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c824c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ca24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ce24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d824c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1da24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1de24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04824000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06824800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08820023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa20023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc20023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee20023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e35000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e400c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05824000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f820900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11820023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a20023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c20023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c43000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e20023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e35000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff0c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01023000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030ee8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030277, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000060, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000180, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000600, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt305MetricSet::CExt305MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt305MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "SAMPLER_INPUT_AVAILABLE_XECORE24", "SAMPLER INPUT AVAILABLE XECORE24",
                          "Percentage of time in which Sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "SAMPLER_INPUT_AVAILABLE_XECORE25", "SAMPLER INPUT AVAILABLE XECORE25",
                          "Percentage of time in which Sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "SAMPLER_INPUT_AVAILABLE_XECORE26", "SAMPLER INPUT AVAILABLE XECORE26",
                          "Percentage of time in which Sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "SAMPLER_INPUT_AVAILABLE_XECORE27", "SAMPLER INPUT AVAILABLE XECORE27",
                          "Percentage of time in which Sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "SAMPLER_INPUT_AVAILABLE_XECORE28", "SAMPLER INPUT AVAILABLE XECORE28",
                          "Percentage of time in which Sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "SAMPLER_INPUT_AVAILABLE_XECORE29", "SAMPLER INPUT AVAILABLE XECORE29",
                          "Percentage of time in which Sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "SAMPLER_INPUT_AVAILABLE_XECORE30", "SAMPLER INPUT AVAILABLE XECORE30",
                          "Percentage of time in which Sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "SAMPLER_INPUT_AVAILABLE_XECORE31", "SAMPLER INPUT AVAILABLE XECORE31",
                          "Percentage of time in which Sampler input is available",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c824c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ca24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ce24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d824c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1da24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1de24c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04824000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06824800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08820023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa20023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc20023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee20023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e35000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e400c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05824000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f820900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11820023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a20023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c20023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c43000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e24000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e20900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e20023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e35000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff0c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01023000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030ee8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030277, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000060, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000180, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000600, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt306MetricSet::CExt306MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt306MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_ACCESS_XECORE0", "SAMPLER TEXTURE CACHE ACCESS XECORE0",
                          "Number of Sampler L1 requests",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_ACCESS_XECORE1", "SAMPLER TEXTURE CACHE ACCESS XECORE1",
                          "Number of Sampler L1 requests",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_ACCESS_XECORE2", "SAMPLER TEXTURE CACHE ACCESS XECORE2",
                          "Number of Sampler L1 requests",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_ACCESS_XECORE3", "SAMPLER TEXTURE CACHE ACCESS XECORE3",
                          "Number of Sampler L1 requests",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_ACCESS_XECORE4", "SAMPLER TEXTURE CACHE ACCESS XECORE4",
                          "Number of Sampler L1 requests",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_ACCESS_XECORE5", "SAMPLER TEXTURE CACHE ACCESS XECORE5",
                          "Number of Sampler L1 requests",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_ACCESS_XECORE6", "SAMPLER TEXTURE CACHE ACCESS XECORE6",
                          "Number of Sampler L1 requests",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_ACCESS_XECORE7", "SAMPLER TEXTURE CACHE ACCESS XECORE7",
                          "Number of Sampler L1 requests",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_ACCESS_XECORE8", "SAMPLER TEXTURE CACHE ACCESS XECORE8",
                          "Number of Sampler L1 requests",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_ACCESS_XECORE9", "SAMPLER TEXTURE CACHE ACCESS XECORE9",
                          "Number of Sampler L1 requests",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_ACCESS_XECORE10", "SAMPLER TEXTURE CACHE ACCESS XECORE10",
                          "Number of Sampler L1 requests",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_ACCESS_XECORE11", "SAMPLER TEXTURE CACHE ACCESS XECORE11",
                          "Number of Sampler L1 requests",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_ACCESS_XECORE12", "SAMPLER TEXTURE CACHE ACCESS XECORE12",
                          "Number of Sampler L1 requests",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_ACCESS_XECORE13", "SAMPLER TEXTURE CACHE ACCESS XECORE13",
                          "Number of Sampler L1 requests",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_ACCESS_XECORE14", "SAMPLER TEXTURE CACHE ACCESS XECORE14",
                          "Number of Sampler L1 requests",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_ACCESS_XECORE15", "SAMPLER TEXTURE CACHE ACCESS XECORE15",
                          "Number of Sampler L1 requests",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18830004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19830004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12830cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a30033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e30033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f830cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa30033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc30cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de30033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00093000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18830004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19830004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a830cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa30033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c30cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e30033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07830cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a30033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c30cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e30033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001004f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03086a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030c0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030ce2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x460300e8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt307MetricSet::CExt307MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt307MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_ACCESS_XECORE16", "SAMPLER TEXTURE CACHE ACCESS XECORE16",
                          "Number of Sampler L1 requests",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_ACCESS_XECORE17", "SAMPLER TEXTURE CACHE ACCESS XECORE17",
                          "Number of Sampler L1 requests",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_ACCESS_XECORE18", "SAMPLER TEXTURE CACHE ACCESS XECORE18",
                          "Number of Sampler L1 requests",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_ACCESS_XECORE19", "SAMPLER TEXTURE CACHE ACCESS XECORE19",
                          "Number of Sampler L1 requests",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_ACCESS_XECORE20", "SAMPLER TEXTURE CACHE ACCESS XECORE20",
                          "Number of Sampler L1 requests",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_ACCESS_XECORE21", "SAMPLER TEXTURE CACHE ACCESS XECORE21",
                          "Number of Sampler L1 requests",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_ACCESS_XECORE22", "SAMPLER TEXTURE CACHE ACCESS XECORE22",
                          "Number of Sampler L1 requests",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_ACCESS_XECORE23", "SAMPLER TEXTURE CACHE ACCESS XECORE23",
                          "Number of Sampler L1 requests",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_ACCESS_XECORE24", "SAMPLER TEXTURE CACHE ACCESS XECORE24",
                          "Number of Sampler L1 requests",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_ACCESS_XECORE25", "SAMPLER TEXTURE CACHE ACCESS XECORE25",
                          "Number of Sampler L1 requests",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_ACCESS_XECORE26", "SAMPLER TEXTURE CACHE ACCESS XECORE26",
                          "Number of Sampler L1 requests",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_ACCESS_XECORE27", "SAMPLER TEXTURE CACHE ACCESS XECORE27",
                          "Number of Sampler L1 requests",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_ACCESS_XECORE28", "SAMPLER TEXTURE CACHE ACCESS XECORE28",
                          "Number of Sampler L1 requests",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_ACCESS_XECORE29", "SAMPLER TEXTURE CACHE ACCESS XECORE29",
                          "Number of Sampler L1 requests",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_ACCESS_XECORE30", "SAMPLER TEXTURE CACHE ACCESS XECORE30",
                          "Number of Sampler L1 requests",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_ACCESS_XECORE31", "SAMPLER TEXTURE CACHE ACCESS XECORE31",
                          "Number of Sampler L1 requests",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18830004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19830004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12830cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a30033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e30033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f830cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa30033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc30cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de30033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00093000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18830004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19830004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a830cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa30033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c30cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e30033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07830cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a30033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c30cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e30033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001004f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03086a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030c0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030ce2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x460300e8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt308MetricSet::CExt308MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt308MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_MISS_XECORE0", "SAMPLER TEXTURE CACHE MISS XECORE0",
                          "Number of Sampler L1 misses",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_MISS_XECORE1", "SAMPLER TEXTURE CACHE MISS XECORE1",
                          "Number of Sampler L1 misses",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_MISS_XECORE2", "SAMPLER TEXTURE CACHE MISS XECORE2",
                          "Number of Sampler L1 misses",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_MISS_XECORE3", "SAMPLER TEXTURE CACHE MISS XECORE3",
                          "Number of Sampler L1 misses",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_MISS_XECORE4", "SAMPLER TEXTURE CACHE MISS XECORE4",
                          "Number of Sampler L1 misses",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_MISS_XECORE5", "SAMPLER TEXTURE CACHE MISS XECORE5",
                          "Number of Sampler L1 misses",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_MISS_XECORE6", "SAMPLER TEXTURE CACHE MISS XECORE6",
                          "Number of Sampler L1 misses",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_MISS_XECORE7", "SAMPLER TEXTURE CACHE MISS XECORE7",
                          "Number of Sampler L1 misses",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_MISS_XECORE8", "SAMPLER TEXTURE CACHE MISS XECORE8",
                          "Number of Sampler L1 misses",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_MISS_XECORE9", "SAMPLER TEXTURE CACHE MISS XECORE9",
                          "Number of Sampler L1 misses",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_MISS_XECORE10", "SAMPLER TEXTURE CACHE MISS XECORE10",
                          "Number of Sampler L1 misses",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_MISS_XECORE11", "SAMPLER TEXTURE CACHE MISS XECORE11",
                          "Number of Sampler L1 misses",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_MISS_XECORE12", "SAMPLER TEXTURE CACHE MISS XECORE12",
                          "Number of Sampler L1 misses",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_MISS_XECORE13", "SAMPLER TEXTURE CACHE MISS XECORE13",
                          "Number of Sampler L1 misses",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_MISS_XECORE14", "SAMPLER TEXTURE CACHE MISS XECORE14",
                          "Number of Sampler L1 misses",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_MISS_XECORE15", "SAMPLER TEXTURE CACHE MISS XECORE15",
                          "Number of Sampler L1 misses",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18830004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19830004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12830c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a30032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e30032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f830c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa30032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc30c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de30032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00093000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18830004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19830004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a830c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa30032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c30c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e30032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07830c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a30032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c30c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e30032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001004f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03086a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030c0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030ce2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x460300e8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt309MetricSet::CExt309MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt309MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_MISS_XECORE16", "SAMPLER TEXTURE CACHE MISS XECORE16",
                          "Number of Sampler L1 misses",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_MISS_XECORE17", "SAMPLER TEXTURE CACHE MISS XECORE17",
                          "Number of Sampler L1 misses",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_MISS_XECORE18", "SAMPLER TEXTURE CACHE MISS XECORE18",
                          "Number of Sampler L1 misses",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_MISS_XECORE19", "SAMPLER TEXTURE CACHE MISS XECORE19",
                          "Number of Sampler L1 misses",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_MISS_XECORE20", "SAMPLER TEXTURE CACHE MISS XECORE20",
                          "Number of Sampler L1 misses",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_MISS_XECORE21", "SAMPLER TEXTURE CACHE MISS XECORE21",
                          "Number of Sampler L1 misses",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_MISS_XECORE22", "SAMPLER TEXTURE CACHE MISS XECORE22",
                          "Number of Sampler L1 misses",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_MISS_XECORE23", "SAMPLER TEXTURE CACHE MISS XECORE23",
                          "Number of Sampler L1 misses",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_MISS_XECORE24", "SAMPLER TEXTURE CACHE MISS XECORE24",
                          "Number of Sampler L1 misses",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_MISS_XECORE25", "SAMPLER TEXTURE CACHE MISS XECORE25",
                          "Number of Sampler L1 misses",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_MISS_XECORE26", "SAMPLER TEXTURE CACHE MISS XECORE26",
                          "Number of Sampler L1 misses",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_MISS_XECORE27", "SAMPLER TEXTURE CACHE MISS XECORE27",
                          "Number of Sampler L1 misses",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_MISS_XECORE28", "SAMPLER TEXTURE CACHE MISS XECORE28",
                          "Number of Sampler L1 misses",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_MISS_XECORE29", "SAMPLER TEXTURE CACHE MISS XECORE29",
                          "Number of Sampler L1 misses",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_MISS_XECORE30", "SAMPLER TEXTURE CACHE MISS XECORE30",
                          "Number of Sampler L1 misses",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "SAMPLER_TEXTURE_CACHE_MISS_XECORE31", "SAMPLER TEXTURE CACHE MISS XECORE31",
                          "Number of Sampler L1 misses",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18830004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19830004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12830c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a30032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c30c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e30032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f830c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa30032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc30c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de30032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00093000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18830004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19830004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a830c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa30032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c30c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e30032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07830c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a30032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c30c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e30032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e30000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001004f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03086a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030c0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030ce2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x460300e8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt310MetricSet::CExt310MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt310MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE0", "XVE DATAPORT READ MESSAGE COUNT XECORE0",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE1", "XVE DATAPORT READ MESSAGE COUNT XECORE1",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE2", "XVE DATAPORT READ MESSAGE COUNT XECORE2",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE3", "XVE DATAPORT READ MESSAGE COUNT XECORE3",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a81000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x088101c5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a81000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa10140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca102c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec101c5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c401c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e10140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e102c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e300a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070056, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080fea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aa555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000201c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt311MetricSet::CExt311MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt311MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE4", "XVE DATAPORT READ MESSAGE COUNT XECORE4",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE5", "XVE DATAPORT READ MESSAGE COUNT XECORE5",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE6", "XVE DATAPORT READ MESSAGE COUNT XECORE6",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE7", "XVE DATAPORT READ MESSAGE COUNT XECORE7",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b81000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x098101c5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b81000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba10140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da102c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc101c5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c401c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e102c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e300a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070056, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080fea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010201c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt312MetricSet::CExt312MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt312MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE8", "XVE DATAPORT READ MESSAGE COUNT XECORE8",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE9", "XVE DATAPORT READ MESSAGE COUNT XECORE9",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE10", "XVE DATAPORT READ MESSAGE COUNT XECORE10",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE11", "XVE DATAPORT READ MESSAGE COUNT XECORE11",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a81000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x088101c5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a81000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa10140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca102c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec101c5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c401c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e10140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e102c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e300a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070056, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080fea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aa555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000201c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt313MetricSet::CExt313MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt313MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE12", "XVE DATAPORT READ MESSAGE COUNT XECORE12",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE13", "XVE DATAPORT READ MESSAGE COUNT XECORE13",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE14", "XVE DATAPORT READ MESSAGE COUNT XECORE14",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE15", "XVE DATAPORT READ MESSAGE COUNT XECORE15",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b81000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x098101c5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b81000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba10140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da102c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc101c5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c401c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e102c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e300a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070056, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080fea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010201c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt314MetricSet::CExt314MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt314MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE16", "XVE DATAPORT READ MESSAGE COUNT XECORE16",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE17", "XVE DATAPORT READ MESSAGE COUNT XECORE17",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE18", "XVE DATAPORT READ MESSAGE COUNT XECORE18",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE19", "XVE DATAPORT READ MESSAGE COUNT XECORE19",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a81000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x088101c5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a81000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa10140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca102c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec101c5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c401c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e10140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e102c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e300a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070056, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080fea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aa555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000201c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt315MetricSet::CExt315MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt315MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE20", "XVE DATAPORT READ MESSAGE COUNT XECORE20",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE21", "XVE DATAPORT READ MESSAGE COUNT XECORE21",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE22", "XVE DATAPORT READ MESSAGE COUNT XECORE22",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE23", "XVE DATAPORT READ MESSAGE COUNT XECORE23",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b81000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x098101c5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b81000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba10140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da102c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc101c5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c401c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e102c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e300a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070056, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080fea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010201c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt316MetricSet::CExt316MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt316MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE24", "XVE DATAPORT READ MESSAGE COUNT XECORE24",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE25", "XVE DATAPORT READ MESSAGE COUNT XECORE25",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE26", "XVE DATAPORT READ MESSAGE COUNT XECORE26",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE27", "XVE DATAPORT READ MESSAGE COUNT XECORE27",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a81000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x088101c5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a81000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa10140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca102c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec101c5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c401c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e10140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e102c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e300a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070056, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080fea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aa555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000201c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020200aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt317MetricSet::CExt317MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt317MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE28", "XVE DATAPORT READ MESSAGE COUNT XECORE28",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE29", "XVE DATAPORT READ MESSAGE COUNT XECORE29",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE30", "XVE DATAPORT READ MESSAGE COUNT XECORE30",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_READ_MESSAGE_COUNT_XECORE31", "XVE DATAPORT READ MESSAGE COUNT XECORE31",
                          "Number of read messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b81000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x098101c5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b81000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba10140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da102c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc101c5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c401c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e102c7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e300a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070056, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080fea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010201c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020200aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt318MetricSet::CExt318MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt318MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE0", "XVE DATAPORT WRITE MESSAGE COUNT XECORE0",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE1", "XVE DATAPORT WRITE MESSAGE COUNT XECORE1",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE2", "XVE DATAPORT WRITE MESSAGE COUNT XECORE2",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE3", "XVE DATAPORT WRITE MESSAGE COUNT XECORE3",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a81000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810206, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a81000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa10180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca102c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec10206, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c401c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e10180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e102c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e300a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070056, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080fea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aa555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000201c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt319MetricSet::CExt319MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt319MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE4", "XVE DATAPORT WRITE MESSAGE COUNT XECORE4",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE5", "XVE DATAPORT WRITE MESSAGE COUNT XECORE5",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE6", "XVE DATAPORT WRITE MESSAGE COUNT XECORE6",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE7", "XVE DATAPORT WRITE MESSAGE COUNT XECORE7",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b81000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810206, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b81000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba10180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da102c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10206, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c401c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e102c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e300a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070056, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080fea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010201c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt320MetricSet::CExt320MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt320MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE8", "XVE DATAPORT WRITE MESSAGE COUNT XECORE8",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE9", "XVE DATAPORT WRITE MESSAGE COUNT XECORE9",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE10", "XVE DATAPORT WRITE MESSAGE COUNT XECORE10",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE11", "XVE DATAPORT WRITE MESSAGE COUNT XECORE11",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a81000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810206, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a81000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa10180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca102c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec10206, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c401c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e10180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e102c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e300a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070056, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080fea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aa555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000201c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt321MetricSet::CExt321MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt321MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE12", "XVE DATAPORT WRITE MESSAGE COUNT XECORE12",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE13", "XVE DATAPORT WRITE MESSAGE COUNT XECORE13",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE14", "XVE DATAPORT WRITE MESSAGE COUNT XECORE14",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE15", "XVE DATAPORT WRITE MESSAGE COUNT XECORE15",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b81000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810206, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b81000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba10180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da102c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10206, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c401c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e102c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e300a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070056, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080fea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010201c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt322MetricSet::CExt322MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt322MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE16", "XVE DATAPORT WRITE MESSAGE COUNT XECORE16",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE17", "XVE DATAPORT WRITE MESSAGE COUNT XECORE17",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE18", "XVE DATAPORT WRITE MESSAGE COUNT XECORE18",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE19", "XVE DATAPORT WRITE MESSAGE COUNT XECORE19",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a81000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810206, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a81000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa10180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca102c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec10206, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c401c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e10180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e102c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e300a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070056, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080fea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aa555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000201c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt323MetricSet::CExt323MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt323MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE20", "XVE DATAPORT WRITE MESSAGE COUNT XECORE20",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE21", "XVE DATAPORT WRITE MESSAGE COUNT XECORE21",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE22", "XVE DATAPORT WRITE MESSAGE COUNT XECORE22",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE23", "XVE DATAPORT WRITE MESSAGE COUNT XECORE23",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b81000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810206, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b81000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba10180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da102c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10206, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c401c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e102c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e300a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070056, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080fea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010201c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt324MetricSet::CExt324MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt324MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE24", "XVE DATAPORT WRITE MESSAGE COUNT XECORE24",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE25", "XVE DATAPORT WRITE MESSAGE COUNT XECORE25",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE26", "XVE DATAPORT WRITE MESSAGE COUNT XECORE26",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE27", "XVE DATAPORT WRITE MESSAGE COUNT XECORE27",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a81000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810206, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a81000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa10180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca102c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec10206, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c401c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e10180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e102c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e300a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070056, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080fea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aa555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000201c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020200aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt325MetricSet::CExt325MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt325MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE28", "XVE DATAPORT WRITE MESSAGE COUNT XECORE28",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE29", "XVE DATAPORT WRITE MESSAGE COUNT XECORE29",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE30", "XVE DATAPORT WRITE MESSAGE COUNT XECORE30",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_WRITE_MESSAGE_COUNT_XECORE31", "XVE DATAPORT WRITE MESSAGE COUNT XECORE31",
                          "Number of write messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b81000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810206, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b81000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba10180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da102c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10206, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c401c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e102c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e300a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070056, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080fea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010201c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020200aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0060001c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x030000c4, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x18000604, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0xc0003004, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt326MetricSet::CExt326MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt326MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE0", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE0",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE1", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE1",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE2", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE2",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE3", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE3",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a81000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a81000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa10140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca102c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec10185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c401c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e10140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e102c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e300a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070056, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080fea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aa555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000201c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt327MetricSet::CExt327MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt327MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE4", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE4",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE5", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE5",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE6", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE6",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE7", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE7",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b81000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b81000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba10140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da102c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c401c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e102c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e300a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070056, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080fea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010201c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt328MetricSet::CExt328MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt328MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE8", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE8",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE9", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE9",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE10", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE10",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE11", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE11",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a81000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a81000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa10140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca102c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec10185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c401c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e10140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e102c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e300a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070056, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080fea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aa555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000201c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt329MetricSet::CExt329MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt329MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE12", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE12",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE13", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE13",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE14", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE14",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE15", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE15",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b81000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b81000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba10140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da102c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c401c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e102c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e300a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070056, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080fea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010201c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt330MetricSet::CExt330MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt330MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE16", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE16",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE17", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE17",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE18", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE18",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE19", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE19",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a81000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a81000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa10140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca102c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec10185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c401c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e10140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e102c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e300a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070056, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080fea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aa555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000201c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt331MetricSet::CExt331MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt331MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE20", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE20",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE21", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE21",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE22", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE22",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE23", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE23",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b81000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b81000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba10140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da102c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c401c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e102c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e300a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070056, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080fea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010201c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt332MetricSet::CExt332MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt332MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE24", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE24",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE25", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE25",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE26", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE26",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE27", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE27",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a81000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a81000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa10140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca102c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec10185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c401c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e10140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e102c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e300a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070056, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080fea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aa555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000201c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020200aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt333MetricSet::CExt333MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt333MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE28", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE28",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE29", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE29",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE30", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE30",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_ATOMIC_MESSAGE_COUNT_XECORE31", "XVE DATAPORT ATOMIC MESSAGE COUNT XECORE31",
                          "Number of atomic messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b81000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b81000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba10140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da102c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c1000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c401c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10076, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e102c6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e300a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070056, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080fea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010201c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020200aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000021, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000101, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000801, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00004001, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt334MetricSet::CExt334MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt334MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE0", "XVE DATAPORT FENCE MESSAGE COUNT XECORE0",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE1", "XVE DATAPORT FENCE MESSAGE COUNT XECORE1",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE2", "XVE DATAPORT FENCE MESSAGE COUNT XECORE2",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE3", "XVE DATAPORT FENCE MESSAGE COUNT XECORE3",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE4", "XVE DATAPORT FENCE MESSAGE COUNT XECORE4",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE5", "XVE DATAPORT FENCE MESSAGE COUNT XECORE5",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE6", "XVE DATAPORT FENCE MESSAGE COUNT XECORE6",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE7", "XVE DATAPORT FENCE MESSAGE COUNT XECORE7",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE8", "XVE DATAPORT FENCE MESSAGE COUNT XECORE8",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE9", "XVE DATAPORT FENCE MESSAGE COUNT XECORE9",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE10", "XVE DATAPORT FENCE MESSAGE COUNT XECORE10",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE11", "XVE DATAPORT FENCE MESSAGE COUNT XECORE11",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE12", "XVE DATAPORT FENCE MESSAGE COUNT XECORE12",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE13", "XVE DATAPORT FENCE MESSAGE COUNT XECORE13",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE14", "XVE DATAPORT FENCE MESSAGE COUNT XECORE14",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE15", "XVE DATAPORT FENCE MESSAGE COUNT XECORE15",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20810011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20a10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20e10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21810011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21a10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21c10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21e10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16810580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02838000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02874000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a10016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c10580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e10016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13810580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c10580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00093000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20810011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20a10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20e10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21810011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21a10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21c10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21e10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e810580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00838000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00874000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea10016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce10016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b810580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba10016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001004f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03086a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030c0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030ce2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x460300e8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt335MetricSet::CExt335MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt335MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE16", "XVE DATAPORT FENCE MESSAGE COUNT XECORE16",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE17", "XVE DATAPORT FENCE MESSAGE COUNT XECORE17",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE18", "XVE DATAPORT FENCE MESSAGE COUNT XECORE18",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE19", "XVE DATAPORT FENCE MESSAGE COUNT XECORE19",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE20", "XVE DATAPORT FENCE MESSAGE COUNT XECORE20",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE21", "XVE DATAPORT FENCE MESSAGE COUNT XECORE21",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE22", "XVE DATAPORT FENCE MESSAGE COUNT XECORE22",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE23", "XVE DATAPORT FENCE MESSAGE COUNT XECORE23",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE24", "XVE DATAPORT FENCE MESSAGE COUNT XECORE24",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE25", "XVE DATAPORT FENCE MESSAGE COUNT XECORE25",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE26", "XVE DATAPORT FENCE MESSAGE COUNT XECORE26",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE27", "XVE DATAPORT FENCE MESSAGE COUNT XECORE27",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE28", "XVE DATAPORT FENCE MESSAGE COUNT XECORE28",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE29", "XVE DATAPORT FENCE MESSAGE COUNT XECORE29",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE30", "XVE DATAPORT FENCE MESSAGE COUNT XECORE30",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_FENCE_MESSAGE_COUNT_XECORE31", "XVE DATAPORT FENCE MESSAGE COUNT XECORE31",
                          "Number of fence messages sent by XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20810011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20a10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20e10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21810011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21a10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21c10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21e10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16810580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02838000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02874000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a10016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c10580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e10016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13810580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c10580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00093000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20810011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20a10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20e10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21810011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21a10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21c10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21e10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e810580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00838000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00874000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea10016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce10016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b810580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba10016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001004f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03086a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030c0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030ce2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x460300e8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt342MetricSet::CExt342MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt342MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE0", "XVE DATAPORT REGISTER REQUEST COUNT XECORE0",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE1", "XVE DATAPORT REGISTER REQUEST COUNT XECORE1",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE2", "XVE DATAPORT REGISTER REQUEST COUNT XECORE2",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE3", "XVE DATAPORT REGISTER REQUEST COUNT XECORE3",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE4", "XVE DATAPORT REGISTER REQUEST COUNT XECORE4",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE5", "XVE DATAPORT REGISTER REQUEST COUNT XECORE5",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4 dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168 qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE6", "XVE DATAPORT REGISTER REQUEST COUNT XECORE6",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE7", "XVE DATAPORT REGISTER REQUEST COUNT XECORE7",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x188102fd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a102fd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c102fd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e102fd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x198102fd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a102fd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c102fd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e102fd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x168103c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02875000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a103c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a43000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a70500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c103c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e103c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f8103c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01875000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da103c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc103c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e103c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000300ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020700a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208af00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a55aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000130ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010700a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108af00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a55aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03210a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030423, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030e21, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030ee7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt343MetricSet::CExt343MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt343MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE8", "XVE DATAPORT REGISTER REQUEST COUNT XECORE8",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE9", "XVE DATAPORT REGISTER REQUEST COUNT XECORE9",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE10", "XVE DATAPORT REGISTER REQUEST COUNT XECORE10",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE11", "XVE DATAPORT REGISTER REQUEST COUNT XECORE11",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE12", "XVE DATAPORT REGISTER REQUEST COUNT XECORE12",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE13", "XVE DATAPORT REGISTER REQUEST COUNT XECORE13",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4 dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168 qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE14", "XVE DATAPORT REGISTER REQUEST COUNT XECORE14",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE15", "XVE DATAPORT REGISTER REQUEST COUNT XECORE15",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x188102fd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a102fd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c102fd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e102fd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x198102fd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a102fd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c102fd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e102fd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x168103c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02875000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a103c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a43000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a70500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c103c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e103c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f8103c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01875000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da103c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc103c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e103c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000300ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020700a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208af00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a55aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000130ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010700a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108af00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a55aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03210a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030423, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030e21, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030ee7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt344MetricSet::CExt344MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt344MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE16", "XVE DATAPORT REGISTER REQUEST COUNT XECORE16",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE17", "XVE DATAPORT REGISTER REQUEST COUNT XECORE17",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE18", "XVE DATAPORT REGISTER REQUEST COUNT XECORE18",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE19", "XVE DATAPORT REGISTER REQUEST COUNT XECORE19",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE20", "XVE DATAPORT REGISTER REQUEST COUNT XECORE20",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE21", "XVE DATAPORT REGISTER REQUEST COUNT XECORE21",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4 dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168 qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE22", "XVE DATAPORT REGISTER REQUEST COUNT XECORE22",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE23", "XVE DATAPORT REGISTER REQUEST COUNT XECORE23",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x188102fd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a102fd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c102fd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e102fd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x198102fd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a102fd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c102fd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e102fd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x168103c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02875000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a103c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a43000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a70500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c103c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e103c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f8103c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01875000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da103c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc103c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e103c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000300ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020700a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208af00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a55aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000130ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010700a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108af00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a55aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03210a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030423, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030e21, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030ee7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt345MetricSet::CExt345MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt345MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE24", "XVE DATAPORT REGISTER REQUEST COUNT XECORE24",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE25", "XVE DATAPORT REGISTER REQUEST COUNT XECORE25",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE26", "XVE DATAPORT REGISTER REQUEST COUNT XECORE26",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE27", "XVE DATAPORT REGISTER REQUEST COUNT XECORE27",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE28", "XVE DATAPORT REGISTER REQUEST COUNT XECORE28",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE29", "XVE DATAPORT REGISTER REQUEST COUNT XECORE29",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4 dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168 qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE30", "XVE DATAPORT REGISTER REQUEST COUNT XECORE30",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_REQUEST_COUNT_XECORE31", "XVE DATAPORT REGISTER REQUEST COUNT XECORE31",
                          "Number of message payload transactions sent from XVEs to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x188102fd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a102fd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c102fd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e102fd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x198102fd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a102fd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c102fd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e102fd, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x168103c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02875000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a103c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a43000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a70500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c103c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e103c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f8103c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01875000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da103c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc103c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e103c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000300ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020700a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208af00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a55aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000130ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010700a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108af00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a55aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03210a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030423, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030e21, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030ee7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt346MetricSet::CExt346MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt346MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE0", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE0",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_FLOAT, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 FADD dw@0xc8 FADD dw@0xcc FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 FADD qw@0x150 FADD qw@0x158 FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE1", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE1",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_FLOAT, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 FADD dw@0xd8 FADD dw@0xdc FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 FADD qw@0x170 FADD qw@0x178 FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1281a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1481b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a1a656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a1b695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04813200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a810656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c810695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e8106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00875555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt347MetricSet::CExt347MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt347MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE2", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE2",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_FLOAT, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 FADD dw@0xc8 FADD dw@0xcc FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 FADD qw@0x150 FADD qw@0x158 FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE3", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE3",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_FLOAT, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 FADD dw@0xd8 FADD dw@0xdc FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 FADD qw@0x170 FADD qw@0x178 FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c1a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c1b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e1a656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e1b695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac10656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt348MetricSet::CExt348MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt348MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE4", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE4",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_FLOAT, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 FADD dw@0xc8 FADD dw@0xcc FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 FADD qw@0x150 FADD qw@0x158 FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE5", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE5",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_FLOAT, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 FADD dw@0xd8 FADD dw@0xdc FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 FADD qw@0x170 FADD qw@0x178 FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1381a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1581b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a1a656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a1b695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05813200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b810656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f8106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01875555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt349MetricSet::CExt349MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt349MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE6", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE6",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_FLOAT, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 FADD dw@0xc8 FADD dw@0xcc FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 FADD qw@0x150 FADD qw@0x158 FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE7", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE7",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_FLOAT, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 FADD dw@0xd8 FADD dw@0xdc FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 FADD qw@0x170 FADD qw@0x178 FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c1a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c1b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e1a656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e1b695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc10656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc10695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt350MetricSet::CExt350MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt350MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE8", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE8",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD 2 UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD 2 UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE9", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE9",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_FLOAT, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 FADD dw@0xd8 FADD dw@0xdc FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 FADD qw@0x170 FADD qw@0x178 FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1281a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1481b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a1a656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a1b695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04813200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a810656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c810695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e8106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00875555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt351MetricSet::CExt351MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt351MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE10", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE10",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_FLOAT, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 FADD dw@0xc8 FADD dw@0xcc FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 FADD qw@0x150 FADD qw@0x158 FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE11", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE11",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_FLOAT, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 FADD dw@0xd8 FADD dw@0xdc FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 FADD qw@0x170 FADD qw@0x178 FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c1a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c1b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e1a656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e1b695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac10656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt352MetricSet::CExt352MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt352MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE12", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE12",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_FLOAT, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 FADD dw@0xc8 FADD dw@0xcc FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 FADD qw@0x150 FADD qw@0x158 FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE13", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE13",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_FLOAT, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 FADD dw@0xd8 FADD dw@0xdc FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 FADD qw@0x170 FADD qw@0x178 FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1381a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1581b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a1a656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a1b695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05813200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b810656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f8106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01875555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt353MetricSet::CExt353MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt353MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE14", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE14",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_FLOAT, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 FADD dw@0xc8 FADD dw@0xcc FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 FADD qw@0x150 FADD qw@0x158 FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE15", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE15",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_FLOAT, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 FADD dw@0xd8 FADD dw@0xdc FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 FADD qw@0x170 FADD qw@0x178 FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c1a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c1b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e1a656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e1b695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc10656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc10695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt354MetricSet::CExt354MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt354MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE16", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE16",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_FLOAT, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 FADD dw@0xc8 FADD dw@0xcc FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 FADD qw@0x150 FADD qw@0x158 FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE17", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE17",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_FLOAT, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 FADD dw@0xd8 FADD dw@0xdc FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 FADD qw@0x170 FADD qw@0x178 FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1281a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1481b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a1a656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a1b695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04813200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a810656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c810695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e8106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00875555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt355MetricSet::CExt355MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt355MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE18", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE18",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_FLOAT, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 FADD dw@0xc8 FADD dw@0xcc FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 FADD qw@0x150 FADD qw@0x158 FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE19", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE19",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_FLOAT, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 FADD dw@0xd8 FADD dw@0xdc FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 FADD qw@0x170 FADD qw@0x178 FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c1a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c1b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e1a656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e1b695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac10656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt356MetricSet::CExt356MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt356MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE20", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE20",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_FLOAT, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 FADD dw@0xc8 FADD dw@0xcc FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 FADD qw@0x150 FADD qw@0x158 FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE21", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE21",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_FLOAT, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 FADD dw@0xd8 FADD dw@0xdc FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 FADD qw@0x170 FADD qw@0x178 FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1381a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1581b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a1a656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a1b695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05813200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b810656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f8106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01875555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt357MetricSet::CExt357MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt357MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE22", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE22",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_FLOAT, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 FADD dw@0xc8 FADD dw@0xcc FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 FADD qw@0x150 FADD qw@0x158 FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE23", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE23",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_FLOAT, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 FADD dw@0xd8 FADD dw@0xdc FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 FADD qw@0x170 FADD qw@0x178 FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c1a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c1b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e1a656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e1b695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc10656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc10695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt358MetricSet::CExt358MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt358MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE24", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE24",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_FLOAT, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 FADD dw@0xc8 FADD dw@0xcc FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 FADD qw@0x150 FADD qw@0x158 FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE25", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE25",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_FLOAT, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 FADD dw@0xd8 FADD dw@0xdc FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 FADD qw@0x170 FADD qw@0x178 FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1281a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1481b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a1a656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a1b695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04813200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a810656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c810695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e8106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00875555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt359MetricSet::CExt359MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt359MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE26", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE26",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_FLOAT, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 FADD dw@0xc8 FADD dw@0xcc FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 FADD qw@0x150 FADD qw@0x158 FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE27", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE27",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_FLOAT, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 FADD dw@0xd8 FADD dw@0xdc FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 FADD qw@0x170 FADD qw@0x178 FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c1a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c1b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e1a656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e1b695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac10656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt360MetricSet::CExt360MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt360MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE28", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE28",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_FLOAT, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 FADD dw@0xc8 FADD dw@0xcc FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 FADD qw@0x150 FADD qw@0x158 FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE29", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE29",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_FLOAT, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 FADD dw@0xd8 FADD dw@0xdc FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 FADD qw@0x170 FADD qw@0x178 FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1381a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1581b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a1a656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a1b695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05813200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b810656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f8106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01875555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt361MetricSet::CExt361MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt361MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE30", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE30",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_FLOAT, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 FADD dw@0xc8 FADD dw@0xcc FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 FADD qw@0x150 FADD qw@0x158 FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "XVE_DATAPORT_REGISTER_RESPONSE_COUNT_XECORE31", "XVE DATAPORT REGISTER RESPONSE COUNT XECORE31",
                          "Number of return message payload transactions sent from the Dataport to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_FLOAT, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 FADD dw@0xd8 FADD dw@0xdc FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 FADD qw@0x170 FADD qw@0x178 FADD 2 FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c1a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c1b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e1a656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e1b695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc10656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc10695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt362MetricSet::CExt362MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt362MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE0", "DATAPORT INPUT AVAILABLE XECORE0",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE1", "DATAPORT INPUT AVAILABLE XECORE1",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1881039b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a1039b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a810207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c810081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e810103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00875555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a10185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a10207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a10081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a10103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ff00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x000000ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt363MetricSet::CExt363MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt363MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE2", "DATAPORT INPUT AVAILABLE XECORE2",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE3", "DATAPORT INPUT AVAILABLE XECORE3",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c1039b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e1039b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac10207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec10103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e10185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e10207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e10081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e10103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ff00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x000000ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt364MetricSet::CExt364MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt364MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE4", "DATAPORT INPUT AVAILABLE XECORE4",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE5", "DATAPORT INPUT AVAILABLE XECORE5",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1981039b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a1039b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b810207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f810103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01875555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a10185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a10081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a10103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ff00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x000000ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt365MetricSet::CExt365MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt365MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE6", "DATAPORT INPUT AVAILABLE XECORE6",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE7", "DATAPORT INPUT AVAILABLE XECORE7",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c1039b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e1039b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc10207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc10081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e10207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e10081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e10103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ff00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x000000ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt366MetricSet::CExt366MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt366MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE8", "DATAPORT INPUT AVAILABLE XECORE8",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE9", "DATAPORT INPUT AVAILABLE XECORE9",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1881039b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a1039b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a810207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c810081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e810103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00875555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a10185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a10207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a10081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a10103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ff00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x000000ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt367MetricSet::CExt367MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt367MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE10", "DATAPORT INPUT AVAILABLE XECORE10",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE11", "DATAPORT INPUT AVAILABLE XECORE11",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c1039b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e1039b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac10207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec10103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e10185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e10207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e10081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e10103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ff00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x000000ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt368MetricSet::CExt368MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt368MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE12", "DATAPORT INPUT AVAILABLE XECORE12",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE13", "DATAPORT INPUT AVAILABLE XECORE13",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1981039b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a1039b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b810207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f810103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01875555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a10185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a10081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a10103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ff00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x000000ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt369MetricSet::CExt369MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt369MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE14", "DATAPORT INPUT AVAILABLE XECORE14",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE15", "DATAPORT INPUT AVAILABLE XECORE15",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c1039b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e1039b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc10207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc10081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e10207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e10081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e10103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ff00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x000000ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt370MetricSet::CExt370MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt370MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE16", "DATAPORT INPUT AVAILABLE XECORE16",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE17", "DATAPORT INPUT AVAILABLE XECORE17",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1881039b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a1039b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a810207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c810081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e810103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00875555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a10185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a10207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a10081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a10103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ff00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x000000ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt371MetricSet::CExt371MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt371MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE18", "DATAPORT INPUT AVAILABLE XECORE18",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE19", "DATAPORT INPUT AVAILABLE XECORE19",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c1039b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e1039b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac10207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec10103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e10185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e10207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e10081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e10103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ff00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x000000ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt372MetricSet::CExt372MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt372MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE20", "DATAPORT INPUT AVAILABLE XECORE20",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE21", "DATAPORT INPUT AVAILABLE XECORE21",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1981039b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a1039b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b810207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f810103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01875555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a10185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a10081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a10103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ff00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x000000ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt373MetricSet::CExt373MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt373MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE22", "DATAPORT INPUT AVAILABLE XECORE22",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE23", "DATAPORT INPUT AVAILABLE XECORE23",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c1039b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e1039b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc10207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc10081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e10207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e10081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e10103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ff00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x000000ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt374MetricSet::CExt374MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt374MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE24", "DATAPORT INPUT AVAILABLE XECORE24",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE25", "DATAPORT INPUT AVAILABLE XECORE25",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1881039b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a1039b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a810207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c810081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e810103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00875555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a10185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a10207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a10081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a10103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ff00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x000000ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt375MetricSet::CExt375MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt375MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE26", "DATAPORT INPUT AVAILABLE XECORE26",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE27", "DATAPORT INPUT AVAILABLE XECORE27",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c1039b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e1039b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac10207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec10103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e10185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e10207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e10081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e10103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ff00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x000000ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt376MetricSet::CExt376MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt376MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE28", "DATAPORT INPUT AVAILABLE XECORE28",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE29", "DATAPORT INPUT AVAILABLE XECORE29",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1981039b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a1039b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b810207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f810103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01875555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a10185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a10081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a10103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ff00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x000000ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt377MetricSet::CExt377MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt377MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE30", "DATAPORT INPUT AVAILABLE XECORE30",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "DATAPORT_INPUT_AVAILABLE_XECORE31", "DATAPORT INPUT AVAILABLE XECORE31",
                          "Percentage of time in which XVEs have requests to the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c1039b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e1039b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc10207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc10081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e10207, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e10081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e10103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ff00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x000000ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt378MetricSet::CExt378MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt378MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE0", "DATAPORT OUTPUT READY XECORE0",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE1", "DATAPORT OUTPUT READY XECORE1",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE2", "DATAPORT OUTPUT READY XECORE2",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE3", "DATAPORT OUTPUT READY XECORE3",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1281c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a1c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c1c4d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e1c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a8104d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca10450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea104d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c10450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e10450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e104d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000078, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000780, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00007800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00078000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt379MetricSet::CExt379MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt379MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE4", "DATAPORT OUTPUT READY XECORE4",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE5", "DATAPORT OUTPUT READY XECORE5",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE6", "DATAPORT OUTPUT READY XECORE6",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE7", "DATAPORT OUTPUT READY XECORE7",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1381c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a1c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c1c4d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e1c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b8104d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da10450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa104d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c10450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e10450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e104d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000078, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000780, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00007800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00078000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt380MetricSet::CExt380MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt380MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE8", "DATAPORT OUTPUT READY XECORE8",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE9", "DATAPORT OUTPUT READY XECORE9",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE10", "DATAPORT OUTPUT READY XECORE10",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE11", "DATAPORT OUTPUT READY XECORE11",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1281c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a1c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c1c4d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e1c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a8104d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca10450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea104d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c10450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e10450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e104d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000078, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000780, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00007800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00078000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt381MetricSet::CExt381MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt381MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE12", "DATAPORT OUTPUT READY XECORE12",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE13", "DATAPORT OUTPUT READY XECORE13",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE14", "DATAPORT OUTPUT READY XECORE14",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE15", "DATAPORT OUTPUT READY XECORE15",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1381c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a1c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c1c4d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e1c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b8104d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da10450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa104d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c10450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e10450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e104d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000078, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000780, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00007800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00078000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt382MetricSet::CExt382MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt382MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE16", "DATAPORT OUTPUT READY XECORE16",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE17", "DATAPORT OUTPUT READY XECORE17",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE18", "DATAPORT OUTPUT READY XECORE18",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE19", "DATAPORT OUTPUT READY XECORE19",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1281c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a1c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c1c4d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e1c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a8104d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca10450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea104d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c10450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e10450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e104d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000078, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000780, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00007800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00078000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt383MetricSet::CExt383MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt383MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE20", "DATAPORT OUTPUT READY XECORE20",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE21", "DATAPORT OUTPUT READY XECORE21",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE22", "DATAPORT OUTPUT READY XECORE22",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE23", "DATAPORT OUTPUT READY XECORE23",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1381c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a1c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c1c4d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e1c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b8104d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da10450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa104d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c10450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e10450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e104d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000078, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000780, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00007800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00078000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt384MetricSet::CExt384MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt384MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE24", "DATAPORT OUTPUT READY XECORE24",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE25", "DATAPORT OUTPUT READY XECORE25",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE26", "DATAPORT OUTPUT READY XECORE26",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE27", "DATAPORT OUTPUT READY XECORE27",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1281c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a1c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c1c4d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e1c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a8104d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca10450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea104d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c10450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e10450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e104d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000078, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000780, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00007800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00078000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt385MetricSet::CExt385MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt385MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE28", "DATAPORT OUTPUT READY XECORE28",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE29", "DATAPORT OUTPUT READY XECORE29",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE30", "DATAPORT OUTPUT READY XECORE30",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "DATAPORT_OUTPUT_READY_XECORE31", "DATAPORT OUTPUT READY XECORE31",
                          "Percentage of time in which the Dataport has data to return to XVEs",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1381c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a1c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c1c4d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e1c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b8104d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da10450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa104d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c10450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e10450, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e104d2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000078, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000780, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00007800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00078000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt386MetricSet::CExt386MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt386MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE0", "DATAPORT BYTE READ XECORE0",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE1", "DATAPORT BYTE READ XECORE1",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1281a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1481b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a1a656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a1b695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04813200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a810656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c810695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e8106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00875555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt387MetricSet::CExt387MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt387MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE2", "DATAPORT BYTE READ XECORE2",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE3", "DATAPORT BYTE READ XECORE3",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c1a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c1b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e1a656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e1b695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac10656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt388MetricSet::CExt388MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt388MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE4", "DATAPORT BYTE READ XECORE4",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE5", "DATAPORT BYTE READ XECORE5",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1381a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1581b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a1a656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a1b695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05813200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b810656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f8106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01875555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt389MetricSet::CExt389MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt389MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE6", "DATAPORT BYTE READ XECORE6",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE7", "DATAPORT BYTE READ XECORE7",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c1a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c1b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e1a656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e1b695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc10656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc10695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt390MetricSet::CExt390MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt390MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE8", "DATAPORT BYTE READ XECORE8",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE9", "DATAPORT BYTE READ XECORE9",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1281a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1481b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a1a656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a1b695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04813200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a810656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c810695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e8106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00875555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt391MetricSet::CExt391MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt391MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE10", "DATAPORT BYTE READ XECORE10",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE11", "DATAPORT BYTE READ XECORE11",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c1a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c1b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e1a656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e1b695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac10656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt392MetricSet::CExt392MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt392MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE12", "DATAPORT BYTE READ XECORE12",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE13", "DATAPORT BYTE READ XECORE13",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1381a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1581b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a1a656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a1b695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05813200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b810656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f8106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01875555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt393MetricSet::CExt393MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt393MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE14", "DATAPORT BYTE READ XECORE14",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE15", "DATAPORT BYTE READ XECORE15",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c1a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c1b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e1a656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e1b695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc10656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc10695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt394MetricSet::CExt394MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt394MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE16", "DATAPORT BYTE READ XECORE16",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE17", "DATAPORT BYTE READ XECORE17",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1281a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1481b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a1a656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a1b695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04813200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a810656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c810695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e8106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00875555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt395MetricSet::CExt395MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt395MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE18", "DATAPORT BYTE READ XECORE18",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE19", "DATAPORT BYTE READ XECORE19",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c1a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c1b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e1a656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e1b695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac10656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt396MetricSet::CExt396MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt396MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE20", "DATAPORT BYTE READ XECORE20",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE21", "DATAPORT BYTE READ XECORE21",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1381a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1581b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a1a656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a1b695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05813200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b810656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f8106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01875555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt397MetricSet::CExt397MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt397MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE22", "DATAPORT BYTE READ XECORE22",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE23", "DATAPORT BYTE READ XECORE23",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c1a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c1b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e1a656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e1b695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc10656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc10695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt398MetricSet::CExt398MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt398MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE24", "DATAPORT BYTE READ XECORE24",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE25", "DATAPORT BYTE READ XECORE25",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1281a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1481b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a1a656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a1b695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04813200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a810656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c810695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e8106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00875555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt399MetricSet::CExt399MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt399MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE26", "DATAPORT BYTE READ XECORE26",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE27", "DATAPORT BYTE READ XECORE27",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c1a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c1b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e1a656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e1b695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac10656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt400MetricSet::CExt400MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt400MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE28", "DATAPORT BYTE READ XECORE28",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE29", "DATAPORT BYTE READ XECORE29",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1381a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1581b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a1a656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a1b695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05813200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b810656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f8106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01875555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt401MetricSet::CExt401MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt401MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE30", "DATAPORT BYTE READ XECORE30",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "DATAPORT_BYTE_READ_XECORE31", "DATAPORT BYTE READ XECORE31",
                          "Number of bytes read through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD 64 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c1a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c1b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e1a656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e1b695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc10656, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc10695, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e13200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10617, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e106d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt402MetricSet::CExt402MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt402MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE0", "DATAPORT BYTE WRITE XECORE0",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "32 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE1", "DATAPORT BYTE WRITE XECORE1",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "32 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE2", "DATAPORT BYTE WRITE XECORE2",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "32 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE3", "DATAPORT BYTE WRITE XECORE3",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "32 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE4", "DATAPORT BYTE WRITE XECORE4",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "32 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE5", "DATAPORT BYTE WRITE XECORE5",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "32 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE6", "DATAPORT BYTE WRITE XECORE6",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "32 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE7", "DATAPORT BYTE WRITE XECORE7",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "32 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE8", "DATAPORT BYTE WRITE XECORE8",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "32 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE9", "DATAPORT BYTE WRITE XECORE9",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "32 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE10", "DATAPORT BYTE WRITE XECORE10",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "32 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE11", "DATAPORT BYTE WRITE XECORE11",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "32 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE12", "DATAPORT BYTE WRITE XECORE12",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "32 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE13", "DATAPORT BYTE WRITE XECORE13",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "32 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE14", "DATAPORT BYTE WRITE XECORE14",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "32 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE15", "DATAPORT BYTE WRITE XECORE15",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "32 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e810340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f810340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16810580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02838000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02874000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a10016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c10580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e10016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13810580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c10580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00093000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e810340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f810340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e810580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00838000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00874000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea10016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce10016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b810580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba10016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001004f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03086a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030c0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030ce2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x460300e8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt403MetricSet::CExt403MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt403MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE16", "DATAPORT BYTE WRITE XECORE16",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "32 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE17", "DATAPORT BYTE WRITE XECORE17",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "32 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE18", "DATAPORT BYTE WRITE XECORE18",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "32 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE19", "DATAPORT BYTE WRITE XECORE19",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "32 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE20", "DATAPORT BYTE WRITE XECORE20",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "32 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE21", "DATAPORT BYTE WRITE XECORE21",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "32 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE22", "DATAPORT BYTE WRITE XECORE22",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "32 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE23", "DATAPORT BYTE WRITE XECORE23",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "32 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE24", "DATAPORT BYTE WRITE XECORE24",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "32 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE25", "DATAPORT BYTE WRITE XECORE25",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "32 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE26", "DATAPORT BYTE WRITE XECORE26",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "32 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE27", "DATAPORT BYTE WRITE XECORE27",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "32 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE28", "DATAPORT BYTE WRITE XECORE28",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "32 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE29", "DATAPORT BYTE WRITE XECORE29",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "32 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE30", "DATAPORT BYTE WRITE XECORE30",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "32 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "DATAPORT_BYTE_WRITE_XECORE31", "DATAPORT BYTE WRITE XECORE31",
                          "Number of bytes written through the Dataport",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "32 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e810340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f810340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16810580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02838000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02874000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a10016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c10580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e10016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13810580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c10580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00093000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e810340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f810340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e810580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00838000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00874000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea10016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce10016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b810580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba10016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001004f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03086a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030c0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030ce2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x460300e8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt404MetricSet::CExt404MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt404MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_ACCESS_XECORE0", "DATAPORT TEXTURE CACHE ACCESS XECORE0",
                          "Number of cacheline requests from the Dataport to the texture cache not including uncached accesses",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_ACCESS_XECORE1", "DATAPORT TEXTURE CACHE ACCESS XECORE1",
                          "Number of cacheline requests from the Dataport to the texture cache not including uncached accesses",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_ACCESS_XECORE2", "DATAPORT TEXTURE CACHE ACCESS XECORE2",
                          "Number of cacheline requests from the Dataport to the texture cache not including uncached accesses",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_ACCESS_XECORE3", "DATAPORT TEXTURE CACHE ACCESS XECORE3",
                          "Number of cacheline requests from the Dataport to the texture cache not including uncached accesses",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_ACCESS_XECORE4", "DATAPORT TEXTURE CACHE ACCESS XECORE4",
                          "Number of cacheline requests from the Dataport to the texture cache not including uncached accesses",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_ACCESS_XECORE5", "DATAPORT TEXTURE CACHE ACCESS XECORE5",
                          "Number of cacheline requests from the Dataport to the texture cache not including uncached accesses",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_ACCESS_XECORE6", "DATAPORT TEXTURE CACHE ACCESS XECORE6",
                          "Number of cacheline requests from the Dataport to the texture cache not including uncached accesses",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_ACCESS_XECORE7", "DATAPORT TEXTURE CACHE ACCESS XECORE7",
                          "Number of cacheline requests from the Dataport to the texture cache not including uncached accesses",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_ACCESS_XECORE8", "DATAPORT TEXTURE CACHE ACCESS XECORE8",
                          "Number of cacheline requests from the Dataport to the texture cache not including uncached accesses",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_ACCESS_XECORE9", "DATAPORT TEXTURE CACHE ACCESS XECORE9",
                          "Number of cacheline requests from the Dataport to the texture cache not including uncached accesses",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_ACCESS_XECORE10", "DATAPORT TEXTURE CACHE ACCESS XECORE10",
                          "Number of cacheline requests from the Dataport to the texture cache not including uncached accesses",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_ACCESS_XECORE11", "DATAPORT TEXTURE CACHE ACCESS XECORE11",
                          "Number of cacheline requests from the Dataport to the texture cache not including uncached accesses",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_ACCESS_XECORE12", "DATAPORT TEXTURE CACHE ACCESS XECORE12",
                          "Number of cacheline requests from the Dataport to the texture cache not including uncached accesses",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_ACCESS_XECORE13", "DATAPORT TEXTURE CACHE ACCESS XECORE13",
                          "Number of cacheline requests from the Dataport to the texture cache not including uncached accesses",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_ACCESS_XECORE14", "DATAPORT TEXTURE CACHE ACCESS XECORE14",
                          "Number of cacheline requests from the Dataport to the texture cache not including uncached accesses",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_ACCESS_XECORE15", "DATAPORT TEXTURE CACHE ACCESS XECORE15",
                          "Number of cacheline requests from the Dataport to the texture cache not including uncached accesses",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e810020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea10020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec10020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee10020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f810020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa10020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc10020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe10020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16810440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02838000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02874000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c10440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13810440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c10440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00093000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e810020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea10020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec10020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee10020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f810020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa10020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc10020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe10020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e810440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00838000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00874000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b810440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001004f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03086a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030c0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030ce2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x460300e8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt405MetricSet::CExt405MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt405MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_ACCESS_XECORE16", "DATAPORT TEXTURE CACHE ACCESS XECORE16",
                          "Number of cacheline requests from the Dataport to the texture cache not including uncached accesses",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_ACCESS_XECORE17", "DATAPORT TEXTURE CACHE ACCESS XECORE17",
                          "Number of cacheline requests from the Dataport to the texture cache not including uncached accesses",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_ACCESS_XECORE18", "DATAPORT TEXTURE CACHE ACCESS XECORE18",
                          "Number of cacheline requests from the Dataport to the texture cache not including uncached accesses",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_ACCESS_XECORE19", "DATAPORT TEXTURE CACHE ACCESS XECORE19",
                          "Number of cacheline requests from the Dataport to the texture cache not including uncached accesses",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_ACCESS_XECORE20", "DATAPORT TEXTURE CACHE ACCESS XECORE20",
                          "Number of cacheline requests from the Dataport to the texture cache not including uncached accesses",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_ACCESS_XECORE21", "DATAPORT TEXTURE CACHE ACCESS XECORE21",
                          "Number of cacheline requests from the Dataport to the texture cache not including uncached accesses",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_ACCESS_XECORE22", "DATAPORT TEXTURE CACHE ACCESS XECORE22",
                          "Number of cacheline requests from the Dataport to the texture cache not including uncached accesses",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_ACCESS_XECORE23", "DATAPORT TEXTURE CACHE ACCESS XECORE23",
                          "Number of cacheline requests from the Dataport to the texture cache not including uncached accesses",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_ACCESS_XECORE24", "DATAPORT TEXTURE CACHE ACCESS XECORE24",
                          "Number of cacheline requests from the Dataport to the texture cache not including uncached accesses",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_ACCESS_XECORE25", "DATAPORT TEXTURE CACHE ACCESS XECORE25",
                          "Number of cacheline requests from the Dataport to the texture cache not including uncached accesses",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_ACCESS_XECORE26", "DATAPORT TEXTURE CACHE ACCESS XECORE26",
                          "Number of cacheline requests from the Dataport to the texture cache not including uncached accesses",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_ACCESS_XECORE27", "DATAPORT TEXTURE CACHE ACCESS XECORE27",
                          "Number of cacheline requests from the Dataport to the texture cache not including uncached accesses",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_ACCESS_XECORE28", "DATAPORT TEXTURE CACHE ACCESS XECORE28",
                          "Number of cacheline requests from the Dataport to the texture cache not including uncached accesses",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_ACCESS_XECORE29", "DATAPORT TEXTURE CACHE ACCESS XECORE29",
                          "Number of cacheline requests from the Dataport to the texture cache not including uncached accesses",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_ACCESS_XECORE30", "DATAPORT TEXTURE CACHE ACCESS XECORE30",
                          "Number of cacheline requests from the Dataport to the texture cache not including uncached accesses",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_ACCESS_XECORE31", "DATAPORT TEXTURE CACHE ACCESS XECORE31",
                          "Number of cacheline requests from the Dataport to the texture cache not including uncached accesses",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e810020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea10020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec10020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee10020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f810020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa10020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc10020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe10020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16810440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02838000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02874000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c10440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13810440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c10440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00093000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e810020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea10020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec10020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee10020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f810020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa10020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc10020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe10020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e810440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00838000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00874000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b810440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001004f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03086a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030c0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030ce2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x460300e8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt406MetricSet::CExt406MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt406MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_HIT_XECORE0", "DATAPORT TEXTURE CACHE HIT XECORE0",
                          "Number of cache requests from the Dataport to the texture cache that resulted in a cache hit",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_HIT_XECORE1", "DATAPORT TEXTURE CACHE HIT XECORE1",
                          "Number of cache requests from the Dataport to the texture cache that resulted in a cache hit",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_HIT_XECORE2", "DATAPORT TEXTURE CACHE HIT XECORE2",
                          "Number of cache requests from the Dataport to the texture cache that resulted in a cache hit",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_HIT_XECORE3", "DATAPORT TEXTURE CACHE HIT XECORE3",
                          "Number of cache requests from the Dataport to the texture cache that resulted in a cache hit",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_HIT_XECORE4", "DATAPORT TEXTURE CACHE HIT XECORE4",
                          "Number of cache requests from the Dataport to the texture cache that resulted in a cache hit",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_HIT_XECORE5", "DATAPORT TEXTURE CACHE HIT XECORE5",
                          "Number of cache requests from the Dataport to the texture cache that resulted in a cache hit",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_HIT_XECORE6", "DATAPORT TEXTURE CACHE HIT XECORE6",
                          "Number of cache requests from the Dataport to the texture cache that resulted in a cache hit",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_HIT_XECORE7", "DATAPORT TEXTURE CACHE HIT XECORE7",
                          "Number of cache requests from the Dataport to the texture cache that resulted in a cache hit",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_HIT_XECORE8", "DATAPORT TEXTURE CACHE HIT XECORE8",
                          "Number of cache requests from the Dataport to the texture cache that resulted in a cache hit",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_HIT_XECORE9", "DATAPORT TEXTURE CACHE HIT XECORE9",
                          "Number of cache requests from the Dataport to the texture cache that resulted in a cache hit",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_HIT_XECORE10", "DATAPORT TEXTURE CACHE HIT XECORE10",
                          "Number of cache requests from the Dataport to the texture cache that resulted in a cache hit",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_HIT_XECORE11", "DATAPORT TEXTURE CACHE HIT XECORE11",
                          "Number of cache requests from the Dataport to the texture cache that resulted in a cache hit",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_HIT_XECORE12", "DATAPORT TEXTURE CACHE HIT XECORE12",
                          "Number of cache requests from the Dataport to the texture cache that resulted in a cache hit",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_HIT_XECORE13", "DATAPORT TEXTURE CACHE HIT XECORE13",
                          "Number of cache requests from the Dataport to the texture cache that resulted in a cache hit",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_HIT_XECORE14", "DATAPORT TEXTURE CACHE HIT XECORE14",
                          "Number of cache requests from the Dataport to the texture cache that resulted in a cache hit",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_HIT_XECORE15", "DATAPORT TEXTURE CACHE HIT XECORE15",
                          "Number of cache requests from the Dataport to the texture cache that resulted in a cache hit",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2081001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20a1001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c1001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20e1001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2181001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21a1001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21c1001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21e1001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16810500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02838000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02874000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a10014, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c10500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e10014, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13810500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10014, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c10500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10014, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00093000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2081001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20a1001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c1001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20e1001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2181001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21a1001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21c1001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21e1001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e810500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00838000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00874000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea10014, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce10014, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b810500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba10014, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10014, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001004f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03086a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030c0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030ce2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x460300e8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt407MetricSet::CExt407MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt407MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_HIT_XECORE16", "DATAPORT TEXTURE CACHE HIT XECORE16",
                          "Number of cache requests from the Dataport to the texture cache that resulted in a cache hit",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_HIT_XECORE17", "DATAPORT TEXTURE CACHE HIT XECORE17",
                          "Number of cache requests from the Dataport to the texture cache that resulted in a cache hit",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_HIT_XECORE18", "DATAPORT TEXTURE CACHE HIT XECORE18",
                          "Number of cache requests from the Dataport to the texture cache that resulted in a cache hit",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_HIT_XECORE19", "DATAPORT TEXTURE CACHE HIT XECORE19",
                          "Number of cache requests from the Dataport to the texture cache that resulted in a cache hit",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_HIT_XECORE20", "DATAPORT TEXTURE CACHE HIT XECORE20",
                          "Number of cache requests from the Dataport to the texture cache that resulted in a cache hit",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_HIT_XECORE21", "DATAPORT TEXTURE CACHE HIT XECORE21",
                          "Number of cache requests from the Dataport to the texture cache that resulted in a cache hit",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_HIT_XECORE22", "DATAPORT TEXTURE CACHE HIT XECORE22",
                          "Number of cache requests from the Dataport to the texture cache that resulted in a cache hit",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_HIT_XECORE23", "DATAPORT TEXTURE CACHE HIT XECORE23",
                          "Number of cache requests from the Dataport to the texture cache that resulted in a cache hit",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_HIT_XECORE24", "DATAPORT TEXTURE CACHE HIT XECORE24",
                          "Number of cache requests from the Dataport to the texture cache that resulted in a cache hit",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_HIT_XECORE25", "DATAPORT TEXTURE CACHE HIT XECORE25",
                          "Number of cache requests from the Dataport to the texture cache that resulted in a cache hit",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_HIT_XECORE26", "DATAPORT TEXTURE CACHE HIT XECORE26",
                          "Number of cache requests from the Dataport to the texture cache that resulted in a cache hit",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_HIT_XECORE27", "DATAPORT TEXTURE CACHE HIT XECORE27",
                          "Number of cache requests from the Dataport to the texture cache that resulted in a cache hit",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_HIT_XECORE28", "DATAPORT TEXTURE CACHE HIT XECORE28",
                          "Number of cache requests from the Dataport to the texture cache that resulted in a cache hit",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_HIT_XECORE29", "DATAPORT TEXTURE CACHE HIT XECORE29",
                          "Number of cache requests from the Dataport to the texture cache that resulted in a cache hit",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_HIT_XECORE30", "DATAPORT TEXTURE CACHE HIT XECORE30",
                          "Number of cache requests from the Dataport to the texture cache that resulted in a cache hit",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "DATAPORT_TEXTURE_CACHE_HIT_XECORE31", "DATAPORT TEXTURE CACHE HIT XECORE31",
                          "Number of cache requests from the Dataport to the texture cache that resulted in a cache hit",
                          "Dataport", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2081001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20a1001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c1001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20e1001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2181001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21a1001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21c1001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21e1001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16810500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02838000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02874000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a10014, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c10500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e10014, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13810500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10014, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c10500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10014, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00093000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2081001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20a1001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c1001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20e1001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2181001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21a1001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21c1001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21e1001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04810600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e810500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00838000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00874000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea10014, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce10014, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05810600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b810500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba10014, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e10600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10014, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001004f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03086a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030c0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030ce2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x460300e8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt408MetricSet::CExt408MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt408MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE0", "RT LOAD STORE CACHE READ MESSAGE COUNT XECORE0",
                          "Number of read messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_WRITE_FROM_MESSAGE_COUNT_XECORE0", "RT LOAD STORE CACHE WRITE FROM MESSAGE COUNT XECORE0",
                          "Number of write messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE0", "RT TRAVERSAL INPUT RAY COUNT XECORE0",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE0", "RT QUAD TEST RAY COUNT XECORE0",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "RT_REQUEST_COLLISION_XECORE0", "RT REQUEST COLLISION XECORE0",
                          "Percentage of time in which  Ray Tracing Leaf has two Traversal inputs valid",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE0", "RT INPUT MESSAGE RAY COUNT XECORE0",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE0", "RT MESSAGE STALL COUNT XECORE0",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE0", "RT TRANSFORM RAY COUNT XECORE0",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16857fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08851000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18894740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e89023a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22896800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28894740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02850b2c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e850154, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x108505d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x128503ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0286aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02893254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x068903c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x088907d1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890be1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890ff1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff3f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt409MetricSet::CExt409MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt409MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE1", "RT LOAD STORE CACHE READ MESSAGE COUNT XECORE1",
                          "Number of read messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_WRITE_FROM_MESSAGE_COUNT_XECORE1", "RT LOAD STORE CACHE WRITE FROM MESSAGE COUNT XECORE1",
                          "Number of write messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE1", "RT TRAVERSAL INPUT RAY COUNT XECORE1",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE1", "RT QUAD TEST RAY COUNT XECORE1",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "RT_REQUEST_COLLISION_XECORE1", "RT REQUEST COLLISION XECORE1",
                          "Percentage of time in which  Ray Tracing Leaf has two Traversal inputs valid",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE1", "RT INPUT MESSAGE RAY COUNT XECORE1",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE1", "RT MESSAGE STALL COUNT XECORE1",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE1", "RT TRANSFORM RAY COUNT XECORE1",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a57fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a51000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea9023a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22a96800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28a94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a50b2c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea50154, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a505d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a503ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a6aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a903c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a907d1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa90be1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca90ff1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff3f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt410MetricSet::CExt410MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt410MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE2", "RT LOAD STORE CACHE READ MESSAGE COUNT XECORE2",
                          "Number of read messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_WRITE_FROM_MESSAGE_COUNT_XECORE2", "RT LOAD STORE CACHE WRITE FROM MESSAGE COUNT XECORE2",
                          "Number of write messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE2", "RT TRAVERSAL INPUT RAY COUNT XECORE2",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE2", "RT QUAD TEST RAY COUNT XECORE2",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "RT_REQUEST_COLLISION_XECORE2", "RT REQUEST COLLISION XECORE2",
                          "Percentage of time in which  Ray Tracing Leaf has two Traversal inputs valid",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE2", "RT INPUT MESSAGE RAY COUNT XECORE2",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE2", "RT MESSAGE STALL COUNT XECORE2",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE2", "RT TRANSFORM RAY COUNT XECORE2",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c57fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c51000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec9023a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c96800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28c94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c50b2c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50154, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c505d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c503ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c6aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c903c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c907d1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90be1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90ff1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff3f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt411MetricSet::CExt411MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt411MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE3", "RT LOAD STORE CACHE READ MESSAGE COUNT XECORE3",
                          "Number of read messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_WRITE_FROM_MESSAGE_COUNT_XECORE3", "RT LOAD STORE CACHE WRITE FROM MESSAGE COUNT XECORE3",
                          "Number of write messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE3", "RT TRAVERSAL INPUT RAY COUNT XECORE3",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE3", "RT QUAD TEST RAY COUNT XECORE3",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "RT_REQUEST_COLLISION_XECORE3", "RT REQUEST COLLISION XECORE3",
                          "Percentage of time in which  Ray Tracing Leaf has two Traversal inputs valid",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE3", "RT INPUT MESSAGE RAY COUNT XECORE3",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE3", "RT MESSAGE STALL COUNT XECORE3",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE3", "RT TRANSFORM RAY COUNT XECORE3",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e57fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e51000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee9023a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22e96800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28e94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e50b2c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee50154, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e505d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e503ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e6aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e903c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e907d1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae90be1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce90ff1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff3f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt412MetricSet::CExt412MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt412MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE4", "RT LOAD STORE CACHE READ MESSAGE COUNT XECORE4",
                          "Number of read messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_WRITE_FROM_MESSAGE_COUNT_XECORE4", "RT LOAD STORE CACHE WRITE FROM MESSAGE COUNT XECORE4",
                          "Number of write messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE4", "RT TRAVERSAL INPUT RAY COUNT XECORE4",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE4", "RT QUAD TEST RAY COUNT XECORE4",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "RT_REQUEST_COLLISION_XECORE4", "RT REQUEST COLLISION XECORE4",
                          "Percentage of time in which  Ray Tracing Leaf has two Traversal inputs valid",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE4", "RT INPUT MESSAGE RAY COUNT XECORE4",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE4", "RT MESSAGE STALL COUNT XECORE4",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE4", "RT TRANSFORM RAY COUNT XECORE4",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17857fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09851000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19894740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f89023a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23896800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29894740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03850b2c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f850154, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x118505d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x138503ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0386aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03893254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x078903c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x098907d1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890be1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890ff1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff3f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt413MetricSet::CExt413MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt413MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE5", "RT LOAD STORE CACHE READ MESSAGE COUNT XECORE5",
                          "Number of read messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_WRITE_FROM_MESSAGE_COUNT_XECORE5", "RT LOAD STORE CACHE WRITE FROM MESSAGE COUNT XECORE5",
                          "Number of write messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE5", "RT TRAVERSAL INPUT RAY COUNT XECORE5",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE5", "RT QUAD TEST RAY COUNT XECORE5",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "RT_REQUEST_COLLISION_XECORE5", "RT REQUEST COLLISION XECORE5",
                          "Percentage of time in which  Ray Tracing Leaf has two Traversal inputs valid",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE5", "RT INPUT MESSAGE RAY COUNT XECORE5",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE5", "RT MESSAGE STALL COUNT XECORE5",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE5", "RT TRANSFORM RAY COUNT XECORE5",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a57fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a51000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa9023a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23a96800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29a94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a50b2c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa50154, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a505d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a503ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a6aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a903c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a907d1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba90be1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da90ff1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff3f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt414MetricSet::CExt414MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt414MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE6", "RT LOAD STORE CACHE READ MESSAGE COUNT XECORE6",
                          "Number of read messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_WRITE_FROM_MESSAGE_COUNT_XECORE6", "RT LOAD STORE CACHE WRITE FROM MESSAGE COUNT XECORE6",
                          "Number of write messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE6", "RT TRAVERSAL INPUT RAY COUNT XECORE6",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE6", "RT QUAD TEST RAY COUNT XECORE6",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "RT_REQUEST_COLLISION_XECORE6", "RT REQUEST COLLISION XECORE6",
                          "Percentage of time in which  Ray Tracing Leaf has two Traversal inputs valid",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE6", "RT INPUT MESSAGE RAY COUNT XECORE6",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE6", "RT MESSAGE STALL COUNT XECORE6",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE6", "RT TRANSFORM RAY COUNT XECORE6",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c57fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c51000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc9023a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c96800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29c94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c50b2c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc50154, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c505d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c503ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c6aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c903c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c907d1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90be1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90ff1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff3f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt415MetricSet::CExt415MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt415MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE7", "RT LOAD STORE CACHE READ MESSAGE COUNT XECORE7",
                          "Number of read messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_WRITE_FROM_MESSAGE_COUNT_XECORE7", "RT LOAD STORE CACHE WRITE FROM MESSAGE COUNT XECORE7",
                          "Number of write messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE7", "RT TRAVERSAL INPUT RAY COUNT XECORE7",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE7", "RT QUAD TEST RAY COUNT XECORE7",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "RT_REQUEST_COLLISION_XECORE7", "RT REQUEST COLLISION XECORE7",
                          "Percentage of time in which  Ray Tracing Leaf has two Traversal inputs valid",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE7", "RT INPUT MESSAGE RAY COUNT XECORE7",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE7", "RT MESSAGE STALL COUNT XECORE7",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE7", "RT TRANSFORM RAY COUNT XECORE7",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e57fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e51000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe9023a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23e96800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29e94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e50b2c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe50154, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e505d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e503ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e903c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e907d1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be90be1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de90ff1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff3f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt416MetricSet::CExt416MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt416MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE8", "RT LOAD STORE CACHE READ MESSAGE COUNT XECORE8",
                          "Number of read messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_WRITE_FROM_MESSAGE_COUNT_XECORE8", "RT LOAD STORE CACHE WRITE FROM MESSAGE COUNT XECORE8",
                          "Number of write messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE8", "RT TRAVERSAL INPUT RAY COUNT XECORE8",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE8", "RT QUAD TEST RAY COUNT XECORE8",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "RT_REQUEST_COLLISION_XECORE8", "RT REQUEST COLLISION XECORE8",
                          "Percentage of time in which  Ray Tracing Leaf has two Traversal inputs valid",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE8", "RT INPUT MESSAGE RAY COUNT XECORE8",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE8", "RT MESSAGE STALL COUNT XECORE8",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE8", "RT TRANSFORM RAY COUNT XECORE8",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16857fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08851000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18894740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e89023a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22896800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28894740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02850b2c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e850154, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x108505d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x128503ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0286aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02893254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x068903c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x088907d1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890be1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890ff1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff3f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt417MetricSet::CExt417MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt417MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE9", "RT LOAD STORE CACHE READ MESSAGE COUNT XECORE9",
                          "Number of read messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_WRITE_FROM_MESSAGE_COUNT_XECORE9", "RT LOAD STORE CACHE WRITE FROM MESSAGE COUNT XECORE9",
                          "Number of write messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE9", "RT TRAVERSAL INPUT RAY COUNT XECORE9",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE9", "RT QUAD TEST RAY COUNT XECORE9",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "RT_REQUEST_COLLISION_XECORE9", "RT REQUEST COLLISION XECORE9",
                          "Percentage of time in which  Ray Tracing Leaf has two Traversal inputs valid",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE9", "RT INPUT MESSAGE RAY COUNT XECORE9",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE9", "RT MESSAGE STALL COUNT XECORE9",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE9", "RT TRANSFORM RAY COUNT XECORE9",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a57fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a51000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea9023a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22a96800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28a94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a50b2c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea50154, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a505d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a503ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a6aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a903c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a907d1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa90be1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca90ff1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff3f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt418MetricSet::CExt418MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt418MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE10", "RT LOAD STORE CACHE READ MESSAGE COUNT XECORE10",
                          "Number of read messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_WRITE_FROM_MESSAGE_COUNT_XECORE10", "RT LOAD STORE CACHE WRITE FROM MESSAGE COUNT XECORE10",
                          "Number of write messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE10", "RT TRAVERSAL INPUT RAY COUNT XECORE10",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE10", "RT QUAD TEST RAY COUNT XECORE10",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "RT_REQUEST_COLLISION_XECORE10", "RT REQUEST COLLISION XECORE10",
                          "Percentage of time in which  Ray Tracing Leaf has two Traversal inputs valid",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE10", "RT INPUT MESSAGE RAY COUNT XECORE10",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE10", "RT MESSAGE STALL COUNT XECORE10",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE10", "RT TRANSFORM RAY COUNT XECORE10",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c57fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c51000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec9023a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c96800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28c94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c50b2c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50154, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c505d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c503ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c6aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c903c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c907d1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90be1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90ff1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff3f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt419MetricSet::CExt419MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt419MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE11", "RT LOAD STORE CACHE READ MESSAGE COUNT XECORE11",
                          "Number of read messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_WRITE_FROM_MESSAGE_COUNT_XECORE11", "RT LOAD STORE CACHE WRITE FROM MESSAGE COUNT XECORE11",
                          "Number of write messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE11", "RT TRAVERSAL INPUT RAY COUNT XECORE11",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE11", "RT QUAD TEST RAY COUNT XECORE11",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "RT_REQUEST_COLLISION_XECORE11", "RT REQUEST COLLISION XECORE11",
                          "Percentage of time in which  Ray Tracing Leaf has two Traversal inputs valid",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE11", "RT INPUT MESSAGE RAY COUNT XECORE11",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE11", "RT MESSAGE STALL COUNT XECORE11",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE11", "RT TRANSFORM RAY COUNT XECORE11",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e57fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e51000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee9023a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22e96800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28e94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e50b2c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee50154, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e505d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e503ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e6aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e903c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e907d1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae90be1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce90ff1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff3f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt420MetricSet::CExt420MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt420MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE12", "RT LOAD STORE CACHE READ MESSAGE COUNT XECORE12",
                          "Number of read messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_WRITE_FROM_MESSAGE_COUNT_XECORE12", "RT LOAD STORE CACHE WRITE FROM MESSAGE COUNT XECORE12",
                          "Number of write messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE12", "RT TRAVERSAL INPUT RAY COUNT XECORE12",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE12", "RT QUAD TEST RAY COUNT XECORE12",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "RT_REQUEST_COLLISION_XECORE12", "RT REQUEST COLLISION XECORE12",
                          "Percentage of time in which  Ray Tracing Leaf has two Traversal inputs valid",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE12", "RT INPUT MESSAGE RAY COUNT XECORE12",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE12", "RT MESSAGE STALL COUNT XECORE12",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE12", "RT TRANSFORM RAY COUNT XECORE12",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17857fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09851000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19894740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f89023a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23896800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29894740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03850b2c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f850154, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x118505d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x138503ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0386aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03893254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x078903c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x098907d1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890be1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890ff1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff3f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt421MetricSet::CExt421MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt421MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE13", "RT LOAD STORE CACHE READ MESSAGE COUNT XECORE13",
                          "Number of read messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_WRITE_FROM_MESSAGE_COUNT_XECORE13", "RT LOAD STORE CACHE WRITE FROM MESSAGE COUNT XECORE13",
                          "Number of write messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE13", "RT TRAVERSAL INPUT RAY COUNT XECORE13",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE13", "RT QUAD TEST RAY COUNT XECORE13",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "RT_REQUEST_COLLISION_XECORE13", "RT REQUEST COLLISION XECORE13",
                          "Percentage of time in which  Ray Tracing Leaf has two Traversal inputs valid",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE13", "RT INPUT MESSAGE RAY COUNT XECORE13",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE13", "RT MESSAGE STALL COUNT XECORE13",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE13", "RT TRANSFORM RAY COUNT XECORE13",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a57fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a51000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa9023a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23a96800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29a94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a50b2c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa50154, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a505d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a503ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a6aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a903c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a907d1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba90be1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da90ff1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff3f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt422MetricSet::CExt422MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt422MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE14", "RT LOAD STORE CACHE READ MESSAGE COUNT XECORE14",
                          "Number of read messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_WRITE_FROM_MESSAGE_COUNT_XECORE14", "RT LOAD STORE CACHE WRITE FROM MESSAGE COUNT XECORE14",
                          "Number of write messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE14", "RT TRAVERSAL INPUT RAY COUNT XECORE14",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE14", "RT QUAD TEST RAY COUNT XECORE14",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "RT_REQUEST_COLLISION_XECORE14", "RT REQUEST COLLISION XECORE14",
                          "Percentage of time in which  Ray Tracing Leaf has two Traversal inputs valid",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE14", "RT INPUT MESSAGE RAY COUNT XECORE14",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE14", "RT MESSAGE STALL COUNT XECORE14",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE14", "RT TRANSFORM RAY COUNT XECORE14",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c57fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c51000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc9023a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c96800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29c94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c50b2c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc50154, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c505d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c503ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c6aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c903c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c907d1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90be1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90ff1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff3f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt423MetricSet::CExt423MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt423MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE15", "RT LOAD STORE CACHE READ MESSAGE COUNT XECORE15",
                          "Number of read messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_WRITE_FROM_MESSAGE_COUNT_XECORE15", "RT LOAD STORE CACHE WRITE FROM MESSAGE COUNT XECORE15",
                          "Number of write messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE15", "RT TRAVERSAL INPUT RAY COUNT XECORE15",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE15", "RT QUAD TEST RAY COUNT XECORE15",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "RT_REQUEST_COLLISION_XECORE15", "RT REQUEST COLLISION XECORE15",
                          "Percentage of time in which  Ray Tracing Leaf has two Traversal inputs valid",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE15", "RT INPUT MESSAGE RAY COUNT XECORE15",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE15", "RT MESSAGE STALL COUNT XECORE15",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE15", "RT TRANSFORM RAY COUNT XECORE15",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e57fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e51000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe9023a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23e96800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29e94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e50b2c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe50154, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e505d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e503ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e903c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e907d1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be90be1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de90ff1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff3f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt424MetricSet::CExt424MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt424MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE16", "RT LOAD STORE CACHE READ MESSAGE COUNT XECORE16",
                          "Number of read messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_WRITE_FROM_MESSAGE_COUNT_XECORE16", "RT LOAD STORE CACHE WRITE FROM MESSAGE COUNT XECORE16",
                          "Number of write messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE16", "RT TRAVERSAL INPUT RAY COUNT XECORE16",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE16", "RT QUAD TEST RAY COUNT XECORE16",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "RT_REQUEST_COLLISION_XECORE16", "RT REQUEST COLLISION XECORE16",
                          "Percentage of time in which  Ray Tracing Leaf has two Traversal inputs valid",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE16", "RT INPUT MESSAGE RAY COUNT XECORE16",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE16", "RT MESSAGE STALL COUNT XECORE16",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE16", "RT TRANSFORM RAY COUNT XECORE16",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16857fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08851000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18894740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e89023a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22896800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28894740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02850b2c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e850154, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x108505d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x128503ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0286aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02893254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x068903c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x088907d1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890be1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890ff1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030049, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff3f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt425MetricSet::CExt425MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt425MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE17", "RT LOAD STORE CACHE READ MESSAGE COUNT XECORE17",
                          "Number of read messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_WRITE_FROM_MESSAGE_COUNT_XECORE17", "RT LOAD STORE CACHE WRITE FROM MESSAGE COUNT XECORE17",
                          "Number of write messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE17", "RT TRAVERSAL INPUT RAY COUNT XECORE17",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE17", "RT QUAD TEST RAY COUNT XECORE17",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "RT_REQUEST_COLLISION_XECORE17", "RT REQUEST COLLISION XECORE17",
                          "Percentage of time in which  Ray Tracing Leaf has two Traversal inputs valid",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE17", "RT INPUT MESSAGE RAY COUNT XECORE17",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE17", "RT MESSAGE STALL COUNT XECORE17",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE17", "RT TRANSFORM RAY COUNT XECORE17",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a57fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a51000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea9023a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22a96800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28a94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a50b2c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea50154, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a505d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a503ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a6aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a903c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a907d1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa90be1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca90ff1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030049, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff3f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt426MetricSet::CExt426MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt426MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE18", "RT LOAD STORE CACHE READ MESSAGE COUNT XECORE18",
                          "Number of read messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_WRITE_FROM_MESSAGE_COUNT_XECORE18", "RT LOAD STORE CACHE WRITE FROM MESSAGE COUNT XECORE18",
                          "Number of write messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE18", "RT TRAVERSAL INPUT RAY COUNT XECORE18",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE18", "RT QUAD TEST RAY COUNT XECORE18",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "RT_REQUEST_COLLISION_XECORE18", "RT REQUEST COLLISION XECORE18",
                          "Percentage of time in which  Ray Tracing Leaf has two Traversal inputs valid",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE18", "RT INPUT MESSAGE RAY COUNT XECORE18",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE18", "RT MESSAGE STALL COUNT XECORE18",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE18", "RT TRANSFORM RAY COUNT XECORE18",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c57fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c51000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec9023a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c96800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28c94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c50b2c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50154, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c505d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c503ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c6aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c903c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c907d1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90be1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90ff1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030049, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff3f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt427MetricSet::CExt427MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt427MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE19", "RT LOAD STORE CACHE READ MESSAGE COUNT XECORE19",
                          "Number of read messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_WRITE_FROM_MESSAGE_COUNT_XECORE19", "RT LOAD STORE CACHE WRITE FROM MESSAGE COUNT XECORE19",
                          "Number of write messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE19", "RT TRAVERSAL INPUT RAY COUNT XECORE19",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE19", "RT QUAD TEST RAY COUNT XECORE19",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "RT_REQUEST_COLLISION_XECORE19", "RT REQUEST COLLISION XECORE19",
                          "Percentage of time in which  Ray Tracing Leaf has two Traversal inputs valid",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE19", "RT INPUT MESSAGE RAY COUNT XECORE19",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE19", "RT MESSAGE STALL COUNT XECORE19",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE19", "RT TRANSFORM RAY COUNT XECORE19",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e57fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e51000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee9023a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22e96800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28e94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e50b2c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee50154, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e505d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e503ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e6aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e903c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e907d1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae90be1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce90ff1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030049, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff3f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt428MetricSet::CExt428MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt428MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE20", "RT LOAD STORE CACHE READ MESSAGE COUNT XECORE20",
                          "Number of read messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_WRITE_FROM_MESSAGE_COUNT_XECORE20", "RT LOAD STORE CACHE WRITE FROM MESSAGE COUNT XECORE20",
                          "Number of write messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE20", "RT TRAVERSAL INPUT RAY COUNT XECORE20",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE20", "RT QUAD TEST RAY COUNT XECORE20",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "RT_REQUEST_COLLISION_XECORE20", "RT REQUEST COLLISION XECORE20",
                          "Percentage of time in which  Ray Tracing Leaf has two Traversal inputs valid",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE20", "RT INPUT MESSAGE RAY COUNT XECORE20",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE20", "RT MESSAGE STALL COUNT XECORE20",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE20", "RT TRANSFORM RAY COUNT XECORE20",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17857fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09851000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19894740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f89023a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23896800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29894740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03850b2c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f850154, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x118505d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x138503ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0386aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03893254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x078903c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x098907d1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890be1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890ff1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030049, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff3f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt429MetricSet::CExt429MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt429MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE21", "RT LOAD STORE CACHE READ MESSAGE COUNT XECORE21",
                          "Number of read messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_WRITE_FROM_MESSAGE_COUNT_XECORE21", "RT LOAD STORE CACHE WRITE FROM MESSAGE COUNT XECORE21",
                          "Number of write messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE21", "RT TRAVERSAL INPUT RAY COUNT XECORE21",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE21", "RT QUAD TEST RAY COUNT XECORE21",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "RT_REQUEST_COLLISION_XECORE21", "RT REQUEST COLLISION XECORE21",
                          "Percentage of time in which  Ray Tracing Leaf has two Traversal inputs valid",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE21", "RT INPUT MESSAGE RAY COUNT XECORE21",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE21", "RT MESSAGE STALL COUNT XECORE21",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE21", "RT TRANSFORM RAY COUNT XECORE21",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a57fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a51000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa9023a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23a96800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29a94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a50b2c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa50154, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a505d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a503ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a6aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a903c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a907d1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba90be1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da90ff1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030049, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff3f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt430MetricSet::CExt430MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt430MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE22", "RT LOAD STORE CACHE READ MESSAGE COUNT XECORE22",
                          "Number of read messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_WRITE_FROM_MESSAGE_COUNT_XECORE22", "RT LOAD STORE CACHE WRITE FROM MESSAGE COUNT XECORE22",
                          "Number of write messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE22", "RT TRAVERSAL INPUT RAY COUNT XECORE22",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE22", "RT QUAD TEST RAY COUNT XECORE22",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "RT_REQUEST_COLLISION_XECORE22", "RT REQUEST COLLISION XECORE22",
                          "Percentage of time in which  Ray Tracing Leaf has two Traversal inputs valid",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE22", "RT INPUT MESSAGE RAY COUNT XECORE22",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE22", "RT MESSAGE STALL COUNT XECORE22",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE22", "RT TRANSFORM RAY COUNT XECORE22",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c57fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c51000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc9023a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c96800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29c94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c50b2c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc50154, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c505d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c503ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c6aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c903c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c907d1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90be1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90ff1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030049, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff3f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt431MetricSet::CExt431MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt431MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE23", "RT LOAD STORE CACHE READ MESSAGE COUNT XECORE23",
                          "Number of read messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_WRITE_FROM_MESSAGE_COUNT_XECORE23", "RT LOAD STORE CACHE WRITE FROM MESSAGE COUNT XECORE23",
                          "Number of write messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE23", "RT TRAVERSAL INPUT RAY COUNT XECORE23",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE23", "RT QUAD TEST RAY COUNT XECORE23",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "RT_REQUEST_COLLISION_XECORE23", "RT REQUEST COLLISION XECORE23",
                          "Percentage of time in which  Ray Tracing Leaf has two Traversal inputs valid",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE23", "RT INPUT MESSAGE RAY COUNT XECORE23",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE23", "RT MESSAGE STALL COUNT XECORE23",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE23", "RT TRANSFORM RAY COUNT XECORE23",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e57fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e51000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe9023a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23e96800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29e94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e50b2c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe50154, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e505d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e503ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e903c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e907d1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be90be1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de90ff1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030049, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff3f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt432MetricSet::CExt432MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt432MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE24", "RT LOAD STORE CACHE READ MESSAGE COUNT XECORE24",
                          "Number of read messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_WRITE_FROM_MESSAGE_COUNT_XECORE24", "RT LOAD STORE CACHE WRITE FROM MESSAGE COUNT XECORE24",
                          "Number of write messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE24", "RT TRAVERSAL INPUT RAY COUNT XECORE24",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE24", "RT QUAD TEST RAY COUNT XECORE24",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "RT_REQUEST_COLLISION_XECORE24", "RT REQUEST COLLISION XECORE24",
                          "Percentage of time in which  Ray Tracing Leaf has two Traversal inputs valid",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE24", "RT INPUT MESSAGE RAY COUNT XECORE24",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE24", "RT MESSAGE STALL COUNT XECORE24",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE24", "RT TRANSFORM RAY COUNT XECORE24",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16857fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08851000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18894740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e89023a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22896800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28894740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02850b2c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e850154, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x108505d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x128503ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0286aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02893254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x068903c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x088907d1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890be1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890ff1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030049, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff3f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt433MetricSet::CExt433MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt433MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE25", "RT LOAD STORE CACHE READ MESSAGE COUNT XECORE25",
                          "Number of read messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_WRITE_FROM_MESSAGE_COUNT_XECORE25", "RT LOAD STORE CACHE WRITE FROM MESSAGE COUNT XECORE25",
                          "Number of write messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE25", "RT TRAVERSAL INPUT RAY COUNT XECORE25",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE25", "RT QUAD TEST RAY COUNT XECORE25",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "RT_REQUEST_COLLISION_XECORE25", "RT REQUEST COLLISION XECORE25",
                          "Percentage of time in which  Ray Tracing Leaf has two Traversal inputs valid",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE25", "RT INPUT MESSAGE RAY COUNT XECORE25",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE25", "RT MESSAGE STALL COUNT XECORE25",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE25", "RT TRANSFORM RAY COUNT XECORE25",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a57fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a51000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea9023a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22a96800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28a94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a50b2c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea50154, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a505d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a503ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a6aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a903c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a907d1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa90be1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca90ff1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030049, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff3f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt434MetricSet::CExt434MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt434MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE26", "RT LOAD STORE CACHE READ MESSAGE COUNT XECORE26",
                          "Number of read messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_WRITE_FROM_MESSAGE_COUNT_XECORE26", "RT LOAD STORE CACHE WRITE FROM MESSAGE COUNT XECORE26",
                          "Number of write messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE26", "RT TRAVERSAL INPUT RAY COUNT XECORE26",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE26", "RT QUAD TEST RAY COUNT XECORE26",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "RT_REQUEST_COLLISION_XECORE26", "RT REQUEST COLLISION XECORE26",
                          "Percentage of time in which  Ray Tracing Leaf has two Traversal inputs valid",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE26", "RT INPUT MESSAGE RAY COUNT XECORE26",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE26", "RT MESSAGE STALL COUNT XECORE26",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE26", "RT TRANSFORM RAY COUNT XECORE26",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c57fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c51000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec9023a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c96800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28c94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c50b2c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50154, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c505d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c503ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c6aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c903c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c907d1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90be1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90ff1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030049, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff3f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt435MetricSet::CExt435MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt435MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE27", "RT LOAD STORE CACHE READ MESSAGE COUNT XECORE27",
                          "Number of read messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_WRITE_FROM_MESSAGE_COUNT_XECORE27", "RT LOAD STORE CACHE WRITE FROM MESSAGE COUNT XECORE27",
                          "Number of write messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE27", "RT TRAVERSAL INPUT RAY COUNT XECORE27",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE27", "RT QUAD TEST RAY COUNT XECORE27",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "RT_REQUEST_COLLISION_XECORE27", "RT REQUEST COLLISION XECORE27",
                          "Percentage of time in which  Ray Tracing Leaf has two Traversal inputs valid",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE27", "RT INPUT MESSAGE RAY COUNT XECORE27",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE27", "RT MESSAGE STALL COUNT XECORE27",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE27", "RT TRANSFORM RAY COUNT XECORE27",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e57fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e51000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee9023a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22e96800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28e94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e50b2c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee50154, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e505d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e503ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e6aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e903c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e907d1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae90be1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce90ff1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030049, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff3f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt436MetricSet::CExt436MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt436MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE28", "RT LOAD STORE CACHE READ MESSAGE COUNT XECORE28",
                          "Number of read messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_WRITE_FROM_MESSAGE_COUNT_XECORE28", "RT LOAD STORE CACHE WRITE FROM MESSAGE COUNT XECORE28",
                          "Number of write messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE28", "RT TRAVERSAL INPUT RAY COUNT XECORE28",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE28", "RT QUAD TEST RAY COUNT XECORE28",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "RT_REQUEST_COLLISION_XECORE28", "RT REQUEST COLLISION XECORE28",
                          "Percentage of time in which  Ray Tracing Leaf has two Traversal inputs valid",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE28", "RT INPUT MESSAGE RAY COUNT XECORE28",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE28", "RT MESSAGE STALL COUNT XECORE28",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE28", "RT TRANSFORM RAY COUNT XECORE28",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17857fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09851000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19894740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f89023a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23896800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29894740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03850b2c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f850154, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x118505d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x138503ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0386aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03893254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x078903c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x098907d1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890be1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890ff1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030049, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff3f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt437MetricSet::CExt437MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt437MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE29", "RT LOAD STORE CACHE READ MESSAGE COUNT XECORE29",
                          "Number of read messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_WRITE_FROM_MESSAGE_COUNT_XECORE29", "RT LOAD STORE CACHE WRITE FROM MESSAGE COUNT XECORE29",
                          "Number of write messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE29", "RT TRAVERSAL INPUT RAY COUNT XECORE29",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE29", "RT QUAD TEST RAY COUNT XECORE29",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "RT_REQUEST_COLLISION_XECORE29", "RT REQUEST COLLISION XECORE29",
                          "Percentage of time in which  Ray Tracing Leaf has two Traversal inputs valid",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE29", "RT INPUT MESSAGE RAY COUNT XECORE29",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE29", "RT MESSAGE STALL COUNT XECORE29",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE29", "RT TRANSFORM RAY COUNT XECORE29",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a57fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a51000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa9023a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23a96800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29a94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a50b2c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa50154, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a505d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a503ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a6aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a903c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a907d1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba90be1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da90ff1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030049, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff3f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt438MetricSet::CExt438MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt438MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE30", "RT LOAD STORE CACHE READ MESSAGE COUNT XECORE30",
                          "Number of read messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_WRITE_FROM_MESSAGE_COUNT_XECORE30", "RT LOAD STORE CACHE WRITE FROM MESSAGE COUNT XECORE30",
                          "Number of write messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE30", "RT TRAVERSAL INPUT RAY COUNT XECORE30",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE30", "RT QUAD TEST RAY COUNT XECORE30",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "RT_REQUEST_COLLISION_XECORE30", "RT REQUEST COLLISION XECORE30",
                          "Percentage of time in which  Ray Tracing Leaf has two Traversal inputs valid",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE30", "RT INPUT MESSAGE RAY COUNT XECORE30",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE30", "RT MESSAGE STALL COUNT XECORE30",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE30", "RT TRANSFORM RAY COUNT XECORE30",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c57fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c51000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc9023a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c96800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29c94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c50b2c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc50154, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c505d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c503ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c6aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c903c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c907d1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90be1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90ff1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030049, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff3f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt439MetricSet::CExt439MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt439MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_READ_MESSAGE_COUNT_XECORE31", "RT LOAD STORE CACHE READ MESSAGE COUNT XECORE31",
                          "Number of read messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "RT_LOAD_STORE_CACHE_WRITE_FROM_MESSAGE_COUNT_XECORE31", "RT LOAD STORE CACHE WRITE FROM MESSAGE COUNT XECORE31",
                          "Number of write messages sent from Ray Tracing unit to the Load Store Cache",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_INPUT_RAY_COUNT_XECORE31", "RT TRAVERSAL INPUT RAY COUNT XECORE31",
                          "Number of Ray Tracing Traversal input rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "RT_QUAD_TEST_RAY_COUNT_XECORE31", "RT QUAD TEST RAY COUNT XECORE31",
                          "Number of nodes processed that use ray-quad intersection pipeline",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "RT_REQUEST_COLLISION_XECORE31", "RT REQUEST COLLISION XECORE31",
                          "Percentage of time in which  Ray Tracing Leaf has two Traversal inputs valid",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "RT_INPUT_MESSAGE_RAY_COUNT_XECORE31", "RT INPUT MESSAGE RAY COUNT XECORE31",
                          "Number of valid SIMD lanes in the TraceRay message",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "RT_MESSAGE_STALL_COUNT_XECORE31", "RT MESSAGE STALL COUNT XECORE31",
                          "Percentage of time in which Ray Tracing message input is stalled while accepting input",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "RT_TRANSFORM_RAY_COUNT_XECORE31", "RT TRANSFORM RAY COUNT XECORE31",
                          "Number of only HW transform accesses",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e57fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e51000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe9023a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23e96800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29e94740, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e400ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e50b2c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe50154, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e505d8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e503ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e903c1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e907d1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be90be1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de90ff1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030049, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fcff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff3f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt440MetricSet::CExt440MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt440MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE0", "RT TRAVERSAL OUTPUT RAY COUNT XECORE0",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE1", "RT TRAVERSAL OUTPUT RAY COUNT XECORE1",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE2", "RT TRAVERSAL OUTPUT RAY COUNT XECORE2",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE3", "RT TRAVERSAL OUTPUT RAY COUNT XECORE3",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e8545e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea545e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec545e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee545e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0485c70e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850e78, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a50c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa50e78, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc50c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50e78, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e50c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e50e78, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt441MetricSet::CExt441MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt441MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE4", "RT TRAVERSAL OUTPUT RAY COUNT XECORE4",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE5", "RT TRAVERSAL OUTPUT RAY COUNT XECORE5",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE6", "RT TRAVERSAL OUTPUT RAY COUNT XECORE6",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE7", "RT TRAVERSAL OUTPUT RAY COUNT XECORE7",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f8545e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa545e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc545e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe545e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0585c70e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850e78, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a50c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba50e78, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc50c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc50e78, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e50c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e50e78, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt442MetricSet::CExt442MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt442MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE8", "RT TRAVERSAL OUTPUT RAY COUNT XECORE8",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE9", "RT TRAVERSAL OUTPUT RAY COUNT XECORE9",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE10", "RT TRAVERSAL OUTPUT RAY COUNT XECORE10",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE11", "RT TRAVERSAL OUTPUT RAY COUNT XECORE11",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e8545e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea545e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec545e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee545e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0485c70e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850e78, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a50c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa50e78, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc50c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50e78, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e50c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e50e78, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt443MetricSet::CExt443MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt443MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE12", "RT TRAVERSAL OUTPUT RAY COUNT XECORE12",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE13", "RT TRAVERSAL OUTPUT RAY COUNT XECORE13",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE14", "RT TRAVERSAL OUTPUT RAY COUNT XECORE14",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE15", "RT TRAVERSAL OUTPUT RAY COUNT XECORE15",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f8545e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa545e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc545e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe545e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0585c70e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850e78, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a50c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba50e78, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc50c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc50e78, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e50c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e50e78, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt444MetricSet::CExt444MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt444MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE16", "RT TRAVERSAL OUTPUT RAY COUNT XECORE16",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE17", "RT TRAVERSAL OUTPUT RAY COUNT XECORE17",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE18", "RT TRAVERSAL OUTPUT RAY COUNT XECORE18",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE19", "RT TRAVERSAL OUTPUT RAY COUNT XECORE19",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e8545e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea545e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec545e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee545e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0485c70e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850e78, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a50c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa50e78, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc50c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50e78, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e50c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e50e78, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt445MetricSet::CExt445MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt445MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE20", "RT TRAVERSAL OUTPUT RAY COUNT XECORE20",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE21", "RT TRAVERSAL OUTPUT RAY COUNT XECORE21",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE22", "RT TRAVERSAL OUTPUT RAY COUNT XECORE22",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE23", "RT TRAVERSAL OUTPUT RAY COUNT XECORE23",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f8545e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa545e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc545e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe545e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0585c70e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850e78, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a50c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba50e78, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc50c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc50e78, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e50c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e50e78, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt446MetricSet::CExt446MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt446MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE24", "RT TRAVERSAL OUTPUT RAY COUNT XECORE24",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE25", "RT TRAVERSAL OUTPUT RAY COUNT XECORE25",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE26", "RT TRAVERSAL OUTPUT RAY COUNT XECORE26",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE27", "RT TRAVERSAL OUTPUT RAY COUNT XECORE27",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e8545e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea545e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec545e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee545e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0485c70e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850e78, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a50c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa50e78, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc50c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50e78, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e50c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e50e78, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt447MetricSet::CExt447MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt447MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE28", "RT TRAVERSAL OUTPUT RAY COUNT XECORE28",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE29", "RT TRAVERSAL OUTPUT RAY COUNT XECORE29",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE30", "RT TRAVERSAL OUTPUT RAY COUNT XECORE30",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_OUTPUT_RAY_COUNT_XECORE31", "RT TRAVERSAL OUTPUT RAY COUNT XECORE31",
                          "Number of Ray Tracing Traversal output rays",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f8545e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa545e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc545e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe545e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0585c70e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850e78, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a50c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba50e78, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc50c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc50e78, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e50c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e50e78, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt448MetricSet::CExt448MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt448MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "RT_ANY_HIT_THREAD_RAY_DISPATCH_XECORE0", "RT ANY HIT THREAD RAY DISPATCH XECORE0",
                          "Number of any hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "RT_ANY_HIT_THREAD_RAY_DISPATCH_XECORE1", "RT ANY HIT THREAD RAY DISPATCH XECORE1",
                          "Number of any hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "RT_ANY_HIT_THREAD_RAY_DISPATCH_XECORE2", "RT ANY HIT THREAD RAY DISPATCH XECORE2",
                          "Number of any hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "RT_ANY_HIT_THREAD_RAY_DISPATCH_XECORE3", "RT ANY HIT THREAD RAY DISPATCH XECORE3",
                          "Number of any hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0485d37e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a50d37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa50f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc50d37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e50d37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e50f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt449MetricSet::CExt449MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt449MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "RT_ANY_HIT_THREAD_RAY_DISPATCH_XECORE4", "RT ANY HIT THREAD RAY DISPATCH XECORE4",
                          "Number of any hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "RT_ANY_HIT_THREAD_RAY_DISPATCH_XECORE5", "RT ANY HIT THREAD RAY DISPATCH XECORE5",
                          "Number of any hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "RT_ANY_HIT_THREAD_RAY_DISPATCH_XECORE6", "RT ANY HIT THREAD RAY DISPATCH XECORE6",
                          "Number of any hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "RT_ANY_HIT_THREAD_RAY_DISPATCH_XECORE7", "RT ANY HIT THREAD RAY DISPATCH XECORE7",
                          "Number of any hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0585d37e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a50d37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba50f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc50d37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc50f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e50d37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e50f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt450MetricSet::CExt450MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt450MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "RT_ANY_HIT_THREAD_RAY_DISPATCH_XECORE8", "RT ANY HIT THREAD RAY DISPATCH XECORE8",
                          "Number of any hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "RT_ANY_HIT_THREAD_RAY_DISPATCH_XECORE9", "RT ANY HIT THREAD RAY DISPATCH XECORE9",
                          "Number of any hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "RT_ANY_HIT_THREAD_RAY_DISPATCH_XECORE10", "RT ANY HIT THREAD RAY DISPATCH XECORE10",
                          "Number of any hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "RT_ANY_HIT_THREAD_RAY_DISPATCH_XECORE11", "RT ANY HIT THREAD RAY DISPATCH XECORE11",
                          "Number of any hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0485d37e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a50d37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa50f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc50d37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e50d37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e50f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt451MetricSet::CExt451MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt451MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "RT_ANY_HIT_THREAD_RAY_DISPATCH_XECORE12", "RT ANY HIT THREAD RAY DISPATCH XECORE12",
                          "Number of any hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "RT_ANY_HIT_THREAD_RAY_DISPATCH_XECORE13", "RT ANY HIT THREAD RAY DISPATCH XECORE13",
                          "Number of any hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "RT_ANY_HIT_THREAD_RAY_DISPATCH_XECORE14", "RT ANY HIT THREAD RAY DISPATCH XECORE14",
                          "Number of any hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "RT_ANY_HIT_THREAD_RAY_DISPATCH_XECORE15", "RT ANY HIT THREAD RAY DISPATCH XECORE15",
                          "Number of any hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0585d37e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a50d37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba50f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc50d37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc50f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e50d37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e50f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt452MetricSet::CExt452MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt452MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "RT_ANY_HIT_THREAD_RAY_DISPATCH_XECORE16", "RT ANY HIT THREAD RAY DISPATCH XECORE16",
                          "Number of any hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "RT_ANY_HIT_THREAD_RAY_DISPATCH_XECORE17", "RT ANY HIT THREAD RAY DISPATCH XECORE17",
                          "Number of any hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "RT_ANY_HIT_THREAD_RAY_DISPATCH_XECORE18", "RT ANY HIT THREAD RAY DISPATCH XECORE18",
                          "Number of any hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "RT_ANY_HIT_THREAD_RAY_DISPATCH_XECORE19", "RT ANY HIT THREAD RAY DISPATCH XECORE19",
                          "Number of any hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0485d37e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a50d37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa50f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc50d37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e50d37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e50f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt453MetricSet::CExt453MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt453MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "RT_ANY_HIT_THREAD_RAY_DISPATCH_XECORE20", "RT ANY HIT THREAD RAY DISPATCH XECORE20",
                          "Number of any hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "RT_ANY_HIT_THREAD_RAY_DISPATCH_XECORE21", "RT ANY HIT THREAD RAY DISPATCH XECORE21",
                          "Number of any hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "RT_ANY_HIT_THREAD_RAY_DISPATCH_XECORE22", "RT ANY HIT THREAD RAY DISPATCH XECORE22",
                          "Number of any hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "RT_ANY_HIT_THREAD_RAY_DISPATCH_XECORE23", "RT ANY HIT THREAD RAY DISPATCH XECORE23",
                          "Number of any hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0585d37e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a50d37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba50f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc50d37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc50f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e50d37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e50f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt454MetricSet::CExt454MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt454MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "RT_ANY_HIT_THREAD_RAY_DISPATCH_XECORE24", "RT ANY HIT THREAD RAY DISPATCH XECORE24",
                          "Number of any hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "RT_ANY_HIT_THREAD_RAY_DISPATCH_XECORE25", "RT ANY HIT THREAD RAY DISPATCH XECORE25",
                          "Number of any hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "RT_ANY_HIT_THREAD_RAY_DISPATCH_XECORE26", "RT ANY HIT THREAD RAY DISPATCH XECORE26",
                          "Number of any hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "RT_ANY_HIT_THREAD_RAY_DISPATCH_XECORE27", "RT ANY HIT THREAD RAY DISPATCH XECORE27",
                          "Number of any hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0485d37e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a50d37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa50f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc50d37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e50d37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e50f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt455MetricSet::CExt455MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt455MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "RT_ANY_HIT_THREAD_RAY_DISPATCH_XECORE28", "RT ANY HIT THREAD RAY DISPATCH XECORE28",
                          "Number of any hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "RT_ANY_HIT_THREAD_RAY_DISPATCH_XECORE29", "RT ANY HIT THREAD RAY DISPATCH XECORE29",
                          "Number of any hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "RT_ANY_HIT_THREAD_RAY_DISPATCH_XECORE30", "RT ANY HIT THREAD RAY DISPATCH XECORE30",
                          "Number of any hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "RT_ANY_HIT_THREAD_RAY_DISPATCH_XECORE31", "RT ANY HIT THREAD RAY DISPATCH XECORE31",
                          "Number of any hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0585d37e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a50d37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba50f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc50d37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc50f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e50d37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e50f3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt456MetricSet::CExt456MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt456MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "RT_CALLABLE_THREAD_RAY_DISPATCH_XECORE0", "RT CALLABLE THREAD RAY DISPATCH XECORE0",
                          "Number of callable threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "RT_CALLABLE_THREAD_RAY_DISPATCH_XECORE1", "RT CALLABLE THREAD RAY DISPATCH XECORE1",
                          "Number of callable threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "RT_CALLABLE_THREAD_RAY_DISPATCH_XECORE2", "RT CALLABLE THREAD RAY DISPATCH XECORE2",
                          "Number of callable threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "RT_CALLABLE_THREAD_RAY_DISPATCH_XECORE3", "RT CALLABLE THREAD RAY DISPATCH XECORE3",
                          "Number of callable threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0485cb7e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850ebf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a50cb7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa50ebf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc50cb7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50ebf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e50cb7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e50ebf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt457MetricSet::CExt457MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt457MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "RT_CALLABLE_THREAD_RAY_DISPATCH_XECORE4", "RT CALLABLE THREAD RAY DISPATCH XECORE4",
                          "Number of callable threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "RT_CALLABLE_THREAD_RAY_DISPATCH_XECORE5", "RT CALLABLE THREAD RAY DISPATCH XECORE5",
                          "Number of callable threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "RT_CALLABLE_THREAD_RAY_DISPATCH_XECORE6", "RT CALLABLE THREAD RAY DISPATCH XECORE6",
                          "Number of callable threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "RT_CALLABLE_THREAD_RAY_DISPATCH_XECORE7", "RT CALLABLE THREAD RAY DISPATCH XECORE7",
                          "Number of callable threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0585cb7e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850ebf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a50cb7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba50ebf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc50cb7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc50ebf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e50cb7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e50ebf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt458MetricSet::CExt458MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt458MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "RT_CALLABLE_THREAD_RAY_DISPATCH_XECORE8", "RT CALLABLE THREAD RAY DISPATCH XECORE8",
                          "Number of callable threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "RT_CALLABLE_THREAD_RAY_DISPATCH_XECORE9", "RT CALLABLE THREAD RAY DISPATCH XECORE9",
                          "Number of callable threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "RT_CALLABLE_THREAD_RAY_DISPATCH_XECORE10", "RT CALLABLE THREAD RAY DISPATCH XECORE10",
                          "Number of callable threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "RT_CALLABLE_THREAD_RAY_DISPATCH_XECORE11", "RT CALLABLE THREAD RAY DISPATCH XECORE11",
                          "Number of callable threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0485cb7e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850ebf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a50cb7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa50ebf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc50cb7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50ebf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e50cb7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e50ebf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt459MetricSet::CExt459MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt459MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "RT_CALLABLE_THREAD_RAY_DISPATCH_XECORE12", "RT CALLABLE THREAD RAY DISPATCH XECORE12",
                          "Number of callable threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "RT_CALLABLE_THREAD_RAY_DISPATCH_XECORE13", "RT CALLABLE THREAD RAY DISPATCH XECORE13",
                          "Number of callable threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "RT_CALLABLE_THREAD_RAY_DISPATCH_XECORE14", "RT CALLABLE THREAD RAY DISPATCH XECORE14",
                          "Number of callable threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "RT_CALLABLE_THREAD_RAY_DISPATCH_XECORE15", "RT CALLABLE THREAD RAY DISPATCH XECORE15",
                          "Number of callable threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0585cb7e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850ebf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a50cb7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba50ebf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc50cb7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc50ebf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e50cb7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e50ebf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt460MetricSet::CExt460MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt460MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "RT_CALLABLE_THREAD_RAY_DISPATCH_XECORE16", "RT CALLABLE THREAD RAY DISPATCH XECORE16",
                          "Number of callable threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "RT_CALLABLE_THREAD_RAY_DISPATCH_XECORE17", "RT CALLABLE THREAD RAY DISPATCH XECORE17",
                          "Number of callable threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "RT_CALLABLE_THREAD_RAY_DISPATCH_XECORE18", "RT CALLABLE THREAD RAY DISPATCH XECORE18",
                          "Number of callable threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "RT_CALLABLE_THREAD_RAY_DISPATCH_XECORE19", "RT CALLABLE THREAD RAY DISPATCH XECORE19",
                          "Number of callable threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0485cb7e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850ebf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a50cb7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa50ebf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc50cb7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50ebf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e50cb7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e50ebf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt461MetricSet::CExt461MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt461MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "RT_CALLABLE_THREAD_RAY_DISPATCH_XECORE20", "RT CALLABLE THREAD RAY DISPATCH XECORE20",
                          "Number of callable threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "RT_CALLABLE_THREAD_RAY_DISPATCH_XECORE21", "RT CALLABLE THREAD RAY DISPATCH XECORE21",
                          "Number of callable threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "RT_CALLABLE_THREAD_RAY_DISPATCH_XECORE22", "RT CALLABLE THREAD RAY DISPATCH XECORE22",
                          "Number of callable threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "RT_CALLABLE_THREAD_RAY_DISPATCH_XECORE23", "RT CALLABLE THREAD RAY DISPATCH XECORE23",
                          "Number of callable threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0585cb7e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850ebf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a50cb7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba50ebf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc50cb7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc50ebf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e50cb7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e50ebf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt462MetricSet::CExt462MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt462MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "RT_CALLABLE_THREAD_RAY_DISPATCH_XECORE24", "RT CALLABLE THREAD RAY DISPATCH XECORE24",
                          "Number of callable threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "RT_CALLABLE_THREAD_RAY_DISPATCH_XECORE25", "RT CALLABLE THREAD RAY DISPATCH XECORE25",
                          "Number of callable threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "RT_CALLABLE_THREAD_RAY_DISPATCH_XECORE26", "RT CALLABLE THREAD RAY DISPATCH XECORE26",
                          "Number of callable threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "RT_CALLABLE_THREAD_RAY_DISPATCH_XECORE27", "RT CALLABLE THREAD RAY DISPATCH XECORE27",
                          "Number of callable threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0485cb7e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850ebf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a50cb7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa50ebf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc50cb7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50ebf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e50cb7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e50ebf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt463MetricSet::CExt463MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt463MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "RT_CALLABLE_THREAD_RAY_DISPATCH_XECORE28", "RT CALLABLE THREAD RAY DISPATCH XECORE28",
                          "Number of callable threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "RT_CALLABLE_THREAD_RAY_DISPATCH_XECORE29", "RT CALLABLE THREAD RAY DISPATCH XECORE29",
                          "Number of callable threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "RT_CALLABLE_THREAD_RAY_DISPATCH_XECORE30", "RT CALLABLE THREAD RAY DISPATCH XECORE30",
                          "Number of callable threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "RT_CALLABLE_THREAD_RAY_DISPATCH_XECORE31", "RT CALLABLE THREAD RAY DISPATCH XECORE31",
                          "Number of callable threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0585cb7e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850ebf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a50cb7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba50ebf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc50cb7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc50ebf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e50cb7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e50ebf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt464MetricSet::CExt464MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt464MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "RT_CLOSEST_HIT_THREAD_RAY_DISPATCH_XECORE0", "RT CLOSEST HIT THREAD RAY DISPATCH XECORE0",
                          "Number of closest hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "RT_CLOSEST_HIT_THREAD_RAY_DISPATCH_XECORE1", "RT CLOSEST HIT THREAD RAY DISPATCH XECORE1",
                          "Number of closest hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "RT_CLOSEST_HIT_THREAD_RAY_DISPATCH_XECORE2", "RT CLOSEST HIT THREAD RAY DISPATCH XECORE2",
                          "Number of closest hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "RT_CLOSEST_HIT_THREAD_RAY_DISPATCH_XECORE3", "RT CLOSEST HIT THREAD RAY DISPATCH XECORE3",
                          "Number of closest hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0485d77e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a50d77, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa50f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc50d77, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e50d77, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e50f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt465MetricSet::CExt465MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt465MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "RT_CLOSEST_HIT_THREAD_RAY_DISPATCH_XECORE4", "RT CLOSEST HIT THREAD RAY DISPATCH XECORE4",
                          "Number of closest hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "RT_CLOSEST_HIT_THREAD_RAY_DISPATCH_XECORE5", "RT CLOSEST HIT THREAD RAY DISPATCH XECORE5",
                          "Number of closest hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "RT_CLOSEST_HIT_THREAD_RAY_DISPATCH_XECORE6", "RT CLOSEST HIT THREAD RAY DISPATCH XECORE6",
                          "Number of closest hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "RT_CLOSEST_HIT_THREAD_RAY_DISPATCH_XECORE7", "RT CLOSEST HIT THREAD RAY DISPATCH XECORE7",
                          "Number of closest hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0585d77e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a50d77, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba50f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc50d77, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc50f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e50d77, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e50f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt466MetricSet::CExt466MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt466MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "RT_CLOSEST_HIT_THREAD_RAY_DISPATCH_XECORE8", "RT CLOSEST HIT THREAD RAY DISPATCH XECORE8",
                          "Number of closest hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "RT_CLOSEST_HIT_THREAD_RAY_DISPATCH_XECORE9", "RT CLOSEST HIT THREAD RAY DISPATCH XECORE9",
                          "Number of closest hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "RT_CLOSEST_HIT_THREAD_RAY_DISPATCH_XECORE10", "RT CLOSEST HIT THREAD RAY DISPATCH XECORE10",
                          "Number of closest hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "RT_CLOSEST_HIT_THREAD_RAY_DISPATCH_XECORE11", "RT CLOSEST HIT THREAD RAY DISPATCH XECORE11",
                          "Number of closest hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0485d77e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a50d77, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa50f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc50d77, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e50d77, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e50f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt467MetricSet::CExt467MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt467MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "RT_CLOSEST_HIT_THREAD_RAY_DISPATCH_XECORE12", "RT CLOSEST HIT THREAD RAY DISPATCH XECORE12",
                          "Number of closest hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "RT_CLOSEST_HIT_THREAD_RAY_DISPATCH_XECORE13", "RT CLOSEST HIT THREAD RAY DISPATCH XECORE13",
                          "Number of closest hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "RT_CLOSEST_HIT_THREAD_RAY_DISPATCH_XECORE14", "RT CLOSEST HIT THREAD RAY DISPATCH XECORE14",
                          "Number of closest hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "RT_CLOSEST_HIT_THREAD_RAY_DISPATCH_XECORE15", "RT CLOSEST HIT THREAD RAY DISPATCH XECORE15",
                          "Number of closest hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0585d77e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a50d77, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba50f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc50d77, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc50f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e50d77, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e50f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt468MetricSet::CExt468MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt468MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "RT_CLOSEST_HIT_THREAD_RAY_DISPATCH_XECORE16", "RT CLOSEST HIT THREAD RAY DISPATCH XECORE16",
                          "Number of closest hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "RT_CLOSEST_HIT_THREAD_RAY_DISPATCH_XECORE17", "RT CLOSEST HIT THREAD RAY DISPATCH XECORE17",
                          "Number of closest hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "RT_CLOSEST_HIT_THREAD_RAY_DISPATCH_XECORE18", "RT CLOSEST HIT THREAD RAY DISPATCH XECORE18",
                          "Number of closest hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "RT_CLOSEST_HIT_THREAD_RAY_DISPATCH_XECORE19", "RT CLOSEST HIT THREAD RAY DISPATCH XECORE19",
                          "Number of closest hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0485d77e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a50d77, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa50f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc50d77, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e50d77, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e50f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt469MetricSet::CExt469MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt469MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "RT_CLOSEST_HIT_THREAD_RAY_DISPATCH_XECORE20", "RT CLOSEST HIT THREAD RAY DISPATCH XECORE20",
                          "Number of closest hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "RT_CLOSEST_HIT_THREAD_RAY_DISPATCH_XECORE21", "RT CLOSEST HIT THREAD RAY DISPATCH XECORE21",
                          "Number of closest hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "RT_CLOSEST_HIT_THREAD_RAY_DISPATCH_XECORE22", "RT CLOSEST HIT THREAD RAY DISPATCH XECORE22",
                          "Number of closest hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "RT_CLOSEST_HIT_THREAD_RAY_DISPATCH_XECORE23", "RT CLOSEST HIT THREAD RAY DISPATCH XECORE23",
                          "Number of closest hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0585d77e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a50d77, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba50f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc50d77, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc50f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e50d77, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e50f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt470MetricSet::CExt470MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt470MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "RT_CLOSEST_HIT_THREAD_RAY_DISPATCH_XECORE24", "RT CLOSEST HIT THREAD RAY DISPATCH XECORE24",
                          "Number of closest hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "RT_CLOSEST_HIT_THREAD_RAY_DISPATCH_XECORE25", "RT CLOSEST HIT THREAD RAY DISPATCH XECORE25",
                          "Number of closest hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "RT_CLOSEST_HIT_THREAD_RAY_DISPATCH_XECORE26", "RT CLOSEST HIT THREAD RAY DISPATCH XECORE26",
                          "Number of closest hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "RT_CLOSEST_HIT_THREAD_RAY_DISPATCH_XECORE27", "RT CLOSEST HIT THREAD RAY DISPATCH XECORE27",
                          "Number of closest hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0485d77e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a50d77, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa50f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc50d77, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e50d77, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e50f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt471MetricSet::CExt471MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt471MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "RT_CLOSEST_HIT_THREAD_RAY_DISPATCH_XECORE28", "RT CLOSEST HIT THREAD RAY DISPATCH XECORE28",
                          "Number of closest hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "RT_CLOSEST_HIT_THREAD_RAY_DISPATCH_XECORE29", "RT CLOSEST HIT THREAD RAY DISPATCH XECORE29",
                          "Number of closest hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "RT_CLOSEST_HIT_THREAD_RAY_DISPATCH_XECORE30", "RT CLOSEST HIT THREAD RAY DISPATCH XECORE30",
                          "Number of closest hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "RT_CLOSEST_HIT_THREAD_RAY_DISPATCH_XECORE31", "RT CLOSEST HIT THREAD RAY DISPATCH XECORE31",
                          "Number of closest hit threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0585d77e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a50d77, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba50f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc50d77, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc50f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e50d77, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e50f7f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt472MetricSet::CExt472MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt472MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "RT_INTERSECTION_THREAD_RAY_DISPATCH_XECORE0", "RT INTERSECTION THREAD RAY DISPATCH XECORE0",
                          "Number of intersection threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "RT_INTERSECTION_THREAD_RAY_DISPATCH_XECORE1", "RT INTERSECTION THREAD RAY DISPATCH XECORE1",
                          "Number of intersection threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "RT_INTERSECTION_THREAD_RAY_DISPATCH_XECORE2", "RT INTERSECTION THREAD RAY DISPATCH XECORE2",
                          "Number of intersection threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "RT_INTERSECTION_THREAD_RAY_DISPATCH_XECORE3", "RT INTERSECTION THREAD RAY DISPATCH XECORE3",
                          "Number of intersection threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0485cf7e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850eff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a50cf7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa50eff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc50cf7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50eff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e50cf7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e50eff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt473MetricSet::CExt473MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt473MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "RT_INTERSECTION_THREAD_RAY_DISPATCH_XECORE4", "RT INTERSECTION THREAD RAY DISPATCH XECORE4",
                          "Number of intersection threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "RT_INTERSECTION_THREAD_RAY_DISPATCH_XECORE5", "RT INTERSECTION THREAD RAY DISPATCH XECORE5",
                          "Number of intersection threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "RT_INTERSECTION_THREAD_RAY_DISPATCH_XECORE6", "RT INTERSECTION THREAD RAY DISPATCH XECORE6",
                          "Number of intersection threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "RT_INTERSECTION_THREAD_RAY_DISPATCH_XECORE7", "RT INTERSECTION THREAD RAY DISPATCH XECORE7",
                          "Number of intersection threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0585cf7e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850eff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a50cf7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba50eff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc50cf7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc50eff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e50cf7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e50eff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt474MetricSet::CExt474MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt474MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "RT_INTERSECTION_THREAD_RAY_DISPATCH_XECORE8", "RT INTERSECTION THREAD RAY DISPATCH XECORE8",
                          "Number of intersection threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "RT_INTERSECTION_THREAD_RAY_DISPATCH_XECORE9", "RT INTERSECTION THREAD RAY DISPATCH XECORE9",
                          "Number of intersection threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "RT_INTERSECTION_THREAD_RAY_DISPATCH_XECORE10", "RT INTERSECTION THREAD RAY DISPATCH XECORE10",
                          "Number of intersection threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "RT_INTERSECTION_THREAD_RAY_DISPATCH_XECORE11", "RT INTERSECTION THREAD RAY DISPATCH XECORE11",
                          "Number of intersection threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0485cf7e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850eff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a50cf7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa50eff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc50cf7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50eff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e50cf7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e50eff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt475MetricSet::CExt475MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt475MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "RT_INTERSECTION_THREAD_RAY_DISPATCH_XECORE12", "RT INTERSECTION THREAD RAY DISPATCH XECORE12",
                          "Number of intersection threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "RT_INTERSECTION_THREAD_RAY_DISPATCH_XECORE13", "RT INTERSECTION THREAD RAY DISPATCH XECORE13",
                          "Number of intersection threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "RT_INTERSECTION_THREAD_RAY_DISPATCH_XECORE14", "RT INTERSECTION THREAD RAY DISPATCH XECORE14",
                          "Number of intersection threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "RT_INTERSECTION_THREAD_RAY_DISPATCH_XECORE15", "RT INTERSECTION THREAD RAY DISPATCH XECORE15",
                          "Number of intersection threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0585cf7e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850eff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a50cf7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba50eff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc50cf7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc50eff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e50cf7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e50eff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt476MetricSet::CExt476MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt476MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "RT_INTERSECTION_THREAD_RAY_DISPATCH_XECORE16", "RT INTERSECTION THREAD RAY DISPATCH XECORE16",
                          "Number of intersection threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "RT_INTERSECTION_THREAD_RAY_DISPATCH_XECORE17", "RT INTERSECTION THREAD RAY DISPATCH XECORE17",
                          "Number of intersection threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "RT_INTERSECTION_THREAD_RAY_DISPATCH_XECORE18", "RT INTERSECTION THREAD RAY DISPATCH XECORE18",
                          "Number of intersection threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "RT_INTERSECTION_THREAD_RAY_DISPATCH_XECORE19", "RT INTERSECTION THREAD RAY DISPATCH XECORE19",
                          "Number of intersection threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0485cf7e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850eff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a50cf7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa50eff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc50cf7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50eff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e50cf7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e50eff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt477MetricSet::CExt477MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt477MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "RT_INTERSECTION_THREAD_RAY_DISPATCH_XECORE20", "RT INTERSECTION THREAD RAY DISPATCH XECORE20",
                          "Number of intersection threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "RT_INTERSECTION_THREAD_RAY_DISPATCH_XECORE21", "RT INTERSECTION THREAD RAY DISPATCH XECORE21",
                          "Number of intersection threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "RT_INTERSECTION_THREAD_RAY_DISPATCH_XECORE22", "RT INTERSECTION THREAD RAY DISPATCH XECORE22",
                          "Number of intersection threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "RT_INTERSECTION_THREAD_RAY_DISPATCH_XECORE23", "RT INTERSECTION THREAD RAY DISPATCH XECORE23",
                          "Number of intersection threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0585cf7e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850eff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a50cf7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba50eff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc50cf7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc50eff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e50cf7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e50eff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt478MetricSet::CExt478MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt478MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "RT_INTERSECTION_THREAD_RAY_DISPATCH_XECORE24", "RT INTERSECTION THREAD RAY DISPATCH XECORE24",
                          "Number of intersection threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "RT_INTERSECTION_THREAD_RAY_DISPATCH_XECORE25", "RT INTERSECTION THREAD RAY DISPATCH XECORE25",
                          "Number of intersection threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "RT_INTERSECTION_THREAD_RAY_DISPATCH_XECORE26", "RT INTERSECTION THREAD RAY DISPATCH XECORE26",
                          "Number of intersection threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "RT_INTERSECTION_THREAD_RAY_DISPATCH_XECORE27", "RT INTERSECTION THREAD RAY DISPATCH XECORE27",
                          "Number of intersection threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0485cf7e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850eff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a50cf7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa50eff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc50cf7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50eff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e50cf7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e50eff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt479MetricSet::CExt479MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt479MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "RT_INTERSECTION_THREAD_RAY_DISPATCH_XECORE28", "RT INTERSECTION THREAD RAY DISPATCH XECORE28",
                          "Number of intersection threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "RT_INTERSECTION_THREAD_RAY_DISPATCH_XECORE29", "RT INTERSECTION THREAD RAY DISPATCH XECORE29",
                          "Number of intersection threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "RT_INTERSECTION_THREAD_RAY_DISPATCH_XECORE30", "RT INTERSECTION THREAD RAY DISPATCH XECORE30",
                          "Number of intersection threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "RT_INTERSECTION_THREAD_RAY_DISPATCH_XECORE31", "RT INTERSECTION THREAD RAY DISPATCH XECORE31",
                          "Number of intersection threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0585cf7e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850eff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a50cf7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba50eff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc50cf7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc50eff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e50cf7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e50eff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt480MetricSet::CExt480MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt480MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "RT_MISS_THREAD_RAY_DISPATCH_XECORE0", "RT MISS THREAD RAY DISPATCH XECORE0",
                          "Number of miss threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "RT_MISS_THREAD_RAY_DISPATCH_XECORE1", "RT MISS THREAD RAY DISPATCH XECORE1",
                          "Number of miss threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "RT_MISS_THREAD_RAY_DISPATCH_XECORE2", "RT MISS THREAD RAY DISPATCH XECORE2",
                          "Number of miss threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "RT_MISS_THREAD_RAY_DISPATCH_XECORE3", "RT MISS THREAD RAY DISPATCH XECORE3",
                          "Number of miss threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0485db7e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a50db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa50fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc50db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e50db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e50fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt481MetricSet::CExt481MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt481MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "RT_MISS_THREAD_RAY_DISPATCH_XECORE4", "RT MISS THREAD RAY DISPATCH XECORE4",
                          "Number of miss threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "RT_MISS_THREAD_RAY_DISPATCH_XECORE5", "RT MISS THREAD RAY DISPATCH XECORE5",
                          "Number of miss threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "RT_MISS_THREAD_RAY_DISPATCH_XECORE6", "RT MISS THREAD RAY DISPATCH XECORE6",
                          "Number of miss threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "RT_MISS_THREAD_RAY_DISPATCH_XECORE7", "RT MISS THREAD RAY DISPATCH XECORE7",
                          "Number of miss threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0585db7e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a50db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba50fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc50db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc50fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e50db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e50fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt482MetricSet::CExt482MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt482MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "RT_MISS_THREAD_RAY_DISPATCH_XECORE8", "RT MISS THREAD RAY DISPATCH XECORE8",
                          "Number of miss threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "RT_MISS_THREAD_RAY_DISPATCH_XECORE9", "RT MISS THREAD RAY DISPATCH XECORE9",
                          "Number of miss threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "RT_MISS_THREAD_RAY_DISPATCH_XECORE10", "RT MISS THREAD RAY DISPATCH XECORE10",
                          "Number of miss threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "RT_MISS_THREAD_RAY_DISPATCH_XECORE11", "RT MISS THREAD RAY DISPATCH XECORE11",
                          "Number of miss threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0485db7e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a50db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa50fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc50db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e50db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e50fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt483MetricSet::CExt483MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt483MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "RT_MISS_THREAD_RAY_DISPATCH_XECORE12", "RT MISS THREAD RAY DISPATCH XECORE12",
                          "Number of miss threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "RT_MISS_THREAD_RAY_DISPATCH_XECORE13", "RT MISS THREAD RAY DISPATCH XECORE13",
                          "Number of miss threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "RT_MISS_THREAD_RAY_DISPATCH_XECORE14", "RT MISS THREAD RAY DISPATCH XECORE14",
                          "Number of miss threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "RT_MISS_THREAD_RAY_DISPATCH_XECORE15", "RT MISS THREAD RAY DISPATCH XECORE15",
                          "Number of miss threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0585db7e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a50db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba50fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc50db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc50fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e50db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e50fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt484MetricSet::CExt484MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt484MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "RT_MISS_THREAD_RAY_DISPATCH_XECORE16", "RT MISS THREAD RAY DISPATCH XECORE16",
                          "Number of miss threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "RT_MISS_THREAD_RAY_DISPATCH_XECORE17", "RT MISS THREAD RAY DISPATCH XECORE17",
                          "Number of miss threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "RT_MISS_THREAD_RAY_DISPATCH_XECORE18", "RT MISS THREAD RAY DISPATCH XECORE18",
                          "Number of miss threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "RT_MISS_THREAD_RAY_DISPATCH_XECORE19", "RT MISS THREAD RAY DISPATCH XECORE19",
                          "Number of miss threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0485db7e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a50db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa50fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc50db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e50db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e50fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt485MetricSet::CExt485MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt485MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "RT_MISS_THREAD_RAY_DISPATCH_XECORE20", "RT MISS THREAD RAY DISPATCH XECORE20",
                          "Number of miss threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "RT_MISS_THREAD_RAY_DISPATCH_XECORE21", "RT MISS THREAD RAY DISPATCH XECORE21",
                          "Number of miss threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "RT_MISS_THREAD_RAY_DISPATCH_XECORE22", "RT MISS THREAD RAY DISPATCH XECORE22",
                          "Number of miss threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "RT_MISS_THREAD_RAY_DISPATCH_XECORE23", "RT MISS THREAD RAY DISPATCH XECORE23",
                          "Number of miss threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0585db7e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a50db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba50fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc50db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc50fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e50db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e50fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt486MetricSet::CExt486MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt486MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "RT_MISS_THREAD_RAY_DISPATCH_XECORE24", "RT MISS THREAD RAY DISPATCH XECORE24",
                          "Number of miss threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "RT_MISS_THREAD_RAY_DISPATCH_XECORE25", "RT MISS THREAD RAY DISPATCH XECORE25",
                          "Number of miss threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "RT_MISS_THREAD_RAY_DISPATCH_XECORE26", "RT MISS THREAD RAY DISPATCH XECORE26",
                          "Number of miss threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "RT_MISS_THREAD_RAY_DISPATCH_XECORE27", "RT MISS THREAD RAY DISPATCH XECORE27",
                          "Number of miss threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0485db7e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a50db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa50fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc50db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e50db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e50fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt487MetricSet::CExt487MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt487MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "RT_MISS_THREAD_RAY_DISPATCH_XECORE28", "RT MISS THREAD RAY DISPATCH XECORE28",
                          "Number of miss threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "RT_MISS_THREAD_RAY_DISPATCH_XECORE29", "RT MISS THREAD RAY DISPATCH XECORE29",
                          "Number of miss threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "RT_MISS_THREAD_RAY_DISPATCH_XECORE30", "RT MISS THREAD RAY DISPATCH XECORE30",
                          "Number of miss threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "RT_MISS_THREAD_RAY_DISPATCH_XECORE31", "RT MISS THREAD RAY DISPATCH XECORE31",
                          "Number of miss threads dispatched for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f8520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe520a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0585db7e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a50db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba50fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc50db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc50fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e5000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e50db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e50fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt488MetricSet::CExt488MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt488MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "EARLY_DEPTH_STENCIL_TEST_FAIL_NP_ZPIPE0", "EARLY DEPTH STENCIL TEST FAIL NP ZPIPE0",
                          "Number of non-promoted 2x2 that failed Depth / Stencil before the Pixel Shader that were previously ambiguous at HiZ",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment", nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "EARLY_DEPTH_STENCIL_TEST_FAIL_P_ZPIPE0", "EARLY DEPTH STENCIL TEST FAIL P ZPIPE0",
                          "Number of promoted 2x2 that failed Depth / Stencil that were previously ambiguous at HiZ",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b0150, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120b0493, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140b0411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032490, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x10800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0002000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0001000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x0000800a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000effe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000400a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7fe, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt489MetricSet::CExt489MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt489MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "EARLY_DEPTH_STENCIL_TEST_FAIL_NP_ZPIPE1", "EARLY DEPTH STENCIL TEST FAIL NP ZPIPE1",
                          "Number of non-promoted 2x2 that failed Depth / Stencil before the Pixel Shader that were previously ambiguous at HiZ",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment", nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "EARLY_DEPTH_STENCIL_TEST_FAIL_P_ZPIPE1", "EARLY DEPTH STENCIL TEST FAIL P ZPIPE1",
                          "Number of promoted 2x2 that failed Depth / Stencil that were previously ambiguous at HiZ",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060c0150, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120c0493, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140c0411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032490, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x10800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0002000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0001000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x0000800a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000effe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000400a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7fe, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt490MetricSet::CExt490MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt490MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "EARLY_DEPTH_STENCIL_TEST_FAIL_NP_ZPIPE2", "EARLY DEPTH STENCIL TEST FAIL NP ZPIPE2",
                          "Number of non-promoted 2x2 that failed Depth / Stencil before the Pixel Shader that were previously ambiguous at HiZ",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment", nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "EARLY_DEPTH_STENCIL_TEST_FAIL_P_ZPIPE2", "EARLY DEPTH STENCIL TEST FAIL P ZPIPE2",
                          "Number of promoted 2x2 that failed Depth / Stencil that were previously ambiguous at HiZ",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b0150, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0493, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150b0411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032490, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x10800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0002000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0001000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x0000800a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000effe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000400a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7fe, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt491MetricSet::CExt491MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt491MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "EARLY_DEPTH_STENCIL_TEST_FAIL_NP_ZPIPE3", "EARLY DEPTH STENCIL TEST FAIL NP ZPIPE3",
                          "Number of non-promoted 2x2 that failed Depth / Stencil before the Pixel Shader that were previously ambiguous at HiZ",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment", nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "EARLY_DEPTH_STENCIL_TEST_FAIL_P_ZPIPE3", "EARLY DEPTH STENCIL TEST FAIL P ZPIPE3",
                          "Number of promoted 2x2 that failed Depth / Stencil that were previously ambiguous at HiZ",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070c0150, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0493, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150c0411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032490, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x10800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0002000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0001000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x0000800a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000effe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000400a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7fe, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt492MetricSet::CExt492MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt492MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "EARLY_DEPTH_STENCIL_TEST_FAIL_NP_ZPIPE4", "EARLY DEPTH STENCIL TEST FAIL NP ZPIPE4",
                          "Number of non-promoted 2x2 that failed Depth / Stencil before the Pixel Shader that were previously ambiguous at HiZ",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment", nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "EARLY_DEPTH_STENCIL_TEST_FAIL_P_ZPIPE4", "EARLY DEPTH STENCIL TEST FAIL P ZPIPE4",
                          "Number of promoted 2x2 that failed Depth / Stencil that were previously ambiguous at HiZ",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b0150, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120b0493, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140b0411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032490, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x10800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0002000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0001000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x0000800a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000effe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000400a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7fe, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt493MetricSet::CExt493MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt493MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "EARLY_DEPTH_STENCIL_TEST_FAIL_NP_ZPIPE5", "EARLY DEPTH STENCIL TEST FAIL NP ZPIPE5",
                          "Number of non-promoted 2x2 that failed Depth / Stencil before the Pixel Shader that were previously ambiguous at HiZ",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment", nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "EARLY_DEPTH_STENCIL_TEST_FAIL_P_ZPIPE5", "EARLY DEPTH STENCIL TEST FAIL P ZPIPE5",
                          "Number of promoted 2x2 that failed Depth / Stencil that were previously ambiguous at HiZ",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060c0150, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120c0493, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140c0411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032490, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x10800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0002000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0001000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x0000800a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000effe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000400a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7fe, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt494MetricSet::CExt494MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt494MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "EARLY_DEPTH_STENCIL_TEST_FAIL_NP_ZPIPE6", "EARLY DEPTH STENCIL TEST FAIL NP ZPIPE6",
                          "Number of non-promoted 2x2 that failed Depth / Stencil before the Pixel Shader that were previously ambiguous at HiZ",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment", nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "EARLY_DEPTH_STENCIL_TEST_FAIL_P_ZPIPE6", "EARLY DEPTH STENCIL TEST FAIL P ZPIPE6",
                          "Number of promoted 2x2 that failed Depth / Stencil that were previously ambiguous at HiZ",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b0150, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0493, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150b0411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032490, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x10800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0002000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0001000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x0000800a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000effe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000400a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7fe, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt495MetricSet::CExt495MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt495MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "EARLY_DEPTH_STENCIL_TEST_FAIL_NP_ZPIPE7", "EARLY DEPTH STENCIL TEST FAIL NP ZPIPE7",
                          "Number of non-promoted 2x2 that failed Depth / Stencil before the Pixel Shader that were previously ambiguous at HiZ",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment", nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "EARLY_DEPTH_STENCIL_TEST_FAIL_P_ZPIPE7", "EARLY DEPTH STENCIL TEST FAIL P ZPIPE7",
                          "Number of promoted 2x2 that failed Depth / Stencil that were previously ambiguous at HiZ",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070c0150, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0493, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150c0411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032490, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x10800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0002000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0001000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x0000800a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000effe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000400a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7fe, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt496MetricSet::CExt496MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt496MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "EARLY_DEPTH_STENCIL_TEST_FAIL_NP_ZPIPE8", "EARLY DEPTH STENCIL TEST FAIL NP ZPIPE8",
                          "Number of non-promoted 2x2 that failed Depth / Stencil before the Pixel Shader that were previously ambiguous at HiZ",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment", nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "EARLY_DEPTH_STENCIL_TEST_FAIL_P_ZPIPE8", "EARLY DEPTH STENCIL TEST FAIL P ZPIPE8",
                          "Number of promoted 2x2 that failed Depth / Stencil that were previously ambiguous at HiZ",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b0150, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120b0493, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140b0411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x10800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0002000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0001000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x0000800a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000effe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000400a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7fe, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt497MetricSet::CExt497MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt497MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "EARLY_DEPTH_STENCIL_TEST_FAIL_NP_ZPIPE9", "EARLY DEPTH STENCIL TEST FAIL NP ZPIPE9",
                          "Number of non-promoted 2x2 that failed Depth / Stencil before the Pixel Shader that were previously ambiguous at HiZ",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment", nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "EARLY_DEPTH_STENCIL_TEST_FAIL_P_ZPIPE9", "EARLY DEPTH STENCIL TEST FAIL P ZPIPE9",
                          "Number of promoted 2x2 that failed Depth / Stencil that were previously ambiguous at HiZ",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060c0150, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120c0493, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140c0411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x10800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0002000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0001000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x0000800a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000effe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000400a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7fe, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt498MetricSet::CExt498MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt498MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "EARLY_DEPTH_STENCIL_TEST_FAIL_NP_ZPIPE10", "EARLY DEPTH STENCIL TEST FAIL NP ZPIPE10",
                          "Number of non-promoted 2x2 that failed Depth / Stencil before the Pixel Shader that were previously ambiguous at HiZ",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment", nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "EARLY_DEPTH_STENCIL_TEST_FAIL_P_ZPIPE10", "EARLY DEPTH STENCIL TEST FAIL P ZPIPE10",
                          "Number of promoted 2x2 that failed Depth / Stencil that were previously ambiguous at HiZ",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b0150, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0493, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150b0411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x10800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0002000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0001000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x0000800a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000effe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000400a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7fe, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt499MetricSet::CExt499MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt499MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "EARLY_DEPTH_STENCIL_TEST_FAIL_NP_ZPIPE11", "EARLY DEPTH STENCIL TEST FAIL NP ZPIPE11",
                          "Number of non-promoted 2x2 that failed Depth / Stencil before the Pixel Shader that were previously ambiguous at HiZ",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment", nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "EARLY_DEPTH_STENCIL_TEST_FAIL_P_ZPIPE11", "EARLY DEPTH STENCIL TEST FAIL P ZPIPE11",
                          "Number of promoted 2x2 that failed Depth / Stencil that were previously ambiguous at HiZ",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070c0150, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0493, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150c0411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x10800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0002000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0001000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x0000800a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000effe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000400a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7fe, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt500MetricSet::CExt500MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt500MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "EARLY_DEPTH_STENCIL_TEST_FAIL_NP_ZPIPE12", "EARLY DEPTH STENCIL TEST FAIL NP ZPIPE12",
                          "Number of non-promoted 2x2 that failed Depth / Stencil before the Pixel Shader that were previously ambiguous at HiZ",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment", nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "EARLY_DEPTH_STENCIL_TEST_FAIL_P_ZPIPE12", "EARLY DEPTH STENCIL TEST FAIL P ZPIPE12",
                          "Number of promoted 2x2 that failed Depth / Stencil that were previously ambiguous at HiZ",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b0150, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120b0493, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140b0411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x10800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0002000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0001000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x0000800a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000effe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000400a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7fe, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt501MetricSet::CExt501MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt501MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "EARLY_DEPTH_STENCIL_TEST_FAIL_NP_ZPIPE13", "EARLY DEPTH STENCIL TEST FAIL NP ZPIPE13",
                          "Number of non-promoted 2x2 that failed Depth / Stencil before the Pixel Shader that were previously ambiguous at HiZ",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment", nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "EARLY_DEPTH_STENCIL_TEST_FAIL_P_ZPIPE13", "EARLY DEPTH STENCIL TEST FAIL P ZPIPE13",
                          "Number of promoted 2x2 that failed Depth / Stencil that were previously ambiguous at HiZ",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060c0150, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120c0493, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140c0411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x10800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0002000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0001000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x0000800a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000effe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000400a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7fe, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt502MetricSet::CExt502MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt502MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "EARLY_DEPTH_STENCIL_TEST_FAIL_NP_ZPIPE14", "EARLY DEPTH STENCIL TEST FAIL NP ZPIPE14",
                          "Number of non-promoted 2x2 that failed Depth / Stencil before the Pixel Shader that were previously ambiguous at HiZ",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment", nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "EARLY_DEPTH_STENCIL_TEST_FAIL_P_ZPIPE14", "EARLY DEPTH STENCIL TEST FAIL P ZPIPE14",
                          "Number of promoted 2x2 that failed Depth / Stencil that were previously ambiguous at HiZ",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b0150, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0493, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150b0411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x10800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0002000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0001000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x0000800a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000effe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000400a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7fe, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt503MetricSet::CExt503MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt503MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "EARLY_DEPTH_STENCIL_TEST_FAIL_NP_ZPIPE15", "EARLY DEPTH STENCIL TEST FAIL NP ZPIPE15",
                          "Number of non-promoted 2x2 that failed Depth / Stencil before the Pixel Shader that were previously ambiguous at HiZ",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment", nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD USUB" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "EARLY_DEPTH_STENCIL_TEST_FAIL_P_ZPIPE15", "EARLY DEPTH STENCIL TEST FAIL P ZPIPE15",
                          "Number of promoted 2x2 that failed Depth / Stencil that were previously ambiguous at HiZ",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070c0150, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0493, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150c0411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x10800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0002000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0001000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x0000800a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000effe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000400a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7fe, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt504MetricSet::CExt504MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt504MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "HIZ_DEPTH_TEST_AMBIG_NP_ZPIPE0", "HIZ DEPTH TEST AMBIG NP ZPIPE0",
                          "Number of non-promoted 2x2 that are ambiguous by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0301e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b5800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180b0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt505MetricSet::CExt505MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt505MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "HIZ_DEPTH_TEST_AMBIG_NP_ZPIPE1", "HIZ DEPTH TEST AMBIG NP ZPIPE1",
                          "Number of non-promoted 2x2 that are ambiguous by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0307e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160c5800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180c0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060c3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100c000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120c000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140c000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt506MetricSet::CExt506MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt506MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "HIZ_DEPTH_TEST_AMBIG_NP_ZPIPE2", "HIZ DEPTH TEST AMBIG NP ZPIPE2",
                          "Number of non-promoted 2x2 that are ambiguous by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e037800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a033de0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x400303c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b5800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190b0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt507MetricSet::CExt507MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt507MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "HIZ_DEPTH_TEST_AMBIG_NP_ZPIPE3", "HIZ DEPTH TEST AMBIG NP ZPIPE3",
                          "Number of non-promoted 2x2 that are ambiguous by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170c5800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190c0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070c3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150c000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt508MetricSet::CExt508MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt508MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "HIZ_DEPTH_TEST_AMBIG_NP_ZPIPE4", "HIZ DEPTH TEST AMBIG NP ZPIPE4",
                          "Number of non-promoted 2x2 that are ambiguous by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0301e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b5800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180b0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt509MetricSet::CExt509MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt509MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "HIZ_DEPTH_TEST_AMBIG_NP_ZPIPE5", "HIZ DEPTH TEST AMBIG NP ZPIPE5",
                          "Number of non-promoted 2x2 that are ambiguous by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0307e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160c5800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180c0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060c3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100c000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120c000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140c000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt510MetricSet::CExt510MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt510MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "HIZ_DEPTH_TEST_AMBIG_NP_ZPIPE6", "HIZ DEPTH TEST AMBIG NP ZPIPE6",
                          "Number of non-promoted 2x2 that are ambiguous by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e037800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a033de0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x400303c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b5800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190b0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt511MetricSet::CExt511MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt511MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "HIZ_DEPTH_TEST_AMBIG_NP_ZPIPE7", "HIZ DEPTH TEST AMBIG NP ZPIPE7",
                          "Number of non-promoted 2x2 that are ambiguous by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170c5800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190c0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070c3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150c000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt512MetricSet::CExt512MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt512MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "HIZ_DEPTH_TEST_AMBIG_NP_ZPIPE8", "HIZ DEPTH TEST AMBIG NP ZPIPE8",
                          "Number of non-promoted 2x2 that are ambiguous by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b5800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180b0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt513MetricSet::CExt513MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt513MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "HIZ_DEPTH_TEST_AMBIG_NP_ZPIPE9", "HIZ DEPTH TEST AMBIG NP ZPIPE9",
                          "Number of non-promoted 2x2 that are ambiguous by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0309e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160c5800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180c0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060c3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100c000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120c000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140c000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt514MetricSet::CExt514MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt514MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "HIZ_DEPTH_TEST_AMBIG_NP_ZPIPE10", "HIZ DEPTH TEST AMBIG NP ZPIPE10",
                          "Number of non-promoted 2x2 that are ambiguous by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e037c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a033fe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x400303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b5800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190b0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt515MetricSet::CExt515MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt515MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "HIZ_DEPTH_TEST_AMBIG_NP_ZPIPE11", "HIZ DEPTH TEST AMBIG NP ZPIPE11",
                          "Number of non-promoted 2x2 that are ambiguous by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0305e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170c5800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190c0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070c3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150c000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt516MetricSet::CExt516MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt516MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "HIZ_DEPTH_TEST_AMBIG_NP_ZPIPE12", "HIZ DEPTH TEST AMBIG NP ZPIPE12",
                          "Number of non-promoted 2x2 that are ambiguous by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02022222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b5800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180b0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt517MetricSet::CExt517MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt517MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "HIZ_DEPTH_TEST_AMBIG_NP_ZPIPE13", "HIZ DEPTH TEST AMBIG NP ZPIPE13",
                          "Number of non-promoted 2x2 that are ambiguous by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02022222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0309e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160c5800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180c0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060c3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100c000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120c000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140c000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt518MetricSet::CExt518MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt518MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "HIZ_DEPTH_TEST_AMBIG_NP_ZPIPE14", "HIZ DEPTH TEST AMBIG NP ZPIPE14",
                          "Number of non-promoted 2x2 that are ambiguous by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02022222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e037c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a033fe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x400303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b5800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190b0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt519MetricSet::CExt519MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt519MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "HIZ_DEPTH_TEST_AMBIG_NP_ZPIPE15", "HIZ DEPTH TEST AMBIG NP ZPIPE15",
                          "Number of non-promoted 2x2 that are ambiguous by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02022222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0305e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170c5800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190c0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070c3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150c000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt520MetricSet::CExt520MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt520MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "HIZ_DEPTH_TEST_AMBIG_P_ZPIPE0", "HIZ DEPTH TEST AMBIG P ZPIPE0",
                          "Number of promoted 2x2 that are ambiguous by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0301e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b5800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180b0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt521MetricSet::CExt521MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt521MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "HIZ_DEPTH_TEST_AMBIG_P_ZPIPE1", "HIZ DEPTH TEST AMBIG P ZPIPE1",
                          "Number of promoted 2x2 that are ambiguous by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0307e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160c5800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180c0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060c3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100c000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120c000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140c000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt522MetricSet::CExt522MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt522MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "HIZ_DEPTH_TEST_AMBIG_P_ZPIPE2", "HIZ DEPTH TEST AMBIG P ZPIPE2",
                          "Number of promoted 2x2 that are ambiguous by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e037800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a033de0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x400303c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b5800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190b0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt523MetricSet::CExt523MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt523MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "HIZ_DEPTH_TEST_AMBIG_P_ZPIPE3", "HIZ DEPTH TEST AMBIG P ZPIPE3",
                          "Number of promoted 2x2 that are ambiguous by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170c5800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190c0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070c3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150c000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt524MetricSet::CExt524MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt524MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "HIZ_DEPTH_TEST_AMBIG_P_ZPIPE4", "HIZ DEPTH TEST AMBIG P ZPIPE4",
                          "Number of promoted 2x2 that are ambiguous by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0301e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b5800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180b0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt525MetricSet::CExt525MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt525MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "HIZ_DEPTH_TEST_AMBIG_P_ZPIPE5", "HIZ DEPTH TEST AMBIG P ZPIPE5",
                          "Number of promoted 2x2 that are ambiguous by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0307e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160c5800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180c0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060c3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100c000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120c000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140c000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt526MetricSet::CExt526MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt526MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "HIZ_DEPTH_TEST_AMBIG_P_ZPIPE6", "HIZ DEPTH TEST AMBIG P ZPIPE6",
                          "Number of promoted 2x2 that are ambiguous by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e037800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a033de0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x400303c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b5800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190b0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt527MetricSet::CExt527MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt527MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "HIZ_DEPTH_TEST_AMBIG_P_ZPIPE7", "HIZ DEPTH TEST AMBIG P ZPIPE7",
                          "Number of promoted 2x2 that are ambiguous by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170c5800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190c0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070c3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150c000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt528MetricSet::CExt528MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt528MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "HIZ_DEPTH_TEST_AMBIG_P_ZPIPE8", "HIZ DEPTH TEST AMBIG P ZPIPE8",
                          "Number of promoted 2x2 that are ambiguous by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b5800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180b0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt529MetricSet::CExt529MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt529MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "HIZ_DEPTH_TEST_AMBIG_P_ZPIPE9", "HIZ DEPTH TEST AMBIG P ZPIPE9",
                          "Number of promoted 2x2 that are ambiguous by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0309e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160c5800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180c0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060c3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100c000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120c000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140c000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt530MetricSet::CExt530MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt530MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "HIZ_DEPTH_TEST_AMBIG_P_ZPIPE10", "HIZ DEPTH TEST AMBIG P ZPIPE10",
                          "Number of promoted 2x2 that are ambiguous by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e037c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a033fe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x400303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b5800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190b0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt531MetricSet::CExt531MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt531MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "HIZ_DEPTH_TEST_AMBIG_P_ZPIPE11", "HIZ DEPTH TEST AMBIG P ZPIPE11",
                          "Number of promoted 2x2 that are ambiguous by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0305e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170c5800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190c0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070c3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150c000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt532MetricSet::CExt532MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt532MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "HIZ_DEPTH_TEST_AMBIG_P_ZPIPE12", "HIZ DEPTH TEST AMBIG P ZPIPE12",
                          "Number of promoted 2x2 that are ambiguous by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02022222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b5800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180b0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt533MetricSet::CExt533MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt533MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "HIZ_DEPTH_TEST_AMBIG_P_ZPIPE13", "HIZ DEPTH TEST AMBIG P ZPIPE13",
                          "Number of promoted 2x2 that are ambiguous by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02022222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0309e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160c5800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180c0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060c3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100c000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120c000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140c000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt534MetricSet::CExt534MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt534MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "HIZ_DEPTH_TEST_AMBIG_P_ZPIPE14", "HIZ DEPTH TEST AMBIG P ZPIPE14",
                          "Number of promoted 2x2 that are ambiguous by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02022222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e037c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a033fe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x400303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b5800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190b0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt535MetricSet::CExt535MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt535MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "HIZ_DEPTH_TEST_AMBIG_P_ZPIPE15", "HIZ DEPTH TEST AMBIG P ZPIPE15",
                          "Number of promoted 2x2 that are ambiguous by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02022222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0305e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170c5800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190c0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070c3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150c000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt536MetricSet::CExt536MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt536MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "HIZ_DEPTH_TEST_FAIL_NP_ZPIPE0", "HIZ DEPTH TEST FAIL NP ZPIPE0",
                          "Number of non-promoted 2x2 that failed the hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0301e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b4400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b3c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140b000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt537MetricSet::CExt537MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt537MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "HIZ_DEPTH_TEST_FAIL_NP_ZPIPE1", "HIZ DEPTH TEST FAIL NP ZPIPE1",
                          "Number of non-promoted 2x2 that failed the hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0307e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160c4400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060c3c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100c000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120c000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140c000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt538MetricSet::CExt538MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt538MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "HIZ_DEPTH_TEST_FAIL_NP_ZPIPE2", "HIZ DEPTH TEST FAIL NP ZPIPE2",
                          "Number of non-promoted 2x2 that failed the hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e037800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a033de0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x400303c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b4400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b3c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150b000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt539MetricSet::CExt539MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt539MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "HIZ_DEPTH_TEST_FAIL_NP_ZPIPE3", "HIZ DEPTH TEST FAIL NP ZPIPE3",
                          "Number of non-promoted 2x2 that failed the hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170c4400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070c3c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150c000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt540MetricSet::CExt540MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt540MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "HIZ_DEPTH_TEST_FAIL_NP_ZPIPE4", "HIZ DEPTH TEST FAIL NP ZPIPE4",
                          "Number of non-promoted 2x2 that failed the hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0301e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b4400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b3c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140b000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt541MetricSet::CExt541MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt541MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "HIZ_DEPTH_TEST_FAIL_NP_ZPIPE5", "HIZ DEPTH TEST FAIL NP ZPIPE5",
                          "Number of non-promoted 2x2 that failed the hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0307e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160c4400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060c3c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100c000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120c000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140c000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt542MetricSet::CExt542MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt542MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "HIZ_DEPTH_TEST_FAIL_NP_ZPIPE6", "HIZ DEPTH TEST FAIL NP ZPIPE6",
                          "Number of non-promoted 2x2 that failed the hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e037800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a033de0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x400303c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b4400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b3c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150b000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt543MetricSet::CExt543MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt543MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "HIZ_DEPTH_TEST_FAIL_NP_ZPIPE7", "HIZ DEPTH TEST FAIL NP ZPIPE7",
                          "Number of non-promoted 2x2 that failed the hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170c4400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070c3c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150c000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt544MetricSet::CExt544MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt544MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "HIZ_DEPTH_TEST_FAIL_NP_ZPIPE8", "HIZ DEPTH TEST FAIL NP ZPIPE8",
                          "Number of non-promoted 2x2 that failed the hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b4400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b3c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140b000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt545MetricSet::CExt545MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt545MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "HIZ_DEPTH_TEST_FAIL_NP_ZPIPE9", "HIZ DEPTH TEST FAIL NP ZPIPE9",
                          "Number of non-promoted 2x2 that failed the hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0309e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160c4400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060c3c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100c000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120c000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140c000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt546MetricSet::CExt546MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt546MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "HIZ_DEPTH_TEST_FAIL_NP_ZPIPE10", "HIZ DEPTH TEST FAIL NP ZPIPE10",
                          "Number of non-promoted 2x2 that failed the hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e037c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a033fe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x400303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b4400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b3c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150b000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt547MetricSet::CExt547MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt547MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "HIZ_DEPTH_TEST_FAIL_NP_ZPIPE11", "HIZ DEPTH TEST FAIL NP ZPIPE11",
                          "Number of non-promoted 2x2 that failed the hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0305e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170c4400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070c3c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150c000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt548MetricSet::CExt548MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt548MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "HIZ_DEPTH_TEST_FAIL_NP_ZPIPE12", "HIZ DEPTH TEST FAIL NP ZPIPE12",
                          "Number of non-promoted 2x2 that failed the hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02022222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b4400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b3c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140b000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt549MetricSet::CExt549MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt549MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "HIZ_DEPTH_TEST_FAIL_NP_ZPIPE13", "HIZ DEPTH TEST FAIL NP ZPIPE13",
                          "Number of non-promoted 2x2 that failed the hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02022222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0309e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160c4400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060c3c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100c000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120c000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140c000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt550MetricSet::CExt550MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt550MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "HIZ_DEPTH_TEST_FAIL_NP_ZPIPE14", "HIZ DEPTH TEST FAIL NP ZPIPE14",
                          "Number of non-promoted 2x2 that failed the hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02022222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e037c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a033fe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x400303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b4400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b3c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150b000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt551MetricSet::CExt551MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt551MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "HIZ_DEPTH_TEST_FAIL_NP_ZPIPE15", "HIZ DEPTH TEST FAIL NP ZPIPE15",
                          "Number of non-promoted 2x2 that failed the hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02022222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0305e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170c4400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070c3c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150c000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt552MetricSet::CExt552MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt552MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "HIZ_DEPTH_TEST_FAIL_P_ZPIPE0", "HIZ DEPTH TEST FAIL P ZPIPE0",
                          "Number of promoted 2x2 that failed the hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0301e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b4400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b3c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140b000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt553MetricSet::CExt553MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt553MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "HIZ_DEPTH_TEST_FAIL_P_ZPIPE1", "HIZ DEPTH TEST FAIL P ZPIPE1",
                          "Number of promoted 2x2 that failed the hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0307e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160c4400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060c3c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100c000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120c000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140c000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt554MetricSet::CExt554MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt554MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "HIZ_DEPTH_TEST_FAIL_P_ZPIPE2", "HIZ DEPTH TEST FAIL P ZPIPE2",
                          "Number of promoted 2x2 that failed the hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e037800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a033de0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x400303c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b4400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b3c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150b000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt555MetricSet::CExt555MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt555MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "HIZ_DEPTH_TEST_FAIL_P_ZPIPE3", "HIZ DEPTH TEST FAIL P ZPIPE3",
                          "Number of promoted 2x2 that failed the hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170c4400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070c3c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150c000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt556MetricSet::CExt556MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt556MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "HIZ_DEPTH_TEST_FAIL_P_ZPIPE4", "HIZ DEPTH TEST FAIL P ZPIPE4",
                          "Number of promoted 2x2 that failed the hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0301e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b4400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b3c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140b000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt557MetricSet::CExt557MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt557MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "HIZ_DEPTH_TEST_FAIL_P_ZPIPE5", "HIZ DEPTH TEST FAIL P ZPIPE5",
                          "Number of promoted 2x2 that failed the hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0307e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160c4400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060c3c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100c000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120c000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140c000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt558MetricSet::CExt558MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt558MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "HIZ_DEPTH_TEST_FAIL_P_ZPIPE6", "HIZ DEPTH TEST FAIL P ZPIPE6",
                          "Number of promoted 2x2 that failed the hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e037800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a033de0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x400303c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b4400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b3c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150b000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt559MetricSet::CExt559MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt559MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "HIZ_DEPTH_TEST_FAIL_P_ZPIPE7", "HIZ DEPTH TEST FAIL P ZPIPE7",
                          "Number of promoted 2x2 that failed the hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170c4400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070c3c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150c000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt560MetricSet::CExt560MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt560MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "HIZ_DEPTH_TEST_FAIL_P_ZPIPE8", "HIZ DEPTH TEST FAIL P ZPIPE8",
                          "Number of promoted 2x2 that failed the hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b4400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b3c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140b000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt561MetricSet::CExt561MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt561MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "HIZ_DEPTH_TEST_FAIL_P_ZPIPE9", "HIZ DEPTH TEST FAIL P ZPIPE9",
                          "Number of promoted 2x2 that failed the hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0309e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160c4400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060c3c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100c000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120c000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140c000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt562MetricSet::CExt562MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt562MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "HIZ_DEPTH_TEST_FAIL_P_ZPIPE10", "HIZ DEPTH TEST FAIL P ZPIPE10",
                          "Number of promoted 2x2 that failed the hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e037c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a033fe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x400303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b4400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b3c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150b000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt563MetricSet::CExt563MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt563MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "HIZ_DEPTH_TEST_FAIL_P_ZPIPE11", "HIZ DEPTH TEST FAIL P ZPIPE11",
                          "Number of promoted 2x2 that failed the hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0305e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170c4400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070c3c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150c000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt564MetricSet::CExt564MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt564MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "HIZ_DEPTH_TEST_FAIL_P_ZPIPE12", "HIZ DEPTH TEST FAIL P ZPIPE12",
                          "Number of promoted 2x2 that failed the hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02022222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b4400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b3c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140b000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt565MetricSet::CExt565MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt565MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "HIZ_DEPTH_TEST_FAIL_P_ZPIPE13", "HIZ DEPTH TEST FAIL P ZPIPE13",
                          "Number of promoted 2x2 that failed the hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02022222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0309e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160c4400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060c3c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100c000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120c000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140c000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt566MetricSet::CExt566MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt566MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "HIZ_DEPTH_TEST_FAIL_P_ZPIPE14", "HIZ DEPTH TEST FAIL P ZPIPE14",
                          "Number of promoted 2x2 that failed the hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02022222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e037c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a033fe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x400303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b4400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b3c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150b000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt567MetricSet::CExt567MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt567MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "HIZ_DEPTH_TEST_FAIL_P_ZPIPE15", "HIZ DEPTH TEST FAIL P ZPIPE15",
                          "Number of promoted 2x2 that failed the hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02022222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0305e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170c4400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070c3c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150c000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt568MetricSet::CExt568MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt568MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "HIZ_DEPTH_TEST_PASS_P_ZPIPE0", "HIZ DEPTH TEST PASS P ZPIPE0",
                          "Number of promoted 2x2 passed by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0301e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180b0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120b0009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt569MetricSet::CExt569MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt569MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "HIZ_DEPTH_TEST_PASS_P_ZPIPE1", "HIZ DEPTH TEST PASS P ZPIPE1",
                          "Number of promoted 2x2 passed by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0307e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180c0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060c3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100c0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120c0009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140c000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt570MetricSet::CExt570MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt570MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "HIZ_DEPTH_TEST_PASS_P_ZPIPE2", "HIZ DEPTH TEST PASS P ZPIPE2",
                          "Number of promoted 2x2 passed by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e037800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a033de0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x400303c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190b0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt571MetricSet::CExt571MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt571MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "HIZ_DEPTH_TEST_PASS_P_ZPIPE3", "HIZ DEPTH TEST PASS P ZPIPE3",
                          "Number of promoted 2x2 passed by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190c0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070c3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150c000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt572MetricSet::CExt572MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt572MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "HIZ_DEPTH_TEST_PASS_P_ZPIPE4", "HIZ DEPTH TEST PASS P ZPIPE4",
                          "Number of promoted 2x2 passed by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0301e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180b0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120b0009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt573MetricSet::CExt573MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt573MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "HIZ_DEPTH_TEST_PASS_P_ZPIPE5", "HIZ DEPTH TEST PASS P ZPIPE5",
                          "Number of promoted 2x2 passed by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0307e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180c0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060c3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100c0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120c0009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140c000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt574MetricSet::CExt574MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt574MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "HIZ_DEPTH_TEST_PASS_P_ZPIPE6", "HIZ DEPTH TEST PASS P ZPIPE6",
                          "Number of promoted 2x2 passed by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e037800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a033de0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x400303c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190b0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt575MetricSet::CExt575MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt575MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "HIZ_DEPTH_TEST_PASS_P_ZPIPE7", "HIZ DEPTH TEST PASS P ZPIPE7",
                          "Number of promoted 2x2 passed by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190c0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070c3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150c000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt576MetricSet::CExt576MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt576MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "HIZ_DEPTH_TEST_PASS_P_ZPIPE8", "HIZ DEPTH TEST PASS P ZPIPE8",
                          "Number of promoted 2x2 passed by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180b0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120b0009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt577MetricSet::CExt577MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt577MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "HIZ_DEPTH_TEST_PASS_P_ZPIPE9", "HIZ DEPTH TEST PASS P ZPIPE9",
                          "Number of promoted 2x2 passed by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0309e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180c0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060c3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100c0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120c0009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140c000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt578MetricSet::CExt578MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt578MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "HIZ_DEPTH_TEST_PASS_P_ZPIPE10", "HIZ DEPTH TEST PASS P ZPIPE10",
                          "Number of promoted 2x2 passed by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e037c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a033fe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x400303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190b0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt579MetricSet::CExt579MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt579MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "HIZ_DEPTH_TEST_PASS_P_ZPIPE11", "HIZ DEPTH TEST PASS P ZPIPE11",
                          "Number of promoted 2x2 passed by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0305e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190c0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070c3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150c000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt580MetricSet::CExt580MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt580MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "HIZ_DEPTH_TEST_PASS_P_ZPIPE12", "HIZ DEPTH TEST PASS P ZPIPE12",
                          "Number of promoted 2x2 passed by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02022222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180b0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120b0009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt581MetricSet::CExt581MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt581MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "HIZ_DEPTH_TEST_PASS_P_ZPIPE13", "HIZ DEPTH TEST PASS P ZPIPE13",
                          "Number of promoted 2x2 passed by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02022222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0309e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180c0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060c3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100c0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120c0009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140c000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt582MetricSet::CExt582MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt582MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "HIZ_DEPTH_TEST_PASS_P_ZPIPE14", "HIZ DEPTH TEST PASS P ZPIPE14",
                          "Number of promoted 2x2 passed by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02022222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e037c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a033fe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x400303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190b0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0b0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt583MetricSet::CExt583MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt583MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "HIZ_DEPTH_TEST_PASS_P_ZPIPE15", "HIZ DEPTH TEST PASS P ZPIPE15",
                          "Number of promoted 2x2 passed by hierarchical depth test",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02022222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0305e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190c0017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03072222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010955ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010255ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c002c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070c3800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0c0185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0c0007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150c000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt584MetricSet::CExt584MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt584MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "IZ_OUTPUT_READY_ZPIPE0", "IZ OUTPUT READY ZPIPE0",
                          "Percentage of time in which IZ has requests to different clients",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "IZ_OUTPUT_READY_ZPIPE1", "IZ OUTPUT READY ZPIPE1",
                          "Percentage of time in which IZ has requests to different clients",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "IZ_OUTPUT_READY_ZPIPE2", "IZ OUTPUT READY ZPIPE2",
                          "Percentage of time in which IZ has requests to different clients",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "IZ_OUTPUT_READY_ZPIPE3", "IZ OUTPUT READY ZPIPE3",
                          "Percentage of time in which IZ has requests to different clients",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "IZ_OUTPUT_READY_ZPIPE4", "IZ OUTPUT READY ZPIPE4",
                          "Percentage of time in which IZ has requests to different clients",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "IZ_OUTPUT_READY_ZPIPE5", "IZ OUTPUT READY ZPIPE5",
                          "Percentage of time in which IZ has requests to different clients",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "IZ_OUTPUT_READY_ZPIPE6", "IZ OUTPUT READY ZPIPE6",
                          "Percentage of time in which IZ has requests to different clients",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "IZ_OUTPUT_READY_ZPIPE7", "IZ OUTPUT READY ZPIPE7",
                          "Percentage of time in which IZ has requests to different clients",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "IZ_OUTPUT_READY_ZPIPE8", "IZ OUTPUT READY ZPIPE8",
                          "Percentage of time in which IZ has requests to different clients",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "IZ_OUTPUT_READY_ZPIPE9", "IZ OUTPUT READY ZPIPE9",
                          "Percentage of time in which IZ has requests to different clients",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "IZ_OUTPUT_READY_ZPIPE10", "IZ OUTPUT READY ZPIPE10",
                          "Percentage of time in which IZ has requests to different clients",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "IZ_OUTPUT_READY_ZPIPE11", "IZ OUTPUT READY ZPIPE11",
                          "Percentage of time in which IZ has requests to different clients",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "IZ_OUTPUT_READY_ZPIPE12", "IZ OUTPUT READY ZPIPE12",
                          "Percentage of time in which IZ has requests to different clients",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "IZ_OUTPUT_READY_ZPIPE13", "IZ OUTPUT READY ZPIPE13",
                          "Percentage of time in which IZ has requests to different clients",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "IZ_OUTPUT_READY_ZPIPE14", "IZ OUTPUT READY ZPIPE14",
                          "Percentage of time in which IZ has requests to different clients",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "IZ_OUTPUT_READY_ZPIPE15", "IZ OUTPUT READY ZPIPE15",
                          "Percentage of time in which IZ has requests to different clients",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02072000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208cf00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00094000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a6500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140b0580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00024000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140c0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03080c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01091000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01012000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01021000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800cf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0065, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b0580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100c0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0c0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0b6580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0c6016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00072000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008cf00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a6500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800cf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0065, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b5800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070c0160, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000255aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032449, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030520, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032061, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46031063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032481, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt585MetricSet::CExt585MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt585MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "HIZ_SUBSPAN_LATENCY_FIFOFULL_ZPIPE0", "HIZ SUBSPAN LATENCY FIFOFULL ZPIPE0",
                          "Percentage of time in which HiZ latency hiding structure full",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "HIZ_SUBSPAN_LATENCY_FIFOFULL_ZPIPE1", "HIZ SUBSPAN LATENCY FIFOFULL ZPIPE1",
                          "Percentage of time in which HiZ latency hiding structure full",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "HIZ_SUBSPAN_LATENCY_FIFOFULL_ZPIPE2", "HIZ SUBSPAN LATENCY FIFOFULL ZPIPE2",
                          "Percentage of time in which HiZ latency hiding structure full",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "HIZ_SUBSPAN_LATENCY_FIFOFULL_ZPIPE3", "HIZ SUBSPAN LATENCY FIFOFULL ZPIPE3",
                          "Percentage of time in which HiZ latency hiding structure full",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "HIZ_SUBSPAN_LATENCY_FIFOFULL_ZPIPE4", "HIZ SUBSPAN LATENCY FIFOFULL ZPIPE4",
                          "Percentage of time in which HiZ latency hiding structure full",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "HIZ_SUBSPAN_LATENCY_FIFOFULL_ZPIPE5", "HIZ SUBSPAN LATENCY FIFOFULL ZPIPE5",
                          "Percentage of time in which HiZ latency hiding structure full",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "HIZ_SUBSPAN_LATENCY_FIFOFULL_ZPIPE6", "HIZ SUBSPAN LATENCY FIFOFULL ZPIPE6",
                          "Percentage of time in which HiZ latency hiding structure full",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "HIZ_SUBSPAN_LATENCY_FIFOFULL_ZPIPE7", "HIZ SUBSPAN LATENCY FIFOFULL ZPIPE7",
                          "Percentage of time in which HiZ latency hiding structure full",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "HIZ_SUBSPAN_LATENCY_FIFOFULL_ZPIPE8", "HIZ SUBSPAN LATENCY FIFOFULL ZPIPE8",
                          "Percentage of time in which HiZ latency hiding structure full",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "HIZ_SUBSPAN_LATENCY_FIFOFULL_ZPIPE9", "HIZ SUBSPAN LATENCY FIFOFULL ZPIPE9",
                          "Percentage of time in which HiZ latency hiding structure full",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "HIZ_SUBSPAN_LATENCY_FIFOFULL_ZPIPE10", "HIZ SUBSPAN LATENCY FIFOFULL ZPIPE10",
                          "Percentage of time in which HiZ latency hiding structure full",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "HIZ_SUBSPAN_LATENCY_FIFOFULL_ZPIPE11", "HIZ SUBSPAN LATENCY FIFOFULL ZPIPE11",
                          "Percentage of time in which HiZ latency hiding structure full",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "HIZ_SUBSPAN_LATENCY_FIFOFULL_ZPIPE12", "HIZ SUBSPAN LATENCY FIFOFULL ZPIPE12",
                          "Percentage of time in which HiZ latency hiding structure full",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "HIZ_SUBSPAN_LATENCY_FIFOFULL_ZPIPE13", "HIZ SUBSPAN LATENCY FIFOFULL ZPIPE13",
                          "Percentage of time in which HiZ latency hiding structure full",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "HIZ_SUBSPAN_LATENCY_FIFOFULL_ZPIPE14", "HIZ SUBSPAN LATENCY FIFOFULL ZPIPE14",
                          "Percentage of time in which HiZ latency hiding structure full",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "HIZ_SUBSPAN_LATENCY_FIFOFULL_ZPIPE15", "HIZ SUBSPAN LATENCY FIFOFULL ZPIPE15",
                          "Percentage of time in which HiZ latency hiding structure full",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160c2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170c2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02072000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208cf00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00094000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a6500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140b0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00024000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03080c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01091000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01012000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01021000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160c2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170c2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800cf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0065, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160c2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170c2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00072000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008cf00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a6500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0b0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160b2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160c2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170b2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170c2c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800cf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0065, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070c0020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000255aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032449, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030520, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032061, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46031063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032481, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt586MetricSet::CExt586MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt586MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "IZ_SUBSPAN_LATENCY_FIFOFULL_ZPIPE0", "IZ SUBSPAN LATENCY FIFOFULL ZPIPE0",
                          "Percentage of time in which IZ latency hiding structure full",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "IZ_SUBSPAN_LATENCY_FIFOFULL_ZPIPE1", "IZ SUBSPAN LATENCY FIFOFULL ZPIPE1",
                          "Percentage of time in which IZ latency hiding structure full",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "IZ_SUBSPAN_LATENCY_FIFOFULL_ZPIPE2", "IZ SUBSPAN LATENCY FIFOFULL ZPIPE2",
                          "Percentage of time in which IZ latency hiding structure full",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "IZ_SUBSPAN_LATENCY_FIFOFULL_ZPIPE3", "IZ SUBSPAN LATENCY FIFOFULL ZPIPE3",
                          "Percentage of time in which IZ latency hiding structure full",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "IZ_SUBSPAN_LATENCY_FIFOFULL_ZPIPE4", "IZ SUBSPAN LATENCY FIFOFULL ZPIPE4",
                          "Percentage of time in which IZ latency hiding structure full",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "IZ_SUBSPAN_LATENCY_FIFOFULL_ZPIPE5", "IZ SUBSPAN LATENCY FIFOFULL ZPIPE5",
                          "Percentage of time in which IZ latency hiding structure full",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "IZ_SUBSPAN_LATENCY_FIFOFULL_ZPIPE6", "IZ SUBSPAN LATENCY FIFOFULL ZPIPE6",
                          "Percentage of time in which IZ latency hiding structure full",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "IZ_SUBSPAN_LATENCY_FIFOFULL_ZPIPE7", "IZ SUBSPAN LATENCY FIFOFULL ZPIPE7",
                          "Percentage of time in which IZ latency hiding structure full",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "IZ_SUBSPAN_LATENCY_FIFOFULL_ZPIPE8", "IZ SUBSPAN LATENCY FIFOFULL ZPIPE8",
                          "Percentage of time in which IZ latency hiding structure full",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "IZ_SUBSPAN_LATENCY_FIFOFULL_ZPIPE9", "IZ SUBSPAN LATENCY FIFOFULL ZPIPE9",
                          "Percentage of time in which IZ latency hiding structure full",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "IZ_SUBSPAN_LATENCY_FIFOFULL_ZPIPE10", "IZ SUBSPAN LATENCY FIFOFULL ZPIPE10",
                          "Percentage of time in which IZ latency hiding structure full",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "IZ_SUBSPAN_LATENCY_FIFOFULL_ZPIPE11", "IZ SUBSPAN LATENCY FIFOFULL ZPIPE11",
                          "Percentage of time in which IZ latency hiding structure full",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "IZ_SUBSPAN_LATENCY_FIFOFULL_ZPIPE12", "IZ SUBSPAN LATENCY FIFOFULL ZPIPE12",
                          "Percentage of time in which IZ latency hiding structure full",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "IZ_SUBSPAN_LATENCY_FIFOFULL_ZPIPE13", "IZ SUBSPAN LATENCY FIFOFULL ZPIPE13",
                          "Percentage of time in which IZ latency hiding structure full",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "IZ_SUBSPAN_LATENCY_FIFOFULL_ZPIPE14", "IZ SUBSPAN LATENCY FIFOFULL ZPIPE14",
                          "Percentage of time in which IZ latency hiding structure full",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "IZ_SUBSPAN_LATENCY_FIFOFULL_ZPIPE15", "IZ SUBSPAN LATENCY FIFOFULL ZPIPE15",
                          "Percentage of time in which IZ latency hiding structure full",
                          "DepthPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02072000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208cf00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00094000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a6500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001b000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140b0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00024000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140c0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03080c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01091000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01012000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130b0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01021000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130c0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b6540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100c6015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800cf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0065, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010b00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0b0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0c0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00072000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008cf00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a6500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0b0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0c0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0b0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0c0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110b6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110c6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800cf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0065, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080b0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080c0015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050b0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070b5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050c0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070c0150, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000255aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032449, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030520, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032061, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46031063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032481, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt587MetricSet::CExt587MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt587MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "COLOR_PIPE_CACHE_LATENCY1_STALL_CPIPE0", "COLOR PIPE CACHE LATENCY1 STALL CPIPE0",
                          "Percentage of time in which Color Pipeline stalled due to MultiSampling Cache latency hiding structure full",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "COLOR_PIPE_CACHE_LATENCY1_STALL_CPIPE1", "COLOR PIPE CACHE LATENCY1 STALL CPIPE1",
                          "Percentage of time in which Color Pipeline stalled due to MultiSampling Cache latency hiding structure full",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "COLOR_PIPE_CACHE_LATENCY1_STALL_CPIPE2", "COLOR PIPE CACHE LATENCY1 STALL CPIPE2",
                          "Percentage of time in which Color Pipeline stalled due to MultiSampling Cache latency hiding structure full",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "COLOR_PIPE_CACHE_LATENCY1_STALL_CPIPE3", "COLOR PIPE CACHE LATENCY1 STALL CPIPE3",
                          "Percentage of time in which Color Pipeline stalled due to MultiSampling Cache latency hiding structure full",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "COLOR_PIPE_CACHE_LATENCY1_STALL_CPIPE4", "COLOR PIPE CACHE LATENCY1 STALL CPIPE4",
                          "Percentage of time in which Color Pipeline stalled due to MultiSampling Cache latency hiding structure full",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "COLOR_PIPE_CACHE_LATENCY1_STALL_CPIPE5", "COLOR PIPE CACHE LATENCY1 STALL CPIPE5",
                          "Percentage of time in which Color Pipeline stalled due to MultiSampling Cache latency hiding structure full",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "COLOR_PIPE_CACHE_LATENCY1_STALL_CPIPE6", "COLOR PIPE CACHE LATENCY1 STALL CPIPE6",
                          "Percentage of time in which Color Pipeline stalled due to MultiSampling Cache latency hiding structure full",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "COLOR_PIPE_CACHE_LATENCY1_STALL_CPIPE7", "COLOR PIPE CACHE LATENCY1 STALL CPIPE7",
                          "Percentage of time in which Color Pipeline stalled due to MultiSampling Cache latency hiding structure full",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "COLOR_PIPE_CACHE_LATENCY1_STALL_CPIPE8", "COLOR PIPE CACHE LATENCY1 STALL CPIPE8",
                          "Percentage of time in which Color Pipeline stalled due to MultiSampling Cache latency hiding structure full",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "COLOR_PIPE_CACHE_LATENCY1_STALL_CPIPE9", "COLOR PIPE CACHE LATENCY1 STALL CPIPE9",
                          "Percentage of time in which Color Pipeline stalled due to MultiSampling Cache latency hiding structure full",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "COLOR_PIPE_CACHE_LATENCY1_STALL_CPIPE10", "COLOR PIPE CACHE LATENCY1 STALL CPIPE10",
                          "Percentage of time in which Color Pipeline stalled due to MultiSampling Cache latency hiding structure full",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "COLOR_PIPE_CACHE_LATENCY1_STALL_CPIPE11", "COLOR PIPE CACHE LATENCY1 STALL CPIPE11",
                          "Percentage of time in which Color Pipeline stalled due to MultiSampling Cache latency hiding structure full",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "COLOR_PIPE_CACHE_LATENCY1_STALL_CPIPE12", "COLOR PIPE CACHE LATENCY1 STALL CPIPE12",
                          "Percentage of time in which Color Pipeline stalled due to MultiSampling Cache latency hiding structure full",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "COLOR_PIPE_CACHE_LATENCY1_STALL_CPIPE13", "COLOR PIPE CACHE LATENCY1 STALL CPIPE13",
                          "Percentage of time in which Color Pipeline stalled due to MultiSampling Cache latency hiding structure full",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "COLOR_PIPE_CACHE_LATENCY1_STALL_CPIPE14", "COLOR PIPE CACHE LATENCY1 STALL CPIPE14",
                          "Percentage of time in which Color Pipeline stalled due to MultiSampling Cache latency hiding structure full",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "COLOR_PIPE_CACHE_LATENCY1_STALL_CPIPE15", "COLOR PIPE CACHE LATENCY1 STALL CPIPE15",
                          "Percentage of time in which Color Pipeline stalled due to MultiSampling Cache latency hiding structure full",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12011000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12021c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13011030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13021000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02072000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208cf00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00094000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a6500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14010030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00013000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03080c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01091000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11020c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12011000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12021000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13011000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13021000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800cf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0065, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10010030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e020c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f010030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d020c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12011000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12021000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13011000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13021000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00072000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008cf00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a6500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c010030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a020c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b010030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09020c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12011000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12021000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13011000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13021000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800cf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0065, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08010030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06020c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07010030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05021800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000255aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032449, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030520, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032061, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46031063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032481, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt588MetricSet::CExt588MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt588MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "PS_OUTPUT_AVAILABLE_CPIPE0", "PS OUTPUT AVAILABLE CPIPE0",
                          "Percentage of time in which Pixel Shader data is available",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "PS_OUTPUT_AVAILABLE_CPIPE1", "PS OUTPUT AVAILABLE CPIPE1",
                          "Percentage of time in which Pixel Shader data is available",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "PS_OUTPUT_AVAILABLE_CPIPE2", "PS OUTPUT AVAILABLE CPIPE2",
                          "Percentage of time in which Pixel Shader data is available",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "PS_OUTPUT_AVAILABLE_CPIPE3", "PS OUTPUT AVAILABLE CPIPE3",
                          "Percentage of time in which Pixel Shader data is available",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "PS_OUTPUT_AVAILABLE_CPIPE4", "PS OUTPUT AVAILABLE CPIPE4",
                          "Percentage of time in which Pixel Shader data is available",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "PS_OUTPUT_AVAILABLE_CPIPE5", "PS OUTPUT AVAILABLE CPIPE5",
                          "Percentage of time in which Pixel Shader data is available",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "PS_OUTPUT_AVAILABLE_CPIPE6", "PS OUTPUT AVAILABLE CPIPE6",
                          "Percentage of time in which Pixel Shader data is available",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "PS_OUTPUT_AVAILABLE_CPIPE7", "PS OUTPUT AVAILABLE CPIPE7",
                          "Percentage of time in which Pixel Shader data is available",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18010320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18020320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19010320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19020320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a55a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04011100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06010021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06020880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08020021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09010880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b010021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b020880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d020021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18010320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18020320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19010320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19020320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ff0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a55a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c010880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e010021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e020880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10020021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03080f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aa500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11010880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13010021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13020880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15020021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0300e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt589MetricSet::CExt589MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt589MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "PS_OUTPUT_AVAILABLE_CPIPE8", "PS OUTPUT AVAILABLE CPIPE8",
                          "Percentage of time in which Pixel Shader data is available",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "PS_OUTPUT_AVAILABLE_CPIPE9", "PS OUTPUT AVAILABLE CPIPE9",
                          "Percentage of time in which Pixel Shader data is available",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "PS_OUTPUT_AVAILABLE_CPIPE10", "PS OUTPUT AVAILABLE CPIPE10",
                          "Percentage of time in which Pixel Shader data is available",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "PS_OUTPUT_AVAILABLE_CPIPE11", "PS OUTPUT AVAILABLE CPIPE11",
                          "Percentage of time in which Pixel Shader data is available",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "PS_OUTPUT_AVAILABLE_CPIPE12", "PS OUTPUT AVAILABLE CPIPE12",
                          "Percentage of time in which Pixel Shader data is available",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "PS_OUTPUT_AVAILABLE_CPIPE13", "PS OUTPUT AVAILABLE CPIPE13",
                          "Percentage of time in which Pixel Shader data is available",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "PS_OUTPUT_AVAILABLE_CPIPE14", "PS OUTPUT AVAILABLE CPIPE14",
                          "Percentage of time in which Pixel Shader data is available",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "PS_OUTPUT_AVAILABLE_CPIPE15", "PS OUTPUT AVAILABLE CPIPE15",
                          "Percentage of time in which Pixel Shader data is available",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18010320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18020320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19010320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19020320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a55a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04011100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06010021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06020880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08020021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09010880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b010021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b020880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d020021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18010320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18020320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19010320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19020320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020700a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ff0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a55a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c010880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e010021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e020880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10020021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03080f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aa500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11010880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13010021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13020880, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15020021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0300e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt590MetricSet::CExt590MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt590MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "PIXEL_POST_PROCESS_OUTPUT_READY_CPIPE0", "PIXEL POST PROCESS OUTPUT READY CPIPE0",
                          "Percentage of time in which Color Pipeline pixel output ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "pixel|fragment", nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "PIXEL_POST_PROCESS_OUTPUT_READY_CPIPE1", "PIXEL POST PROCESS OUTPUT READY CPIPE1",
                          "Percentage of time in which Color Pipeline pixel output ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "pixel|fragment", nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "PIXEL_POST_PROCESS_OUTPUT_READY_CPIPE2", "PIXEL POST PROCESS OUTPUT READY CPIPE2",
                          "Percentage of time in which Color Pipeline pixel output ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "pixel|fragment", nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "PIXEL_POST_PROCESS_OUTPUT_READY_CPIPE3", "PIXEL POST PROCESS OUTPUT READY CPIPE3",
                          "Percentage of time in which Color Pipeline pixel output ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "pixel|fragment", nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "PIXEL_POST_PROCESS_OUTPUT_READY_CPIPE4", "PIXEL POST PROCESS OUTPUT READY CPIPE4",
                          "Percentage of time in which Color Pipeline pixel output ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "pixel|fragment", nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "PIXEL_POST_PROCESS_OUTPUT_READY_CPIPE5", "PIXEL POST PROCESS OUTPUT READY CPIPE5",
                          "Percentage of time in which Color Pipeline pixel output ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "pixel|fragment", nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "PIXEL_POST_PROCESS_OUTPUT_READY_CPIPE6", "PIXEL POST PROCESS OUTPUT READY CPIPE6",
                          "Percentage of time in which Color Pipeline pixel output ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "pixel|fragment", nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "PIXEL_POST_PROCESS_OUTPUT_READY_CPIPE7", "PIXEL POST PROCESS OUTPUT READY CPIPE7",
                          "Percentage of time in which Color Pipeline pixel output ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "pixel|fragment", nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "PIXEL_POST_PROCESS_OUTPUT_READY_CPIPE8", "PIXEL POST PROCESS OUTPUT READY CPIPE8",
                          "Percentage of time in which Color Pipeline pixel output ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "pixel|fragment", nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "PIXEL_POST_PROCESS_OUTPUT_READY_CPIPE9", "PIXEL POST PROCESS OUTPUT READY CPIPE9",
                          "Percentage of time in which Color Pipeline pixel output ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "pixel|fragment", nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "PIXEL_POST_PROCESS_OUTPUT_READY_CPIPE10", "PIXEL POST PROCESS OUTPUT READY CPIPE10",
                          "Percentage of time in which Color Pipeline pixel output ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "pixel|fragment", nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "PIXEL_POST_PROCESS_OUTPUT_READY_CPIPE11", "PIXEL POST PROCESS OUTPUT READY CPIPE11",
                          "Percentage of time in which Color Pipeline pixel output ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "pixel|fragment", nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "PIXEL_POST_PROCESS_OUTPUT_READY_CPIPE12", "PIXEL POST PROCESS OUTPUT READY CPIPE12",
                          "Percentage of time in which Color Pipeline pixel output ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "pixel|fragment", nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "PIXEL_POST_PROCESS_OUTPUT_READY_CPIPE13", "PIXEL POST PROCESS OUTPUT READY CPIPE13",
                          "Percentage of time in which Color Pipeline pixel output ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "pixel|fragment", nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "PIXEL_POST_PROCESS_OUTPUT_READY_CPIPE14", "PIXEL POST PROCESS OUTPUT READY CPIPE14",
                          "Percentage of time in which Color Pipeline pixel output ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "pixel|fragment", nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "PIXEL_POST_PROCESS_OUTPUT_READY_CPIPE15", "PIXEL POST PROCESS OUTPUT READY CPIPE15",
                          "Percentage of time in which Color Pipeline pixel output ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "pixel|fragment", nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16010003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16020003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17010003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17020003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02072000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208cf00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00094000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a6500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14010017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00013000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120205c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03080c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01091000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13010017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110205c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16010003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16020003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17010003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17020003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800cf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0065, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10010017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0205c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f010017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0205c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16010003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16020003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17010003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17020003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00072000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008cf00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a6500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c010017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0205c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b010017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090205c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16010003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16020003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17010003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17020003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800cf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0065, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08010017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060205c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07010017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05020b80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000255aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032449, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030520, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032061, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46031063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032481, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt591MetricSet::CExt591MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt591MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "PIXEL_POST_PROCESS_INPUT_AVAILABLE_CPIPE0", "PIXEL POST PROCESS INPUT AVAILABLE CPIPE0",
                          "Percentage of time in which Color Pipeline input ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "PIXEL_POST_PROCESS_INPUT_AVAILABLE_CPIPE1", "PIXEL POST PROCESS INPUT AVAILABLE CPIPE1",
                          "Percentage of time in which Color Pipeline input ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20860011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20a60011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c60011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20e60011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04860180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06862800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08860595, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a860017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a60180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca60595, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea60017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c60180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c60595, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c60017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e60180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e60595, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e60017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000007f8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ff00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0007f800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x000000ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt592MetricSet::CExt592MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt592MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "PIXEL_POST_PROCESS_INPUT_AVAILABLE_CPIPE2", "PIXEL POST PROCESS INPUT AVAILABLE CPIPE2",
                          "Percentage of time in which Color Pipeline input ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "PIXEL_POST_PROCESS_INPUT_AVAILABLE_CPIPE3", "PIXEL POST PROCESS INPUT AVAILABLE CPIPE3",
                          "Percentage of time in which Color Pipeline input ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21860011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21a60011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21c60011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21e60011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05860180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07862800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09860595, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b860017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a60180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da60595, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa60017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c60180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c60595, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c60017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e60180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e60595, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e60017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000007f8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ff00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0007f800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x000000ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt593MetricSet::CExt593MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt593MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "PIXEL_POST_PROCESS_INPUT_AVAILABLE_CPIPE4", "PIXEL POST PROCESS INPUT AVAILABLE CPIPE4",
                          "Percentage of time in which Color Pipeline input ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "PIXEL_POST_PROCESS_INPUT_AVAILABLE_CPIPE5", "PIXEL POST PROCESS INPUT AVAILABLE CPIPE5",
                          "Percentage of time in which Color Pipeline input ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20860011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20a60011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c60011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20e60011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04860180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06862800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08860595, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a860017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a60180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca60595, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea60017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c60180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c60595, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c60017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e60180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e60595, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e60017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000007f8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ff00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0007f800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x000000ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt594MetricSet::CExt594MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt594MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "PIXEL_POST_PROCESS_INPUT_AVAILABLE_CPIPE6", "PIXEL POST PROCESS INPUT AVAILABLE CPIPE6",
                          "Percentage of time in which Color Pipeline input ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "PIXEL_POST_PROCESS_INPUT_AVAILABLE_CPIPE7", "PIXEL POST PROCESS INPUT AVAILABLE CPIPE7",
                          "Percentage of time in which Color Pipeline input ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21860011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21a60011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21c60011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21e60011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05860180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07862800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09860595, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b860017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a60180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da60595, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa60017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c60180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c60595, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c60017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e60180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e60595, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e60017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000007f8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ff00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0007f800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x000000ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt595MetricSet::CExt595MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt595MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "PIXEL_POST_PROCESS_INPUT_AVAILABLE_CPIPE8", "PIXEL POST PROCESS INPUT AVAILABLE CPIPE8",
                          "Percentage of time in which Color Pipeline input ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "PIXEL_POST_PROCESS_INPUT_AVAILABLE_CPIPE9", "PIXEL POST PROCESS INPUT AVAILABLE CPIPE9",
                          "Percentage of time in which Color Pipeline input ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20860011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20a60011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c60011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20e60011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04860180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06862800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08860595, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a860017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a60180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca60595, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea60017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c60180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c60595, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c60017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e60180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e60595, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e60017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000007f8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ff00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0007f800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x000000ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt596MetricSet::CExt596MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt596MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "PIXEL_POST_PROCESS_INPUT_AVAILABLE_CPIPE10", "PIXEL POST PROCESS INPUT AVAILABLE CPIPE10",
                          "Percentage of time in which Color Pipeline input ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "PIXEL_POST_PROCESS_INPUT_AVAILABLE_CPIPE11", "PIXEL POST PROCESS INPUT AVAILABLE CPIPE11",
                          "Percentage of time in which Color Pipeline input ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21860011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21a60011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21c60011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21e60011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05860180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07862800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09860595, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b860017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a60180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da60595, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa60017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c60180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c60595, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c60017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e60180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e60595, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e60017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000007f8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ff00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0007f800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x000000ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt597MetricSet::CExt597MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt597MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "PIXEL_POST_PROCESS_INPUT_AVAILABLE_CPIPE12", "PIXEL POST PROCESS INPUT AVAILABLE CPIPE12",
                          "Percentage of time in which Color Pipeline input ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "PIXEL_POST_PROCESS_INPUT_AVAILABLE_CPIPE13", "PIXEL POST PROCESS INPUT AVAILABLE CPIPE13",
                          "Percentage of time in which Color Pipeline input ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20860011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20a60011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20c60011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20e60011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04860180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06862800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08860595, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a860017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a60180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca60595, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea60017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c60180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c60595, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c60017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e60180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e60595, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e60017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000007f8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ff00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0007f800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x000000ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt598MetricSet::CExt598MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt598MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "PIXEL_POST_PROCESS_INPUT_AVAILABLE_CPIPE14", "PIXEL POST PROCESS INPUT AVAILABLE CPIPE14",
                          "Percentage of time in which Color Pipeline input ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "PIXEL_POST_PROCESS_INPUT_AVAILABLE_CPIPE15", "PIXEL POST PROCESS INPUT AVAILABLE CPIPE15",
                          "Percentage of time in which Color Pipeline input ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21860011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21a60011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21c60011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x21e60011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05860180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07862800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09860595, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b860017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a60180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da60595, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa60017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c60180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c60595, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c60017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e60180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e60595, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e60017, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030755aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203084a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030062, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000007f8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ff00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0007f800, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x000000ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt599MetricSet::CExt599MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt599MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "AMFS_STALL_ALL_INPUT_SLICE0", "AMFS STALL ALL INPUT SLICE0",
                          "Percentage of time in which AMFS stalls at both of the color pipe inputs",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "AMFS_STALL_ANY_INPUT_SLICE0", "AMFS STALL ANY INPUT SLICE0",
                          "Percentage of time in which AMFS stalls at any of the color pipe inputs",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "AMFS_CACHE_HIT_SLICE0", "AMFS CACHE HIT SLICE0",
                          "Number of hits in the AMFS cache",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "AMFS_CACHE_MISS_SLICE0", "AMFS CACHE MISS SLICE0",
                          "Number of cache misses in AMFS",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_HIT_L3NODE0", "RENDER CACHE HIT L3NODE0",
                          "Number of Render Cache hits",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_READ_L3NODE0", "RENDER CACHE READ L3NODE0",
                          "Number of Render Cache reads",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_WRITE_L3NODE0", "RENDER CACHE WRITE L3NODE0",
                          "Number of Render Cache writes",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_INPUT_AVAILABLE_L3NODE0", "RENDER_CACHE_INPUT_AVAILABLE _L3NODE0",
                          "Percentage of time when render cache input is available",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_OUTPUT_READY_L3NODE0", "RENDER_CACHE_OUTPUT_READY _L3NODE0",
                          "Percentage of time when render cache output is ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14060700, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1606001a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02060010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06060081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080603c3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a06034e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00081555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a1555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14087800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16087840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080126, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001007f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080438, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080ba7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032490, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x400314a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00100030, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x0000007a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000282, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ff8f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ff8f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fff3, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt600MetricSet::CExt600MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt600MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "AMFS_STALL_ALL_INPUT_SLICE1", "AMFS STALL ALL INPUT SLICE1",
                          "Percentage of time in which AMFS stalls at both of the color pipe inputs",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "AMFS_STALL_ANY_INPUT_SLICE1", "AMFS STALL ANY INPUT SLICE1",
                          "Percentage of time in which AMFS stalls at any of the color pipe inputs",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "AMFS_CACHE_HIT_SLICE1", "AMFS CACHE HIT SLICE1",
                          "Number of hits in the AMFS cache",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "AMFS_CACHE_MISS_SLICE1", "AMFS CACHE MISS SLICE1",
                          "Number of cache misses in AMFS",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_HIT_L3NODE1", "RENDER CACHE HIT L3NODE1",
                          "Number of Render Cache hits",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_READ_L3NODE1", "RENDER CACHE READ L3NODE1",
                          "Number of Render Cache reads",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_WRITE_L3NODE1", "RENDER CACHE WRITE L3NODE1",
                          "Number of Render Cache writes",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_INPUT_AVAILABLE_L3NODE1", "RENDER_CACHE_INPUT_AVAILABLE _L3NODE1",
                          "Percentage of time when render cache input is available",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_OUTPUT_READY_L3NODE1", "RENDER_CACHE_OUTPUT_READY _L3NODE1",
                          "Percentage of time when render cache output is ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15060700, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1706001a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003007f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00083fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a1555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001007f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b2aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03060010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07060081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090603c3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b06034e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01081555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a1555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16037840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030126, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001007f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e030c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10030438, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030ba7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032490, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2003f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00100030, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x0000007a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000282, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ff8f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ff8f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fff3, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt601MetricSet::CExt601MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt601MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "AMFS_STALL_ALL_INPUT_SLICE2", "AMFS STALL ALL INPUT SLICE2",
                          "Percentage of time in which AMFS stalls at both of the color pipe inputs",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "AMFS_STALL_ANY_INPUT_SLICE2", "AMFS STALL ANY INPUT SLICE2",
                          "Percentage of time in which AMFS stalls at any of the color pipe inputs",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "AMFS_CACHE_HIT_SLICE2", "AMFS CACHE HIT SLICE2",
                          "Number of hits in the AMFS cache",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "AMFS_CACHE_MISS_SLICE2", "AMFS CACHE MISS SLICE2",
                          "Number of cache misses in AMFS",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_HIT_L3NODE2", "RENDER CACHE HIT L3NODE2",
                          "Number of Render Cache hits",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_READ_L3NODE2", "RENDER CACHE READ L3NODE2",
                          "Number of Render Cache reads",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_WRITE_L3NODE2", "RENDER CACHE WRITE L3NODE2",
                          "Number of Render Cache writes",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_INPUT_AVAILABLE_L3NODE2", "RENDER_CACHE_INPUT_AVAILABLE _L3NODE2",
                          "Percentage of time when render cache input is available",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_OUTPUT_READY_L3NODE2", "RENDER_CACHE_OUTPUT_READY _L3NODE2",
                          "Percentage of time when render cache output is ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14060700, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1606001a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02060010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06060081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080603c3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a06034e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00081555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a1555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14087800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16087840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080126, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001007f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080438, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080ba7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00083fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032490, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x400314a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00100030, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x0000007a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000282, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ff8f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ff8f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fff3, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt602MetricSet::CExt602MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt602MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "AMFS_STALL_ALL_INPUT_SLICE3", "AMFS STALL ALL INPUT SLICE3",
                          "Percentage of time in which AMFS stalls at both of the color pipe inputs",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "AMFS_STALL_ANY_INPUT_SLICE3", "AMFS STALL ANY INPUT SLICE3",
                          "Percentage of time in which AMFS stalls at any of the color pipe inputs",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "AMFS_CACHE_HIT_SLICE3", "AMFS CACHE HIT SLICE3",
                          "Number of hits in the AMFS cache",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "AMFS_CACHE_MISS_SLICE3", "AMFS CACHE MISS SLICE3",
                          "Number of cache misses in AMFS",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_HIT_L3NODE3", "RENDER CACHE HIT L3NODE3",
                          "Number of Render Cache hits",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_READ_L3NODE3", "RENDER CACHE READ L3NODE3",
                          "Number of Render Cache reads",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_WRITE_L3NODE3", "RENDER CACHE WRITE L3NODE3",
                          "Number of Render Cache writes",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_INPUT_AVAILABLE_L3NODE3", "RENDER_CACHE_INPUT_AVAILABLE _L3NODE3",
                          "Percentage of time when render cache input is available",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_OUTPUT_READY_L3NODE3", "RENDER_CACHE_OUTPUT_READY _L3NODE3",
                          "Percentage of time when render cache output is ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15060700, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1706001a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003007f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00083fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a1555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001007f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b2aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03060010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07060081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090603c3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b06034e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01081555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a1555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16037840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030126, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001007f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e030c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10030438, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030ba7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00083fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032490, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2003f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00100030, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x0000007a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000282, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ff8f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ff8f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fff3, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt603MetricSet::CExt603MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt603MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "AMFS_STALL_ALL_INPUT_SLICE4", "AMFS STALL ALL INPUT SLICE4",
                          "Percentage of time in which AMFS stalls at both of the color pipe inputs",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "AMFS_STALL_ANY_INPUT_SLICE4", "AMFS STALL ANY INPUT SLICE4",
                          "Percentage of time in which AMFS stalls at any of the color pipe inputs",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "AMFS_CACHE_HIT_SLICE4", "AMFS CACHE HIT SLICE4",
                          "Number of hits in the AMFS cache",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "AMFS_CACHE_MISS_SLICE4", "AMFS CACHE MISS SLICE4",
                          "Number of cache misses in AMFS",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_HIT_L3NODE4", "RENDER CACHE HIT L3NODE4",
                          "Number of Render Cache hits",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_READ_L3NODE4", "RENDER CACHE READ L3NODE4",
                          "Number of Render Cache reads",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_WRITE_L3NODE4", "RENDER CACHE WRITE L3NODE4",
                          "Number of Render Cache writes",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_INPUT_AVAILABLE_L3NODE4", "RENDER_CACHE_INPUT_AVAILABLE _L3NODE4",
                          "Percentage of time when render cache input is available",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_OUTPUT_READY_L3NODE4", "RENDER_CACHE_OUTPUT_READY _L3NODE4",
                          "Percentage of time when render cache output is ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14060700, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1606001a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02060010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06060081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080603c3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a06034e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00081555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a1555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14087800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16087840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080126, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001007f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080438, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080ba7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x400314a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00100030, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x0000007a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000282, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ff8f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ff8f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fff3, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt604MetricSet::CExt604MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt604MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "AMFS_STALL_ALL_INPUT_SLICE5", "AMFS STALL ALL INPUT SLICE5",
                          "Percentage of time in which AMFS stalls at both of the color pipe inputs",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "AMFS_STALL_ANY_INPUT_SLICE5", "AMFS STALL ANY INPUT SLICE5",
                          "Percentage of time in which AMFS stalls at any of the color pipe inputs",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "AMFS_CACHE_HIT_SLICE5", "AMFS CACHE HIT SLICE5",
                          "Number of hits in the AMFS cache",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "AMFS_CACHE_MISS_SLICE5", "AMFS CACHE MISS SLICE5",
                          "Number of cache misses in AMFS",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_HIT_L3NODE5", "RENDER CACHE HIT L3NODE5",
                          "Number of Render Cache hits",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_READ_L3NODE5", "RENDER CACHE READ L3NODE5",
                          "Number of Render Cache reads",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_WRITE_L3NODE5", "RENDER CACHE WRITE L3NODE5",
                          "Number of Render Cache writes",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_INPUT_AVAILABLE_L3NODE5", "RENDER_CACHE_INPUT_AVAILABLE _L3NODE5",
                          "Percentage of time when render cache input is available",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_OUTPUT_READY_L3NODE5", "RENDER_CACHE_OUTPUT_READY _L3NODE5",
                          "Percentage of time when render cache output is ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15060700, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1706001a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003007f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00083fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a1555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001007f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b2aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03060010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07060081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090603c3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b06034e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01081555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a1555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16037840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030126, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001007f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e030c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10030438, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030ba7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2003f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00100030, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x0000007a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000282, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ff8f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ff8f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fff3, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt605MetricSet::CExt605MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt605MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "AMFS_STALL_ALL_INPUT_SLICE6", "AMFS STALL ALL INPUT SLICE6",
                          "Percentage of time in which AMFS stalls at both of the color pipe inputs",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "AMFS_STALL_ANY_INPUT_SLICE6", "AMFS STALL ANY INPUT SLICE6",
                          "Percentage of time in which AMFS stalls at any of the color pipe inputs",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "AMFS_CACHE_HIT_SLICE6", "AMFS CACHE HIT SLICE6",
                          "Number of hits in the AMFS cache",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "AMFS_CACHE_MISS_SLICE6", "AMFS CACHE MISS SLICE6",
                          "Number of cache misses in AMFS",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_HIT_L3NODE6", "RENDER CACHE HIT L3NODE6",
                          "Number of Render Cache hits",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_READ_L3NODE6", "RENDER CACHE READ L3NODE6",
                          "Number of Render Cache reads",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_WRITE_L3NODE6", "RENDER CACHE WRITE L3NODE6",
                          "Number of Render Cache writes",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_INPUT_AVAILABLE_L3NODE6", "RENDER_CACHE_INPUT_AVAILABLE _L3NODE6",
                          "Percentage of time when render cache input is available",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_OUTPUT_READY_L3NODE6", "RENDER_CACHE_OUTPUT_READY _L3NODE6",
                          "Percentage of time when render cache output is ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14060700, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1606001a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02060010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06060081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080603c3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a06034e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00081555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a1555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14087800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16087840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080126, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001007f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e080c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080438, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080ba7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x400314a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00100030, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x0000007a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000282, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ff8f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ff8f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fff3, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt606MetricSet::CExt606MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt606MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "AMFS_STALL_ALL_INPUT_SLICE7", "AMFS STALL ALL INPUT SLICE7",
                          "Percentage of time in which AMFS stalls at both of the color pipe inputs",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "AMFS_STALL_ANY_INPUT_SLICE7", "AMFS STALL ANY INPUT SLICE7",
                          "Percentage of time in which AMFS stalls at any of the color pipe inputs",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "AMFS_CACHE_HIT_SLICE7", "AMFS CACHE HIT SLICE7",
                          "Number of hits in the AMFS cache",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "AMFS_CACHE_MISS_SLICE7", "AMFS CACHE MISS SLICE7",
                          "Number of cache misses in AMFS",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_HIT_L3NODE7", "RENDER CACHE HIT L3NODE7",
                          "Number of Render Cache hits",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_READ_L3NODE7", "RENDER CACHE READ L3NODE7",
                          "Number of Render Cache reads",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_WRITE_L3NODE7", "RENDER CACHE WRITE L3NODE7",
                          "Number of Render Cache writes",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_INPUT_AVAILABLE_L3NODE7", "RENDER_CACHE_INPUT_AVAILABLE _L3NODE7",
                          "Percentage of time when render cache input is available",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_OUTPUT_READY_L3NODE7", "RENDER_CACHE_OUTPUT_READY _L3NODE7",
                          "Percentage of time when render cache output is ready",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15060700, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1706001a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003007f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00083fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a1555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001007f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b2aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03060010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07060081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090603c3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b06034e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01081555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a1555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16037840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030126, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001007f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e030c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10030438, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030ba7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aa80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2003f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00100030, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x0000007a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000282, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ff8f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ff8f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fff3, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt607MetricSet::CExt607MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt607MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "AMFS_4X4_SHADING_REQUEST_SLICE0", "AMFS 4X4 SHADING REQUEST SLICE0",
                          "Number of Shading Request (evaluate) messages processed by AMFS",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "AMFS_4X4_SHADING_REQUEST_SLICE1", "AMFS 4X4 SHADING REQUEST SLICE1",
                          "Number of Shading Request (evaluate) messages processed by AMFS",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "AMFS_4X4_SHADING_REQUEST_SLICE2", "AMFS 4X4 SHADING REQUEST SLICE2",
                          "Number of Shading Request (evaluate) messages processed by AMFS",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "AMFS_4X4_SHADING_REQUEST_SLICE3", "AMFS 4X4 SHADING REQUEST SLICE3",
                          "Number of Shading Request (evaluate) messages processed by AMFS",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "AMFS_4X4_SHADING_REQUEST_SLICE4", "AMFS 4X4 SHADING REQUEST SLICE4",
                          "Number of Shading Request (evaluate) messages processed by AMFS",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "AMFS_4X4_SHADING_REQUEST_SLICE5", "AMFS 4X4 SHADING REQUEST SLICE5",
                          "Number of Shading Request (evaluate) messages processed by AMFS",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "AMFS_4X4_SHADING_REQUEST_SLICE6", "AMFS 4X4 SHADING REQUEST SLICE6",
                          "Number of Shading Request (evaluate) messages processed by AMFS",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "AMFS_4X4_SHADING_REQUEST_SLICE7", "AMFS 4X4 SHADING REQUEST SLICE7",
                          "Number of Shading Request (evaluate) messages processed by AMFS",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1606001a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1706001a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02060002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04060e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06060006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800f5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b00a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03060002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070601c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09060006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1606001a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1706001a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02060002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080601c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a060006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008f500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000ba000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03060002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0601c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d060006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1606001a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1706001a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02060002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0601c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e060006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800f5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03060002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0601c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11060006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03080050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1606001a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1706001a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02060002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100601c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12060006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208f500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020ba000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03060002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130601c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15060006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031292, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030520, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030d21, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030209, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030610, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt608MetricSet::CExt608MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt608MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "AMFS_L3_ATOMIC_SLICE0", "AMFS L3 ATOMIC SLICE0",
                          "Number of AMFS atomics to L3",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "AMFS_L3_ATOMIC_SLICE1", "AMFS L3 ATOMIC SLICE1",
                          "Number of AMFS atomics to L3",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "AMFS_L3_ATOMIC_SLICE2", "AMFS L3 ATOMIC SLICE2",
                          "Number of AMFS atomics to L3",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "AMFS_L3_ATOMIC_SLICE3", "AMFS L3 ATOMIC SLICE3",
                          "Number of AMFS atomics to L3",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "AMFS_L3_ATOMIC_SLICE4", "AMFS L3 ATOMIC SLICE4",
                          "Number of AMFS atomics to L3",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "AMFS_L3_ATOMIC_SLICE5", "AMFS L3 ATOMIC SLICE5",
                          "Number of AMFS atomics to L3",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "AMFS_L3_ATOMIC_SLICE6", "AMFS L3 ATOMIC SLICE6",
                          "Number of AMFS atomics to L3",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "AMFS_L3_ATOMIC_SLICE7", "AMFS L3 ATOMIC SLICE7",
                          "Number of AMFS atomics to L3",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1606014c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1706014c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0206001a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04060e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06060008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800f5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b00a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0306001a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070601c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09060008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1606014c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1706014c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0206001a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080601c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a060008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008f500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000ba000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0306001a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0601c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d060008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1606014c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1706014c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0206001a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0601c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e060008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800f5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0306001a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0601c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11060008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03080050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1606014c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1706014c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0206001a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100601c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12060008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208f500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020ba000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0306001a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130601c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15060008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031292, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030520, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030d21, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030209, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030610, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt609MetricSet::CExt609MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt609MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "AMFS_L3_ACCESS_SLICE0", "AMFS L3 ACCESS SLICE0",
                          "Number of AMFS accesses to L3",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "AMFS_L3_ACCESS_SLICE1", "AMFS L3 ACCESS SLICE1",
                          "Number of AMFS accesses to L3",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "AMFS_L3_ACCESS_SLICE2", "AMFS L3 ACCESS SLICE2",
                          "Number of AMFS accesses to L3",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "AMFS_L3_ACCESS_SLICE3", "AMFS L3 ACCESS SLICE3",
                          "Number of AMFS accesses to L3",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "AMFS_L3_ACCESS_SLICE4", "AMFS L3 ACCESS SLICE4",
                          "Number of AMFS accesses to L3",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "AMFS_L3_ACCESS_SLICE5", "AMFS L3 ACCESS SLICE5",
                          "Number of AMFS accesses to L3",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "AMFS_L3_ACCESS_SLICE6", "AMFS L3 ACCESS SLICE6",
                          "Number of AMFS accesses to L3",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "AMFS_L3_ACCESS_SLICE7", "AMFS L3 ACCESS SLICE7",
                          "Number of AMFS accesses to L3",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1606000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1706000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00034000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02060002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14060007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02087000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03060002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130601c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1606000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1706000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02060002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12060007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080700, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00011000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03060002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110601c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03080100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1606000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1706000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02060002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10060007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03060002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0601c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03080010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1606000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1706000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02060002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e060007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03060002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0601c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03080001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208af00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032489, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030521, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00013000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt610MetricSet::CExt610MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt610MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "AMFS_L3_WRITE_SLICE0", "AMFS L3 WRITE SLICE0",
                          "Number of AMFS writes to L3",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "AMFS_L3_WRITE_SLICE1", "AMFS L3 WRITE SLICE1",
                          "Number of AMFS writes to L3",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "AMFS_L3_WRITE_SLICE2", "AMFS L3 WRITE SLICE2",
                          "Number of AMFS writes to L3",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "AMFS_L3_WRITE_SLICE3", "AMFS L3 WRITE SLICE3",
                          "Number of AMFS writes to L3",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "AMFS_L3_WRITE_SLICE4", "AMFS L3 WRITE SLICE4",
                          "Number of AMFS writes to L3",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "AMFS_L3_WRITE_SLICE5", "AMFS L3 WRITE SLICE5",
                          "Number of AMFS writes to L3",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "AMFS_L3_WRITE_SLICE6", "AMFS L3 WRITE SLICE6",
                          "Number of AMFS writes to L3",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "AMFS_L3_WRITE_SLICE7", "AMFS L3 WRITE SLICE7",
                          "Number of AMFS writes to L3",
                          "AMFS", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1606014c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1706014c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0206001a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04060e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06060008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800f5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b00a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0306001a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070601c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09060008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1606014c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1706014c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0206001a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080601c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a060008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008f500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000ba000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0306001a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0601c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d060008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1606014c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1706014c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0206001a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0601c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e060008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800f5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0306001a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0601c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11060008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03080050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1606014c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1706014c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0206001a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100601c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12060008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208f500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020ba000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0306001a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130601c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15060008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01060000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031292, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030520, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030d21, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030209, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030610, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000062, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000182, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt611MetricSet::CExt611MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt611MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "CLIPPER_INPUT_VERTEX_SLICE0", "CLIPPER INPUT VERTEX SLICE0",
                          "Number of Clipper input vertices",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "CLIPPER_INPUT_VERTEX_SLICE1", "CLIPPER INPUT VERTEX SLICE1",
                          "Number of Clipper input vertices",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "CLIPPER_INPUT_VERTEX_SLICE2", "CLIPPER INPUT VERTEX SLICE2",
                          "Number of Clipper input vertices",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "CLIPPER_INPUT_VERTEX_SLICE3", "CLIPPER INPUT VERTEX SLICE3",
                          "Number of Clipper input vertices",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "STREAMOUT_OUTPUT_VERTEX_COUNT_SLICE0", "STREAMOUT OUTPUT VERTEX COUNT SLICE0",
                          "Number of vertices written by SOL",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "STREAMOUT_OUTPUT_VERTEX_COUNT_SLICE1", "STREAMOUT OUTPUT VERTEX COUNT SLICE1",
                          "Number of vertices written by SOL",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "STREAMOUT_OUTPUT_VERTEX_COUNT_SLICE2", "STREAMOUT OUTPUT VERTEX COUNT SLICE2",
                          "Number of vertices written by SOL",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "STREAMOUT_OUTPUT_VERTEX_COUNT_SLICE3", "STREAMOUT OUTPUT VERTEX COUNT SLICE3",
                          "Number of vertices written by SOL",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c073c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14090440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16090013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d073c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15090440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17090013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00034038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16070034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0609034a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00098000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a056a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a9000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15070d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03090010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09090285, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b09000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01094000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c073c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14090440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16090013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d073c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15090440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17090013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14070034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020803fc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a090140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c09034a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00092000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aa000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0956, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00011e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b02a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13070d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03090010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f090285, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1109000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01091000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a02a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008faaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208afff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030428, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030084, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x460302e4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030e17, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001c03f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00013fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fffa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x000000c2, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffe7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffd7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000febf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00003002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000f9ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00001002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000f5ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt612MetricSet::CExt612MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt612MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "CLIPPER_INPUT_VERTEX_SLICE4", "CLIPPER INPUT VERTEX SLICE4",
                          "Number of Clipper input vertices",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "CLIPPER_INPUT_VERTEX_SLICE5", "CLIPPER INPUT VERTEX SLICE5",
                          "Number of Clipper input vertices",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "CLIPPER_INPUT_VERTEX_SLICE6", "CLIPPER INPUT VERTEX SLICE6",
                          "Number of Clipper input vertices",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "CLIPPER_INPUT_VERTEX_SLICE7", "CLIPPER INPUT VERTEX SLICE7",
                          "Number of Clipper input vertices",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "STREAMOUT_OUTPUT_VERTEX_COUNT_SLICE4", "STREAMOUT OUTPUT VERTEX COUNT SLICE4",
                          "Number of vertices written by SOL",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "STREAMOUT_OUTPUT_VERTEX_COUNT_SLICE5", "STREAMOUT OUTPUT VERTEX COUNT SLICE5",
                          "Number of vertices written by SOL",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "STREAMOUT_OUTPUT_VERTEX_COUNT_SLICE6", "STREAMOUT OUTPUT VERTEX COUNT SLICE6",
                          "Number of vertices written by SOL",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "STREAMOUT_OUTPUT_VERTEX_COUNT_SLICE7", "STREAMOUT OUTPUT VERTEX COUNT SLICE7",
                          "Number of vertices written by SOL",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c073c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14090440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16090013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d073c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15090440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17090013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00034038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16070034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0609034a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00098000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a056a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a9000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15070d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03090010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09090285, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b09000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01094000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c073c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14090440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16090013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d073c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15090440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17090013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14070034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020803fc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a090140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c09034a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00092000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aa000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0956, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00011e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b02a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13070d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03090010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f090285, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1109000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01091000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a02a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002a555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030428, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030084, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x460302e4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030e17, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030801, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001c03f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00013fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fffa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x000000c2, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffe7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffd7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000febf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00003002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000f9ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00001002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000f5ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt613MetricSet::CExt613MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt613MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "VERTEX_FETCH_INPUT_AVAILABLE_SLICE0", "VERTEX FETCH INPUT AVAILABLE SLICE0",
                          "Percentage of time in which Vertex Fetch input is available",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "VERTEX_FETCH_INPUT_AVAILABLE_SLICE1", "VERTEX FETCH INPUT AVAILABLE SLICE1",
                          "Percentage of time in which Vertex Fetch input is available",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "VERTEX_FETCH_INPUT_AVAILABLE_SLICE2", "VERTEX FETCH INPUT AVAILABLE SLICE2",
                          "Percentage of time in which Vertex Fetch input is available",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "VERTEX_FETCH_INPUT_AVAILABLE_SLICE3", "VERTEX FETCH INPUT AVAILABLE SLICE3",
                          "Percentage of time in which Vertex Fetch input is available",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "VERTEX_FETCH_INPUT_AVAILABLE_SLICE4", "VERTEX FETCH INPUT AVAILABLE SLICE4",
                          "Percentage of time in which Vertex Fetch input is available",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "VERTEX_FETCH_INPUT_AVAILABLE_SLICE5", "VERTEX FETCH INPUT AVAILABLE SLICE5",
                          "Percentage of time in which Vertex Fetch input is available",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "VERTEX_FETCH_INPUT_AVAILABLE_SLICE6", "VERTEX FETCH INPUT AVAILABLE SLICE6",
                          "Percentage of time in which Vertex Fetch input is available",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "VERTEX_FETCH_INPUT_AVAILABLE_SLICE7", "VERTEX FETCH INPUT AVAILABLE SLICE7",
                          "Percentage of time in which Vertex Fetch input is available",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "VERTEX_FETCH_OUTPUT_READY_SLICE0", "VERTEX FETCH OUTPUT READY SLICE0",
                          "Percentage of time in which Vertex Fetch output is ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "VERTEX_FETCH_OUTPUT_READY_SLICE1", "VERTEX FETCH OUTPUT READY SLICE1",
                          "Percentage of time in which Vertex Fetch output is ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "VERTEX_FETCH_OUTPUT_READY_SLICE2", "VERTEX FETCH OUTPUT READY SLICE2",
                          "Percentage of time in which Vertex Fetch output is ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "VERTEX_FETCH_OUTPUT_READY_SLICE3", "VERTEX FETCH OUTPUT READY SLICE3",
                          "Percentage of time in which Vertex Fetch output is ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "VERTEX_FETCH_OUTPUT_READY_SLICE4", "VERTEX FETCH OUTPUT READY SLICE4",
                          "Percentage of time in which Vertex Fetch output is ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "VERTEX_FETCH_OUTPUT_READY_SLICE5", "VERTEX FETCH OUTPUT READY SLICE5",
                          "Percentage of time in which Vertex Fetch output is ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "VERTEX_FETCH_OUTPUT_READY_SLICE6", "VERTEX FETCH OUTPUT READY SLICE6",
                          "Percentage of time in which Vertex Fetch output is ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "VERTEX_FETCH_OUTPUT_READY_SLICE7", "VERTEX FETCH OUTPUT READY SLICE7",
                          "Percentage of time in which Vertex Fetch output is ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a01f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a01f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00034002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040a0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140a0d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050a0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x070a09c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x150a0036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a01f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a01f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040a0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x080a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120a0d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00011008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050a0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x090a09c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x130a0036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a01f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a01f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040a0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100a0d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050a0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0a09c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110a0036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160a01f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180a001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170a01f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190a001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040a0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0a0027, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0a0d80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a4000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b8000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x050a0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d0a09c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0a0036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208af00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002a500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032489, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032429, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46031060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030521, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001c003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001300c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010c30, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt614MetricSet::CExt614MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt614MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "VS_OUTPUT_READY_SLICE0", "VS OUTPUT READY SLICE0",
                          "Percentage of time in which Vertex Shader output is ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "VS_OUTPUT_READY_SLICE1", "VS OUTPUT READY SLICE1",
                          "Percentage of time in which Vertex Shader output is ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "VS_OUTPUT_READY_SLICE2", "VS OUTPUT READY SLICE2",
                          "Percentage of time in which Vertex Shader output is ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "VS_OUTPUT_READY_SLICE3", "VS OUTPUT READY SLICE3",
                          "Percentage of time in which Vertex Shader output is ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "VS_OUTPUT_READY_SLICE4", "VS OUTPUT READY SLICE4",
                          "Percentage of time in which Vertex Shader output is ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "VS_OUTPUT_READY_SLICE5", "VS OUTPUT READY SLICE5",
                          "Percentage of time in which Vertex Shader output is ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "VS_OUTPUT_READY_SLICE6", "VS OUTPUT READY SLICE6",
                          "Percentage of time in which Vertex Shader output is ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "VS_OUTPUT_READY_SLICE7", "VS OUTPUT READY SLICE7",
                          "Percentage of time in which Vertex Shader output is ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "CLIPPER_INPUT_AVAILABLE_SLICE0", "CLIPPER INPUT AVAILABLE SLICE0",
                          "Percentage of time in which Clipper has input available (from Vertex Shader or SOL)",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "CLIPPER_INPUT_AVAILABLE_SLICE1", "CLIPPER INPUT AVAILABLE SLICE1",
                          "Percentage of time in which Clipper has input available (from Vertex Shader or SOL)",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "CLIPPER_INPUT_AVAILABLE_SLICE2", "CLIPPER INPUT AVAILABLE SLICE2",
                          "Percentage of time in which Clipper has input available (from Vertex Shader or SOL)",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "CLIPPER_INPUT_AVAILABLE_SLICE3", "CLIPPER INPUT AVAILABLE SLICE3",
                          "Percentage of time in which Clipper has input available (from Vertex Shader or SOL)",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "CLIPPER_INPUT_AVAILABLE_SLICE4", "CLIPPER INPUT AVAILABLE SLICE4",
                          "Percentage of time in which Clipper has input available (from Vertex Shader or SOL)",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "CLIPPER_INPUT_AVAILABLE_SLICE5", "CLIPPER INPUT AVAILABLE SLICE5",
                          "Percentage of time in which Clipper has input available (from Vertex Shader or SOL)",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "CLIPPER_INPUT_AVAILABLE_SLICE6", "CLIPPER INPUT AVAILABLE SLICE6",
                          "Percentage of time in which Clipper has input available (from Vertex Shader or SOL)",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "CLIPPER_INPUT_AVAILABLE_SLICE7", "CLIPPER INPUT AVAILABLE SLICE7",
                          "Percentage of time in which Clipper has input available (from Vertex Shader or SOL)",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16090340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17090340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00034040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00083000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a9000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001c040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020ba000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13030c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03083000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03090003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01014000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16090340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17090340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00013010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11030c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03080300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03090003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01011000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16090340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17090340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10030031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010c04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f030c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03080030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03090003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16090340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d030c40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17090340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e030031, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010301, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03090003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008af00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208af00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031292, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032489, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2603f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42031449, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3203f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44033cc2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030c23, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4803003f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030521, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001c0c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00013030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010c0c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010303, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt615MetricSet::CExt615MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt615MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "CLIPPER_OUTPUT_READY_SLICE0", "CLIPPER OUTPUT READY SLICE0",
                          "Percentage of time in which Clipper output ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "CLIPPER_OUTPUT_READY_SLICE1", "CLIPPER OUTPUT READY SLICE1",
                          "Percentage of time in which Clipper output ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "CLIPPER_OUTPUT_READY_SLICE2", "CLIPPER OUTPUT READY SLICE2",
                          "Percentage of time in which Clipper output ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "CLIPPER_OUTPUT_READY_SLICE3", "CLIPPER OUTPUT READY SLICE3",
                          "Percentage of time in which Clipper output ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "CLIPPER_OUTPUT_READY_SLICE4", "CLIPPER OUTPUT READY SLICE4",
                          "Percentage of time in which Clipper output ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "CLIPPER_OUTPUT_READY_SLICE5", "CLIPPER OUTPUT READY SLICE5",
                          "Percentage of time in which Clipper output ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "CLIPPER_OUTPUT_READY_SLICE6", "CLIPPER OUTPUT READY SLICE6",
                          "Percentage of time in which Clipper output ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "CLIPPER_OUTPUT_READY_SLICE7", "CLIPPER OUTPUT READY SLICE7",
                          "Percentage of time in which Clipper output ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18091800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19091800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04092400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03090040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07090012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18091800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19091800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06090480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03090040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09090012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18091800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19091800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08090480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03090040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b090012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18091800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19091800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a090480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b8000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03090040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d090012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a8000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002a500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030049, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46031060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt616MetricSet::CExt616MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt616MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_WRITE_SQIDI0", "GPU MEMORY WRITE SQIDI0",
                          "Number of GTI memory writes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_WRITE_SQIDI1", "GPU MEMORY WRITE SQIDI1",
                          "Number of GTI memory writes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_WRITE_SQIDI2", "GPU MEMORY WRITE SQIDI2",
                          "Number of GTI memory writes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_WRITE_SQIDI3", "GPU MEMORY WRITE SQIDI3",
                          "Number of GTI memory writes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_WRITE_SQIDI4", "GPU MEMORY WRITE SQIDI4",
                          "Number of GTI memory writes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_WRITE_SQIDI5", "GPU MEMORY WRITE SQIDI5",
                          "Number of GTI memory writes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_WRITE_SQIDI6", "GPU MEMORY WRITE SQIDI6",
                          "Number of GTI memory writes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_WRITE_SQIDI7", "GPU MEMORY WRITE SQIDI7",
                          "Number of GTI memory writes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_WRITE", "GPU MEMORY WRITE",
                          "Number of GTI memory writes",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$$GPU_MEMORY_WRITE_SQIDI2 $$GPU_MEMORY_WRITE_SQIDI0 UADD $$GPU_MEMORY_WRITE_SQIDI1 UADD $$GPU_MEMORY_WRITE_SQIDI3 UADD $$GPU_MEMORY_WRITE_SQIDI4 UADD $$GPU_MEMORY_WRITE_SQIDI5 UADD $$GPU_MEMORY_WRITE_SQIDI6 UADD $$GPU_MEMORY_WRITE_SQIDI7 UADD" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18013800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18213800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18413800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18613800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18813800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a13800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c13800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e13800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0101c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02210006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10210007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02410006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x104101c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00410000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02610006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12610007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00610000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x128101c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a10007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c101c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e10007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02034800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04034924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04093440, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06090004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040a1252, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b0023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030841, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt617MetricSet::CExt617MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt617MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "CLIPPER_PRIMITIVE_OUTPUT_SLICE0", "CLIPPER PRIMITIVE OUTPUT SLICE0",
                          "Number of primitives going out of Clipper, must clip plus the trivial accept",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "CLIPPER_PRIMITIVE_OUTPUT_SLICE1", "CLIPPER PRIMITIVE OUTPUT SLICE1",
                          "Number of primitives going out of Clipper, must clip plus the trivial accept",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "CLIPPER_PRIMITIVE_OUTPUT_SLICE2", "CLIPPER PRIMITIVE OUTPUT SLICE2",
                          "Number of primitives going out of Clipper, must clip plus the trivial accept",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "CLIPPER_PRIMITIVE_OUTPUT_SLICE3", "CLIPPER PRIMITIVE OUTPUT SLICE3",
                          "Number of primitives going out of Clipper, must clip plus the trivial accept",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "CLIPPER_PRIMITIVE_OUTPUT_SLICE4", "CLIPPER PRIMITIVE OUTPUT SLICE4",
                          "Number of primitives going out of Clipper, must clip plus the trivial accept",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "CLIPPER_PRIMITIVE_OUTPUT_SLICE5", "CLIPPER PRIMITIVE OUTPUT SLICE5",
                          "Number of primitives going out of Clipper, must clip plus the trivial accept",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "CLIPPER_PRIMITIVE_OUTPUT_SLICE6", "CLIPPER PRIMITIVE OUTPUT SLICE6",
                          "Number of primitives going out of Clipper, must clip plus the trivial accept",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "CLIPPER_PRIMITIVE_OUTPUT_SLICE7", "CLIPPER PRIMITIVE OUTPUT SLICE7",
                          "Number of primitives going out of Clipper, must clip plus the trivial accept",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0903e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0903e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00083000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02094000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c090025, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a9000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03094000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b090940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0903e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0903e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02094000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a090025, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03094000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09090940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0903e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0903e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02094000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08090025, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03094000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07090940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c0903e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d0903e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02094000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06090025, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03094000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05094a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008af00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030c28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030209, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030093, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt618MetricSet::CExt618MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt618MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "CLIPPER_PRIMITIVE_CULL_SLICE0", "CLIPPER PRIMITIVE CULL SLICE0",
                          "Number of Clipper early cull primitives",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "CLIPPER_PRIMITIVE_CULL_SLICE1", "CLIPPER PRIMITIVE CULL SLICE1",
                          "Number of Clipper early cull primitives",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "CLIPPER_PRIMITIVE_CULL_SLICE2", "CLIPPER PRIMITIVE CULL SLICE2",
                          "Number of Clipper early cull primitives",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "CLIPPER_PRIMITIVE_CULL_SLICE3", "CLIPPER PRIMITIVE CULL SLICE3",
                          "Number of Clipper early cull primitives",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "CLIPPER_PRIMITIVE_CULL_SLICE4", "CLIPPER PRIMITIVE CULL SLICE4",
                          "Number of Clipper early cull primitives",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "CLIPPER_PRIMITIVE_CULL_SLICE5", "CLIPPER PRIMITIVE CULL SLICE5",
                          "Number of Clipper early cull primitives",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4 dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168 qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "CLIPPER_PRIMITIVE_CULL_SLICE6", "CLIPPER PRIMITIVE CULL SLICE6",
                          "Number of Clipper early cull primitives",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "CLIPPER_PRIMITIVE_CULL_SLICE7", "CLIPPER PRIMITIVE CULL SLICE7",
                          "Number of Clipper early cull primitives",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12090480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14090013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aa500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00013000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03090040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11090480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13090013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e090480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10090013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a00a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03090040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d090480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f090013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a090480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c090013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aa500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03090040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09090480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b090013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06090480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08090013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a00a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03090040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05092400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07090013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000255aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032449, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032520, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46031060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt619MetricSet::CExt619MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt619MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "CLIPPER_PRIMITIVE_FAR_NEAR_CLIP_SLICE0", "CLIPPER PRIMITIVE FAR NEAR CLIP SLICE0",
                          "Number of primitives clipped by Clipper due to near/far planes",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "CLIPPER_PRIMITIVE_FAR_NEAR_CLIP_SLICE1", "CLIPPER PRIMITIVE FAR NEAR CLIP SLICE1",
                          "Number of primitives clipped by Clipper due to near/far planes",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "CLIPPER_PRIMITIVE_FAR_NEAR_CLIP_SLICE2", "CLIPPER PRIMITIVE FAR NEAR CLIP SLICE2",
                          "Number of primitives clipped by Clipper due to near/far planes",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "CLIPPER_PRIMITIVE_FAR_NEAR_CLIP_SLICE3", "CLIPPER PRIMITIVE FAR NEAR CLIP SLICE3",
                          "Number of primitives clipped by Clipper due to near/far planes",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160929c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170929c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060902cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a056a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03090023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09090306, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b09000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160929c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170929c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800fc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a090180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0902cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aa000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0056, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03090023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f090306, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1109000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a00a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008faaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46031060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030683, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001003f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0000002a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fffa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x000000c2, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffe7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000142, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffd7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000a02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000febf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00003002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000f9ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00005002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000f5ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt620MetricSet::CExt620MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt620MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "CLIPPER_PRIMITIVE_FAR_NEAR_CLIP_SLICE4", "CLIPPER PRIMITIVE FAR NEAR CLIP SLICE4",
                          "Number of primitives clipped by Clipper due to near/far planes",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "CLIPPER_PRIMITIVE_FAR_NEAR_CLIP_SLICE5", "CLIPPER PRIMITIVE FAR NEAR CLIP SLICE5",
                          "Number of primitives clipped by Clipper due to near/far planes",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "CLIPPER_PRIMITIVE_FAR_NEAR_CLIP_SLICE6", "CLIPPER PRIMITIVE FAR NEAR CLIP SLICE6",
                          "Number of primitives clipped by Clipper due to near/far planes",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "CLIPPER_PRIMITIVE_FAR_NEAR_CLIP_SLICE7", "CLIPPER PRIMITIVE FAR NEAR CLIP SLICE7",
                          "Number of primitives clipped by Clipper due to near/far planes",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8 dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170 qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160929c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170929c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060902cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a056a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03090023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09090306, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b09000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x160929c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x170929c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800fc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a090180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0902cc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aa000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0056, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03090023, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f090306, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1109000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a00a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002a555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020200aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46031060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030683, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001003f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0000002a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fffa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x000000c2, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffe7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000142, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffd7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000602, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000a02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000febf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00003002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000f9ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00005002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000f5ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt621MetricSet::CExt621MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt621MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "CLIPPER_TRANSACTION_OUTPUT_SLICE0", "CLIPPER TRANSACTION OUTPUT SLICE0",
                          "Number of elements pushed by Clipper into Stripsfan stage",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "CLIPPER_TRANSACTION_OUTPUT_SLICE1", "CLIPPER TRANSACTION OUTPUT SLICE1",
                          "Number of elements pushed by Clipper into Stripsfan stage",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "CLIPPER_TRANSACTION_OUTPUT_SLICE2", "CLIPPER TRANSACTION OUTPUT SLICE2",
                          "Number of elements pushed by Clipper into Stripsfan stage",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "CLIPPER_TRANSACTION_OUTPUT_SLICE3", "CLIPPER TRANSACTION OUTPUT SLICE3",
                          "Number of elements pushed by Clipper into Stripsfan stage",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "CLIPPER_TRANSACTION_OUTPUT_SLICE4", "CLIPPER TRANSACTION OUTPUT SLICE4",
                          "Number of elements pushed by Clipper into Stripsfan stage",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "CLIPPER_TRANSACTION_OUTPUT_SLICE5", "CLIPPER TRANSACTION OUTPUT SLICE5",
                          "Number of elements pushed by Clipper into Stripsfan stage",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "CLIPPER_TRANSACTION_OUTPUT_SLICE6", "CLIPPER TRANSACTION OUTPUT SLICE6",
                          "Number of elements pushed by Clipper into Stripsfan stage",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "CLIPPER_TRANSACTION_OUTPUT_SLICE7", "CLIPPER TRANSACTION OUTPUT SLICE7",
                          "Number of elements pushed by Clipper into Stripsfan stage",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "RASTERIZER_INPUT_AVAILABLE_SLICE0", "RASTERIZER INPUT AVAILABLE SLICE0",
                          "Percentage of time in which Rasterizer input is available",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "RASTERIZER_INPUT_AVAILABLE_SLICE1", "RASTERIZER INPUT AVAILABLE SLICE1",
                          "Percentage of time in which Rasterizer input is available",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "RASTERIZER_INPUT_AVAILABLE_SLICE2", "RASTERIZER INPUT AVAILABLE SLICE2",
                          "Percentage of time in which Rasterizer input is available",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "RASTERIZER_INPUT_AVAILABLE_SLICE3", "RASTERIZER INPUT AVAILABLE SLICE3",
                          "Percentage of time in which Rasterizer input is available",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003400c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00058000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020530c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800f5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a9000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001400c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b00a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01058000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05050c32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0106000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000310c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00058000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06050c32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008f500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000110c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000ba000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01058000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09050c32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010600c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0090, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208af00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031292, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032489, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e0310e8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0308e7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x400320a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001c00f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000130f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000060, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000180, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000600, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt622MetricSet::CExt622MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt622MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "RASTERIZER_INPUT_AVAILABLE_SLICE4", "RASTERIZER INPUT AVAILABLE SLICE4",
                          "Percentage of time in which Rasterizer input is available",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "RASTERIZER_INPUT_AVAILABLE_SLICE5", "RASTERIZER INPUT AVAILABLE SLICE5",
                          "Percentage of time in which Rasterizer input is available",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "RASTERIZER_INPUT_AVAILABLE_SLICE6", "RASTERIZER INPUT AVAILABLE SLICE6",
                          "Percentage of time in which Rasterizer input is available",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "RASTERIZER_INPUT_AVAILABLE_SLICE7", "RASTERIZER INPUT AVAILABLE SLICE7",
                          "Percentage of time in which Rasterizer input is available",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "RASTERIZER_TRANSACTION_OUTPUT_SLICE0", "RASTERIZER TRANSACTION OUTPUT SLICE0",
                          "Number of transactions pushed from Rasterizer to the Z pipe",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "RASTERIZER_TRANSACTION_OUTPUT_SLICE1", "RASTERIZER TRANSACTION OUTPUT SLICE1",
                          "Number of transactions pushed from Rasterizer to the Z pipe",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "RASTERIZER_TRANSACTION_OUTPUT_SLICE2", "RASTERIZER TRANSACTION OUTPUT SLICE2",
                          "Number of transactions pushed from Rasterizer to the Z pipe",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "RASTERIZER_TRANSACTION_OUTPUT_SLICE3", "RASTERIZER TRANSACTION OUTPUT SLICE3",
                          "Number of transactions pushed from Rasterizer to the Z pipe",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a057c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c050013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b057c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d050013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10050f31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0006c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02085f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00013000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f050f31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01063000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03080500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a057c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c050013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b057c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d050013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c050f31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208005f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b050f31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01060300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03080005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00058000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020530c8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800f5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b00a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01058000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05050c32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0106000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000300c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00058000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06050c32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008f500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000ba000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01058000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09050c32, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010600c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01085000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032449, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032528, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030109, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000060, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000180, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000600, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt623MetricSet::CExt623MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt623MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "RASTERIZER_TRANSACTION_OUTPUT_SLICE4", "RASTERIZER TRANSACTION OUTPUT SLICE4",
                          "Number of transactions pushed from Rasterizer to the Z pipe",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "RASTERIZER_TRANSACTION_OUTPUT_SLICE5", "RASTERIZER TRANSACTION OUTPUT SLICE5",
                          "Number of transactions pushed from Rasterizer to the Z pipe",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "RASTERIZER_TRANSACTION_OUTPUT_SLICE6", "RASTERIZER TRANSACTION OUTPUT SLICE6",
                          "Number of transactions pushed from Rasterizer to the Z pipe",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "RASTERIZER_TRANSACTION_OUTPUT_SLICE7", "RASTERIZER TRANSACTION OUTPUT SLICE7",
                          "Number of transactions pushed from Rasterizer to the Z pipe",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "STRIPSFAN_OBJECTS_CULL_SLICE0", "STRIPSFAN OBJECTS CULL SLICE0",
                          "Number of simple culled objects in Stripsfan stage",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, "PS|FS", nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "STRIPSFAN_OBJECTS_CULL_SLICE1", "STRIPSFAN OBJECTS CULL SLICE1",
                          "Number of simple culled objects in Stripsfan stage",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, "PS|FS", nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4 dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168 qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "STRIPSFAN_OBJECTS_CULL_SLICE2", "STRIPSFAN OBJECTS CULL SLICE2",
                          "Number of simple culled objects in Stripsfan stage",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, "PS|FS", nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "STRIPSFAN_OBJECTS_CULL_SLICE3", "STRIPSFAN OBJECTS CULL SLICE3",
                          "Number of simple culled objects in Stripsfan stage",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, "PS|FS", nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c097fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d097fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02094000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a090940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c09002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aa500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03094000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05090005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09090940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b09002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c097fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d097fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02094000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06090940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0809002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a00a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03094000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05094a05, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0709002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a057c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c050013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b057c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d050013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10050f31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0006c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02085f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00013000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f050f31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01063000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03080500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a057c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c050013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b057c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d050013, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c050f31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208005f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b050f31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01060300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03080005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020255aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031292, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032109, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42031928, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030126, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030ce9, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030067, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt624MetricSet::CExt624MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt624MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "STRIPSFAN_OBJECT_COUNT_SLICE0", "STRIPSFAN OBJECT COUNT SLICE0",
                          "Number of objects exiting Stripsfan stage",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, "PS|FS", nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "STRIPSFAN_OBJECT_COUNT_SLICE1", "STRIPSFAN OBJECT COUNT SLICE1",
                          "Number of objects exiting Stripsfan stage",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, "PS|FS", nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "STRIPSFAN_OBJECT_COUNT_SLICE2", "STRIPSFAN OBJECT COUNT SLICE2",
                          "Number of objects exiting Stripsfan stage",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, "PS|FS", nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "STRIPSFAN_OBJECT_COUNT_SLICE3", "STRIPSFAN OBJECT COUNT SLICE3",
                          "Number of objects exiting Stripsfan stage",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, "PS|FS", nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "STRIPSFAN_OBJECT_COUNT_SLICE4", "STRIPSFAN OBJECT COUNT SLICE4",
                          "Number of objects exiting Stripsfan stage",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, "PS|FS", nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "STRIPSFAN_OBJECT_COUNT_SLICE5", "STRIPSFAN OBJECT COUNT SLICE5",
                          "Number of objects exiting Stripsfan stage",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, "PS|FS", nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "STRIPSFAN_OBJECT_COUNT_SLICE6", "STRIPSFAN OBJECT COUNT SLICE6",
                          "Number of objects exiting Stripsfan stage",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, "PS|FS", nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "STRIPSFAN_OBJECT_COUNT_SLICE7", "STRIPSFAN OBJECT COUNT SLICE7",
                          "Number of objects exiting Stripsfan stage",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, "PS|FS", nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "RASTERIZER_OUTPUT_READY_SLICE0", "RASTERIZER OUTPUT READY SLICE0",
                          "Percentage of time in which Rasterizer output is ready",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "RASTERIZER_OUTPUT_READY_SLICE1", "RASTERIZER OUTPUT READY SLICE1",
                          "Percentage of time in which Rasterizer output is ready",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "RASTERIZER_OUTPUT_READY_SLICE2", "RASTERIZER OUTPUT READY SLICE2",
                          "Percentage of time in which Rasterizer output is ready",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "RASTERIZER_OUTPUT_READY_SLICE3", "RASTERIZER OUTPUT READY SLICE3",
                          "Percentage of time in which Rasterizer output is ready",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "RASTERIZER_OUTPUT_READY_SLICE4", "RASTERIZER OUTPUT READY SLICE4",
                          "Percentage of time in which Rasterizer output is ready",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "RASTERIZER_OUTPUT_READY_SLICE5", "RASTERIZER OUTPUT READY SLICE5",
                          "Percentage of time in which Rasterizer output is ready",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "RASTERIZER_OUTPUT_READY_SLICE6", "RASTERIZER OUTPUT READY SLICE6",
                          "Percentage of time in which Rasterizer output is ready",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "RASTERIZER_OUTPUT_READY_SLICE7", "RASTERIZER OUTPUT READY SLICE7",
                          "Percentage of time in which Rasterizer output is ready",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12057c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a057800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13057c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b057800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00034040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08050d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10050080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00068080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00087000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02087000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01050002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09050034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11050002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01064040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12057c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a057800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13057c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b057800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06050d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e050080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00062020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080700, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080700, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00011010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01050002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07050034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f050002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01061010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03080100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12057c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a057800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13057c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b057800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04050d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c050080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060808, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080070, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01050002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05050034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d050002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01060404, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03080010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12057c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a057800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13057c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b057800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02053400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a050080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00060202, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01050002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030500d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b050002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01060101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03080001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008af00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208af00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031292, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032489, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030109, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030c28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030209, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030093, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030521, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001c0c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00013030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010c0c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010303, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt625MetricSet::CExt625MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt625MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "STRIPSFAN_OBJECTS_CULL_SLICE4", "STRIPSFAN OBJECTS CULL SLICE4",
                          "Number of simple culled objects in Stripsfan stage",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, "PS|FS", nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "STRIPSFAN_OBJECTS_CULL_SLICE5", "STRIPSFAN OBJECTS CULL SLICE5",
                          "Number of simple culled objects in Stripsfan stage",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, "PS|FS", nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4 dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8 qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "STRIPSFAN_OBJECTS_CULL_SLICE6", "STRIPSFAN OBJECTS CULL SLICE6",
                          "Number of simple culled objects in Stripsfan stage",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, "PS|FS", nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "STRIPSFAN_OBJECTS_CULL_SLICE7", "STRIPSFAN OBJECTS CULL SLICE7",
                          "Number of simple culled objects in Stripsfan stage",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, "PS|FS", nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "STRIPSFAN_OUTPUT_READY_SLICE0", "STRIPSFAN OUTPUT READY SLICE0",
                          "Percentage of time in which in which geometry pipeline output is ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "PS|FS", nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "STRIPSFAN_OUTPUT_READY_SLICE1", "STRIPSFAN OUTPUT READY SLICE1",
                          "Percentage of time in which in which geometry pipeline output is ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "PS|FS", nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "STRIPSFAN_OUTPUT_READY_SLICE2", "STRIPSFAN OUTPUT READY SLICE2",
                          "Percentage of time in which in which geometry pipeline output is ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "PS|FS", nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "STRIPSFAN_OUTPUT_READY_SLICE3", "STRIPSFAN OUTPUT READY SLICE3",
                          "Percentage of time in which in which geometry pipeline output is ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "PS|FS", nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "STRIPSFAN_OUTPUT_READY_SLICE4", "STRIPSFAN OUTPUT READY SLICE4",
                          "Percentage of time in which in which geometry pipeline output is ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "PS|FS", nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "STRIPSFAN_OUTPUT_READY_SLICE5", "STRIPSFAN OUTPUT READY SLICE5",
                          "Percentage of time in which in which geometry pipeline output is ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "PS|FS", nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "STRIPSFAN_OUTPUT_READY_SLICE6", "STRIPSFAN OUTPUT READY SLICE6",
                          "Percentage of time in which in which geometry pipeline output is ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "PS|FS", nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "STRIPSFAN_OUTPUT_READY_SLICE7", "STRIPSFAN OUTPUT READY SLICE7",
                          "Percentage of time in which in which geometry pipeline output is ready",
                          "Geometry", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_SLICE, availabilityEquation, "PS|FS", nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e09000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f09000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04096800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07090034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e09000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f09000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06090d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09090034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c097fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e09000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d097fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f09000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00033020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02094000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08090d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12090940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1409002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aa500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00013020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03094000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05090005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b090034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11090940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1309002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c097fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e09000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d097fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f09000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02094000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a090d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e090940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1009002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a6000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a00a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b8000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03094000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05090005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d090974, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f09002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a8000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002a500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020255aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032109, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032428, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030101, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46031060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt626MetricSet::CExt626MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt626MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "URB_READ_SLICE0", "URB READ SLICE0",
                          "Number of URB reads",
                          "URB", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD dw@0xec UADD dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD qw@0x198 UADD qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "URB_WRITE_SLICE0", "URB WRITE SLICE0",
                          "Number of URB writes",
                          "URB", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD dw@0xdc UADD dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD qw@0x178 UADD qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "URB_CROSS_SLICE_READ_SLICE0", "URB CROSS SLICE READ SLICE0",
                          "Number of URB reads occurred from cross slices",
                          "URB", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180703c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a070180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04072100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08070840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a070020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0704d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10070012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14070597, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16070015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0608c310, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0808e4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100809a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080025, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009e38c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a95a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aa95a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt627MetricSet::CExt627MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt627MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "URB_READ_SLICE1", "URB READ SLICE1",
                          "Number of URB reads",
                          "URB", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD dw@0xec UADD dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD qw@0x198 UADD qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "URB_WRITE_SLICE1", "URB WRITE SLICE1",
                          "Number of URB writes",
                          "URB", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD dw@0xdc UADD dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD qw@0x178 UADD qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "URB_CROSS_SLICE_READ_SLICE1", "URB CROSS SLICE READ SLICE1",
                          "Number of URB reads occurred from cross slices",
                          "URB", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190703c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b070180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19080f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b080180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05072100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09070840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b070020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0704d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11070012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15070597, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17070015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0708c310, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0808e4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d080022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110809a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13080025, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109e38c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a95a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aa95a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt628MetricSet::CExt628MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt628MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "URB_READ_SLICE2", "URB READ SLICE2",
                          "Number of URB reads",
                          "URB", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD dw@0xec UADD dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD qw@0x198 UADD qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "URB_WRITE_SLICE2", "URB WRITE SLICE2",
                          "Number of URB writes",
                          "URB", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD dw@0xdc UADD dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD qw@0x178 UADD qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "URB_CROSS_SLICE_READ_SLICE2", "URB CROSS SLICE READ SLICE2",
                          "Number of URB reads occurred from cross slices",
                          "URB", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180703c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a070180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04072100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08070840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a070020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0704d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10070012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14070597, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16070015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0608c310, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0808e4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100809a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080025, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009e38c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a95a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aa95a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt629MetricSet::CExt629MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt629MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "URB_READ_SLICE3", "URB READ SLICE3",
                          "Number of URB reads",
                          "URB", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD dw@0xec UADD dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD qw@0x198 UADD qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "URB_WRITE_SLICE3", "URB WRITE SLICE3",
                          "Number of URB writes",
                          "URB", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD dw@0xdc UADD dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD qw@0x178 UADD qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "URB_CROSS_SLICE_READ_SLICE3", "URB CROSS SLICE READ SLICE3",
                          "Number of URB reads occurred from cross slices",
                          "URB", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190703c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b070180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19080f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b080180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05072100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09070840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b070020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0704d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11070012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15070597, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17070015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0708c310, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0808e4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d080022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110809a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13080025, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109e38c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a95a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aa95a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt630MetricSet::CExt630MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt630MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "URB_READ_SLICE4", "URB READ SLICE4",
                          "Number of URB reads",
                          "URB", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD dw@0xec UADD dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD qw@0x198 UADD qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "URB_WRITE_SLICE4", "URB WRITE SLICE4",
                          "Number of URB writes",
                          "URB", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD dw@0xdc UADD dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD qw@0x178 UADD qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "URB_CROSS_SLICE_READ_SLICE4", "URB CROSS SLICE READ SLICE4",
                          "Number of URB reads occurred from cross slices",
                          "URB", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180703c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a070180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04072100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08070840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a070020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0704d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10070012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14070597, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16070015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0608c310, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0808e4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100809a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080025, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009e38c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a95a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aa95a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt631MetricSet::CExt631MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt631MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "URB_READ_SLICE5", "URB READ SLICE5",
                          "Number of URB reads",
                          "URB", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD dw@0xec UADD dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD qw@0x198 UADD qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "URB_WRITE_SLICE5", "URB WRITE SLICE5",
                          "Number of URB writes",
                          "URB", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD dw@0xdc UADD dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD qw@0x178 UADD qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "URB_CROSS_SLICE_READ_SLICE5", "URB CROSS SLICE READ SLICE5",
                          "Number of URB reads occurred from cross slices",
                          "URB", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190703c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b070180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19080f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b080180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05072100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09070840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b070020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0704d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11070012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15070597, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17070015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0708c310, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0808e4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d080022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110809a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13080025, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109e38c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a95a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aa95a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt632MetricSet::CExt632MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt632MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "URB_READ_SLICE6", "URB READ SLICE6",
                          "Number of URB reads",
                          "URB", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD dw@0xec UADD dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD qw@0x198 UADD qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "URB_WRITE_SLICE6", "URB WRITE SLICE6",
                          "Number of URB writes",
                          "URB", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD dw@0xdc UADD dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD qw@0x178 UADD qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "URB_CROSS_SLICE_READ_SLICE6", "URB CROSS SLICE READ SLICE6",
                          "Number of URB reads occurred from cross slices",
                          "URB", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180703c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a070180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18080f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a080180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04072100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08070840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a070020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0704d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10070012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14070597, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16070015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0608c310, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0808e4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100809a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080025, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009e38c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a95a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aa95a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt633MetricSet::CExt633MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt633MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "URB_READ_SLICE7", "URB READ SLICE7",
                          "Number of URB reads",
                          "URB", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD dw@0xec UADD dw@0xe8 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD qw@0x198 UADD qw@0x190 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "URB_WRITE_SLICE7", "URB WRITE SLICE7",
                          "Number of URB writes",
                          "URB", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4 dw@0xe0 UADD dw@0xdc UADD dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188 qw@0x180 UADD qw@0x178 UADD qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "URB_CROSS_SLICE_READ_SLICE7", "URB CROSS SLICE READ SLICE7",
                          "Number of URB reads occurred from cross slices",
                          "URB", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x190703c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b070180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19080f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b080180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05072100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09070840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b070020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f0704d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11070012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15070597, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17070015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0708c310, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b0808e4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d080022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x110809a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13080025, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109e38c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a95a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aa95a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt634MetricSet::CExt634MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt634MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_COMPUTE_ENGINE_BUSY_CCS0", "COMMAND PARSER COMPUTE ENGINE BUSY CCS0",
                          "Percentage of time in which there is a context loaded and active on the compute queue",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_COMPUTE_ENGINE_BUSY_CCS1", "COMMAND PARSER COMPUTE ENGINE BUSY CCS1",
                          "Percentage of time in which there is a context loaded and active on the compute queue",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_COMPUTE_ENGINE_BUSY_CCS2", "COMMAND PARSER COMPUTE ENGINE BUSY CCS2",
                          "Percentage of time in which there is a context loaded and active on the compute queue",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_COMPUTE_ENGINE_BUSY_CCS3", "COMMAND PARSER COMPUTE ENGINE BUSY CCS3",
                          "Percentage of time in which there is a context loaded and active on the compute queue",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_COMPUTE_ENGINE_BUSY", "COMMAND PARSER COMPUTE ENGINE BUSY",
                          "Percentage of time in which there is a context loaded and active on the compute queue",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$COMMAND_PARSER_COMPUTE_ENGINE_BUSY_CCS1 $COMMAND_PARSER_COMPUTE_ENGINE_BUSY_CCS0 FADD $COMMAND_PARSER_COMPUTE_ENGINE_BUSY_CCS2 FADD $COMMAND_PARSER_COMPUTE_ENGINE_BUSY_CCS3 FADD 4 FDIV $GpuCoreClocks FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_RENDER_ENGINE_BUSY", "COMMAND PARSER RENDER ENGINE BUSY",
                          "Percentage of time in which there is a context loaded and active on the 3D queue",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14040400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c040200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24040200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c040200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38040010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000401c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020400ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04040000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06040081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08040248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a04040a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c040491, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e040658, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1004081a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120408a1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00085555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02081555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x10800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000038, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x000001c0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000e00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00038000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00008fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt635MetricSet::CExt635MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt635MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_COPY_ENGINE_BUSY", "COMMAND PARSER COPY ENGINE BUSY",
                          "Percentage of time in which there is a context loaded and active on the copy queue.",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_VIDEO_ENGINE_BUSY_VDBOX0", "COMMAND PARSER VIDEO ENGINE BUSY VDBOX0",
                          "Percentage of time in which there is a context loaded and active on the media queue",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_VIDEO_ENHANCEMENT_ENGINE_BUSY_VEBOX0", "COMMAND PARSER VIDEO ENHANCEMENT ENGINE BUSY VEBOX0",
                          "Percentage of time in which there is a context loaded and active on the video enhancement queue",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_VIDEO_ENGINE_BUSY_VDBOX1", "COMMAND PARSER VIDEO ENGINE BUSY VDBOX1",
                          "Percentage of time in which there is a context loaded and active on the media queue",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_VIDEO_ENHANCEMENT_ENGINE_BUSY_VEBOX1", "COMMAND PARSER VIDEO ENHANCEMENT ENGINE BUSY VEBOX1",
                          "Percentage of time in which there is a context loaded and active on the video enhancement queue",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_VIDEO_ENGINE_BUSY", "COMMAND PARSER VIDEO ENGINE BUSY",
                          "Percentage of time in which there is a context loaded and active on the media queue",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$COMMAND_PARSER_VIDEO_ENGINE_BUSY_VDBOX0 $COMMAND_PARSER_VIDEO_ENGINE_BUSY_VDBOX1 FADD 2 FDIV $GpuCoreClocks FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_VIDEO_ENHANCEMENT_ENGINE_BUSY", "COMMAND PARSER VIDEO ENHANCEMENT ENGINE BUSY",
                          "Percentage of time in which there is a context loaded and active on the video enhancement queue",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$COMMAND_PARSER_VIDEO_ENHANCEMENT_ENGINE_BUSY_VEBOX0 $COMMAND_PARSER_VIDEO_ENHANCEMENT_ENGINE_BUSY_VEBOX1 FADD 2 FDIV $GpuCoreClocks FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x420a0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18130100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040a001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c0a0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0a0491, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00105a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02100001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00125000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02120001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08130800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a1308a1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x420a0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18130100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040a001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120a0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x140a0491, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x021015a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02121500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00130000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e130800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x101308a1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18010010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08010081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02052aa9, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00035a92, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02035b6d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04035b6d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030846, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x420318c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x10800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000038, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x000001c0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000e00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00007000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00038000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00008fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt636MetricSet::CExt636MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt636MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_COMPUTE_ENGINE_DISPATCH_KERNEL_COUNT_CCS0", "COMMAND PARSER COMPUTE ENGINE DISPATCH KERNEL COUNT CCS0",
                          "Number of compute walker commands parsed on the compute engine",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_COMPUTE_ENGINE_DISPATCH_KERNEL_COUNT_CCS1", "COMMAND PARSER COMPUTE ENGINE DISPATCH KERNEL COUNT CCS1",
                          "Number of compute walker commands parsed on the compute engine",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_COMPUTE_ENGINE_DISPATCH_KERNEL_COUNT_CCS2", "COMMAND PARSER COMPUTE ENGINE DISPATCH KERNEL COUNT CCS2",
                          "Number of compute walker commands parsed on the compute engine",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_COMPUTE_ENGINE_DISPATCH_KERNEL_COUNT_CCS3", "COMMAND PARSER COMPUTE ENGINE DISPATCH KERNEL COUNT CCS3",
                          "Number of compute walker commands parsed on the compute engine",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_COMPUTE_ENGINE_DISPATCH_KERNEL_COUNT", "COMMAND PARSER COMPUTE ENGINE DISPATCH KERNEL COUNT",
                          "Number of compute walker commands parsed on the compute engine",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$$COMMAND_PARSER_COMPUTE_ENGINE_DISPATCH_KERNEL_COUNT_CCS1 $$COMMAND_PARSER_COMPUTE_ENGINE_DISPATCH_KERNEL_COUNT_CCS0 UADD $$COMMAND_PARSER_COMPUTE_ENGINE_DISPATCH_KERNEL_COUNT_CCS2 UADD $$COMMAND_PARSER_COMPUTE_ENGINE_DISPATCH_KERNEL_COUNT_CCS3 UADD" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_RENDER_ENGINE_DISPATCH_KERNEL_COUNT", "COMMAND PARSER RENDER ENGINE DISPATCH KERNEL COUNT",
                          "Number of compute walker commands parsed on the 3D engine",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_FLUSH_COUNT", "COMMAND PARSER FLUSH COUNT",
                          "Number of Stalling flushes at the top of the pipe",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "COMMAND_PARSER_RENDER_ENGINE_DRAW_COUNT", "COMMAND PARSER RENDER ENGINE DRAW COUNT",
                          "Number of DRAW and MESH commands parsed on the 3D engine",
                          "FrontEnd", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c04001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2404001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c04001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x340403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4004001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fc03, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000435bb, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040660, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04048c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06040022, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e040900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10040a20, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12040010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14040008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02085550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x10800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt637MetricSet::CExt637MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt637MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE0_XVE0_THREAD0", "XVE STALL ALUWR XECORE0 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE0_XVE0_THREAD0", "XVE STALL BARRIER XECORE0 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE0_XVE0_THREAD0", "XVE STALL INSTFETCH XECORE0 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE0_XVE0_THREAD0", "XVE STALL OTHER XECORE0 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE0_XVE0_THREAD0", "XVE STALL SBID XECORE0 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE0_XVE0_THREAD0", "XVE STALL SENDWR XECORE0 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE0_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE0 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a900236, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c90016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x009042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02904e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04900717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x069000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08900840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00815555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02815415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00875555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02875415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f9ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt638MetricSet::CExt638MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt638MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE1_XVE0_THREAD0", "XVE STALL ALUWR XECORE1 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE1_XVE0_THREAD0", "XVE STALL BARRIER XECORE1 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE1_XVE0_THREAD0", "XVE STALL INSTFETCH XECORE1 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE1_XVE0_THREAD0", "XVE STALL OTHER XECORE1 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE1_XVE0_THREAD0", "XVE STALL SBID XECORE1 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE1_XVE0_THREAD0", "XVE STALL SENDWR XECORE1 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE1_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE1 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ab00236, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cb0016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00b042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02b04e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04b00717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06b000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08b00840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a15415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a75415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fc3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f9ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt639MetricSet::CExt639MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt639MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE2_XVE0_THREAD0", "XVE STALL ALUWR XECORE2 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE2_XVE0_THREAD0", "XVE STALL BARRIER XECORE2 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE2_XVE0_THREAD0", "XVE STALL INSTFETCH XECORE2 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE2_XVE0_THREAD0", "XVE STALL OTHER XECORE2 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE2_XVE0_THREAD0", "XVE STALL SBID XECORE2 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE2_XVE0_THREAD0", "XVE STALL SENDWR XECORE2 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE2_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE2 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ad00236, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cd0016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d04e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04d00717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06d000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08d00840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c15415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c3a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c65415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c75415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aa82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f9ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt640MetricSet::CExt640MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt640MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE3_XVE0_THREAD0", "XVE STALL ALUWR XECORE3 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE3_XVE0_THREAD0", "XVE STALL BARRIER XECORE3 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE3_XVE0_THREAD0", "XVE STALL INSTFETCH XECORE3 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE3_XVE0_THREAD0", "XVE STALL OTHER XECORE3 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE3_XVE0_THREAD0", "XVE STALL SBID XECORE3 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE3_XVE0_THREAD0", "XVE STALL SENDWR XECORE3 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE3_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE3 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0af00236, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cf0016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f04e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04f00717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06f000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08f00840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e15415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e75415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aa82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f9ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt641MetricSet::CExt641MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt641MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE4_XVE0_THREAD0", "XVE STALL ALUWR XECORE4 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE4_XVE0_THREAD0", "XVE STALL BARRIER XECORE4 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE4_XVE0_THREAD0", "XVE STALL INSTFETCH XECORE4 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE4_XVE0_THREAD0", "XVE STALL OTHER XECORE4 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE4_XVE0_THREAD0", "XVE STALL SBID XECORE4 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE4_XVE0_THREAD0", "XVE STALL SENDWR XECORE4 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE4_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE4 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b900236, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d90016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x019042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03904e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05900717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x079000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09900840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01815555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03815415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01875555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03875415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fc3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020ba82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f9ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt642MetricSet::CExt642MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt642MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE5_XVE0_THREAD0", "XVE STALL ALUWR XECORE5 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE5_XVE0_THREAD0", "XVE STALL BARRIER XECORE5 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE5_XVE0_THREAD0", "XVE STALL INSTFETCH XECORE5 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE5_XVE0_THREAD0", "XVE STALL OTHER XECORE5 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE5_XVE0_THREAD0", "XVE STALL SBID XECORE5 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE5_XVE0_THREAD0", "XVE STALL SENDWR XECORE5 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE5_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE5 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bb00236, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0db0016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01b042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03b04e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05b00717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07b000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09b00840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a15415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a75415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fc3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020ba82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308fc3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f9ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt643MetricSet::CExt643MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt643MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE6_XVE0_THREAD0", "XVE STALL ALUWR XECORE6 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE6_XVE0_THREAD0", "XVE STALL BARRIER XECORE6 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE6_XVE0_THREAD0", "XVE STALL INSTFETCH XECORE6 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE6_XVE0_THREAD0", "XVE STALL OTHER XECORE6 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE6_XVE0_THREAD0", "XVE STALL SBID XECORE6 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE6_XVE0_THREAD0", "XVE STALL SENDWR XECORE6 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE6_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE6 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bd00236, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dd0016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03d04e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05d00717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07d000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09d00840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c15415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c3a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c65415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c75415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fc3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020ba82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aa82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f9ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt644MetricSet::CExt644MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt644MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE7_XVE0_THREAD0", "XVE STALL ALUWR XECORE7 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE7_XVE0_THREAD0", "XVE STALL BARRIER XECORE7 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE7_XVE0_THREAD0", "XVE STALL INSTFETCH XECORE7 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE7_XVE0_THREAD0", "XVE STALL OTHER XECORE7 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE7_XVE0_THREAD0", "XVE STALL SBID XECORE7 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE7_XVE0_THREAD0", "XVE STALL SENDWR XECORE7 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE7_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE7 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bf00236, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0df0016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03f04e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05f00717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07f000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09f00840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e15415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e75415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fc3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020ba82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aa82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f9ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt645MetricSet::CExt645MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt645MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE8_XVE0_THREAD0", "XVE STALL ALUWR XECORE8 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE8_XVE0_THREAD0", "XVE STALL BARRIER XECORE8 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE8_XVE0_THREAD0", "XVE STALL INSTFETCH XECORE8 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE8_XVE0_THREAD0", "XVE STALL OTHER XECORE8 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE8_XVE0_THREAD0", "XVE STALL SBID XECORE8 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE8_XVE0_THREAD0", "XVE STALL SENDWR XECORE8 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE8_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE8 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a900236, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c90016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x009042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02904e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04900717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x069000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08900840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00815555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02815415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00875555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02875415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fc3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f9ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt646MetricSet::CExt646MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt646MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE9_XVE0_THREAD0", "XVE STALL ALUWR XECORE9 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE9_XVE0_THREAD0", "XVE STALL BARRIER XECORE9 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE9_XVE0_THREAD0", "XVE STALL INSTFETCH XECORE9 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE9_XVE0_THREAD0", "XVE STALL OTHER XECORE9 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE9_XVE0_THREAD0", "XVE STALL SBID XECORE9 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE9_XVE0_THREAD0", "XVE STALL SENDWR XECORE9 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE9_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE9 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ab00236, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cb0016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00b042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02b04e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04b00717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06b000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08b00840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a15415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a75415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fc3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fc3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f9ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt647MetricSet::CExt647MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt647MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE10_XVE0_THREAD0", "XVE STALL ALUWR XECORE10 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE10_XVE0_THREAD0", "XVE STALL BARRIER XECORE10 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE10_XVE0_THREAD0", "XVE STALL INSTFETCH XECORE10 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE10_XVE0_THREAD0", "XVE STALL OTHER XECORE10 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE10_XVE0_THREAD0", "XVE STALL SBID XECORE10 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE10_XVE0_THREAD0", "XVE STALL SENDWR XECORE10 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE10_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE10 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ad00236, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cd0016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d04e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04d00717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06d000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08d00840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c15415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c3a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c65415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c75415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aa82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fc3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f9ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt648MetricSet::CExt648MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt648MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE11_XVE0_THREAD0", "XVE STALL ALUWR XECORE11 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE11_XVE0_THREAD0", "XVE STALL BARRIER XECORE11 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE11_XVE0_THREAD0", "XVE STALL INSTFETCH XECORE11 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE11_XVE0_THREAD0", "XVE STALL OTHER XECORE11 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE11_XVE0_THREAD0", "XVE STALL SBID XECORE11 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE11_XVE0_THREAD0", "XVE STALL SENDWR XECORE11 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE11_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE11 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0af00236, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cf0016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f04e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04f00717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06f000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08f00840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e15415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e75415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aa82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fc3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f9ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt649MetricSet::CExt649MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt649MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE12_XVE0_THREAD0", "XVE STALL ALUWR XECORE12 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE12_XVE0_THREAD0", "XVE STALL BARRIER XECORE12 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE12_XVE0_THREAD0", "XVE STALL INSTFETCH XECORE12 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE12_XVE0_THREAD0", "XVE STALL OTHER XECORE12 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE12_XVE0_THREAD0", "XVE STALL SBID XECORE12 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE12_XVE0_THREAD0", "XVE STALL SENDWR XECORE12 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE12_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE12 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b900236, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d90016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x019042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03904e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05900717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x079000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09900840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01815555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03815415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01875555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03875415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fc3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020ba82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fc3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f9ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt650MetricSet::CExt650MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt650MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE13_XVE0_THREAD0", "XVE STALL ALUWR XECORE13 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE13_XVE0_THREAD0", "XVE STALL BARRIER XECORE13 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE13_XVE0_THREAD0", "XVE STALL INSTFETCH XECORE13 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE13_XVE0_THREAD0", "XVE STALL OTHER XECORE13 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE13_XVE0_THREAD0", "XVE STALL SBID XECORE13 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE13_XVE0_THREAD0", "XVE STALL SENDWR XECORE13 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE13_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE13 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bb00236, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0db0016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01b042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03b04e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05b00717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07b000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09b00840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a15415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a75415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fc3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020ba82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308fc3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fc3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f9ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt651MetricSet::CExt651MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt651MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE14_XVE0_THREAD0", "XVE STALL ALUWR XECORE14 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE14_XVE0_THREAD0", "XVE STALL BARRIER XECORE14 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE14_XVE0_THREAD0", "XVE STALL INSTFETCH XECORE14 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE14_XVE0_THREAD0", "XVE STALL OTHER XECORE14 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE14_XVE0_THREAD0", "XVE STALL SBID XECORE14 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE14_XVE0_THREAD0", "XVE STALL SENDWR XECORE14 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE14_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE14 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bd00236, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dd0016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03d04e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05d00717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07d000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09d00840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c15415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c3a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c65415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c75415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fc3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020ba82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aa82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fc3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f9ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt652MetricSet::CExt652MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt652MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE15_XVE0_THREAD0", "XVE STALL ALUWR XECORE15 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE15_XVE0_THREAD0", "XVE STALL BARRIER XECORE15 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE15_XVE0_THREAD0", "XVE STALL INSTFETCH XECORE15 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE15_XVE0_THREAD0", "XVE STALL OTHER XECORE15 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE15_XVE0_THREAD0", "XVE STALL SBID XECORE15 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE15_XVE0_THREAD0", "XVE STALL SENDWR XECORE15 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE15_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE15 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bf00236, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0df0016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03f04e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05f00717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07f000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09f00840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e15415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e75415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fc3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020ba82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aa82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fc3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032402, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f9ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt653MetricSet::CExt653MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt653MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE16_XVE0_THREAD0", "XVE STALL ALUWR XECORE16 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE16_XVE0_THREAD0", "XVE STALL BARRIER XECORE16 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE16_XVE0_THREAD0", "XVE STALL INSTFETCH XECORE16 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE16_XVE0_THREAD0", "XVE STALL OTHER XECORE16 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE16_XVE0_THREAD0", "XVE STALL SBID XECORE16 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE16_XVE0_THREAD0", "XVE STALL SENDWR XECORE16 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE16_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE16 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a900236, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c90016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x009042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02904e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04900717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x069000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08900840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00815555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02815415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00875555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02875415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f9ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt654MetricSet::CExt654MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt654MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE17_XVE0_THREAD0", "XVE STALL ALUWR XECORE17 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE17_XVE0_THREAD0", "XVE STALL BARRIER XECORE17 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE17_XVE0_THREAD0", "XVE STALL INSTFETCH XECORE17 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE17_XVE0_THREAD0", "XVE STALL OTHER XECORE17 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE17_XVE0_THREAD0", "XVE STALL SBID XECORE17 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE17_XVE0_THREAD0", "XVE STALL SENDWR XECORE17 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE17_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE17 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ab00236, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cb0016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00b042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02b04e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04b00717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06b000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08b00840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a15415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a75415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fc3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f9ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt655MetricSet::CExt655MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt655MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE18_XVE0_THREAD0", "XVE STALL ALUWR XECORE18 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE18_XVE0_THREAD0", "XVE STALL BARRIER XECORE18 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE18_XVE0_THREAD0", "XVE STALL INSTFETCH XECORE18 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE18_XVE0_THREAD0", "XVE STALL OTHER XECORE18 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE18_XVE0_THREAD0", "XVE STALL SBID XECORE18 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE18_XVE0_THREAD0", "XVE STALL SENDWR XECORE18 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE18_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE18 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ad00236, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cd0016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d04e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04d00717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06d000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08d00840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c15415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c3a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c65415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c75415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aa82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f9ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt656MetricSet::CExt656MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt656MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE19_XVE0_THREAD0", "XVE STALL ALUWR XECORE19 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE19_XVE0_THREAD0", "XVE STALL BARRIER XECORE19 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE19_XVE0_THREAD0", "XVE STALL INSTFETCH XECORE19 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE19_XVE0_THREAD0", "XVE STALL OTHER XECORE19 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE19_XVE0_THREAD0", "XVE STALL SBID XECORE19 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE19_XVE0_THREAD0", "XVE STALL SENDWR XECORE19 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE19_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE19 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0af00236, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cf0016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f04e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04f00717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06f000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08f00840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e15415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e75415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aa82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f9ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt657MetricSet::CExt657MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt657MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE20_XVE0_THREAD0", "XVE STALL ALUWR XECORE20 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE20_XVE0_THREAD0", "XVE STALL BARRIER XECORE20 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE20_XVE0_THREAD0", "XVE STALL INSTFETCH XECORE20 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE20_XVE0_THREAD0", "XVE STALL OTHER XECORE20 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE20_XVE0_THREAD0", "XVE STALL SBID XECORE20 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE20_XVE0_THREAD0", "XVE STALL SENDWR XECORE20 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE20_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE20 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b900236, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d90016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x019042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03904e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05900717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x079000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09900840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01815555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03815415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01875555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03875415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fc3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020ba82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f9ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt658MetricSet::CExt658MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt658MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE21_XVE0_THREAD0", "XVE STALL ALUWR XECORE21 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE21_XVE0_THREAD0", "XVE STALL BARRIER XECORE21 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE21_XVE0_THREAD0", "XVE STALL INSTFETCH XECORE21 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE21_XVE0_THREAD0", "XVE STALL OTHER XECORE21 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE21_XVE0_THREAD0", "XVE STALL SBID XECORE21 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE21_XVE0_THREAD0", "XVE STALL SENDWR XECORE21 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE21_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE21 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bb00236, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0db0016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01b042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03b04e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05b00717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07b000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09b00840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a15415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a75415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fc3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020ba82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308fc3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f9ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt659MetricSet::CExt659MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt659MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE22_XVE0_THREAD0", "XVE STALL ALUWR XECORE22 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE22_XVE0_THREAD0", "XVE STALL BARRIER XECORE22 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE22_XVE0_THREAD0", "XVE STALL INSTFETCH XECORE22 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE22_XVE0_THREAD0", "XVE STALL OTHER XECORE22 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE22_XVE0_THREAD0", "XVE STALL SBID XECORE22 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE22_XVE0_THREAD0", "XVE STALL SENDWR XECORE22 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE22_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE22 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bd00236, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dd0016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03d04e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05d00717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07d000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09d00840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c15415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c3a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c65415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c75415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fc3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020ba82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aa82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f9ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt660MetricSet::CExt660MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt660MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE23_XVE0_THREAD0", "XVE STALL ALUWR XECORE23 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE23_XVE0_THREAD0", "XVE STALL BARRIER XECORE23 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE23_XVE0_THREAD0", "XVE STALL INSTFETCH XECORE23 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE23_XVE0_THREAD0", "XVE STALL OTHER XECORE23 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE23_XVE0_THREAD0", "XVE STALL SBID XECORE23 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE23_XVE0_THREAD0", "XVE STALL SENDWR XECORE23 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE23_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE23 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bf00236, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0df0016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03f04e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05f00717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07f000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09f00840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e15415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e75415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fc3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020ba82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aa82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f9ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt661MetricSet::CExt661MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt661MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE24_XVE0_THREAD0", "XVE STALL ALUWR XECORE24 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE24_XVE0_THREAD0", "XVE STALL BARRIER XECORE24 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE24_XVE0_THREAD0", "XVE STALL INSTFETCH XECORE24 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE24_XVE0_THREAD0", "XVE STALL OTHER XECORE24 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE24_XVE0_THREAD0", "XVE STALL SBID XECORE24 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE24_XVE0_THREAD0", "XVE STALL SENDWR XECORE24 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE24_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE24 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a900236, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c90016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x009042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02904e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04900717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x069000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08900840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00815555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02815415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00875555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02875415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f9ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt662MetricSet::CExt662MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt662MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE25_XVE0_THREAD0", "XVE STALL ALUWR XECORE25 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE25_XVE0_THREAD0", "XVE STALL BARRIER XECORE25 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE25_XVE0_THREAD0", "XVE STALL INSTFETCH XECORE25 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE25_XVE0_THREAD0", "XVE STALL OTHER XECORE25 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE25_XVE0_THREAD0", "XVE STALL SBID XECORE25 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE25_XVE0_THREAD0", "XVE STALL SENDWR XECORE25 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE25_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE25 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ab00236, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cb0016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00b042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02b04e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04b00717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06b000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08b00840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a15415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a75415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fc3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f9ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt663MetricSet::CExt663MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt663MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE26_XVE0_THREAD0", "XVE STALL ALUWR XECORE26 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE26_XVE0_THREAD0", "XVE STALL BARRIER XECORE26 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE26_XVE0_THREAD0", "XVE STALL INSTFETCH XECORE26 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE26_XVE0_THREAD0", "XVE STALL OTHER XECORE26 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE26_XVE0_THREAD0", "XVE STALL SBID XECORE26 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE26_XVE0_THREAD0", "XVE STALL SENDWR XECORE26 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE26_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE26 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ad00236, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cd0016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d04e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04d00717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06d000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08d00840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c15415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c3a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c65415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c75415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aa82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f9ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt664MetricSet::CExt664MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt664MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE27_XVE0_THREAD0", "XVE STALL ALUWR XECORE27 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE27_XVE0_THREAD0", "XVE STALL BARRIER XECORE27 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE27_XVE0_THREAD0", "XVE STALL INSTFETCH XECORE27 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE27_XVE0_THREAD0", "XVE STALL OTHER XECORE27 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE27_XVE0_THREAD0", "XVE STALL SBID XECORE27 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE27_XVE0_THREAD0", "XVE STALL SENDWR XECORE27 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE27_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE27 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0af00236, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cf0016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f04e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04f00717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06f000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08f00840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e15415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e75415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aa82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f9ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt665MetricSet::CExt665MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt665MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE28_XVE0_THREAD0", "XVE STALL ALUWR XECORE28 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE28_XVE0_THREAD0", "XVE STALL BARRIER XECORE28 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE28_XVE0_THREAD0", "XVE STALL INSTFETCH XECORE28 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE28_XVE0_THREAD0", "XVE STALL OTHER XECORE28 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE28_XVE0_THREAD0", "XVE STALL SBID XECORE28 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE28_XVE0_THREAD0", "XVE STALL SENDWR XECORE28 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE28_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE28 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b900236, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d90016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x019042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03904e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05900717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x079000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09900840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01815555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03815415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01875555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03875415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fc3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020ba82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f9ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt666MetricSet::CExt666MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt666MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE29_XVE0_THREAD0", "XVE STALL ALUWR XECORE29 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE29_XVE0_THREAD0", "XVE STALL BARRIER XECORE29 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE29_XVE0_THREAD0", "XVE STALL INSTFETCH XECORE29 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE29_XVE0_THREAD0", "XVE STALL OTHER XECORE29 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE29_XVE0_THREAD0", "XVE STALL SBID XECORE29 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE29_XVE0_THREAD0", "XVE STALL SENDWR XECORE29 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE29_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE29 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bb00236, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0db0016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01b042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03b04e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05b00717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07b000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09b00840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a15415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a75415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fc3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020ba82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308fc3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f9ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt667MetricSet::CExt667MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt667MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE30_XVE0_THREAD0", "XVE STALL ALUWR XECORE30 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE30_XVE0_THREAD0", "XVE STALL BARRIER XECORE30 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE30_XVE0_THREAD0", "XVE STALL INSTFETCH XECORE30 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE30_XVE0_THREAD0", "XVE STALL OTHER XECORE30 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE30_XVE0_THREAD0", "XVE STALL SBID XECORE30 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE30_XVE0_THREAD0", "XVE STALL SENDWR XECORE30 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE30_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE30 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bd00236, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dd0016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03d04e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05d00717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07d000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09d00840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c15415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c3a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c65415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c75415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fc3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020ba82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aa82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f9ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt668MetricSet::CExt668MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt668MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "XVE_STALL_ALUWR_XECORE31_XVE0_THREAD0", "XVE STALL ALUWR XECORE31 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for ALU to write GRF/ACC register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "XVE_STALL_BARRIER_XECORE31_XVE0_THREAD0", "XVE STALL BARRIER XECORE31 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Gateway to write Notify register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "XVE_STALL_INSTFETCH_XECORE31_XVE0_THREAD0", "XVE STALL INSTFETCH XECORE31 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Instruction Fetch",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "XVE_STALL_OTHER_XECORE31_XVE0_THREAD0", "XVE STALL OTHER XECORE31 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting on any other dependency (Flag/EoT etc)",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "XVE_STALL_SBID_XECORE31_XVE0_THREAD0", "XVE STALL SBID XECORE31 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for Scoreboard token to be available",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "XVE_STALL_SENDWR_XECORE31_XVE0_THREAD0", "XVE STALL SENDWR XECORE31 XVE0 THREAD0",
                          "Percentage of time in which XVE stalled, with at least one thread waiting for SEND to write GRF register",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "XVE_SHARED_FUNCTION_ACCESS_HOLD_XECORE31_XVE0_THREAD0", "XVE SHARED FUNCTION ACCESS HOLD XECORE31 XVE0 THREAD0",
                          "Percentage of time in which XVE requests stalled by Shared Function units",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bf00236, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0df0016a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f042b2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03f04e9c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05f00717, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07f000e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09f00840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e15555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e15415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e75555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e75415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fc3f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020ba82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aa82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001e7ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055415, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a82a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000018, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f80, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f9ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt669MetricSet::CExt669MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt669MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE0_XVE0", "XVE INST ISSUED ALL XECORE0 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE1_XVE0", "XVE INST ISSUED ALL XECORE1 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE2_XVE0", "XVE INST ISSUED ALL XECORE2 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a906f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c900006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ab06f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cb00006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ad06f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cd00006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00904eb4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02900166, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02b05000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04b01a75, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06b0000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00b00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a15400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06d05680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08d02cd3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c11550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c32aa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c47c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c61550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c71550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02072aa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008feaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00097c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2aa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00027c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c1550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000fa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001f02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0003e002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt670MetricSet::CExt670MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt670MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE3_XVE0", "XVE INST ISSUED ALL XECORE3 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE4_XVE0", "XVE INST ISSUED ALL XECORE4 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE5_XVE0", "XVE INST ISSUED ALL XECORE5 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0af06f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cf00006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b906f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d900006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bb06f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0db00006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f04eb4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f00166, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03905000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05901a75, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0790000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01900000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01815400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01875400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07b05680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09b02cd3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01b00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a11550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a32aa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a47c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a61550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a71550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00037fe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a56aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017fe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000ba800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03083ffa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01017c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b1550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42031080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030084, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000fa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001f02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0003e002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt671MetricSet::CExt671MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt671MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE6_XVE0", "XVE INST ISSUED ALL XECORE6 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE7_XVE0", "XVE INST ISSUED ALL XECORE7 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE8_XVE0", "XVE INST ISSUED ALL XECORE8 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bd06f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dd00006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bf06f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0df00006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d04eb4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03d00166, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03f05000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05f01a75, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07f0000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e15400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000303ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010756aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010903ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a906f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c900006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06905680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08902cd3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00900000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02811550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02832aa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00847c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02861550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02871550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083ffa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000fa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001f02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0003e002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt672MetricSet::CExt672MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt672MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE9_XVE0", "XVE INST ISSUED ALL XECORE9 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE10_XVE0", "XVE INST ISSUED ALL XECORE10 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE11_XVE0", "XVE INST ISSUED ALL XECORE11 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ab06f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cb00006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ad06f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cd00006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0af06f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cf00006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00b04eb4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02b00166, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d05000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04d01a75, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06d0000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c15400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06f05680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08f02cd3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e11550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e32aa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e47c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e61550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e71550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207155a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000803ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00097fe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aa955, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000203e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032943, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030c60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000fa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001f02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0003e002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt673MetricSet::CExt673MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt673MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE12_XVE0", "XVE INST ISSUED ALL XECORE12 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE13_XVE0", "XVE INST ISSUED ALL XECORE13 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE14_XVE0", "XVE INST ISSUED ALL XECORE14 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b906f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d900006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bb06f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0db00006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bd06f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dd00006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01904eb4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03900166, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03b05000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05b01a75, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07b0000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01b00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a15400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07d05680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09d02cd3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c11550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c32aa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c47c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c61550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c71550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00037fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03072aa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108feaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01097c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a2aa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010103e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01027c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c1550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000fa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001f02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0003e002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt674MetricSet::CExt674MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt674MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE15_XVE0", "XVE INST ISSUED ALL XECORE15 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE16_XVE0", "XVE INST ISSUED ALL XECORE16 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE17_XVE0", "XVE INST ISSUED ALL XECORE17 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bf06f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0df00006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f04eb4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03f00166, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000803ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b02aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a02aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a906f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c900006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ab06f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cb00006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02905000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04901a75, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0690000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00900000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00815400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00875400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06b05680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08b02cd3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00b00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a11550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a32aa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a47c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a71550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083ffa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b1550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000803ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603146a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480306a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03146a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000802aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017fe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000fa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001f02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0003e002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt675MetricSet::CExt675MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt675MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE18_XVE0", "XVE INST ISSUED ALL XECORE18 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE19_XVE0", "XVE INST ISSUED ALL XECORE19 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE20_XVE0", "XVE INST ISSUED ALL XECORE20 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ad06f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cd00006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0af06f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cf00006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b906f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d900006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d04eb4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02d00166, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f05000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04f01a75, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06f0000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e15400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07905680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09902cd3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01900000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03811550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03832aa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01847c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03861550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03871550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00037c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000756aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000903ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a155a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2aa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03082aa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x420318c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030cc6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030a65, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030653, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030a65, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000fa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001f02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0003e002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt676MetricSet::CExt676MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt676MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE21_XVE0", "XVE INST ISSUED ALL XECORE21 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE22_XVE0", "XVE INST ISSUED ALL XECORE22 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE23_XVE0", "XVE INST ISSUED ALL XECORE23 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bb06f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0db00006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bd06f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dd00006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bf06f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0df00006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01b04eb4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03b00166, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03d05000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05d01a75, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07d0000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c15400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07f05680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09f02cd3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e11550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e32aa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e47c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e61550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e71550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00037fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307155a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010803ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01097fe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa955, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a2aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010203e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032943, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030c60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000fa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001f02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0003e002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt677MetricSet::CExt677MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt677MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE24_XVE0", "XVE INST ISSUED ALL XECORE24 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE25_XVE0", "XVE INST ISSUED ALL XECORE25 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE26_XVE0", "XVE INST ISSUED ALL XECORE26 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a906f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c900006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ab06f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cb00006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ad06f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cd00006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00904eb4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02900166, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02b05000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04b01a75, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06b0000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00b00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a15400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06d05680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08d02cd3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c11550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c32aa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c47c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c61550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c71550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02072aa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008feaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00097c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2aa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00027c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c1550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02022aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000fa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001f02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0003e002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt678MetricSet::CExt678MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt678MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE27_XVE0", "XVE INST ISSUED ALL XECORE27 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE28_XVE0", "XVE INST ISSUED ALL XECORE28 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE29_XVE0", "XVE INST ISSUED ALL XECORE29 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0af06f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cf00006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b906f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d900006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bb06f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0db00006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f04eb4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02f00166, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03905000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05901a75, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0790000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01900000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01815400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01875400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07b05680, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09b02cd3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01b00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a11550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a32aa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a47c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a61550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a71550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00037fe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a56aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017fe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000ba800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03083ffa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01017c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b1550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02022aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42031080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030084, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000fa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001f02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x0003e002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt679MetricSet::CExt679MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt679MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE30_XVE0", "XVE INST ISSUED ALL XECORE30 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "XVE_INST_ISSUED_ALL_XECORE31_XVE0", "XVE INST ISSUED ALL XECORE31 XVE0",
                          "Number of instructions issued (decoded) to any pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bd06f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dd00006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bf06f40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0df00006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d04eb4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03d00166, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03f05000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05f01a75, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07f0000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e15400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000303ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010756aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010903ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000fa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001f02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt680MetricSet::CExt680MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt680MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_ALLOC_L3NODE0", "RENDER CACHE ALLOC L3NODE0",
                          "Number of Render Cache allocations",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 0 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_ALLOC_L3NODE1", "RENDER CACHE ALLOC L3NODE1",
                          "Number of Render Cache allocations",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_ALLOC_L3NODE2", "RENDER CACHE ALLOC L3NODE2",
                          "Number of Render Cache allocations",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 1 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_ALLOC_L3NODE3", "RENDER CACHE ALLOC L3NODE3",
                          "Number of Render Cache allocations",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_ALLOC_L3NODE4", "RENDER CACHE ALLOC L3NODE4",
                          "Number of Render Cache allocations",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 2 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_ALLOC_L3NODE5", "RENDER CACHE ALLOC L3NODE5",
                          "Number of Render Cache allocations",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_ALLOC_L3NODE6", "RENDER CACHE ALLOC L3NODE6",
                          "Number of Render Cache allocations",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$SliceMask 3 3 2 UMUL << AND";
        metric               = AddMetric( "RENDER_CACHE_ALLOC_L3NODE7", "RENDER CACHE ALLOC L3NODE7",
                          "Number of Render Cache allocations",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180301e9, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180801e9, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030e30, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000400a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080e30, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180301e9, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180801e9, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a030e30, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0004a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080e30, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180301e9, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180801e9, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e030e30, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020400a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c080e30, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180301e9, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x180801e9, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12030e30, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0204a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080e30, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031292, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030401, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00002002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00020002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt681MetricSet::CExt681MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt681MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE0", "GPGPU THREADGROUP COUNT XECORE0",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE4", "ASYNC GPGPU THREADGROUP COUNT XECORE4",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE8", "ASYNC GPGPU THREAD EXIT COUNT XECORE8",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e81001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2d812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f81001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06819800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a810d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c810039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07819800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f810d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11810fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01875400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008feaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000ba800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c813000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12810c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14810cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16810db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02875550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fffa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt682MetricSet::CExt682MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt682MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE1", "GPGPU THREADGROUP COUNT XECORE1",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE5", "ASYNC GPGPU THREADGROUP COUNT XECORE5",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE9", "ASYNC GPGPU THREAD EXIT COUNT XECORE9",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ca12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ea1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2da12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2fa1001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da10c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa10d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a10fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000ba955, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010103e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ca13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a10c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a75550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fffa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt683MetricSet::CExt683MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt683MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE2", "GPGPU THREADGROUP COUNT XECORE2",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE6", "ASYNC GPGPU THREADGROUP COUNT XECORE6",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE10", "ASYNC GPGPU THREAD EXIT COUNT XECORE10",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2cc12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ec1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2dc12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2fc1001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc10c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c10fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000702aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a56aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000ba800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010903e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010203e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2cc13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c10c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c3aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c65550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c75550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fffa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt684MetricSet::CExt684MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt684MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE3", "GPGPU THREADGROUP COUNT XECORE3",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE7", "ASYNC GPGPU THREADGROUP COUNT XECORE7",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE11", "ASYNC GPGPU THREAD EXIT COUNT XECORE11",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ce12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ee1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2de12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2fe1001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de10c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe10d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a56aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000ba800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010903e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ce13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e10c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e75550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fffa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt685MetricSet::CExt685MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt685MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE4", "GPGPU THREADGROUP COUNT XECORE4",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE8", "ASYNC GPGPU THREADGROUP COUNT XECORE8",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE12", "ASYNC GPGPU THREAD EXIT COUNT XECORE12",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2d812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f81001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07819800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b810d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000803ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b02aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010802aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e81001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2d813000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06819800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c810c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e810d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10810fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00875400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13810c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15810cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17810db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03875550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fffa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008feaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030683, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000802aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt686MetricSet::CExt686MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt686MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE5", "GPGPU THREADGROUP COUNT XECORE5",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE9", "ASYNC GPGPU THREADGROUP COUNT XECORE9",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE13", "ASYNC GPGPU THREAD EXIT COUNT XECORE13",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2da12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2fa1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000803ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b02aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010803ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ca12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ea1001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2da13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca10c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea10d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a10fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a75550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008feaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030683, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000802aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt687MetricSet::CExt687MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt687MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE6", "GPGPU THREADGROUP COUNT XECORE6",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE10", "ASYNC GPGPU THREADGROUP COUNT XECORE10",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE14", "ASYNC GPGPU THREAD EXIT COUNT XECORE14",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2dc12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2fc1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000803ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b02aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010702aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a02aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2cc12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ec1001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2dc13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec10d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c10fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c10c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c3aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c65550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c75550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000903e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aa800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a555a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000203e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008feaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030683, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000802aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt688MetricSet::CExt688MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt688MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE7", "GPGPU THREADGROUP COUNT XECORE7",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE11", "ASYNC GPGPU THREADGROUP COUNT XECORE11",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE15", "ASYNC GPGPU THREAD EXIT COUNT XECORE15",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2de12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2fe1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000803ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b02aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a02aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ce12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ee1001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2de13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce10c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee10d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e10fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e10c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e75550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000903e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aa800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a555a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008feaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030683, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000802aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt689MetricSet::CExt689MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt689MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE8", "GPGPU THREADGROUP COUNT XECORE8",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE12", "ASYNC GPGPU THREADGROUP COUNT XECORE12",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE16", "ASYNC GPGPU THREAD EXIT COUNT XECORE16",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e81001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2d812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f81001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06819800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a810d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c810039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07819800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f810d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11810fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01875400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008feaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000ba800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c813000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12810c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14810cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16810db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02875550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031ce7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt690MetricSet::CExt690MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt690MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE9", "GPGPU THREADGROUP COUNT XECORE9",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE13", "ASYNC GPGPU THREADGROUP COUNT XECORE13",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE17", "ASYNC GPGPU THREAD EXIT COUNT XECORE17",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ca12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ea1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2da12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2fa1001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da10c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa10d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a10fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000ba955, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010103e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ca13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a10c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a75550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031ce7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt691MetricSet::CExt691MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt691MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE10", "GPGPU THREADGROUP COUNT XECORE10",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE14", "ASYNC GPGPU THREADGROUP COUNT XECORE14",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE18", "ASYNC GPGPU THREAD EXIT COUNT XECORE18",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2cc12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ec1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2dc12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2fc1001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc10c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c10fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000702aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a56aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000ba800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010903e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010203e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2cc13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c10c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c3aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c65550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c75550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031ce7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt692MetricSet::CExt692MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt692MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE11", "GPGPU THREADGROUP COUNT XECORE11",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE15", "ASYNC GPGPU THREADGROUP COUNT XECORE15",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE19", "ASYNC GPGPU THREAD EXIT COUNT XECORE19",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ce12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ee1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2de12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2fe1001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de10c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe10d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a56aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000ba800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010903e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ce13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e10c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e75550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031ce8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031ce7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt693MetricSet::CExt693MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt693MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE12", "GPGPU THREADGROUP COUNT XECORE12",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE16", "ASYNC GPGPU THREADGROUP COUNT XECORE16",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE20", "ASYNC GPGPU THREAD EXIT COUNT XECORE20",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2d812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f81001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07819800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b810d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000803ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b02aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010802aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e81001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2d813000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06819800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c810c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e810d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10810fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00875400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13810c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15810cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17810db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03875550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fffa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000803ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030c21, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030683, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000802aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt694MetricSet::CExt694MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt694MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE13", "GPGPU THREADGROUP COUNT XECORE13",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE17", "ASYNC GPGPU THREADGROUP COUNT XECORE17",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE21", "ASYNC GPGPU THREAD EXIT COUNT XECORE21",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2da12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2fa1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000803ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b02aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010803ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ca12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ea1001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2da13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca10c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea10d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a10fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a75550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000803ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030c21, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030683, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000802aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt695MetricSet::CExt695MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt695MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE14", "GPGPU THREADGROUP COUNT XECORE14",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE18", "ASYNC GPGPU THREADGROUP COUNT XECORE18",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE22", "ASYNC GPGPU THREAD EXIT COUNT XECORE22",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2dc12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2fc1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000803ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b02aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010702aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a02aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2cc12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ec1001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2dc13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec10d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c10fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c10c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c3aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c65550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c75550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000903e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aa800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a555a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000203e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000803ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030c21, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030683, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000802aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt696MetricSet::CExt696MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt696MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE15", "GPGPU THREADGROUP COUNT XECORE15",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE19", "ASYNC GPGPU THREADGROUP COUNT XECORE19",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE23", "ASYNC GPGPU THREAD EXIT COUNT XECORE23",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2de12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2fe1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000803ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b02aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a02aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ce12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ee1001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2de13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce10c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee10d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e10fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e10c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e75550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000903e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aa800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a555a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000803ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030c21, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030683, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000802aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt697MetricSet::CExt697MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt697MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE16", "GPGPU THREADGROUP COUNT XECORE16",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE20", "ASYNC GPGPU THREADGROUP COUNT XECORE20",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE24", "ASYNC GPGPU THREAD EXIT COUNT XECORE24",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e81001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2d812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f81001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06819800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a810d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c810039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07819800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f810d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11810fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01875400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008feaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000ba800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c813000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12810c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14810cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16810db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02875550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt698MetricSet::CExt698MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt698MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE17", "GPGPU THREADGROUP COUNT XECORE17",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE21", "ASYNC GPGPU THREADGROUP COUNT XECORE21",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE25", "ASYNC GPGPU THREAD EXIT COUNT XECORE25",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ca12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ea1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2da12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2fa1001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da10c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa10d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a10fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000ba955, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010103e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ca13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a10c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a75550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt699MetricSet::CExt699MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt699MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE18", "GPGPU THREADGROUP COUNT XECORE18",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE22", "ASYNC GPGPU THREADGROUP COUNT XECORE22",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE26", "ASYNC GPGPU THREAD EXIT COUNT XECORE26",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2cc12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ec1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2dc12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2fc1001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc10c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c10fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000702aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a56aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000ba800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010903e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010203e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2cc13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c10c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c3aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c65550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c75550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt700MetricSet::CExt700MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt700MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE19", "GPGPU THREADGROUP COUNT XECORE19",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE23", "ASYNC GPGPU THREADGROUP COUNT XECORE23",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE27", "ASYNC GPGPU THREAD EXIT COUNT XECORE27",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ce12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ee1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2de12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2fe1001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de10c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe10d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a56aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000ba800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010903e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ce13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e10c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e75550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt701MetricSet::CExt701MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt701MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE20", "GPGPU THREADGROUP COUNT XECORE20",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE24", "ASYNC GPGPU THREADGROUP COUNT XECORE24",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE28", "ASYNC GPGPU THREAD EXIT COUNT XECORE28",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2d812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f81001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07819800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b810d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000803ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b02aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010802aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e81001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2d813000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06819800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c810c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e810d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10810fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00875400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13810c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15810cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17810db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03875550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fffa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002a955, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030683, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000802aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt702MetricSet::CExt702MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt702MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE21", "GPGPU THREADGROUP COUNT XECORE21",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE25", "ASYNC GPGPU THREADGROUP COUNT XECORE25",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE29", "ASYNC GPGPU THREAD EXIT COUNT XECORE29",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2da12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2fa1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000803ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b02aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010803ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ca12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ea1001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2da13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca10c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea10d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a10fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a75550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002a955, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030683, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000802aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt703MetricSet::CExt703MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt703MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE22", "GPGPU THREADGROUP COUNT XECORE22",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE26", "ASYNC GPGPU THREADGROUP COUNT XECORE26",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE30", "ASYNC GPGPU THREAD EXIT COUNT XECORE30",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2dc12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2fc1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000803ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b02aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010702aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a02aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2cc12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ec1001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2dc13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec10d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c10fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c10c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c3aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c65550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c75550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000903e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aa800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a555a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000203e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002a955, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030683, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000802aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt704MetricSet::CExt704MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt704MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE23", "GPGPU THREADGROUP COUNT XECORE23",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE27", "ASYNC GPGPU THREADGROUP COUNT XECORE27",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE31", "ASYNC GPGPU THREAD EXIT COUNT XECORE31",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2de12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2fe1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000803ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b02aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a02aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ce12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ee1001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2de13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce10c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee10d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e10fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e10c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e75550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000903e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aa800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a555a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002a955, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030683, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000802aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt705MetricSet::CExt705MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt705MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE24", "GPGPU THREADGROUP COUNT XECORE24",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE28", "ASYNC GPGPU THREADGROUP COUNT XECORE28",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE0", "ASYNC GPGPU THREAD EXIT COUNT XECORE0",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c813000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12810c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14810cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16810db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02875550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e81001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2d812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f81001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06819800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a810d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c810039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07819800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f810d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11810fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01875400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008feaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000ba800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032528, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032109, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032529, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt706MetricSet::CExt706MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt706MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE25", "GPGPU THREADGROUP COUNT XECORE25",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE29", "ASYNC GPGPU THREADGROUP COUNT XECORE29",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE1", "ASYNC GPGPU THREAD EXIT COUNT XECORE1",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ca13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a10c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a75550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ca12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ea1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2da12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2fa1001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da10c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa10d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a10fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000ba955, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010103e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032528, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032109, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032529, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt707MetricSet::CExt707MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt707MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE26", "GPGPU THREADGROUP COUNT XECORE26",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE30", "ASYNC GPGPU THREADGROUP COUNT XECORE30",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE2", "ASYNC GPGPU THREAD EXIT COUNT XECORE2",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2cc13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c10c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c3aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c65550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c75550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2cc12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ec1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2dc12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2fc1001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc10c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c10fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000702aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a56aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000ba800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010903e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010203e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032528, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032109, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032529, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt708MetricSet::CExt708MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt708MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE27", "GPGPU THREADGROUP COUNT XECORE27",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE31", "ASYNC GPGPU THREADGROUP COUNT XECORE31",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE3", "ASYNC GPGPU THREAD EXIT COUNT XECORE3",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ce13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e10c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e75550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ce12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ee1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2de12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2fe1001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de10c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe10d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000303e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a56aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000ba800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010903e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032528, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032109, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032529, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt709MetricSet::CExt709MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt709MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE28", "GPGPU THREADGROUP COUNT XECORE28",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE0", "ASYNC GPGPU THREADGROUP COUNT XECORE0",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE4", "ASYNC GPGPU THREAD EXIT COUNT XECORE4",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e81001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2d813000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06819800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c810c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e810d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10810fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00875400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13810c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15810cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17810db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03875550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fffa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2d812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f81001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07819800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b810d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000803ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b02aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010802aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000202aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46031269, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030693, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031269, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000802aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt710MetricSet::CExt710MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt710MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE29", "GPGPU THREADGROUP COUNT XECORE29",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE1", "ASYNC GPGPU THREADGROUP COUNT XECORE1",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE5", "ASYNC GPGPU THREAD EXIT COUNT XECORE5",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ca12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ea1001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2da13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca10c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea10d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a10fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a75550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2da12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2fa1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000803ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b02aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010803ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000202aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46031269, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030693, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031269, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000802aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt711MetricSet::CExt711MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt711MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE30", "GPGPU THREADGROUP COUNT XECORE30",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE2", "ASYNC GPGPU THREADGROUP COUNT XECORE2",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE6", "ASYNC GPGPU THREAD EXIT COUNT XECORE6",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2cc12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ec1001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2dc13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec10d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c10fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c10c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c3aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c65550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c75550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000903e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aa800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a555a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000203e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c5550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2dc12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2fc1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000803ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b02aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010702aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a02aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000202aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46031269, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030693, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031269, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000802aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt712MetricSet::CExt712MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt712MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "GPGPU_THREADGROUP_COUNT_XECORE31", "GPGPU THREADGROUP COUNT XECORE31",
                          "Number of GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "ASYNC_GPGPU_THREADGROUP_COUNT_XECORE3", "ASYNC GPGPU THREADGROUP COUNT XECORE3",
                          "Number of Async GPGPU threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "ASYNC_GPGPU_THREAD_EXIT_COUNT_XECORE7", "ASYNC GPGPU THREAD EXIT COUNT XECORE7",
                          "Number of Async GPGPU EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ce12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ee1001d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2de13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce10c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee10d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e10fb5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e10c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e75550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000903e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aa800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a555a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2de12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2fe1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000803ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b02aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a02aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000202aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46031269, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030693, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031269, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000802aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ba, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00001802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00030002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000003ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt713MetricSet::CExt713MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt713MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "TASK_THREADGROUP_COUNT_XECORE0", "TASK THREADGROUP COUNT XECORE0",
                          "Number of Task Shader threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "TASK_THREAD_EXIT_COUNT_XECORE4", "TASK THREAD EXIT COUNT XECORE4",
                          "Number of Task Shader EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE8", "THREADGROUP DISPATCH RESOURCE STALL XECORE8",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier, BTD stack)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e81001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2d813000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06819800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c810cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e810d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10810039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02830002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008401f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00875500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11810c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13810cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15810df3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17810036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03832aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01847e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03861554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03871554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00037e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083ffe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03082aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c817800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a810cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030d08, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030683, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000882, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00011002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000081ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt714MetricSet::CExt714MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt714MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "TASK_THREADGROUP_COUNT_XECORE1", "TASK THREADGROUP COUNT XECORE1",
                          "Number of Task Shader threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "TASK_THREAD_EXIT_COUNT_XECORE5", "TASK THREAD EXIT COUNT XECORE5",
                          "Number of Task Shader EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE9", "THREADGROUP DISPATCH RESOURCE STALL XECORE9",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier, BTD stack)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ca12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ea1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2da13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a401f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a10df3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a10036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a32aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a47e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a61554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a71554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00037e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2aa9, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03083ffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01017e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b1554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ca17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa10cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030d08, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030683, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000882, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00011002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000081ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt715MetricSet::CExt715MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt715MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "TASK_THREADGROUP_COUNT_XECORE2", "TASK THREADGROUP COUNT XECORE2",
                          "Number of Task Shader threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "TASK_THREAD_EXIT_COUNT_XECORE6", "TASK THREAD EXIT COUNT XECORE6",
                          "Number of Task Shader EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE10", "THREADGROUP DISPATCH RESOURCE STALL XECORE10",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier, BTD stack)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2cc12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ec1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2dc13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c401f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c10df3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c10036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c32aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c47e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c61554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c71554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00037e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083ffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000901f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1556, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000201f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03072aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01097e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a2aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01027e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c1554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2cc17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac10cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030d08, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030683, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000882, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00011002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000081ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt716MetricSet::CExt716MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt716MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "TASK_THREADGROUP_COUNT_XECORE3", "TASK THREADGROUP COUNT XECORE3",
                          "Number of Task Shader threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "TASK_THREAD_EXIT_COUNT_XECORE7", "TASK THREAD EXIT COUNT XECORE7",
                          "Number of Task Shader EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE11", "THREADGROUP DISPATCH RESOURCE STALL XECORE11",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier, BTD stack)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ce12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ee1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2de13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e401f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e10df3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e10036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e32aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e47e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e61554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e71554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00037e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083ffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000901f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1556, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03071554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01097e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a2aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ce17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae10cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030d08, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030683, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000882, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00011002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000081ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt717MetricSet::CExt717MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt717MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "TASK_THREADGROUP_COUNT_XECORE4", "TASK THREADGROUP COUNT XECORE4",
                          "Number of Task Shader threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "TASK_THREAD_EXIT_COUNT_XECORE8", "TASK THREAD EXIT COUNT XECORE8",
                          "Number of Task Shader EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE12", "THREADGROUP DISPATCH RESOURCE STALL XECORE12",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier, BTD stack)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2d812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f81001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07819800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f810d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11810039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018401f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01875500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000301f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000101f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c813000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2d817800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10810c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12810cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14810df3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16810036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02832aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00847e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02861554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02871554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b810cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083ffe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000101f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017e0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000882, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00011002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000081ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt718MetricSet::CExt718MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt718MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "TASK_THREADGROUP_COUNT_XECORE5", "TASK THREADGROUP COUNT XECORE5",
                          "Number of Task Shader threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "TASK_THREAD_EXIT_COUNT_XECORE9", "TASK THREAD EXIT COUNT XECORE9",
                          "Number of Task Shader EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE13", "THREADGROUP DISPATCH RESOURCE STALL XECORE13",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier, BTD stack)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2da12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2fa1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a401f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000301f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000101f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010101f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ca13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2da17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a10df3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a10036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a32aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a47e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a71554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba10cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083ffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017e0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b1554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083ffe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000101f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017e0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000882, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00011002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000081ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt719MetricSet::CExt719MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt719MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "TASK_THREADGROUP_COUNT_XECORE6", "TASK THREADGROUP COUNT XECORE6",
                          "Number of Task Shader threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "TASK_THREAD_EXIT_COUNT_XECORE10", "TASK THREAD EXIT COUNT XECORE10",
                          "Number of Task Shader EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE14", "THREADGROUP DISPATCH RESOURCE STALL XECORE14",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier, BTD stack)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2dc12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2fc1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c401f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000301f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000101f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010901f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010201f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2cc13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2dc17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c10df3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c10036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c32aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c47e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c61554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c71554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc10cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02072aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00097e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00027e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c1554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083ffe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000101f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017e0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000882, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00011002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000081ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt720MetricSet::CExt720MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt720MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "TASK_THREADGROUP_COUNT_XECORE7", "TASK THREADGROUP COUNT XECORE7",
                          "Number of Task Shader threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "TASK_THREAD_EXIT_COUNT_XECORE11", "TASK THREAD EXIT COUNT XECORE11",
                          "Number of Task Shader EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE15", "THREADGROUP DISPATCH RESOURCE STALL XECORE15",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier, BTD stack)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2de12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2fe1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e401f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000301f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000101f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010901f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ce13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2de17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e10df3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e10036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e32aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e47e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e61554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e71554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be10cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02071554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00097e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083ffe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000101f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017e0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000882, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00011002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000081ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt721MetricSet::CExt721MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt721MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "TASK_THREADGROUP_COUNT_XECORE8", "TASK THREADGROUP COUNT XECORE8",
                          "Number of Task Shader threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "TASK_THREAD_EXIT_COUNT_XECORE12", "TASK THREAD EXIT COUNT XECORE12",
                          "Number of Task Shader EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE16", "THREADGROUP DISPATCH RESOURCE STALL XECORE16",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier, BTD stack)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e81001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2d813000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06819800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c810cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e810d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10810039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02830002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008401f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00875500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11810c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13810cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15810df3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17810036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03832aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01847e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03861554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03871554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00037e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083ffe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03082aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c817800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a810cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42031ce0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030d07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030683, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000882, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00011002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000081ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt722MetricSet::CExt722MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt722MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "TASK_THREADGROUP_COUNT_XECORE9", "TASK THREADGROUP COUNT XECORE9",
                          "Number of Task Shader threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "TASK_THREAD_EXIT_COUNT_XECORE13", "TASK THREAD EXIT COUNT XECORE13",
                          "Number of Task Shader EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE17", "THREADGROUP DISPATCH RESOURCE STALL XECORE17",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier, BTD stack)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ca12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ea1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2da13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a401f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a10df3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a10036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a32aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a47e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a61554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a71554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00037e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2aa9, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03083ffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01017e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b1554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ca17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa10cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42031ce0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030d07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030683, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000882, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00011002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000081ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt723MetricSet::CExt723MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt723MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "TASK_THREADGROUP_COUNT_XECORE10", "TASK THREADGROUP COUNT XECORE10",
                          "Number of Task Shader threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "TASK_THREAD_EXIT_COUNT_XECORE14", "TASK THREAD EXIT COUNT XECORE14",
                          "Number of Task Shader EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE18", "THREADGROUP DISPATCH RESOURCE STALL XECORE18",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier, BTD stack)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2cc12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ec1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2dc13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c401f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c10df3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c10036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c32aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c47e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c61554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c71554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00037e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083ffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000901f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1556, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000201f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03072aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01097e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a2aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01027e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c1554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2cc17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac10cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42031ce0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030d07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030683, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000882, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00011002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000081ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt724MetricSet::CExt724MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt724MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "TASK_THREADGROUP_COUNT_XECORE11", "TASK THREADGROUP COUNT XECORE11",
                          "Number of Task Shader threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "TASK_THREAD_EXIT_COUNT_XECORE15", "TASK THREAD EXIT COUNT XECORE15",
                          "Number of Task Shader EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE19", "THREADGROUP DISPATCH RESOURCE STALL XECORE19",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier, BTD stack)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ce12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ee1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2de13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e401f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e10df3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e10036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e32aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e47e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e61554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e71554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00037e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083ffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000901f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1556, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03071554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01097e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a2aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ce17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae10cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42031ce0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030d07, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030683, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000882, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00011002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000081ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt725MetricSet::CExt725MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt725MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "TASK_THREADGROUP_COUNT_XECORE12", "TASK THREADGROUP COUNT XECORE12",
                          "Number of Task Shader threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "TASK_THREAD_EXIT_COUNT_XECORE16", "TASK THREAD EXIT COUNT XECORE16",
                          "Number of Task Shader EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE20", "THREADGROUP DISPATCH RESOURCE STALL XECORE20",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier, BTD stack)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2d812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f81001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07819800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f810d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11810039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018401f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01875500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000301f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000101f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c813000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2d817800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10810c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12810cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14810df3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16810036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02832aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00847e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02861554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02871554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b810cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031061, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000101f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017e0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000882, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00011002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000081ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt726MetricSet::CExt726MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt726MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "TASK_THREADGROUP_COUNT_XECORE13", "TASK THREADGROUP COUNT XECORE13",
                          "Number of Task Shader threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "TASK_THREAD_EXIT_COUNT_XECORE17", "TASK THREAD EXIT COUNT XECORE17",
                          "Number of Task Shader EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE21", "THREADGROUP DISPATCH RESOURCE STALL XECORE21",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier, BTD stack)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2da12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2fa1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a401f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000301f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000101f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010101f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ca13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2da17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a10df3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a10036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a32aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a47e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a71554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba10cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083ffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017e0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b1554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031061, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000101f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017e0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000882, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00011002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000081ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt727MetricSet::CExt727MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt727MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "TASK_THREADGROUP_COUNT_XECORE14", "TASK THREADGROUP COUNT XECORE14",
                          "Number of Task Shader threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "TASK_THREAD_EXIT_COUNT_XECORE18", "TASK THREAD EXIT COUNT XECORE18",
                          "Number of Task Shader EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE22", "THREADGROUP DISPATCH RESOURCE STALL XECORE22",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier, BTD stack)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2dc12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2fc1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c401f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000301f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000101f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010901f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010201f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2cc13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2dc17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c10df3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c10036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c32aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c47e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c61554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c71554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc10cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02072aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00097e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00027e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c1554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031061, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000101f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017e0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000882, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00011002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000081ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt728MetricSet::CExt728MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt728MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "TASK_THREADGROUP_COUNT_XECORE15", "TASK THREADGROUP COUNT XECORE15",
                          "Number of Task Shader threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "TASK_THREAD_EXIT_COUNT_XECORE19", "TASK THREAD EXIT COUNT XECORE19",
                          "Number of Task Shader EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE23", "THREADGROUP DISPATCH RESOURCE STALL XECORE23",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier, BTD stack)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2de12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2fe1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e401f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000301f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000101f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010901f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ce13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2de17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e10df3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e10036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e32aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e47e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e61554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e71554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be10cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02071554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00097e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031061, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000101f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017e0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000882, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00011002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000081ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt729MetricSet::CExt729MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt729MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "TASK_THREADGROUP_COUNT_XECORE16", "TASK THREADGROUP COUNT XECORE16",
                          "Number of Task Shader threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "TASK_THREAD_EXIT_COUNT_XECORE20", "TASK THREAD EXIT COUNT XECORE20",
                          "Number of Task Shader EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE24", "THREADGROUP DISPATCH RESOURCE STALL XECORE24",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier, BTD stack)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e81001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2d813000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06819800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c810cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e810d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10810039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02830002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008401f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00875500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11810c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13810cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15810df3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17810036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03832aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01847e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03861554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03871554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00037e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083ffe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03082aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c817800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a810cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000255aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030d08, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030683, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000882, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00011002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000081ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt730MetricSet::CExt730MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt730MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "TASK_THREADGROUP_COUNT_XECORE17", "TASK THREADGROUP COUNT XECORE17",
                          "Number of Task Shader threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "TASK_THREAD_EXIT_COUNT_XECORE21", "TASK THREAD EXIT COUNT XECORE21",
                          "Number of Task Shader EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE25", "THREADGROUP DISPATCH RESOURCE STALL XECORE25",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier, BTD stack)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ca12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ea1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2da13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a401f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a10df3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a10036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a32aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a47e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a61554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a71554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00037e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2aa9, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03083ffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01017e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b1554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ca17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa10cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000255aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030d08, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030683, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000882, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00011002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000081ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt731MetricSet::CExt731MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt731MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "TASK_THREADGROUP_COUNT_XECORE18", "TASK THREADGROUP COUNT XECORE18",
                          "Number of Task Shader threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "TASK_THREAD_EXIT_COUNT_XECORE22", "TASK THREAD EXIT COUNT XECORE22",
                          "Number of Task Shader EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE26", "THREADGROUP DISPATCH RESOURCE STALL XECORE26",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier, BTD stack)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2cc12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ec1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2dc13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c401f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c10df3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c10036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c32aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c47e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c61554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c71554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00037e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083ffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000901f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1556, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000201f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03072aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01097e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a2aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01027e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c1554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2cc17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac10cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000255aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030d08, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030683, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000882, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00011002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000081ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt732MetricSet::CExt732MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt732MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "TASK_THREADGROUP_COUNT_XECORE19", "TASK THREADGROUP COUNT XECORE19",
                          "Number of Task Shader threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "TASK_THREAD_EXIT_COUNT_XECORE23", "TASK THREAD EXIT COUNT XECORE23",
                          "Number of Task Shader EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE27", "THREADGROUP DISPATCH RESOURCE STALL XECORE27",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier, BTD stack)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ce12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ee1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2de13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e401f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e10df3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e10036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e32aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e47e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e61554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e71554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00037e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083ffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000901f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1556, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03071554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01097e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a2aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ce17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae10cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000255aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030d08, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030683, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000882, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00011002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000081ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt733MetricSet::CExt733MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt733MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "TASK_THREADGROUP_COUNT_XECORE20", "TASK THREADGROUP COUNT XECORE20",
                          "Number of Task Shader threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "TASK_THREAD_EXIT_COUNT_XECORE24", "TASK THREAD EXIT COUNT XECORE24",
                          "Number of Task Shader EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE28", "THREADGROUP DISPATCH RESOURCE STALL XECORE28",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier, BTD stack)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2d812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f81001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07819800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f810d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11810039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018401f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01875500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000301f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000101f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c813000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2d817800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10810c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12810cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14810df3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16810036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02832aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00847e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02861554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02871554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b810cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000255aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02022aa9, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000101f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017e0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000882, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00011002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000081ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt734MetricSet::CExt734MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt734MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "TASK_THREADGROUP_COUNT_XECORE21", "TASK THREADGROUP COUNT XECORE21",
                          "Number of Task Shader threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "TASK_THREAD_EXIT_COUNT_XECORE25", "TASK THREAD EXIT COUNT XECORE25",
                          "Number of Task Shader EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE29", "THREADGROUP DISPATCH RESOURCE STALL XECORE29",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier, BTD stack)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2da12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2fa1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a401f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000301f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000101f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010101f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ca13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2da17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a10df3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a10036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a32aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a47e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a71554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba10cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083ffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017e0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b1554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000255aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02022aa9, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000101f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017e0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000882, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00011002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000081ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt735MetricSet::CExt735MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt735MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "TASK_THREADGROUP_COUNT_XECORE22", "TASK THREADGROUP COUNT XECORE22",
                          "Number of Task Shader threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "TASK_THREAD_EXIT_COUNT_XECORE26", "TASK THREAD EXIT COUNT XECORE26",
                          "Number of Task Shader EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE30", "THREADGROUP DISPATCH RESOURCE STALL XECORE30",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier, BTD stack)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2dc12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2fc1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c401f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000301f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000101f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010901f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010201f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2cc13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2dc17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c10df3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c10036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c32aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c47e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c61554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c71554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc10cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02072aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00097e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00027e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c1554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000255aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02022aa9, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000101f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017e0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000882, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00011002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000081ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt736MetricSet::CExt736MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt736MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "TASK_THREADGROUP_COUNT_XECORE23", "TASK THREADGROUP COUNT XECORE23",
                          "Number of Task Shader threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "TASK_THREAD_EXIT_COUNT_XECORE27", "TASK THREAD EXIT COUNT XECORE27",
                          "Number of Task Shader EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE31", "THREADGROUP DISPATCH RESOURCE STALL XECORE31",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier, BTD stack)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2de12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2fe1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e401f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000301f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000101f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010901f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ce13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2de17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e10df3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e10036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e32aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e47e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e61554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e71554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be10cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02071554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00097e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000255aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02022aa9, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032108, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000101f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017e0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000882, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00011002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000081ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt737MetricSet::CExt737MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt737MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "TASK_THREADGROUP_COUNT_XECORE24", "TASK THREADGROUP COUNT XECORE24",
                          "Number of Task Shader threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "TASK_THREAD_EXIT_COUNT_XECORE28", "TASK THREAD EXIT COUNT XECORE28",
                          "Number of Task Shader EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE0", "THREADGROUP DISPATCH RESOURCE STALL XECORE0",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier, BTD stack)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c817800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a810cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e81001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2d813000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06819800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c810cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e810d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10810039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02830002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008401f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00875500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11810c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13810cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15810df3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17810036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03832aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01847e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03861554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03871554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00037e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083ffe, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03082aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02022aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032520, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030d09, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030683, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000882, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00011002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000081ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt738MetricSet::CExt738MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt738MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "TASK_THREADGROUP_COUNT_XECORE25", "TASK THREADGROUP COUNT XECORE25",
                          "Number of Task Shader threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "TASK_THREAD_EXIT_COUNT_XECORE29", "TASK THREAD EXIT COUNT XECORE29",
                          "Number of Task Shader EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE1", "THREADGROUP DISPATCH RESOURCE STALL XECORE1",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier, BTD stack)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ca17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa10cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ca12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ea1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2da13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a401f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a10df3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a10036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a32aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a47e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a61554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a71554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00037e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2aa9, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03083ffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01017e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b1554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02022aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032520, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030d09, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030683, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000882, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00011002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000081ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt739MetricSet::CExt739MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt739MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "TASK_THREADGROUP_COUNT_XECORE26", "TASK THREADGROUP COUNT XECORE26",
                          "Number of Task Shader threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "TASK_THREAD_EXIT_COUNT_XECORE30", "TASK THREAD EXIT COUNT XECORE30",
                          "Number of Task Shader EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE2", "THREADGROUP DISPATCH RESOURCE STALL XECORE2",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier, BTD stack)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2cc17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac10cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2cc12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ec1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2dc13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c401f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c10df3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c10036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c32aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c47e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c61554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c71554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00037e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083ffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000901f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1556, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000201f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03072aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01097e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a2aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01027e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c1554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02022aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032520, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030d09, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030683, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000882, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00011002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000081ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt740MetricSet::CExt740MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt740MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "TASK_THREADGROUP_COUNT_XECORE27", "TASK THREADGROUP COUNT XECORE27",
                          "Number of Task Shader threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "TASK_THREAD_EXIT_COUNT_XECORE31", "TASK THREAD EXIT COUNT XECORE31",
                          "Number of Task Shader EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE3", "THREADGROUP DISPATCH RESOURCE STALL XECORE3",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier, BTD stack)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ce17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae10cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ce12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ee1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2de13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e401f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e10df3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e10036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e32aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e47e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e61554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e71554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00037e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083ffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000901f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1556, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03071554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01097e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a2aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02022aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032520, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030d09, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46031068, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030683, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000882, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00011002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000081ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt741MetricSet::CExt741MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt741MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "TASK_THREADGROUP_COUNT_XECORE28", "TASK THREADGROUP COUNT XECORE28",
                          "Number of Task Shader threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "TASK_THREAD_EXIT_COUNT_XECORE0", "TASK THREAD EXIT COUNT XECORE0",
                          "Number of Task Shader EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE4", "THREADGROUP DISPATCH RESOURCE STALL XECORE4",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier, BTD stack)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c813000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2d817800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10810c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12810cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14810df3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16810036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02832aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00847e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02861554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02871554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b810cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2d812800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2f81001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07819800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f810d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11810039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018401f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01875500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000301f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000101f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032521, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032529, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017e0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000101f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000882, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00011002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000081ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt742MetricSet::CExt742MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt742MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "TASK_THREADGROUP_COUNT_XECORE29", "TASK THREADGROUP COUNT XECORE29",
                          "Number of Task Shader threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "TASK_THREAD_EXIT_COUNT_XECORE1", "TASK THREAD EXIT COUNT XECORE1",
                          "Number of Task Shader EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE5", "THREADGROUP DISPATCH RESOURCE STALL XECORE5",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier, BTD stack)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ca13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2da17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a10df3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a10036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a32aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a47e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a71554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba10cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083ffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017e0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b1554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2da12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2fa1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a401f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000301f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000101f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010101f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032521, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032529, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017e0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000101f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000882, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00011002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000081ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt743MetricSet::CExt743MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt743MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "TASK_THREADGROUP_COUNT_XECORE30", "TASK THREADGROUP COUNT XECORE30",
                          "Number of Task Shader threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "TASK_THREAD_EXIT_COUNT_XECORE2", "TASK THREAD EXIT COUNT XECORE2",
                          "Number of Task Shader EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE6", "THREADGROUP DISPATCH RESOURCE STALL XECORE6",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier, BTD stack)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2cc13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2dc17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c10df3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c10036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c32aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c47e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c61554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c71554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc10cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02072aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00097e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00027e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c1554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010700aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2dc12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2fc1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c401f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000301f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000101f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010901f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010201f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032521, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032529, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017e0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000101f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000882, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00011002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000081ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt744MetricSet::CExt744MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt744MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "TASK_THREADGROUP_COUNT_XECORE31", "TASK THREADGROUP COUNT XECORE31",
                          "Number of Task Shader threadgroups dispatched",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "TASK_THREAD_EXIT_COUNT_XECORE3", "TASK THREAD EXIT COUNT XECORE3",
                          "Number of Task Shader EOT messages received",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_RESOURCE_STALL_XECORE7", "THREADGROUP DISPATCH RESOURCE STALL XECORE7",
                          "Percentage of time in which Thread Spawner is stalled waiting for resources to be available (SLM, Barrier, BTD stack)",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ce13000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2de17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e10df3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e10036, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e32aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e47e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e61554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e71554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10db7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be10cf5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e70055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02071554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00097e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2de12800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2fe1001e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e19800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe10d74, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10039, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e401f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e75500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000301f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000101f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010901f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032521, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031260, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032529, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017e0f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000101f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000041, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000882, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fe0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00011002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x000081ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt745MetricSet::CExt745MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt745MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE0", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE0",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE1", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE1",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE2", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE2",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE3", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE3",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE4", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE4",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE5", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE5",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE6", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE6",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE7", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE7",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE8", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE8",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE9", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE9",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE10", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE10",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE11", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE11",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE12", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE12",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE13", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE13",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE14", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE14",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE15", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE15",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c817800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ca17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2cc17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ce17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2d817800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2da17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2dc17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2de17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16810c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02838000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02874000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a10030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e10030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13810c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00093000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c817800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ca17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2cc17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ce17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2d817800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2da17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2dc17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2de17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e810c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00838000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00874000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea10030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce10030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b810c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba10030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001004f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03086a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030c0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030ce2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x460300e8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt746MetricSet::CExt746MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt746MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE16", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE16",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE17", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE17",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE18", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE18",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE19", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE19",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE20", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE20",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE21", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE21",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE22", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE22",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE23", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE23",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE24", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE24",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE25", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE25",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE26", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE26",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE27", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE27",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE28", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE28",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE29", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE29",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE30", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE30",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE0_INPUT_AVAILABLE_XECORE31", "THREADGROUP DISPATCH QUEUE0 INPUT AVAILABLE XECORE31",
                          "Percentage of time in which Thread Spawner has input available on queue 0",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c817800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ca17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2cc17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ce17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2d817800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2da17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2dc17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2de17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16810c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02838000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02874000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a10030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e10030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13810c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00093000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c817800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ca17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2cc17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ce17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2d817800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2da17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2dc17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2de17800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e810c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00838000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00874000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea10030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce10030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b810c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba10030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001004f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03086a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030c0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030ce2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x460300e8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt747MetricSet::CExt747MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt747MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE0", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE0",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE1", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE1",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE2", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE2",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE3", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE3",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE4", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE4",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE5", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE5",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE6", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE6",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE7", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE7",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE8", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE8",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE9", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE9",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE10", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE10",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE11", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE11",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE12", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE12",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE13", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE13",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE14", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE14",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE15", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE15",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c817400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ca17400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2cc17400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ce17400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2d817400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2da17400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2dc17400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2de17400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16810dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02838000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02874000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a10037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c10dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e10037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13810dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c10dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00093000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c817400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ca17400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2cc17400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ce17400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2d817400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2da17400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2dc17400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2de17400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e810dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00838000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00874000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea10037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce10037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b810dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba10037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001004f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03086a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030c0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030ce2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x460300e8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt748MetricSet::CExt748MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt748MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE16", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE16",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE17", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE17",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE18", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE18",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE19", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE19",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE20", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE20",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE21", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE21",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE22", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE22",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE23", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE23",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE24", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE24",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE25", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE25",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE26", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE26",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE27", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE27",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE28", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE28",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE29", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE29",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE30", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE30",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "THREADGROUP_DISPATCH_QUEUE1_INPUT_AVAILABLE_XECORE31", "THREADGROUP DISPATCH QUEUE1 INPUT AVAILABLE XECORE31",
                          "Percentage of time in which Thread Spawner has input available on queue 1",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c817400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ca17400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2cc17400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ce17400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2d817400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2da17400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2dc17400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2de17400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16810dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02838000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02874000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a10037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c10dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e10037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13810dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c10dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00093000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c817400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ca17400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2cc17400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ce17400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2d817400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2da17400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2dc17400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2de17400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e810dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00838000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00874000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea10037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce10037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b810dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba10037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10037, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001004f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03086a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030c0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030ce2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x460300e8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt749MetricSet::CExt749MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt749MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE0", "THREAD DISPATCH QUEUE0 ACTIVE XECORE0",
                          "Percentage of time in which non-Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment", nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE1", "THREAD DISPATCH QUEUE0 ACTIVE XECORE1",
                          "Percentage of time in which non-Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment", nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE2", "THREAD DISPATCH QUEUE0 ACTIVE XECORE2",
                          "Percentage of time in which non-Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment", nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE3", "THREAD DISPATCH QUEUE0 ACTIVE XECORE3",
                          "Percentage of time in which non-Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment", nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE4", "THREAD DISPATCH QUEUE0 ACTIVE XECORE4",
                          "Percentage of time in which non-Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment", nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE5", "THREAD DISPATCH QUEUE0 ACTIVE XECORE5",
                          "Percentage of time in which non-Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment", nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE6", "THREAD DISPATCH QUEUE0 ACTIVE XECORE6",
                          "Percentage of time in which non-Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment", nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE7", "THREAD DISPATCH QUEUE0 ACTIVE XECORE7",
                          "Percentage of time in which non-Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment", nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a810002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b810002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac10034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae10d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da10d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe10d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e38000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e64000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e74000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff0e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a55a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01076000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030047, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt750MetricSet::CExt750MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt750MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE8", "THREAD DISPATCH QUEUE0 ACTIVE XECORE8",
                          "Percentage of time in which non-Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment", nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE9", "THREAD DISPATCH QUEUE0 ACTIVE XECORE9",
                          "Percentage of time in which non-Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment", nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE10", "THREAD DISPATCH QUEUE0 ACTIVE XECORE10",
                          "Percentage of time in which non-Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment", nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE11", "THREAD DISPATCH QUEUE0 ACTIVE XECORE11",
                          "Percentage of time in which non-Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment", nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE12", "THREAD DISPATCH QUEUE0 ACTIVE XECORE12",
                          "Percentage of time in which non-Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment", nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE13", "THREAD DISPATCH QUEUE0 ACTIVE XECORE13",
                          "Percentage of time in which non-Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment", nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE14", "THREAD DISPATCH QUEUE0 ACTIVE XECORE14",
                          "Percentage of time in which non-Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment", nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE15", "THREAD DISPATCH QUEUE0 ACTIVE XECORE15",
                          "Percentage of time in which non-Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment", nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a810002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b810002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac10034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae10d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da10d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe10d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e38000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e64000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e74000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff0e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a55a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01076000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030047, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt751MetricSet::CExt751MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt751MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE16", "THREAD DISPATCH QUEUE0 ACTIVE XECORE16",
                          "Percentage of time in which non-Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment", nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE17", "THREAD DISPATCH QUEUE0 ACTIVE XECORE17",
                          "Percentage of time in which non-Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment", nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE18", "THREAD DISPATCH QUEUE0 ACTIVE XECORE18",
                          "Percentage of time in which non-Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment", nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE19", "THREAD DISPATCH QUEUE0 ACTIVE XECORE19",
                          "Percentage of time in which non-Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment", nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE20", "THREAD DISPATCH QUEUE0 ACTIVE XECORE20",
                          "Percentage of time in which non-Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment", nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE21", "THREAD DISPATCH QUEUE0 ACTIVE XECORE21",
                          "Percentage of time in which non-Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment", nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE22", "THREAD DISPATCH QUEUE0 ACTIVE XECORE22",
                          "Percentage of time in which non-Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment", nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE23", "THREAD DISPATCH QUEUE0 ACTIVE XECORE23",
                          "Percentage of time in which non-Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment", nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a810002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b810002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac10034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae10d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da10d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe10d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e38000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e64000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e74000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff0e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a55a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01076000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030049, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030047, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt752MetricSet::CExt752MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt752MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE24", "THREAD DISPATCH QUEUE0 ACTIVE XECORE24",
                          "Percentage of time in which non-Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment", nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE25", "THREAD DISPATCH QUEUE0 ACTIVE XECORE25",
                          "Percentage of time in which non-Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment", nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE26", "THREAD DISPATCH QUEUE0 ACTIVE XECORE26",
                          "Percentage of time in which non-Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment", nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE27", "THREAD DISPATCH QUEUE0 ACTIVE XECORE27",
                          "Percentage of time in which non-Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment", nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE28", "THREAD DISPATCH QUEUE0 ACTIVE XECORE28",
                          "Percentage of time in which non-Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment", nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE29", "THREAD DISPATCH QUEUE0 ACTIVE XECORE29",
                          "Percentage of time in which non-Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment", nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE30", "THREAD DISPATCH QUEUE0 ACTIVE XECORE30",
                          "Percentage of time in which non-Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment", nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE0_ACTIVE_XECORE31", "THREAD DISPATCH QUEUE0 ACTIVE XECORE31",
                          "Percentage of time in which non-Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment", nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a810002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b810002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be10002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac10034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae10d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da10d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10034, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe10d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e38000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e64000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e74000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000300f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff0e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a55a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100f2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01076000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030049, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030047, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt753MetricSet::CExt753MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt753MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE0", "THREAD DISPATCH QUEUE1 ACTIVE XECORE0",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE1", "THREAD DISPATCH QUEUE1 ACTIVE XECORE1",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE2", "THREAD DISPATCH QUEUE1 ACTIVE XECORE2",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE3", "THREAD DISPATCH QUEUE1 ACTIVE XECORE3",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE4", "THREAD DISPATCH QUEUE1 ACTIVE XECORE4",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE5", "THREAD DISPATCH QUEUE1 ACTIVE XECORE5",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE6", "THREAD DISPATCH QUEUE1 ACTIVE XECORE6",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE7", "THREAD DISPATCH QUEUE1 ACTIVE XECORE7",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE0", "THREAD DISPATCH STALL XECORE0",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE1", "THREAD DISPATCH STALL XECORE1",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE2", "THREAD DISPATCH STALL XECORE2",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE3", "THREAD DISPATCH STALL XECORE3",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE4", "THREAD DISPATCH STALL XECORE4",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE5", "THREAD DISPATCH STALL XECORE5",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE6", "THREAD DISPATCH STALL XECORE6",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE7", "THREAD DISPATCH STALL XECORE7",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28810320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a810004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28a10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28c10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28e10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29810320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b810004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29a10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29c10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29e10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06811300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16810f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02838000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02874000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a11300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10d40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a1003c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c11300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac10035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c10f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e11300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae10d40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e1003c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07811300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13810f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840810, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a11300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da10d40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a1003c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c11300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c10f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e11300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe10d40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e1003c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e38000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e64000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e74000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff0e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009300c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a55a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014ff2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01076000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010903c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03086a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203200a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030047, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt754MetricSet::CExt754MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt754MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE8", "THREAD DISPATCH QUEUE1 ACTIVE XECORE8",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE9", "THREAD DISPATCH QUEUE1 ACTIVE XECORE9",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE10", "THREAD DISPATCH QUEUE1 ACTIVE XECORE10",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE11", "THREAD DISPATCH QUEUE1 ACTIVE XECORE11",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE12", "THREAD DISPATCH QUEUE1 ACTIVE XECORE12",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE13", "THREAD DISPATCH QUEUE1 ACTIVE XECORE13",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE14", "THREAD DISPATCH QUEUE1 ACTIVE XECORE14",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE15", "THREAD DISPATCH QUEUE1 ACTIVE XECORE15",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE8", "THREAD DISPATCH STALL XECORE8",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE9", "THREAD DISPATCH STALL XECORE9",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE10", "THREAD DISPATCH STALL XECORE10",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE11", "THREAD DISPATCH STALL XECORE11",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE12", "THREAD DISPATCH STALL XECORE12",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE13", "THREAD DISPATCH STALL XECORE13",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE14", "THREAD DISPATCH STALL XECORE14",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE15", "THREAD DISPATCH STALL XECORE15",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28810320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a810004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28a10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28c10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28e10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29810320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b810004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29a10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29c10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29e10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06811300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16810f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02838000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02874000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a11300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10d40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a1003c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c11300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac10035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c10f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e11300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae10d40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e1003c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07811300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13810f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840810, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a11300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da10d40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a1003c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c11300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c10f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e11300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe10d40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e1003c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e38000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e64000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e74000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff0e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009300c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a55a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014ff2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01076000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010903c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03086a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203200a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030047, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt755MetricSet::CExt755MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt755MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE16", "THREAD DISPATCH QUEUE1 ACTIVE XECORE16",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE17", "THREAD DISPATCH QUEUE1 ACTIVE XECORE17",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE18", "THREAD DISPATCH QUEUE1 ACTIVE XECORE18",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE19", "THREAD DISPATCH QUEUE1 ACTIVE XECORE19",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE20", "THREAD DISPATCH QUEUE1 ACTIVE XECORE20",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE21", "THREAD DISPATCH QUEUE1 ACTIVE XECORE21",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE22", "THREAD DISPATCH QUEUE1 ACTIVE XECORE22",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE23", "THREAD DISPATCH QUEUE1 ACTIVE XECORE23",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE16", "THREAD DISPATCH STALL XECORE16",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE17", "THREAD DISPATCH STALL XECORE17",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE18", "THREAD DISPATCH STALL XECORE18",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE19", "THREAD DISPATCH STALL XECORE19",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE20", "THREAD DISPATCH STALL XECORE20",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE21", "THREAD DISPATCH STALL XECORE21",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE22", "THREAD DISPATCH STALL XECORE22",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE23", "THREAD DISPATCH STALL XECORE23",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28810320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a810004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28a10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28c10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28e10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29810320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b810004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29a10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29c10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29e10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06811300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16810f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02838000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02874000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a11300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10d40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a1003c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c11300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac10035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c10f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e11300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae10d40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e1003c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07811300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13810f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840810, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a11300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da10d40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a1003c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c11300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c10f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e11300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe10d40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e1003c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e38000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e64000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e74000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff0e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009300c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a55a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014ff2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01076000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010903c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03086a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203200a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030047, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt756MetricSet::CExt756MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt756MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE24", "THREAD DISPATCH QUEUE1 ACTIVE XECORE24",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE25", "THREAD DISPATCH QUEUE1 ACTIVE XECORE25",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE26", "THREAD DISPATCH QUEUE1 ACTIVE XECORE26",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE27", "THREAD DISPATCH QUEUE1 ACTIVE XECORE27",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE28", "THREAD DISPATCH QUEUE1 ACTIVE XECORE28",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE29", "THREAD DISPATCH QUEUE1 ACTIVE XECORE29",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE30", "THREAD DISPATCH QUEUE1 ACTIVE XECORE30",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_QUEUE1_ACTIVE_XECORE31", "THREAD DISPATCH QUEUE1 ACTIVE XECORE31",
                          "Percentage of time in which Async GPGPU threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE24", "THREAD DISPATCH STALL XECORE24",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE25", "THREAD DISPATCH STALL XECORE25",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE26", "THREAD DISPATCH STALL XECORE26",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE27", "THREAD DISPATCH STALL XECORE27",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE28", "THREAD DISPATCH STALL XECORE28",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE29", "THREAD DISPATCH STALL XECORE29",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE30", "THREAD DISPATCH STALL XECORE30",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_STALL_XECORE31", "THREAD DISPATCH STALL XECORE31",
                          "Percentage of time in which Thread Dispatch is stalled waiting for threads to be available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28810320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2a810004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28a10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2aa10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28c10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ac10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28e10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ae10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29810320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2b810004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29a10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ba10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29c10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2bc10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29e10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2be10004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06811300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16810f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02838000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02874000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a11300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10d40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a1003c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c11300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac10035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c10f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e11300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae10d40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e1003c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07811300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13810f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840810, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a11300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da10d40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a1003c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c11300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10035, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c10f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e11300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe10d40, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e1003c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e38000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e64000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e74000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff0e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009300c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a55a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014ff2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01076000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010903c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03086a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203200a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030047, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ffbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000ff7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt757MetricSet::CExt757MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt757MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE0", "THREAD DISPATCH INPUT AVAILABLE XECORE0",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE1", "THREAD DISPATCH INPUT AVAILABLE XECORE1",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE2", "THREAD DISPATCH INPUT AVAILABLE XECORE2",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE3", "THREAD DISPATCH INPUT AVAILABLE XECORE3",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE4", "THREAD DISPATCH INPUT AVAILABLE XECORE4",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE5", "THREAD DISPATCH INPUT AVAILABLE XECORE5",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE6", "THREAD DISPATCH INPUT AVAILABLE XECORE6",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE7", "THREAD DISPATCH INPUT AVAILABLE XECORE7",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE8", "THREAD DISPATCH INPUT AVAILABLE XECORE8",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE9", "THREAD DISPATCH INPUT AVAILABLE XECORE9",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE10", "THREAD DISPATCH INPUT AVAILABLE XECORE10",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE11", "THREAD DISPATCH INPUT AVAILABLE XECORE11",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE12", "THREAD DISPATCH INPUT AVAILABLE XECORE12",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE13", "THREAD DISPATCH INPUT AVAILABLE XECORE13",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE14", "THREAD DISPATCH INPUT AVAILABLE XECORE14",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE15", "THREAD DISPATCH INPUT AVAILABLE XECORE15",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28810320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28a10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28c10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28e10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29810320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29a10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29c10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29e10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16810c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02838000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02874000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a10032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c10c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e10032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13810c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c10c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00093000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28810320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28a10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28c10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28e10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29810320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29a10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29c10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29e10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e810c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00838000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00874000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea10032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce10032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b810c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba10032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001004f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03086a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030c0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030ce2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x460300e8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt758MetricSet::CExt758MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt758MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE16", "THREAD DISPATCH INPUT AVAILABLE XECORE16",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE17", "THREAD DISPATCH INPUT AVAILABLE XECORE17",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE18", "THREAD DISPATCH INPUT AVAILABLE XECORE18",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE19", "THREAD DISPATCH INPUT AVAILABLE XECORE19",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE20", "THREAD DISPATCH INPUT AVAILABLE XECORE20",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE21", "THREAD DISPATCH INPUT AVAILABLE XECORE21",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE22", "THREAD DISPATCH INPUT AVAILABLE XECORE22",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE23", "THREAD DISPATCH INPUT AVAILABLE XECORE23",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE24", "THREAD DISPATCH INPUT AVAILABLE XECORE24",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE25", "THREAD DISPATCH INPUT AVAILABLE XECORE25",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE26", "THREAD DISPATCH INPUT AVAILABLE XECORE26",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE27", "THREAD DISPATCH INPUT AVAILABLE XECORE27",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE28", "THREAD DISPATCH INPUT AVAILABLE XECORE28",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE29", "THREAD DISPATCH INPUT AVAILABLE XECORE29",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE30", "THREAD DISPATCH INPUT AVAILABLE XECORE30",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_INPUT_AVAILABLE_XECORE31", "THREAD DISPATCH INPUT AVAILABLE XECORE31",
                          "Percentage of time in which Thread Dispatch input is available",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28810320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28a10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28c10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28e10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29810320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29a10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29c10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29e10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16810c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02838000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02874000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a10032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c10c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e10032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13810c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c10c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00093000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28810320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28a10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28c10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28e10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29810320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29a10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29c10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29e10320, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e810c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00838000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00874000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea10032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a32000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a71000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce10032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b810c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba10032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c30008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10032, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001004f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03086a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030c0a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030ce2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x460300e8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000100ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt759MetricSet::CExt759MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt759MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_PS_ACTIVE_XECORE0", "THREAD DISPATCH PS ACTIVE XECORE0",
                          "Percentage of time in which Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_PS_ACTIVE_XECORE1", "THREAD DISPATCH PS ACTIVE XECORE1",
                          "Percentage of time in which Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_PS_ACTIVE_XECORE2", "THREAD DISPATCH PS ACTIVE XECORE2",
                          "Percentage of time in which Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_PS_ACTIVE_XECORE3", "THREAD DISPATCH PS ACTIVE XECORE3",
                          "Percentage of time in which Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_PS_ACTIVE_XECORE4", "THREAD DISPATCH PS ACTIVE XECORE4",
                          "Percentage of time in which Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_PS_ACTIVE_XECORE5", "THREAD DISPATCH PS ACTIVE XECORE5",
                          "Percentage of time in which Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_PS_ACTIVE_XECORE6", "THREAD DISPATCH PS ACTIVE XECORE6",
                          "Percentage of time in which Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_PS_ACTIVE_XECORE7", "THREAD DISPATCH PS ACTIVE XECORE7",
                          "Percentage of time in which Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28810340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28a10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28c10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28e10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29810340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29a10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29c10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29e10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e400c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11810c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c43000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff0c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01023000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030ee8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030277, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt760MetricSet::CExt760MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt760MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_PS_ACTIVE_XECORE8", "THREAD DISPATCH PS ACTIVE XECORE8",
                          "Percentage of time in which Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_PS_ACTIVE_XECORE9", "THREAD DISPATCH PS ACTIVE XECORE9",
                          "Percentage of time in which Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_PS_ACTIVE_XECORE10", "THREAD DISPATCH PS ACTIVE XECORE10",
                          "Percentage of time in which Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_PS_ACTIVE_XECORE11", "THREAD DISPATCH PS ACTIVE XECORE11",
                          "Percentage of time in which Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_PS_ACTIVE_XECORE12", "THREAD DISPATCH PS ACTIVE XECORE12",
                          "Percentage of time in which Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_PS_ACTIVE_XECORE13", "THREAD DISPATCH PS ACTIVE XECORE13",
                          "Percentage of time in which Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_PS_ACTIVE_XECORE14", "THREAD DISPATCH PS ACTIVE XECORE14",
                          "Percentage of time in which Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_PS_ACTIVE_XECORE15", "THREAD DISPATCH PS ACTIVE XECORE15",
                          "Percentage of time in which Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28810340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28a10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28c10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28e10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29810340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29a10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29c10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29e10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e400c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11810c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c43000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff0c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01023000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030ee8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030277, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt761MetricSet::CExt761MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt761MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_PS_ACTIVE_XECORE16", "THREAD DISPATCH PS ACTIVE XECORE16",
                          "Percentage of time in which Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_PS_ACTIVE_XECORE17", "THREAD DISPATCH PS ACTIVE XECORE17",
                          "Percentage of time in which Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_PS_ACTIVE_XECORE18", "THREAD DISPATCH PS ACTIVE XECORE18",
                          "Percentage of time in which Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_PS_ACTIVE_XECORE19", "THREAD DISPATCH PS ACTIVE XECORE19",
                          "Percentage of time in which Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_PS_ACTIVE_XECORE20", "THREAD DISPATCH PS ACTIVE XECORE20",
                          "Percentage of time in which Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_PS_ACTIVE_XECORE21", "THREAD DISPATCH PS ACTIVE XECORE21",
                          "Percentage of time in which Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_PS_ACTIVE_XECORE22", "THREAD DISPATCH PS ACTIVE XECORE22",
                          "Percentage of time in which Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_PS_ACTIVE_XECORE23", "THREAD DISPATCH PS ACTIVE XECORE23",
                          "Percentage of time in which Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28810340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28a10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28c10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28e10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29810340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29a10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29c10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29e10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e400c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11810c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c43000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff0c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01023000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030ee8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030277, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt762MetricSet::CExt762MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt762MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_PS_ACTIVE_XECORE24", "THREAD DISPATCH PS ACTIVE XECORE24",
                          "Percentage of time in which Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_PS_ACTIVE_XECORE25", "THREAD DISPATCH PS ACTIVE XECORE25",
                          "Percentage of time in which Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_PS_ACTIVE_XECORE26", "THREAD DISPATCH PS ACTIVE XECORE26",
                          "Percentage of time in which Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_PS_ACTIVE_XECORE27", "THREAD DISPATCH PS ACTIVE XECORE27",
                          "Percentage of time in which Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "THREAD_DISPATCH_PS_ACTIVE_XECORE28", "THREAD DISPATCH PS ACTIVE XECORE28",
                          "Percentage of time in which Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "THREAD_DISPATCH_PS_ACTIVE_XECORE29", "THREAD DISPATCH PS ACTIVE XECORE29",
                          "Percentage of time in which Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "THREAD_DISPATCH_PS_ACTIVE_XECORE30", "THREAD DISPATCH PS ACTIVE XECORE30",
                          "Percentage of time in which Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "THREAD_DISPATCH_PS_ACTIVE_XECORE31", "THREAD DISPATCH PS ACTIVE XECORE31",
                          "Percentage of time in which Pixel Shader threads are ready for dispatch in a particular Xe core",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28810340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28a10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28c10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28e10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29810340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29a10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29c10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29e10340, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c40030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e400c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11810c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c43000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e10c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4c000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff0c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01023000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030ee8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030277, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt763MetricSet::CExt763MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt763MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "HOST_TO_GPUMEM_TRANSACTION_READ", "HOST TO GPUMEM TRANSACTION READ",
                          "Number of host reads to GPU local (HBM) memory (downstream)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "HOST_TO_GPUMEM_TRANSACTION_WRITE", "HOST TO GPUMEM TRANSACTION WRITE",
                          "Number of host writes to GPU local (HBM) memory (downstream)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12091580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04034000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x100903d6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040a1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt764MetricSet::CExt764MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt764MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SYSMEM_TRANSACTION_READ", "SYSMEM TRANSACTION READ",
                          "Number of system memory reads (upstream)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SYSMEM_TRANSACTION_WRITE", "SYSMEM TRANSACTION WRITE",
                          "Number of system memory writes (upstream)",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x120900a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04034000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10090254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06090000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040a1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt765MetricSet::CExt765MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt765MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE0", "GPGPU DISPATCH XECORE0",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE1", "GPGPU DISPATCH XECORE1",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE2", "GPGPU DISPATCH XECORE2",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c813c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ca13c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2cc13c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810c37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a810cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c810033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca10dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea10c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c10c37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c10033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c32aa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c47c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c61550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c71550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02072aa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008feaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00097c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2aa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00027c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c1550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000007a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0000008a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00001102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0001e002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x000083ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00022002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt766MetricSet::CExt766MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt766MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE3", "GPGPU DISPATCH XECORE3",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE4", "GPGPU DISPATCH XECORE4",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE5", "GPGPU DISPATCH XECORE5",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ce13c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2d813c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2da13c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10c37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce10033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f810c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11810cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01875400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10c37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a10033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a32aa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a47c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a61550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a71550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00037fe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a56aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017fe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000ba800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03083ffa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01017c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b1550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42031080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030084, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000007a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0000008a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00001102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0001e002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x000083ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00022002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt767MetricSet::CExt767MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt767MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE6", "GPGPU DISPATCH XECORE6",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE7", "GPGPU DISPATCH XECORE7",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE8", "GPGPU DISPATCH XECORE8",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2dc13c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2de13c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10c37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc10033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de10dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe10c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000303ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010756aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010903ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c813c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12810c37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14810cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16810033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02832aa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00847c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02861550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02871550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083ffa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032940, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000007a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0000008a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00001102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0001e002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x000083ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00022002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt768MetricSet::CExt768MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt768MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE9", "GPGPU DISPATCH XECORE9",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE10", "GPGPU DISPATCH XECORE10",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE11", "GPGPU DISPATCH XECORE11",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ca13c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2cc13c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ce13c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10c37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca10033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec10c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e10c37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e10033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e32aa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e47c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e61550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e71550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207155a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000803ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00097fe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aa955, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000203e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032943, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030c60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000007a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0000008a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00001102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0001e002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x000083ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00022002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt769MetricSet::CExt769MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt769MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE12", "GPGPU DISPATCH XECORE12",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE13", "GPGPU DISPATCH XECORE13",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE14", "GPGPU DISPATCH XECORE14",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2d813c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2da13c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2dc13c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810c37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b810cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da10dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa10c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c10c37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c10033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c32aa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c47c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c61550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c71550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00037fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03072aa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108feaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01097c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a2aa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010103e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01027c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c1550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000007a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0000008a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00001102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0001e002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x000083ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00022002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt770MetricSet::CExt770MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt770MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE15", "GPGPU DISPATCH XECORE15",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE16", "GPGPU DISPATCH XECORE16",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE17", "GPGPU DISPATCH XECORE17",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2de13c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10c37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de10033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000803ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b02aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01070155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a02aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c813c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ca13c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c810dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e810c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10810cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00875400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a10c37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a10033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a32aa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a47c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a71550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083ffa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b1550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000803ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603146a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480306a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03146a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00040155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000802aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017fe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000007a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0000008a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00001102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0001e002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x000083ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00022002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt771MetricSet::CExt771MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt771MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE18", "GPGPU DISPATCH XECORE18",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE19", "GPGPU DISPATCH XECORE19",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE20", "GPGPU DISPATCH XECORE20",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2cc13c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ce13c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2d813c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10c37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc10033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce10dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee10c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13810c37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15810cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17810033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03832aa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01847c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03861550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03871550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00037c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000756aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000903ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a155a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2aa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03082aa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x420318c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030cc6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030a65, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030653, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030a65, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000007a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0000008a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00001102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0001e002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x000083ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00022002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt772MetricSet::CExt772MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt772MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE21", "GPGPU DISPATCH XECORE21",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE22", "GPGPU DISPATCH XECORE22",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE23", "GPGPU DISPATCH XECORE23",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2da13c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2dc13c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2de13c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10c37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da10033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc10dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc10c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e10c37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e10033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e32aa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e47c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e61550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e71550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00037fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307155a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010803ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01097fe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa955, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a2aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010203e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032943, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030c60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4003294a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000007a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0000008a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00001102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0001e002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x000083ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00022002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt773MetricSet::CExt773MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt773MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE24", "GPGPU DISPATCH XECORE24",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE25", "GPGPU DISPATCH XECORE25",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE26", "GPGPU DISPATCH XECORE26",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c813c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ca13c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2cc13c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810c37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a810cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c810033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca10dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea10c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c10c37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c10033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c32aa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c47c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c61550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c71550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02072aa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008feaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00097c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2aa5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00027c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c1550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02022aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000007a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0000008a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00001102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0001e002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x000083ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00022002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt774MetricSet::CExt774MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt774MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE27", "GPGPU DISPATCH XECORE27",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE28", "GPGPU DISPATCH XECORE28",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE29", "GPGPU DISPATCH XECORE29",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2ce13c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2d813c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2da13c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10c37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce10033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07810800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d810dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f810c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11810cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x018403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01875400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a10c37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a10033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a32aa0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a47c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a61550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a71550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00037fe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008fc00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a56aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017fe0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000ba800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03083ffa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01017c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b1550, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02022aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42031080, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030084, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00017fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082aaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000007a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0000008a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00001102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0001e002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x000083ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00022002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x000083ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt775MetricSet::CExt775MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt775MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE30", "GPGPU DISPATCH XECORE30",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "GPGPU_DISPATCH_XECORE31", "GPGPU DISPATCH XECORE31",
                          "Percentage of time spent dispatching GPGPU threads to XVEs",
                          "ThreadDispatcher", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2dc13c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2de13c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c10c37, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc10cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc10033, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c302aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c60155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e10800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de10dc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe10c70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e10cf2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3a800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e403e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e75400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000303ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010756aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010903ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c0155, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4603140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03140a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000103ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000007a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0000008a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffe0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000f02, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fc1f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00001102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000fc1f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt776MetricSet::CExt776MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt776MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE0_XVE0", "XVE MULTIPLE PIPE ACTIVE XECORE0 XVE0",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xd0 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x160 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE1_XVE0", "XVE MULTIPLE PIPE ACTIVE XECORE1 XVE0",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xd4 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x168 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE2_XVE0", "XVE MULTIPLE PIPE ACTIVE XECORE2 XVE0",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xd8 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x170 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE3_XVE0", "XVE MULTIPLE PIPE ACTIVE XECORE3 XVE0",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xdc USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x178 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a902960, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ab02960, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ad02960, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0af02960, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x009039e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02b039e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00b00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04d039e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c15000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c401c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06f039e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e300a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070056, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080fea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aa555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000201c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001b, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x000000c3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000603, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00003003, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00004002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt777MetricSet::CExt777MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt777MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE4_XVE0", "XVE MULTIPLE PIPE ACTIVE XECORE4 XVE0",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xd0 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x160 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE5_XVE0", "XVE MULTIPLE PIPE ACTIVE XECORE5 XVE0",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xd4 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x168 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE6_XVE0", "XVE MULTIPLE PIPE ACTIVE XECORE6 XVE0",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xd8 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x170 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE7_XVE0", "XVE MULTIPLE PIPE ACTIVE XECORE7 XVE0",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xdc USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x178 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b902960, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bb02960, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bd02960, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bf02960, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x019039e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03b039e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01b00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05d039e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c15000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c401c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07f039e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e300a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070056, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080fea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010201c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001b, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x000000c3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000603, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00003003, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00004002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt778MetricSet::CExt778MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt778MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE8_XVE0", "XVE MULTIPLE PIPE ACTIVE XECORE8 XVE0",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xd0 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x160 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE9_XVE0", "XVE MULTIPLE PIPE ACTIVE XECORE9 XVE0",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xd4 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x168 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE10_XVE0", "XVE MULTIPLE PIPE ACTIVE XECORE10 XVE0",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xd8 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x170 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE11_XVE0", "XVE MULTIPLE PIPE ACTIVE XECORE11 XVE0",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xdc USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x178 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a902960, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ab02960, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ad02960, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0af02960, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x009039e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02b039e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00b00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04d039e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c15000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c401c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06f039e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e300a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070056, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080fea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aa555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000201c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001b, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x000000c3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000603, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00003003, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00004002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt779MetricSet::CExt779MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt779MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE12_XVE0", "XVE MULTIPLE PIPE ACTIVE XECORE12 XVE0",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xd0 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x160 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE13_XVE0", "XVE MULTIPLE PIPE ACTIVE XECORE13 XVE0",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xd4 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x168 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE14_XVE0", "XVE MULTIPLE PIPE ACTIVE XECORE14 XVE0",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xd8 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x170 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE15_XVE0", "XVE MULTIPLE PIPE ACTIVE XECORE15 XVE0",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xdc USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x178 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b902960, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bb02960, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bd02960, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bf02960, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x019039e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03b039e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01b00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05d039e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c15000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c401c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07f039e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e300a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070056, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080fea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010201c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001b, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x000000c3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000603, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00003003, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00004002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt780MetricSet::CExt780MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt780MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE16_XVE0", "XVE MULTIPLE PIPE ACTIVE XECORE16 XVE0",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xd0 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x160 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE17_XVE0", "XVE MULTIPLE PIPE ACTIVE XECORE17 XVE0",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xd4 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x168 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE18_XVE0", "XVE MULTIPLE PIPE ACTIVE XECORE18 XVE0",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xd8 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x170 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE19_XVE0", "XVE MULTIPLE PIPE ACTIVE XECORE19 XVE0",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xdc USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x178 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a902960, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ab02960, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ad02960, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0af02960, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x009039e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02b039e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00b00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04d039e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c15000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c401c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06f039e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e300a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070056, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080fea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aa555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000201c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001b, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x000000c3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000603, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00003003, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00004002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt781MetricSet::CExt781MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt781MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE20_XVE0", "XVE MULTIPLE PIPE ACTIVE XECORE20 XVE0",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xd0 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x160 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE21_XVE0", "XVE MULTIPLE PIPE ACTIVE XECORE21 XVE0",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xd4 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x168 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE22_XVE0", "XVE MULTIPLE PIPE ACTIVE XECORE22 XVE0",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xd8 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x170 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE23_XVE0", "XVE MULTIPLE PIPE ACTIVE XECORE23 XVE0",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xdc USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x178 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b902960, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bb02960, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bd02960, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bf02960, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x019039e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03b039e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01b00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05d039e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c15000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c401c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07f039e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e300a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070056, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080fea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010201c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001b, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x000000c3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000603, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00003003, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00004002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt782MetricSet::CExt782MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt782MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE24_XVE0", "XVE MULTIPLE PIPE ACTIVE XECORE24 XVE0",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xd0 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x160 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE25_XVE0", "XVE MULTIPLE PIPE ACTIVE XECORE25 XVE0",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xd4 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x168 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE26_XVE0", "XVE MULTIPLE PIPE ACTIVE XECORE26 XVE0",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xd8 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x170 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE27_XVE0", "XVE MULTIPLE PIPE ACTIVE XECORE27 XVE0",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xdc USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x178 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a902960, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ab02960, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ad02960, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0af02960, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x009039e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00840007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00870015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02b039e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00b00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a70540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04d039e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00d00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c15000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c401c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06f039e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00f00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e300a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e40e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070056, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00080fea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00090fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aa555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000201c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020200aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001b, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x000000c3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000603, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00003003, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00004002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt783MetricSet::CExt783MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt783MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE28_XVE0", "XVE MULTIPLE PIPE ACTIVE XECORE28 XVE0",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xd0 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x160 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE29_XVE0", "XVE MULTIPLE PIPE ACTIVE XECORE29 XVE0",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4 dw@0xd4 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148 qw@0x168 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE30_XVE0", "XVE MULTIPLE PIPE ACTIVE XECORE30 XVE0",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8 dw@0xd8 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150 qw@0x170 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "XVE_MULTIPLE_PIPE_ACTIVE_XECORE31_XVE0", "XVE MULTIPLE PIPE ACTIVE XECORE31 XVE0",
                          "Percentage of time in which at least two pipes are actively executing a Gen ISA instruction among ALU0, ALU1 and XMX pipes",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xdc USUB" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x178 USUB" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b902960, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bb02960, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bd02960, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bf02960, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x019039e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01810015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183002a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840007, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01870015, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03b039e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01b00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a10540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30a80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a70540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05d039e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01d00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c15000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c10001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c401c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c75000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07f039e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01f00000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e10054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e300a8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e70054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070056, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080fea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01090fc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a00aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010038, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010201c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020200aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04030009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030840, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030063, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a031400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010fff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02020055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02040055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02050055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020800aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001b, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x000000c3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000603, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00003003, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000f1ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fff8, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffc7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fe3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00004002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000f1ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt784MetricSet::CExt784MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt784MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "PIXEL_2x2_LIT_POST_RASTERIZER_EARLY_DEPTH_SLICE0", "PIXEL 2x2 LIT POST RASTERIZER EARLY DEPTH SLICE0",
                          "Number of promoted 2x2 that are lit from Rasterizer",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "1 dw@0xc0 UMUL 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "1 qw@0x140 UMUL 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0310e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a052800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c05001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02053fc1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04050cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06050d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08050db5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a05003b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c05003c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e05003d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1005003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000655ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00085555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02081111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt785MetricSet::CExt785MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt785MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "PIXEL_2x2_LIT_POST_RASTERIZER_EARLY_DEPTH_SLICE1", "PIXEL 2x2 LIT POST RASTERIZER EARLY DEPTH SLICE1",
                          "Number of promoted 2x2 that are lit from Rasterizer",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "1 dw@0xc0 UMUL 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "1 qw@0x140 UMUL 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e036c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0337e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030360, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b052800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d05001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03053fc1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05050cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07050d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09050db5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b05003b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d05003c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f05003d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1105003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010655ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01085555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03081111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt786MetricSet::CExt786MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt786MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "PIXEL_2x2_LIT_POST_RASTERIZER_EARLY_DEPTH_SLICE2", "PIXEL 2x2 LIT POST RASTERIZER EARLY DEPTH SLICE2",
                          "Number of promoted 2x2 that are lit from Rasterizer",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "1 dw@0xc0 UMUL 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "1 qw@0x140 UMUL 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0310e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a052800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c05001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02053fc1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04050cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06050d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08050db5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a05003b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c05003c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e05003d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1005003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000655ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00085555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02081111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt787MetricSet::CExt787MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt787MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "PIXEL_2x2_LIT_POST_RASTERIZER_EARLY_DEPTH_SLICE3", "PIXEL 2x2 LIT POST RASTERIZER EARLY DEPTH SLICE3",
                          "Number of promoted 2x2 that are lit from Rasterizer",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "1 dw@0xc0 UMUL 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "1 qw@0x140 UMUL 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e036c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0337e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030360, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b052800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d05001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03053fc1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05050cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07050d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09050db5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b05003b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d05003c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f05003d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1105003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010655ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01085555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03081111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt788MetricSet::CExt788MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt788MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "PIXEL_2x2_LIT_POST_RASTERIZER_EARLY_DEPTH_SLICE4", "PIXEL 2x2 LIT POST RASTERIZER EARLY DEPTH SLICE4",
                          "Number of promoted 2x2 that are lit from Rasterizer",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "1 dw@0xc0 UMUL 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "1 qw@0x140 UMUL 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0312e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a052800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c05001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02053fc1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04050cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06050d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08050db5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a05003b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c05003c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e05003d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1005003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000655ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00085555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02081111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt789MetricSet::CExt789MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt789MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "PIXEL_2x2_LIT_POST_RASTERIZER_EARLY_DEPTH_SLICE5", "PIXEL 2x2 LIT POST RASTERIZER EARLY DEPTH SLICE5",
                          "Number of promoted 2x2 that are lit from Rasterizer",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "1 dw@0xc0 UMUL 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "1 qw@0x140 UMUL 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0339e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b052800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d05001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03053fc1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05050cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07050d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09050db5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b05003b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d05003c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f05003d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1105003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010655ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01085555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03081111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt790MetricSet::CExt790MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt790MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "PIXEL_2x2_LIT_POST_RASTERIZER_EARLY_DEPTH_SLICE6", "PIXEL 2x2 LIT POST RASTERIZER EARLY DEPTH SLICE6",
                          "Number of promoted 2x2 that are lit from Rasterizer",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "1 dw@0xc0 UMUL 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "1 qw@0x140 UMUL 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02022222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0312e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a052800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c05001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02053fc1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04050cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06050d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08050db5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a05003b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c05003c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e05003d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1005003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000655ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00085555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02081111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt791MetricSet::CExt791MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt791MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "PIXEL_2x2_LIT_POST_RASTERIZER_EARLY_DEPTH_SLICE7", "PIXEL 2x2 LIT POST RASTERIZER EARLY DEPTH SLICE7",
                          "Number of promoted 2x2 that are lit from Rasterizer",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "1 dw@0xc0 UMUL 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "1 qw@0x140 UMUL 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02022222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0339e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b052800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d05001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03053fc1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05050cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07050d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09050db5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b05003b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d05003c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f05003d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1105003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010655ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01085555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03081111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000812, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt792MetricSet::CExt792MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt792MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0";
        metric               = AddMetric( "PIXEL_2x2_LIT_POST_RASTERIZER_LATE_DEPTH_SLICE0", "PIXEL 2x2 LIT POST RASTERIZER LATE DEPTH SLICE0",
                          "Number of non-promoted 2x2 that are lit from Rasterizer",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "1 dw@0xc0 UMUL 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "1 qw@0x140 UMUL 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0310e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a052800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c05001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02053fc1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04050cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06050d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08050db5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a05003b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c05003c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e05003d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1005003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000655ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00085555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02081111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt793MetricSet::CExt793MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt793MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1";
        metric               = AddMetric( "PIXEL_2x2_LIT_POST_RASTERIZER_LATE_DEPTH_SLICE1", "PIXEL 2x2 LIT POST RASTERIZER LATE DEPTH SLICE1",
                          "Number of non-promoted 2x2 that are lit from Rasterizer",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "1 dw@0xc0 UMUL 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "1 qw@0x140 UMUL 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e036c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0337e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030360, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b052800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d05001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03053fc1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05050cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07050d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09050db5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b05003b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d05003c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f05003d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1105003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010655ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01085555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03081111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt794MetricSet::CExt794MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt794MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2";
        metric               = AddMetric( "PIXEL_2x2_LIT_POST_RASTERIZER_LATE_DEPTH_SLICE2", "PIXEL 2x2 LIT POST RASTERIZER LATE DEPTH SLICE2",
                          "Number of non-promoted 2x2 that are lit from Rasterizer",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "1 dw@0xc0 UMUL 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "1 qw@0x140 UMUL 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0310e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a052800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c05001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02053fc1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04050cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06050d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08050db5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a05003b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c05003c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e05003d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1005003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000655ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00085555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02081111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt795MetricSet::CExt795MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt795MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3";
        metric               = AddMetric( "PIXEL_2x2_LIT_POST_RASTERIZER_LATE_DEPTH_SLICE3", "PIXEL 2x2 LIT POST RASTERIZER LATE DEPTH SLICE3",
                          "Number of non-promoted 2x2 that are lit from Rasterizer",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "1 dw@0xc0 UMUL 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "1 qw@0x140 UMUL 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e036c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0337e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030360, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b052800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d05001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03053fc1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05050cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07050d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09050db5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b05003b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d05003c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f05003d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1105003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010655ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01085555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03081111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt796MetricSet::CExt796MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt796MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4";
        metric               = AddMetric( "PIXEL_2x2_LIT_POST_RASTERIZER_LATE_DEPTH_SLICE4", "PIXEL 2x2 LIT POST RASTERIZER LATE DEPTH SLICE4",
                          "Number of non-promoted 2x2 that are lit from Rasterizer",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "1 dw@0xc0 UMUL 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "1 qw@0x140 UMUL 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0312e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a052800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c05001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02053fc1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04050cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06050d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08050db5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a05003b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c05003c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e05003d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1005003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000655ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00085555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02081111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt797MetricSet::CExt797MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt797MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5";
        metric               = AddMetric( "PIXEL_2x2_LIT_POST_RASTERIZER_LATE_DEPTH_SLICE5", "PIXEL 2x2 LIT POST RASTERIZER LATE DEPTH SLICE5",
                          "Number of non-promoted 2x2 that are lit from Rasterizer",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "1 dw@0xc0 UMUL 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "1 qw@0x140 UMUL 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0339e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b052800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d05001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03053fc1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05050cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07050d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09050db5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b05003b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d05003c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f05003d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1105003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010655ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01085555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03081111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt798MetricSet::CExt798MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt798MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6";
        metric               = AddMetric( "PIXEL_2x2_LIT_POST_RASTERIZER_LATE_DEPTH_SLICE6", "PIXEL 2x2 LIT POST RASTERIZER LATE DEPTH SLICE6",
                          "Number of non-promoted 2x2 that are lit from Rasterizer",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "1 dw@0xc0 UMUL 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "1 qw@0x140 UMUL 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02022222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e032400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0312e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030120, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a052800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c05001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02053fc1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04050cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06050d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08050db5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a05003b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c05003c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e05003d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1005003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000655ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00085555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02081111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt799MetricSet::CExt799MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt799MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7";
        metric               = AddMetric( "PIXEL_2x2_LIT_POST_RASTERIZER_LATE_DEPTH_SLICE7", "PIXEL 2x2 LIT POST RASTERIZER LATE DEPTH SLICE7",
                          "Number of non-promoted 2x2 that are lit from Rasterizer",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_SLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "1 dw@0xc0 UMUL 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD 128 dw@0xdc UMUL UADD 256 dw@0xe4 UMUL UADD 512 dw@0xec UMUL UADD 1024 dw@0xf4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "1 qw@0x140 UMUL 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD 128 qw@0x178 UMUL UADD 256 qw@0x188 UMUL UADD 512 qw@0x198 UMUL UADD 1024 qw@0x1a8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2e080400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x30080018, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06081000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10080cc0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12080c80, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14080ec0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02080000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02022222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031451, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a0339e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1803f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c03f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b052800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d05001c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000355ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02083333, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01050000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03053fc1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05050cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07050d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09050db5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b05003b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d05003c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f05003d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1105003e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010655ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01085555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03081111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a1111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000155ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02021111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02041111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02051111, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02082222, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf080fefe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf08000fe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fefd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd90c, 0x1111111a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd908, 0x1111111c, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd91c, 0x1111111e, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt800MetricSet::CExt800MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt800MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE0", "RT INSTANCE NODE RAY COUNT XECORE0",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE0", "RT INTERNAL NODE RAY COUNT XECORE0",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE0", "RT TRAVERSAL STEP RAY COUNT XECORE0",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a8503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c85001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02858000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04858240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850b28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x088508a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a850baa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10850beb, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x128509e3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0086aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0286aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00010042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000dff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000efbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00010402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000df7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt801MetricSet::CExt801MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt801MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE1", "RT INSTANCE NODE RAY COUNT XECORE1",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE1", "RT INTERNAL NODE RAY COUNT XECORE1",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE1", "RT TRAVERSAL STEP RAY COUNT XECORE1",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ca5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a58240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50b28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a508a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa50baa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a50beb, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a509e3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00010042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000dff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000efbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00010402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000df7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt802MetricSet::CExt802MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt802MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE2", "RT INSTANCE NODE RAY COUNT XECORE2",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE2", "RT INTERNAL NODE RAY COUNT XECORE2",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE2", "RT TRAVERSAL STEP RAY COUNT XECORE2",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c58240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50b28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c508a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac50baa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c50beb, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c509e3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00010042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000dff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000efbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00010402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000df7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt803MetricSet::CExt803MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt803MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE3", "RT INSTANCE NODE RAY COUNT XECORE3",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE3", "RT INTERNAL NODE RAY COUNT XECORE3",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE3", "RT TRAVERSAL STEP RAY COUNT XECORE3",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ce5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e58240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50b28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e508a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae50baa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e50beb, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e509e3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00010042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000dff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000efbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00010402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000df7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt804MetricSet::CExt804MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt804MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE4", "RT INSTANCE NODE RAY COUNT XECORE4",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE4", "RT INTERNAL NODE RAY COUNT XECORE4",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE4", "RT TRAVERSAL STEP RAY COUNT XECORE4",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b8503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d85001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03858000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05858240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850b28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x098508a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b850baa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11850beb, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x138509e3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0186aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0386aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00010042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000dff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000efbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00010402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000df7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt805MetricSet::CExt805MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt805MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE5", "RT INSTANCE NODE RAY COUNT XECORE5",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE5", "RT INTERNAL NODE RAY COUNT XECORE5",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE5", "RT TRAVERSAL STEP RAY COUNT XECORE5",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1da5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a58240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50b28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a508a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba50baa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a50beb, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a509e3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00010042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000dff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000efbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00010402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000df7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt806MetricSet::CExt806MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt806MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE6", "RT INSTANCE NODE RAY COUNT XECORE6",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE6", "RT INTERNAL NODE RAY COUNT XECORE6",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE6", "RT TRAVERSAL STEP RAY COUNT XECORE6",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c58240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50b28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c508a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc50baa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c50beb, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c509e3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00010042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000dff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000efbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00010402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000df7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt807MetricSet::CExt807MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt807MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE7", "RT INSTANCE NODE RAY COUNT XECORE7",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE7", "RT INTERNAL NODE RAY COUNT XECORE7",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE7", "RT TRAVERSAL STEP RAY COUNT XECORE7",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1de5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e58240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50b28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e508a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be50baa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e50beb, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e509e3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00010042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000dff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000efbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00010402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000df7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt808MetricSet::CExt808MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt808MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE8", "RT INSTANCE NODE RAY COUNT XECORE8",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE8", "RT INTERNAL NODE RAY COUNT XECORE8",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE8", "RT TRAVERSAL STEP RAY COUNT XECORE8",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a8503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c85001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02858000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04858240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850b28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x088508a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a850baa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10850beb, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x128509e3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0086aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0286aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00010042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000dff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000efbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00010402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000df7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt809MetricSet::CExt809MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt809MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE9", "RT INSTANCE NODE RAY COUNT XECORE9",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE9", "RT INTERNAL NODE RAY COUNT XECORE9",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE9", "RT TRAVERSAL STEP RAY COUNT XECORE9",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ca5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a58240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50b28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a508a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa50baa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a50beb, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a509e3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00010042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000dff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000efbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00010402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000df7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt810MetricSet::CExt810MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt810MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE10", "RT INSTANCE NODE RAY COUNT XECORE10",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE10", "RT INTERNAL NODE RAY COUNT XECORE10",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE10", "RT TRAVERSAL STEP RAY COUNT XECORE10",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c58240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50b28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c508a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac50baa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c50beb, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c509e3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00010042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000dff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000efbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00010402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000df7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt811MetricSet::CExt811MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt811MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE11", "RT INSTANCE NODE RAY COUNT XECORE11",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE11", "RT INTERNAL NODE RAY COUNT XECORE11",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE11", "RT TRAVERSAL STEP RAY COUNT XECORE11",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ce5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e58240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50b28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e508a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae50baa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e50beb, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e509e3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00010042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000dff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000efbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00010402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000df7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt812MetricSet::CExt812MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt812MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE12", "RT INSTANCE NODE RAY COUNT XECORE12",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE12", "RT INTERNAL NODE RAY COUNT XECORE12",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE12", "RT TRAVERSAL STEP RAY COUNT XECORE12",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b8503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d85001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03858000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05858240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850b28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x098508a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b850baa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11850beb, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x138509e3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0186aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0386aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00010042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000dff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000efbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00010402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000df7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt813MetricSet::CExt813MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt813MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE13", "RT INSTANCE NODE RAY COUNT XECORE13",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE13", "RT INTERNAL NODE RAY COUNT XECORE13",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE13", "RT TRAVERSAL STEP RAY COUNT XECORE13",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1da5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a58240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50b28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a508a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba50baa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a50beb, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a509e3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00010042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000dff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000efbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00010402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000df7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt814MetricSet::CExt814MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt814MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE14", "RT INSTANCE NODE RAY COUNT XECORE14",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE14", "RT INTERNAL NODE RAY COUNT XECORE14",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE14", "RT TRAVERSAL STEP RAY COUNT XECORE14",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c58240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50b28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c508a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc50baa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c50beb, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c509e3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00010042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000dff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000efbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00010402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000df7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt815MetricSet::CExt815MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt815MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE15", "RT INSTANCE NODE RAY COUNT XECORE15",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE15", "RT INTERNAL NODE RAY COUNT XECORE15",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE15", "RT TRAVERSAL STEP RAY COUNT XECORE15",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1de5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e58240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50b28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e508a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be50baa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e50beb, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e509e3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032480, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00010042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000dff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000efbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00010402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000df7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt816MetricSet::CExt816MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt816MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE16", "RT INSTANCE NODE RAY COUNT XECORE16",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE16", "RT INTERNAL NODE RAY COUNT XECORE16",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE16", "RT TRAVERSAL STEP RAY COUNT XECORE16",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a8503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c85001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02858000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04858240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850b28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x088508a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a850baa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10850beb, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x128509e3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0086aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0286aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030049, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00010042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000dff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000efbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00010402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000df7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt817MetricSet::CExt817MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt817MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE17", "RT INSTANCE NODE RAY COUNT XECORE17",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE17", "RT INTERNAL NODE RAY COUNT XECORE17",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE17", "RT TRAVERSAL STEP RAY COUNT XECORE17",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ca5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a58240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50b28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a508a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa50baa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a50beb, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a509e3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030049, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00010042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000dff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000efbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00010402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000df7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt818MetricSet::CExt818MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt818MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE18", "RT INSTANCE NODE RAY COUNT XECORE18",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE18", "RT INTERNAL NODE RAY COUNT XECORE18",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE18", "RT TRAVERSAL STEP RAY COUNT XECORE18",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c58240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50b28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c508a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac50baa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c50beb, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c509e3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030049, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00010042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000dff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000efbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00010402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000df7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt819MetricSet::CExt819MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt819MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE19", "RT INSTANCE NODE RAY COUNT XECORE19",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE19", "RT INTERNAL NODE RAY COUNT XECORE19",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE19", "RT TRAVERSAL STEP RAY COUNT XECORE19",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ce5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e58240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50b28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e508a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae50baa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e50beb, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e509e3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030049, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00010042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000dff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000efbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00010402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000df7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt820MetricSet::CExt820MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt820MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE20", "RT INSTANCE NODE RAY COUNT XECORE20",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE20", "RT INTERNAL NODE RAY COUNT XECORE20",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE20", "RT TRAVERSAL STEP RAY COUNT XECORE20",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b8503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d85001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03858000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05858240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850b28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x098508a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b850baa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11850beb, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x138509e3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0186aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0386aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030049, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00010042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000dff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000efbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00010402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000df7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt821MetricSet::CExt821MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt821MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE21", "RT INSTANCE NODE RAY COUNT XECORE21",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE21", "RT INTERNAL NODE RAY COUNT XECORE21",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE21", "RT TRAVERSAL STEP RAY COUNT XECORE21",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1da5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a58240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50b28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a508a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba50baa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a50beb, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a509e3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030049, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00010042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000dff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000efbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00010402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000df7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt822MetricSet::CExt822MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt822MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE22", "RT INSTANCE NODE RAY COUNT XECORE22",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE22", "RT INTERNAL NODE RAY COUNT XECORE22",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE22", "RT TRAVERSAL STEP RAY COUNT XECORE22",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c58240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50b28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c508a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc50baa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c50beb, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c509e3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030049, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00010042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000dff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000efbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00010402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000df7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt823MetricSet::CExt823MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt823MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE23", "RT INSTANCE NODE RAY COUNT XECORE23",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE23", "RT INTERNAL NODE RAY COUNT XECORE23",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE23", "RT TRAVERSAL STEP RAY COUNT XECORE23",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1de5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e58240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50b28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e508a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be50baa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e50beb, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e509e3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030049, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00010042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000dff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000efbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00010402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000df7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt824MetricSet::CExt824MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt824MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE24", "RT INSTANCE NODE RAY COUNT XECORE24",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE24", "RT INTERNAL NODE RAY COUNT XECORE24",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE24", "RT TRAVERSAL STEP RAY COUNT XECORE24",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a8503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c85001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02858000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04858240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850b28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x088508a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a850baa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10850beb, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x128509e3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0086aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0286aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030049, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00010042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000dff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000efbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00010402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000df7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt825MetricSet::CExt825MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt825MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE25", "RT INSTANCE NODE RAY COUNT XECORE25",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE25", "RT INTERNAL NODE RAY COUNT XECORE25",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE25", "RT TRAVERSAL STEP RAY COUNT XECORE25",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ca5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a58240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50b28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a508a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa50baa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a50beb, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a509e3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030049, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00010042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000dff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000efbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00010402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000df7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt826MetricSet::CExt826MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt826MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE26", "RT INSTANCE NODE RAY COUNT XECORE26",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE26", "RT INTERNAL NODE RAY COUNT XECORE26",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE26", "RT TRAVERSAL STEP RAY COUNT XECORE26",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c58240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50b28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c508a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac50baa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c50beb, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c509e3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030049, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00010042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000dff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000efbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00010402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000df7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt827MetricSet::CExt827MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt827MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE27", "RT INSTANCE NODE RAY COUNT XECORE27",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE27", "RT INTERNAL NODE RAY COUNT XECORE27",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE27", "RT TRAVERSAL STEP RAY COUNT XECORE27",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ce5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e58240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50b28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e508a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae50baa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e50beb, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e509e3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030049, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00010042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000dff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000efbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00010402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000df7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt828MetricSet::CExt828MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt828MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE28", "RT INSTANCE NODE RAY COUNT XECORE28",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE28", "RT INTERNAL NODE RAY COUNT XECORE28",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE28", "RT TRAVERSAL STEP RAY COUNT XECORE28",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b8503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d85001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03858000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05858240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850b28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x098508a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b850baa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11850beb, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x138509e3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0186aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0386aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030049, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00010042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000dff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000efbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00010402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000df7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt829MetricSet::CExt829MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt829MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE29", "RT INSTANCE NODE RAY COUNT XECORE29",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE29", "RT INTERNAL NODE RAY COUNT XECORE29",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE29", "RT TRAVERSAL STEP RAY COUNT XECORE29",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1da5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a58240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50b28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a508a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba50baa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a50beb, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a509e3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030049, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00010042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000dff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000efbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00010402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000df7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt830MetricSet::CExt830MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt830MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE30", "RT INSTANCE NODE RAY COUNT XECORE30",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE30", "RT INTERNAL NODE RAY COUNT XECORE30",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE30", "RT TRAVERSAL STEP RAY COUNT XECORE30",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c58240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50b28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c508a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc50baa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c50beb, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c509e3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030049, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00010042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000dff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000efbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00010402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000df7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt831MetricSet::CExt831MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt831MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "RT_INSTANCE_NODE_RAY_COUNT_XECORE31", "RT INSTANCE NODE RAY COUNT XECORE31",
                          "Number of instance BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "RT_INTERNAL_NODE_RAY_COUNT_XECORE31", "RT INTERNAL NODE RAY COUNT XECORE31",
                          "Number of internal BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "RT_TRAVERSAL_STEP_RAY_COUNT_XECORE31", "RT TRAVERSAL STEP RAY COUNT XECORE31",
                          "Number of BVH nodes processed",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1de5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e58240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50b28, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e508a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be50baa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e50beb, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e509e3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030049, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001f0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0004000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00020012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00008022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000effb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00010042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000dff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00040082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x00007fef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00020102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000bfdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00008202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000efbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00010402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000df7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt832MetricSet::CExt832MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt832MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE0", "RT QUAD LEAF RAY COUNT XECORE0",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE0", "RT PROCEDURAL NODE RAY COUNT XECORE0",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a8503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c85001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02858000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04859a70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x088508a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a850821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c850baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e850b2d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10850aab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12850a29, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0086aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0286aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000002a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000282, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffaf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00028002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000afff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00002802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000faff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt833MetricSet::CExt833MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt833MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE1", "RT QUAD LEAF RAY COUNT XECORE1",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE1", "RT PROCEDURAL NODE RAY COUNT XECORE1",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ca5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a59a70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a508a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa50821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca50baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea50b2d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a50aab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a50a29, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000002a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000282, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffaf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00028002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000afff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00002802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000faff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt834MetricSet::CExt834MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt834MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE2", "RT QUAD LEAF RAY COUNT XECORE2",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE2", "RT PROCEDURAL NODE RAY COUNT XECORE2",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c59a70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c508a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac50821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc50baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50b2d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c50aab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c50a29, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000002a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000282, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffaf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00028002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000afff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00002802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000faff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt835MetricSet::CExt835MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt835MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE3", "RT QUAD LEAF RAY COUNT XECORE3",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE3", "RT PROCEDURAL NODE RAY COUNT XECORE3",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ce5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e59a70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e508a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae50821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce50baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee50b2d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e50aab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e50a29, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000002a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000282, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffaf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00028002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000afff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00002802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000faff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt836MetricSet::CExt836MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt836MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE4", "RT QUAD LEAF RAY COUNT XECORE4",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE4", "RT PROCEDURAL NODE RAY COUNT XECORE4",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b8503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d85001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03858000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05859a70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x098508a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b850821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d850baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f850b2d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11850aab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13850a29, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0186aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0386aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000002a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000282, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffaf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00028002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000afff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00002802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000faff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt837MetricSet::CExt837MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt837MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE5", "RT QUAD LEAF RAY COUNT XECORE5",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE5", "RT PROCEDURAL NODE RAY COUNT XECORE5",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1da5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a59a70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a508a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba50821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da50baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa50b2d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a50aab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a50a29, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000002a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000282, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffaf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00028002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000afff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00002802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000faff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt838MetricSet::CExt838MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt838MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE6", "RT QUAD LEAF RAY COUNT XECORE6",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE6", "RT PROCEDURAL NODE RAY COUNT XECORE6",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c59a70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c508a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc50821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc50baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc50b2d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c50aab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c50a29, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000002a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000282, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffaf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00028002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000afff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00002802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000faff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt839MetricSet::CExt839MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt839MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE7", "RT QUAD LEAF RAY COUNT XECORE7",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE7", "RT PROCEDURAL NODE RAY COUNT XECORE7",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1de5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e59a70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e508a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be50821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de50baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe50b2d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e50aab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e50a29, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000002a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000282, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffaf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00028002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000afff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00002802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000faff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt840MetricSet::CExt840MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt840MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE8", "RT QUAD LEAF RAY COUNT XECORE8",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE8", "RT PROCEDURAL NODE RAY COUNT XECORE8",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a8503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c85001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02858000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04859a70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x088508a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a850821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c850baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e850b2d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10850aab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12850a29, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0086aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0286aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000002a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000282, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffaf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00028002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000afff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00002802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000faff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt841MetricSet::CExt841MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt841MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE9", "RT QUAD LEAF RAY COUNT XECORE9",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE9", "RT PROCEDURAL NODE RAY COUNT XECORE9",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ca5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a59a70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a508a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa50821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca50baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea50b2d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a50aab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a50a29, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000002a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000282, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffaf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00028002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000afff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00002802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000faff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt842MetricSet::CExt842MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt842MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE10", "RT QUAD LEAF RAY COUNT XECORE10",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE10", "RT PROCEDURAL NODE RAY COUNT XECORE10",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c59a70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c508a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac50821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc50baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50b2d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c50aab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c50a29, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000002a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000282, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffaf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00028002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000afff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00002802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000faff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt843MetricSet::CExt843MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt843MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE11", "RT QUAD LEAF RAY COUNT XECORE11",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE11", "RT PROCEDURAL NODE RAY COUNT XECORE11",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ce5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e59a70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e508a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae50821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce50baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee50b2d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e50aab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e50a29, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000002a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000282, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffaf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00028002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000afff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00002802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000faff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt844MetricSet::CExt844MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt844MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE12", "RT QUAD LEAF RAY COUNT XECORE12",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE12", "RT PROCEDURAL NODE RAY COUNT XECORE12",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b8503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d85001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03858000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05859a70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x098508a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b850821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d850baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f850b2d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11850aab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13850a29, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0186aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0386aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000002a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000282, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffaf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00028002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000afff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00002802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000faff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt845MetricSet::CExt845MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt845MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE13", "RT QUAD LEAF RAY COUNT XECORE13",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE13", "RT PROCEDURAL NODE RAY COUNT XECORE13",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1da5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a59a70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a508a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba50821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da50baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa50b2d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a50aab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a50a29, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000002a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000282, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffaf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00028002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000afff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00002802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000faff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt846MetricSet::CExt846MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt846MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE14", "RT QUAD LEAF RAY COUNT XECORE14",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE14", "RT PROCEDURAL NODE RAY COUNT XECORE14",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c59a70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c508a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc50821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc50baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc50b2d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c50aab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c50a29, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000002a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000282, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffaf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00028002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000afff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00002802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000faff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt847MetricSet::CExt847MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt847MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE15", "RT QUAD LEAF RAY COUNT XECORE15",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE15", "RT PROCEDURAL NODE RAY COUNT XECORE15",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1de5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e59a70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e508a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be50821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de50baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe50b2d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e50aab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e50a29, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000002a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000282, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffaf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00028002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000afff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00002802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000faff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt848MetricSet::CExt848MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt848MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE16", "RT QUAD LEAF RAY COUNT XECORE16",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE16", "RT PROCEDURAL NODE RAY COUNT XECORE16",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a8503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c85001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02858000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04859a70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x088508a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a850821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c850baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e850b2d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10850aab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12850a29, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0086aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0286aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000002a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000282, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffaf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00028002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000afff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00002802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000faff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt849MetricSet::CExt849MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt849MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE17", "RT QUAD LEAF RAY COUNT XECORE17",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE17", "RT PROCEDURAL NODE RAY COUNT XECORE17",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ca5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a59a70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a508a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa50821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca50baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea50b2d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a50aab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a50a29, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000002a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000282, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffaf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00028002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000afff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00002802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000faff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt850MetricSet::CExt850MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt850MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE18", "RT QUAD LEAF RAY COUNT XECORE18",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE18", "RT PROCEDURAL NODE RAY COUNT XECORE18",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c59a70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c508a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac50821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc50baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50b2d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c50aab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c50a29, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000002a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000282, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffaf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00028002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000afff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00002802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000faff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt851MetricSet::CExt851MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt851MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE19", "RT QUAD LEAF RAY COUNT XECORE19",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE19", "RT PROCEDURAL NODE RAY COUNT XECORE19",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ce5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e59a70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e508a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae50821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce50baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee50b2d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e50aab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e50a29, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000002a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000282, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffaf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00028002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000afff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00002802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000faff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt852MetricSet::CExt852MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt852MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE20", "RT QUAD LEAF RAY COUNT XECORE20",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE20", "RT PROCEDURAL NODE RAY COUNT XECORE20",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b8503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d85001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03858000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05859a70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x098508a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b850821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d850baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f850b2d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11850aab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13850a29, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0186aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0386aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000002a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000282, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffaf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00028002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000afff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00002802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000faff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt853MetricSet::CExt853MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt853MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE21", "RT QUAD LEAF RAY COUNT XECORE21",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE21", "RT PROCEDURAL NODE RAY COUNT XECORE21",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1da5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a59a70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a508a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba50821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da50baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa50b2d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a50aab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a50a29, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000002a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000282, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffaf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00028002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000afff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00002802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000faff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt854MetricSet::CExt854MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt854MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE22", "RT QUAD LEAF RAY COUNT XECORE22",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE22", "RT PROCEDURAL NODE RAY COUNT XECORE22",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c59a70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c508a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc50821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc50baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc50b2d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c50aab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c50a29, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000002a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000282, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffaf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00028002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000afff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00002802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000faff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt855MetricSet::CExt855MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt855MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE23", "RT QUAD LEAF RAY COUNT XECORE23",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE23", "RT PROCEDURAL NODE RAY COUNT XECORE23",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1de5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e59a70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e508a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be50821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de50baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe50b2d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e50aab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e50a29, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000002a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000282, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffaf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00028002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000afff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00002802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000faff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt856MetricSet::CExt856MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt856MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE24", "RT QUAD LEAF RAY COUNT XECORE24",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE24", "RT PROCEDURAL NODE RAY COUNT XECORE24",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a8503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c85001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02858000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04859a70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x088508a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a850821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c850baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e850b2d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10850aab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12850a29, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0086aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0286aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000002a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000282, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffaf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00028002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000afff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00002802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000faff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt857MetricSet::CExt857MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt857MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE25", "RT QUAD LEAF RAY COUNT XECORE25",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE25", "RT PROCEDURAL NODE RAY COUNT XECORE25",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ca5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a59a70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a508a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa50821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca50baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea50b2d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a50aab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a50a29, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000002a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000282, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffaf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00028002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000afff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00002802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000faff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt858MetricSet::CExt858MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt858MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE26", "RT QUAD LEAF RAY COUNT XECORE26",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE26", "RT PROCEDURAL NODE RAY COUNT XECORE26",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1cc5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c59a70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c508a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac50821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc50baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec50b2d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c50aab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c50a29, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000002a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000282, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffaf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00028002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000afff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00002802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000faff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt859MetricSet::CExt859MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt859MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE27", "RT QUAD LEAF RAY COUNT XECORE27",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE27", "RT PROCEDURAL NODE RAY COUNT XECORE27",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ce5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e59a70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e508a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae50821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce50baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee50b2d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e50aab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e50a29, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000002a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000282, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffaf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00028002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000afff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00002802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000faff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt860MetricSet::CExt860MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt860MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE28", "RT QUAD LEAF RAY COUNT XECORE28",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE28", "RT PROCEDURAL NODE RAY COUNT XECORE28",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b8503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1d85001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03858000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05859a70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x098508a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b850821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d850baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f850b2d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11850aab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13850a29, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0186aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0386aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000002a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000282, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffaf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00028002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000afff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00002802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000faff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt861MetricSet::CExt861MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt861MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE29", "RT QUAD LEAF RAY COUNT XECORE29",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE29", "RT PROCEDURAL NODE RAY COUNT XECORE29",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1da5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a59a70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a508a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba50821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da50baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa50b2d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a50aab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a50a29, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000002a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000282, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffaf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00028002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000afff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00002802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000faff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt862MetricSet::CExt862MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt862MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE30", "RT QUAD LEAF RAY COUNT XECORE30",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE30", "RT PROCEDURAL NODE RAY COUNT XECORE30",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1dc5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c59a70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c508a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc50821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc50baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc50b2d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c50aab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c50a29, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000002a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000282, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffaf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00028002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000afff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00002802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000faff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt863MetricSet::CExt863MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt863MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "RT_QUAD_LEAF_RAY_COUNT_XECORE31", "RT QUAD LEAF RAY COUNT XECORE31",
                          "Number of triangle BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD dw@0xc8 UADD dw@0xcc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD qw@0x150 UADD qw@0x158 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "RT_PROCEDURAL_NODE_RAY_COUNT_XECORE31", "RT PROCEDURAL NODE RAY COUNT XECORE31",
                          "Number of procedural BVH nodes processed by the traversal function",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0 dw@0xd4 UADD dw@0xd8 UADD dw@0xdc UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160 qw@0x168 UADD qw@0x170 UADD qw@0x178 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be503e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1de5001f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e58000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e59a70, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50925, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e508a3, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be50821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de50baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe50b2d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e50aab, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e50a29, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fff0, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000ff0f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000f0ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00008002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x00000fff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x0000002a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fffa, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000282, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffaf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00028002, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000afff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00002802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000faff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt864MetricSet::CExt864MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt864MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE0", "RT BVH CACHE MISS XECORE0",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE1", "RT BVH CACHE MISS XECORE1",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE2", "RT BVH CACHE MISS XECORE2",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE3", "RT BVH CACHE MISS XECORE3",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02850002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10850083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12850001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0286aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a50002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca50083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c50002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c50083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e50002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e50830, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt865MetricSet::CExt865MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt865MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE4", "RT BVH CACHE MISS XECORE4",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE5", "RT BVH CACHE MISS XECORE5",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE6", "RT BVH CACHE MISS XECORE6",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE7", "RT BVH CACHE MISS XECORE7",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03850002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11850083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13850001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0386aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a50002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da50083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c50002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c50083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e50002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e50830, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt866MetricSet::CExt866MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt866MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE8", "RT BVH CACHE MISS XECORE8",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE9", "RT BVH CACHE MISS XECORE9",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE10", "RT BVH CACHE MISS XECORE10",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE11", "RT BVH CACHE MISS XECORE11",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02850002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10850083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12850001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0286aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a50002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca50083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c50002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c50083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e50002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e50830, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt867MetricSet::CExt867MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt867MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE12", "RT BVH CACHE MISS XECORE12",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE13", "RT BVH CACHE MISS XECORE13",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE14", "RT BVH CACHE MISS XECORE14",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE15", "RT BVH CACHE MISS XECORE15",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03850002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11850083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13850001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0386aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a50002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da50083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c50002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c50083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e50002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e50830, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt868MetricSet::CExt868MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt868MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE16", "RT BVH CACHE MISS XECORE16",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE17", "RT BVH CACHE MISS XECORE17",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE18", "RT BVH CACHE MISS XECORE18",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE19", "RT BVH CACHE MISS XECORE19",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02850002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10850083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12850001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0286aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a50002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca50083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c50002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c50083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e50002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e50830, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt869MetricSet::CExt869MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt869MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE20", "RT BVH CACHE MISS XECORE20",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE21", "RT BVH CACHE MISS XECORE21",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE22", "RT BVH CACHE MISS XECORE22",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE23", "RT BVH CACHE MISS XECORE23",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03850002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11850083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13850001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0386aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a50002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da50083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c50002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c50083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e50002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e50830, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt870MetricSet::CExt870MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt870MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE24", "RT BVH CACHE MISS XECORE24",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE25", "RT BVH CACHE MISS XECORE25",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE26", "RT BVH CACHE MISS XECORE26",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE27", "RT BVH CACHE MISS XECORE27",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02850002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10850083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12850001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0286aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a50002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca50083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c50002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c50083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e50002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e50830, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt871MetricSet::CExt871MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt871MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE28", "RT BVH CACHE MISS XECORE28",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE29", "RT BVH CACHE MISS XECORE29",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE30", "RT BVH CACHE MISS XECORE30",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "RT_BVH_CACHE_MISS_XECORE31", "RT BVH CACHE MISS XECORE31",
                          "Number of BVH cache misses for RayQuery only",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03850002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11850083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13850001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0386aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a50002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da50083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c50002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c50083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c6aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e50002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e50830, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e600aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42032942, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4403000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt872MetricSet::CExt872MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt872MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "SLM_ACCESS_COUNT_XECORE0", "SLM ACCESS COUNT XECORE0",
                          "Number of SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "SLM_ACCESS_COUNT_XECORE1", "SLM ACCESS COUNT XECORE1",
                          "Number of SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "SLM_ACCESS_COUNT_XECORE2", "SLM ACCESS COUNT XECORE2",
                          "Number of SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "SLM_ACCESS_COUNT_XECORE3", "SLM ACCESS COUNT XECORE3",
                          "Number of SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1687000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a87000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1288000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1688000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x148701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e8801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00893000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031cea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030d46, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt873MetricSet::CExt873MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt873MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "SLM_ACCESS_COUNT_XECORE4", "SLM ACCESS COUNT XECORE4",
                          "Number of SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "SLM_ACCESS_COUNT_XECORE5", "SLM ACCESS COUNT XECORE5",
                          "Number of SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "SLM_ACCESS_COUNT_XECORE6", "SLM ACCESS COUNT XECORE6",
                          "Number of SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "SLM_ACCESS_COUNT_XECORE7", "SLM ACCESS COUNT XECORE7",
                          "Number of SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1787000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b87000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1388000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1788000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x158701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f8801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01893000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031cea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030d46, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt874MetricSet::CExt874MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt874MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "SLM_ACCESS_COUNT_XECORE8", "SLM ACCESS COUNT XECORE8",
                          "Number of SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "SLM_ACCESS_COUNT_XECORE9", "SLM ACCESS COUNT XECORE9",
                          "Number of SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "SLM_ACCESS_COUNT_XECORE10", "SLM ACCESS COUNT XECORE10",
                          "Number of SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "SLM_ACCESS_COUNT_XECORE11", "SLM ACCESS COUNT XECORE11",
                          "Number of SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1687000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a87000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1288000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1688000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x148701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e8801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00893000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031cea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030d46, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt875MetricSet::CExt875MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt875MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "SLM_ACCESS_COUNT_XECORE12", "SLM ACCESS COUNT XECORE12",
                          "Number of SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "SLM_ACCESS_COUNT_XECORE13", "SLM ACCESS COUNT XECORE13",
                          "Number of SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "SLM_ACCESS_COUNT_XECORE14", "SLM ACCESS COUNT XECORE14",
                          "Number of SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "SLM_ACCESS_COUNT_XECORE15", "SLM ACCESS COUNT XECORE15",
                          "Number of SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1787000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b87000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1388000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1788000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x158701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f8801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01893000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031cea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030d46, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt876MetricSet::CExt876MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt876MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "SLM_ACCESS_COUNT_XECORE16", "SLM ACCESS COUNT XECORE16",
                          "Number of SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "SLM_ACCESS_COUNT_XECORE17", "SLM ACCESS COUNT XECORE17",
                          "Number of SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "SLM_ACCESS_COUNT_XECORE18", "SLM ACCESS COUNT XECORE18",
                          "Number of SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "SLM_ACCESS_COUNT_XECORE19", "SLM ACCESS COUNT XECORE19",
                          "Number of SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1687000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a87000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1288000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1688000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x148701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e8801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00893000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031cea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030d46, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt877MetricSet::CExt877MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt877MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "SLM_ACCESS_COUNT_XECORE20", "SLM ACCESS COUNT XECORE20",
                          "Number of SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "SLM_ACCESS_COUNT_XECORE21", "SLM ACCESS COUNT XECORE21",
                          "Number of SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "SLM_ACCESS_COUNT_XECORE22", "SLM ACCESS COUNT XECORE22",
                          "Number of SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "SLM_ACCESS_COUNT_XECORE23", "SLM ACCESS COUNT XECORE23",
                          "Number of SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1787000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b87000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1388000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1788000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x158701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f8801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01893000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031cea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030d46, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt878MetricSet::CExt878MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt878MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "SLM_ACCESS_COUNT_XECORE24", "SLM ACCESS COUNT XECORE24",
                          "Number of SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "SLM_ACCESS_COUNT_XECORE25", "SLM ACCESS COUNT XECORE25",
                          "Number of SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "SLM_ACCESS_COUNT_XECORE26", "SLM ACCESS COUNT XECORE26",
                          "Number of SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "SLM_ACCESS_COUNT_XECORE27", "SLM ACCESS COUNT XECORE27",
                          "Number of SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1687000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a87000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1288000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1688000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x148701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e8801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00893000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031cea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030d46, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt879MetricSet::CExt879MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt879MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "SLM_ACCESS_COUNT_XECORE28", "SLM ACCESS COUNT XECORE28",
                          "Number of SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "SLM_ACCESS_COUNT_XECORE29", "SLM ACCESS COUNT XECORE29",
                          "Number of SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "SLM_ACCESS_COUNT_XECORE30", "SLM ACCESS COUNT XECORE30",
                          "Number of SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "SLM_ACCESS_COUNT_XECORE31", "SLM ACCESS COUNT XECORE31",
                          "Number of SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1787000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b87000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1388000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1788000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be7000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e8000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x158701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f8801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01893000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e701d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e801d7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031cea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030d46, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt880MetricSet::CExt880MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt880MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_L3_WRITE_SQIDI0", "GPU MEMORY L3 WRITE SQIDI0",
                          "Number of GTI memory writes from L3 caused by L3 invalidations",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18013800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a01000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020100e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06011c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08010248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a0102ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c01034c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e0103ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00034924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a2492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b1249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x10800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000018a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fe00, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt881MetricSet::CExt881MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt881MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_L3_WRITE_SQIDI1", "GPU MEMORY L3 WRITE SQIDI1",
                          "Number of GTI memory writes from L3 caused by L3 invalidations",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18213800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a21000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022100e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06211c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08210248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a2102ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c21034c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e2103ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00034924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a2492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b2492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x10800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000018a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fe00, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt882MetricSet::CExt882MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt882MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_L3_WRITE_SQIDI2", "GPU MEMORY L3 WRITE SQIDI2",
                          "Number of GTI memory writes from L3 caused by L3 invalidations",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18413800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a41000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x024100e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06411c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08410248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a4102ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c41034c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e4103ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00410000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00034924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a2492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b36db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b06db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x10800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000018a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fe00, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt883MetricSet::CExt883MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt883MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_L3_WRITE_SQIDI3", "GPU MEMORY L3 WRITE SQIDI3",
                          "Number of GTI memory writes from L3 caused by L3 invalidations",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18613800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a61000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x026100e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06611c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08610248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a6102ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c61034c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e6103ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00610000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00034924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a2492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b4924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x10800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000018a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fe00, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt884MetricSet::CExt884MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt884MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_L3_WRITE_SQIDI4", "GPU MEMORY L3 WRITE SQIDI4",
                          "Number of GTI memory writes from L3 caused by L3 invalidations",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18813800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a81000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x028100e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06811c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a8102ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c81034c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e8103ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00034924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00091249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a1249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x10800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000018a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fe00, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt885MetricSet::CExt885MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt885MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_L3_WRITE_SQIDI5", "GPU MEMORY L3 WRITE SQIDI5",
                          "Number of GTI memory writes from L3 caused by L3 invalidations",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a13800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa1000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a100e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a11c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa102ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca1034c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea103ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00034924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00092492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a1249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x10800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000018a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fe00, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt886MetricSet::CExt886MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt886MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_L3_WRITE_SQIDI6", "GPU MEMORY L3 WRITE SQIDI6",
                          "Number of GTI memory writes from L3 caused by L3 invalidations",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c13800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac1000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c100e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c11c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac102ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc1034c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec103ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00034924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000936db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020906db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a1249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x10800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000018a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fe00, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt887MetricSet::CExt887MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt887MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_L3_WRITE_SQIDI7", "GPU MEMORY L3 WRITE SQIDI7",
                          "Number of GTI memory writes from L3 caused by L3 invalidations",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e13800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae1000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e100e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e11c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae102ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce1034c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee103ce, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00034924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02030924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00094924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02090924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a1249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a0249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x10800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000018a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fe00, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt888MetricSet::CExt888MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt888MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_NUMBER_OF_BANK_ACCESS_COUNT_XECORE0", "LOAD STORE CACHE NUMBER OF BANK ACCESS COUNT XECORE0",
                          "Number of Load Store Cache banks accessed in a clock.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_NUMBER_OF_BANK_ACCESS_COUNT_XECORE1", "LOAD STORE CACHE NUMBER OF BANK ACCESS COUNT XECORE1",
                          "Number of Load Store Cache banks accessed in a clock.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_NUMBER_OF_BANK_ACCESS_COUNT_XECORE2", "LOAD STORE CACHE NUMBER OF BANK ACCESS COUNT XECORE2",
                          "Number of Load Store Cache banks accessed in a clock.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_NUMBER_OF_BANK_ACCESS_COUNT_XECORE3", "LOAD STORE CACHE NUMBER OF BANK ACCESS COUNT XECORE3",
                          "Number of Load Store Cache banks accessed in a clock.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14870010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e880010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00893000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031cea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030d46, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt889MetricSet::CExt889MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt889MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_NUMBER_OF_BANK_ACCESS_COUNT_XECORE4", "LOAD STORE CACHE NUMBER OF BANK ACCESS COUNT XECORE4",
                          "Number of Load Store Cache banks accessed in a clock.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_NUMBER_OF_BANK_ACCESS_COUNT_XECORE5", "LOAD STORE CACHE NUMBER OF BANK ACCESS COUNT XECORE5",
                          "Number of Load Store Cache banks accessed in a clock.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_NUMBER_OF_BANK_ACCESS_COUNT_XECORE6", "LOAD STORE CACHE NUMBER OF BANK ACCESS COUNT XECORE6",
                          "Number of Load Store Cache banks accessed in a clock.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_NUMBER_OF_BANK_ACCESS_COUNT_XECORE7", "LOAD STORE CACHE NUMBER OF BANK ACCESS COUNT XECORE7",
                          "Number of Load Store Cache banks accessed in a clock.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15870010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f880010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01893000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031cea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030d46, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt890MetricSet::CExt890MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt890MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_NUMBER_OF_BANK_ACCESS_COUNT_XECORE8", "LOAD STORE CACHE NUMBER OF BANK ACCESS COUNT XECORE8",
                          "Number of Load Store Cache banks accessed in a clock.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_NUMBER_OF_BANK_ACCESS_COUNT_XECORE9", "LOAD STORE CACHE NUMBER OF BANK ACCESS COUNT XECORE9",
                          "Number of Load Store Cache banks accessed in a clock.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_NUMBER_OF_BANK_ACCESS_COUNT_XECORE10", "LOAD STORE CACHE NUMBER OF BANK ACCESS COUNT XECORE10",
                          "Number of Load Store Cache banks accessed in a clock.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_NUMBER_OF_BANK_ACCESS_COUNT_XECORE11", "LOAD STORE CACHE NUMBER OF BANK ACCESS COUNT XECORE11",
                          "Number of Load Store Cache banks accessed in a clock.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14870010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e880010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00893000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031cea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030d46, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt891MetricSet::CExt891MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt891MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_NUMBER_OF_BANK_ACCESS_COUNT_XECORE12", "LOAD STORE CACHE NUMBER OF BANK ACCESS COUNT XECORE12",
                          "Number of Load Store Cache banks accessed in a clock.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_NUMBER_OF_BANK_ACCESS_COUNT_XECORE13", "LOAD STORE CACHE NUMBER OF BANK ACCESS COUNT XECORE13",
                          "Number of Load Store Cache banks accessed in a clock.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_NUMBER_OF_BANK_ACCESS_COUNT_XECORE14", "LOAD STORE CACHE NUMBER OF BANK ACCESS COUNT XECORE14",
                          "Number of Load Store Cache banks accessed in a clock.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_NUMBER_OF_BANK_ACCESS_COUNT_XECORE15", "LOAD STORE CACHE NUMBER OF BANK ACCESS COUNT XECORE15",
                          "Number of Load Store Cache banks accessed in a clock.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15870010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f880010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01893000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031cea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030d46, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt892MetricSet::CExt892MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt892MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_NUMBER_OF_BANK_ACCESS_COUNT_XECORE16", "LOAD STORE CACHE NUMBER OF BANK ACCESS COUNT XECORE16",
                          "Number of Load Store Cache banks accessed in a clock.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_NUMBER_OF_BANK_ACCESS_COUNT_XECORE17", "LOAD STORE CACHE NUMBER OF BANK ACCESS COUNT XECORE17",
                          "Number of Load Store Cache banks accessed in a clock.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_NUMBER_OF_BANK_ACCESS_COUNT_XECORE18", "LOAD STORE CACHE NUMBER OF BANK ACCESS COUNT XECORE18",
                          "Number of Load Store Cache banks accessed in a clock.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_NUMBER_OF_BANK_ACCESS_COUNT_XECORE19", "LOAD STORE CACHE NUMBER OF BANK ACCESS COUNT XECORE19",
                          "Number of Load Store Cache banks accessed in a clock.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14870010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e880010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00893000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031cea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030d46, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt893MetricSet::CExt893MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt893MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_NUMBER_OF_BANK_ACCESS_COUNT_XECORE20", "LOAD STORE CACHE NUMBER OF BANK ACCESS COUNT XECORE20",
                          "Number of Load Store Cache banks accessed in a clock.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_NUMBER_OF_BANK_ACCESS_COUNT_XECORE21", "LOAD STORE CACHE NUMBER OF BANK ACCESS COUNT XECORE21",
                          "Number of Load Store Cache banks accessed in a clock.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_NUMBER_OF_BANK_ACCESS_COUNT_XECORE22", "LOAD STORE CACHE NUMBER OF BANK ACCESS COUNT XECORE22",
                          "Number of Load Store Cache banks accessed in a clock.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_NUMBER_OF_BANK_ACCESS_COUNT_XECORE23", "LOAD STORE CACHE NUMBER OF BANK ACCESS COUNT XECORE23",
                          "Number of Load Store Cache banks accessed in a clock.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15870010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f880010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01893000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031cea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030d46, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt894MetricSet::CExt894MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt894MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_NUMBER_OF_BANK_ACCESS_COUNT_XECORE24", "LOAD STORE CACHE NUMBER OF BANK ACCESS COUNT XECORE24",
                          "Number of Load Store Cache banks accessed in a clock.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_NUMBER_OF_BANK_ACCESS_COUNT_XECORE25", "LOAD STORE CACHE NUMBER OF BANK ACCESS COUNT XECORE25",
                          "Number of Load Store Cache banks accessed in a clock.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_NUMBER_OF_BANK_ACCESS_COUNT_XECORE26", "LOAD STORE CACHE NUMBER OF BANK ACCESS COUNT XECORE26",
                          "Number of Load Store Cache banks accessed in a clock.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_NUMBER_OF_BANK_ACCESS_COUNT_XECORE27", "LOAD STORE CACHE NUMBER OF BANK ACCESS COUNT XECORE27",
                          "Number of Load Store Cache banks accessed in a clock.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14870010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e880010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00893000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031cea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030d46, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt895MetricSet::CExt895MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt895MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_NUMBER_OF_BANK_ACCESS_COUNT_XECORE28", "LOAD STORE CACHE NUMBER OF BANK ACCESS COUNT XECORE28",
                          "Number of Load Store Cache banks accessed in a clock.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc dw@0xf8 UADD dw@0xf4 UADD dw@0xf0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 qw@0x1b0 UADD qw@0x1a8 UADD qw@0x1a0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_NUMBER_OF_BANK_ACCESS_COUNT_XECORE29", "LOAD STORE CACHE NUMBER OF BANK ACCESS COUNT XECORE29",
                          "Number of Load Store Cache banks accessed in a clock.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec dw@0xe8 UADD dw@0xe4 UADD dw@0xe0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198 qw@0x190 UADD qw@0x188 UADD qw@0x180 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_NUMBER_OF_BANK_ACCESS_COUNT_XECORE30", "LOAD STORE CACHE NUMBER OF BANK ACCESS COUNT XECORE30",
                          "Number of Load Store Cache banks accessed in a clock.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc dw@0xd8 UADD dw@0xd4 UADD dw@0xd0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178 qw@0x170 UADD qw@0x168 UADD qw@0x160 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_NUMBER_OF_BANK_ACCESS_COUNT_XECORE31", "LOAD STORE CACHE NUMBER OF BANK ACCESS COUNT XECORE31",
                          "Number of Load Store Cache banks accessed in a clock.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc dw@0xc8 UADD dw@0xc4 UADD dw@0xc0 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158 qw@0x150 UADD qw@0x148 UADD qw@0x140 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1b870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ba70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1bc70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1be70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15870010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03870a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f880010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01893000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90300, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aa00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c400f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c70a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e300aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e60055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e70010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e80010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010900ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010f00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0055, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010200f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e031cea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030d46, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030603, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40031842, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt896MetricSet::CExt896MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt896MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "ICACHE_HIT_BANK0_XECORE0", "ICACHE HIT BANK0 XECORE0",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "ICACHE_HIT_BANK0_XECORE1", "ICACHE HIT BANK0 XECORE1",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "ICACHE_HIT_BANK0_XECORE2", "ICACHE HIT BANK0 XECORE2",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "ICACHE_HIT_BANK0_XECORE3", "ICACHE HIT BANK0 XECORE3",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "ICACHE_HIT_BANK0_XECORE4", "ICACHE HIT BANK0 XECORE4",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "ICACHE_HIT_BANK0_XECORE5", "ICACHE HIT BANK0 XECORE5",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "ICACHE_HIT_BANK0_XECORE6", "ICACHE HIT BANK0 XECORE6",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "ICACHE_HIT_BANK0_XECORE7", "ICACHE HIT BANK0 XECORE7",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "ICACHE_MISS_BANK0_XECORE0", "ICACHE MISS BANK0 XECORE0",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "ICACHE_MISS_BANK0_XECORE1", "ICACHE MISS BANK0 XECORE1",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "ICACHE_MISS_BANK0_XECORE2", "ICACHE MISS BANK0 XECORE2",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "ICACHE_MISS_BANK0_XECORE3", "ICACHE MISS BANK0 XECORE3",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "ICACHE_MISS_BANK0_XECORE4", "ICACHE MISS BANK0 XECORE4",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "ICACHE_MISS_BANK0_XECORE5", "ICACHE MISS BANK0 XECORE5",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "ICACHE_MISS_BANK0_XECORE6", "ICACHE MISS BANK0 XECORE6",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "ICACHE_MISS_BANK0_XECORE7", "ICACHE MISS BANK0 XECORE7",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1882000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a2000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c2000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e2000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1982000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a2000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c2000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e2000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04820002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06820c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16820005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02834000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c20180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c20005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05820002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b820180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13820005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840810, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc20180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c20005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe20146, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e34000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e64000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff0e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009300c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a55a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014ff2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01076000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010903c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03086a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203200a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030047, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000eff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7ef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fbdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fdbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fe7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt897MetricSet::CExt897MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt897MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "ICACHE_HIT_BANK0_XECORE8", "ICACHE HIT BANK0 XECORE8",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "ICACHE_HIT_BANK0_XECORE9", "ICACHE HIT BANK0 XECORE9",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "ICACHE_HIT_BANK0_XECORE10", "ICACHE HIT BANK0 XECORE10",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "ICACHE_HIT_BANK0_XECORE11", "ICACHE HIT BANK0 XECORE11",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "ICACHE_HIT_BANK0_XECORE12", "ICACHE HIT BANK0 XECORE12",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "ICACHE_HIT_BANK0_XECORE13", "ICACHE HIT BANK0 XECORE13",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "ICACHE_HIT_BANK0_XECORE14", "ICACHE HIT BANK0 XECORE14",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "ICACHE_HIT_BANK0_XECORE15", "ICACHE HIT BANK0 XECORE15",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "ICACHE_MISS_BANK0_XECORE8", "ICACHE MISS BANK0 XECORE8",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "ICACHE_MISS_BANK0_XECORE9", "ICACHE MISS BANK0 XECORE9",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "ICACHE_MISS_BANK0_XECORE10", "ICACHE MISS BANK0 XECORE10",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "ICACHE_MISS_BANK0_XECORE11", "ICACHE MISS BANK0 XECORE11",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "ICACHE_MISS_BANK0_XECORE12", "ICACHE MISS BANK0 XECORE12",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "ICACHE_MISS_BANK0_XECORE13", "ICACHE MISS BANK0 XECORE13",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "ICACHE_MISS_BANK0_XECORE14", "ICACHE MISS BANK0 XECORE14",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "ICACHE_MISS_BANK0_XECORE15", "ICACHE MISS BANK0 XECORE15",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1882000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a2000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c2000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e2000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1982000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a2000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c2000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e2000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04820002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06820c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16820005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02834000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c20180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c20005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05820002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b820180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13820005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840810, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc20180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c20005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe20146, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e34000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e64000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff0e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009300c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a55a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014ff2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01076000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010903c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03086a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203200a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030047, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000eff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7ef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fbdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fdbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fe7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt898MetricSet::CExt898MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt898MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "ICACHE_HIT_BANK0_XECORE16", "ICACHE HIT BANK0 XECORE16",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "ICACHE_HIT_BANK0_XECORE17", "ICACHE HIT BANK0 XECORE17",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "ICACHE_HIT_BANK0_XECORE18", "ICACHE HIT BANK0 XECORE18",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "ICACHE_HIT_BANK0_XECORE19", "ICACHE HIT BANK0 XECORE19",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "ICACHE_HIT_BANK0_XECORE20", "ICACHE HIT BANK0 XECORE20",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "ICACHE_HIT_BANK0_XECORE21", "ICACHE HIT BANK0 XECORE21",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "ICACHE_HIT_BANK0_XECORE22", "ICACHE HIT BANK0 XECORE22",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "ICACHE_HIT_BANK0_XECORE23", "ICACHE HIT BANK0 XECORE23",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "ICACHE_MISS_BANK0_XECORE16", "ICACHE MISS BANK0 XECORE16",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "ICACHE_MISS_BANK0_XECORE17", "ICACHE MISS BANK0 XECORE17",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "ICACHE_MISS_BANK0_XECORE18", "ICACHE MISS BANK0 XECORE18",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "ICACHE_MISS_BANK0_XECORE19", "ICACHE MISS BANK0 XECORE19",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "ICACHE_MISS_BANK0_XECORE20", "ICACHE MISS BANK0 XECORE20",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "ICACHE_MISS_BANK0_XECORE21", "ICACHE MISS BANK0 XECORE21",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "ICACHE_MISS_BANK0_XECORE22", "ICACHE MISS BANK0 XECORE22",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "ICACHE_MISS_BANK0_XECORE23", "ICACHE MISS BANK0 XECORE23",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1882000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a2000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c2000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e2000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1982000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a2000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c2000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e2000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04820002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06820c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16820005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02834000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c20180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c20005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05820002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b820180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13820005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840810, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc20180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c20005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe20146, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e34000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e64000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff0e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009300c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a55a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014ff2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01076000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010903c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03086a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203200a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030047, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000eff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7ef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fbdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fdbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fe7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt899MetricSet::CExt899MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt899MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "ICACHE_HIT_BANK0_XECORE24", "ICACHE HIT BANK0 XECORE24",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "ICACHE_HIT_BANK0_XECORE25", "ICACHE HIT BANK0 XECORE25",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "ICACHE_HIT_BANK0_XECORE26", "ICACHE HIT BANK0 XECORE26",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "ICACHE_HIT_BANK0_XECORE27", "ICACHE HIT BANK0 XECORE27",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "ICACHE_HIT_BANK0_XECORE28", "ICACHE HIT BANK0 XECORE28",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "ICACHE_HIT_BANK0_XECORE29", "ICACHE HIT BANK0 XECORE29",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "ICACHE_HIT_BANK0_XECORE30", "ICACHE HIT BANK0 XECORE30",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "ICACHE_HIT_BANK0_XECORE31", "ICACHE HIT BANK0 XECORE31",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "ICACHE_MISS_BANK0_XECORE24", "ICACHE MISS BANK0 XECORE24",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "ICACHE_MISS_BANK0_XECORE25", "ICACHE MISS BANK0 XECORE25",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "ICACHE_MISS_BANK0_XECORE26", "ICACHE MISS BANK0 XECORE26",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "ICACHE_MISS_BANK0_XECORE27", "ICACHE MISS BANK0 XECORE27",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "ICACHE_MISS_BANK0_XECORE28", "ICACHE MISS BANK0 XECORE28",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "ICACHE_MISS_BANK0_XECORE29", "ICACHE MISS BANK0 XECORE29",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "ICACHE_MISS_BANK0_XECORE30", "ICACHE MISS BANK0 XECORE30",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "ICACHE_MISS_BANK0_XECORE31", "ICACHE MISS BANK0 XECORE31",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1882000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a2000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c2000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e2000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1982000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a2000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c2000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e2000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04820002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06820c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16820005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02834000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c20180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c20005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05820002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b820180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13820005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840810, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc20180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c20005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe20146, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e34000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e64000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff0e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009300c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a55a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014ff2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01076000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010903c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03086a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203200a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030047, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000eff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7ef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fbdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fdbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fe7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt900MetricSet::CExt900MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt900MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "ICACHE_HIT_BANK1_XECORE0", "ICACHE HIT BANK1 XECORE0",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "ICACHE_HIT_BANK1_XECORE1", "ICACHE HIT BANK1 XECORE1",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "ICACHE_HIT_BANK1_XECORE2", "ICACHE HIT BANK1 XECORE2",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "ICACHE_HIT_BANK1_XECORE3", "ICACHE HIT BANK1 XECORE3",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "ICACHE_HIT_BANK1_XECORE4", "ICACHE HIT BANK1 XECORE4",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "ICACHE_HIT_BANK1_XECORE5", "ICACHE HIT BANK1 XECORE5",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "ICACHE_HIT_BANK1_XECORE6", "ICACHE HIT BANK1 XECORE6",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "ICACHE_HIT_BANK1_XECORE7", "ICACHE HIT BANK1 XECORE7",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "ICACHE_MISS_BANK1_XECORE0", "ICACHE MISS BANK1 XECORE0",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "ICACHE_MISS_BANK1_XECORE1", "ICACHE MISS BANK1 XECORE1",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "ICACHE_MISS_BANK1_XECORE2", "ICACHE MISS BANK1 XECORE2",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "ICACHE_MISS_BANK1_XECORE3", "ICACHE MISS BANK1 XECORE3",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "ICACHE_MISS_BANK1_XECORE4", "ICACHE MISS BANK1 XECORE4",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "ICACHE_MISS_BANK1_XECORE5", "ICACHE MISS BANK1 XECORE5",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "ICACHE_MISS_BANK1_XECORE6", "ICACHE MISS BANK1 XECORE6",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "ICACHE_MISS_BANK1_XECORE7", "ICACHE MISS BANK1 XECORE7",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18820011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a20011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c20011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e20011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19820011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a20011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c20011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e20011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04820002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06820c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16820005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02834000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c20180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c20005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05820002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b820180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13820005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840810, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc20180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c20005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe20146, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e34000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e64000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff0e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009300c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a55a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014ff2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01076000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010903c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03086a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203200a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030047, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000eff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7ef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fbdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fdbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fe7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt901MetricSet::CExt901MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt901MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "ICACHE_HIT_BANK1_XECORE8", "ICACHE HIT BANK1 XECORE8",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "ICACHE_HIT_BANK1_XECORE9", "ICACHE HIT BANK1 XECORE9",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "ICACHE_HIT_BANK1_XECORE10", "ICACHE HIT BANK1 XECORE10",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "ICACHE_HIT_BANK1_XECORE11", "ICACHE HIT BANK1 XECORE11",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "ICACHE_HIT_BANK1_XECORE12", "ICACHE HIT BANK1 XECORE12",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "ICACHE_HIT_BANK1_XECORE13", "ICACHE HIT BANK1 XECORE13",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "ICACHE_HIT_BANK1_XECORE14", "ICACHE HIT BANK1 XECORE14",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "ICACHE_HIT_BANK1_XECORE15", "ICACHE HIT BANK1 XECORE15",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "ICACHE_MISS_BANK1_XECORE8", "ICACHE MISS BANK1 XECORE8",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "ICACHE_MISS_BANK1_XECORE9", "ICACHE MISS BANK1 XECORE9",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "ICACHE_MISS_BANK1_XECORE10", "ICACHE MISS BANK1 XECORE10",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "ICACHE_MISS_BANK1_XECORE11", "ICACHE MISS BANK1 XECORE11",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "ICACHE_MISS_BANK1_XECORE12", "ICACHE MISS BANK1 XECORE12",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "ICACHE_MISS_BANK1_XECORE13", "ICACHE MISS BANK1 XECORE13",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "ICACHE_MISS_BANK1_XECORE14", "ICACHE MISS BANK1 XECORE14",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "ICACHE_MISS_BANK1_XECORE15", "ICACHE MISS BANK1 XECORE15",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18820011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a20011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c20011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e20011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19820011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a20011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c20011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e20011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04820002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06820c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16820005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02834000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c20180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c20005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05820002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b820180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13820005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840810, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc20180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c20005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe20146, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e34000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e64000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff0e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009300c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a55a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014ff2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01076000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010903c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03086a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203200a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030047, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000eff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7ef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fbdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fdbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fe7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt902MetricSet::CExt902MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt902MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "ICACHE_HIT_BANK1_XECORE16", "ICACHE HIT BANK1 XECORE16",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "ICACHE_HIT_BANK1_XECORE17", "ICACHE HIT BANK1 XECORE17",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "ICACHE_HIT_BANK1_XECORE18", "ICACHE HIT BANK1 XECORE18",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "ICACHE_HIT_BANK1_XECORE19", "ICACHE HIT BANK1 XECORE19",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "ICACHE_HIT_BANK1_XECORE20", "ICACHE HIT BANK1 XECORE20",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "ICACHE_HIT_BANK1_XECORE21", "ICACHE HIT BANK1 XECORE21",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "ICACHE_HIT_BANK1_XECORE22", "ICACHE HIT BANK1 XECORE22",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "ICACHE_HIT_BANK1_XECORE23", "ICACHE HIT BANK1 XECORE23",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "ICACHE_MISS_BANK1_XECORE16", "ICACHE MISS BANK1 XECORE16",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "ICACHE_MISS_BANK1_XECORE17", "ICACHE MISS BANK1 XECORE17",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "ICACHE_MISS_BANK1_XECORE18", "ICACHE MISS BANK1 XECORE18",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "ICACHE_MISS_BANK1_XECORE19", "ICACHE MISS BANK1 XECORE19",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "ICACHE_MISS_BANK1_XECORE20", "ICACHE MISS BANK1 XECORE20",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "ICACHE_MISS_BANK1_XECORE21", "ICACHE MISS BANK1 XECORE21",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "ICACHE_MISS_BANK1_XECORE22", "ICACHE MISS BANK1 XECORE22",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "ICACHE_MISS_BANK1_XECORE23", "ICACHE MISS BANK1 XECORE23",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18820011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a20011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c20011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e20011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19820011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a20011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c20011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e20011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04820002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06820c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16820005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02834000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c20180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c20005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05820002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b820180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13820005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840810, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc20180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c20005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe20146, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e34000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e64000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff0e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009300c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a55a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014ff2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01076000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010903c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03086a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203200a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030047, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000eff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7ef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fbdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fdbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fe7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt903MetricSet::CExt903MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt903MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "ICACHE_HIT_BANK1_XECORE24", "ICACHE HIT BANK1 XECORE24",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "ICACHE_HIT_BANK1_XECORE25", "ICACHE HIT BANK1 XECORE25",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "ICACHE_HIT_BANK1_XECORE26", "ICACHE HIT BANK1 XECORE26",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "ICACHE_HIT_BANK1_XECORE27", "ICACHE HIT BANK1 XECORE27",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "ICACHE_HIT_BANK1_XECORE28", "ICACHE HIT BANK1 XECORE28",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "ICACHE_HIT_BANK1_XECORE29", "ICACHE HIT BANK1 XECORE29",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "ICACHE_HIT_BANK1_XECORE30", "ICACHE HIT BANK1 XECORE30",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "ICACHE_HIT_BANK1_XECORE31", "ICACHE HIT BANK1 XECORE31",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "ICACHE_MISS_BANK1_XECORE24", "ICACHE MISS BANK1 XECORE24",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "ICACHE_MISS_BANK1_XECORE25", "ICACHE MISS BANK1 XECORE25",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "ICACHE_MISS_BANK1_XECORE26", "ICACHE MISS BANK1 XECORE26",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "ICACHE_MISS_BANK1_XECORE27", "ICACHE MISS BANK1 XECORE27",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "ICACHE_MISS_BANK1_XECORE28", "ICACHE MISS BANK1 XECORE28",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "ICACHE_MISS_BANK1_XECORE29", "ICACHE MISS BANK1 XECORE29",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "ICACHE_MISS_BANK1_XECORE30", "ICACHE MISS BANK1 XECORE30",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "ICACHE_MISS_BANK1_XECORE31", "ICACHE MISS BANK1 XECORE31",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18820011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a20011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c20011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e20011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19820011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a20011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c20011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e20011, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04820002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06820c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16820005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02834000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c20180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c20005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05820002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b820180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13820005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840810, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc20180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c20005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe20146, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e34000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e64000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff0e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009300c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a55a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014ff2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01076000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010903c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03086a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203200a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030047, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000eff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7ef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fbdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fdbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fe7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt904MetricSet::CExt904MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt904MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "ICACHE_HIT_BANK2_XECORE0", "ICACHE HIT BANK2 XECORE0",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "ICACHE_HIT_BANK2_XECORE1", "ICACHE HIT BANK2 XECORE1",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "ICACHE_HIT_BANK2_XECORE2", "ICACHE HIT BANK2 XECORE2",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "ICACHE_HIT_BANK2_XECORE3", "ICACHE HIT BANK2 XECORE3",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "ICACHE_HIT_BANK2_XECORE4", "ICACHE HIT BANK2 XECORE4",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "ICACHE_HIT_BANK2_XECORE5", "ICACHE HIT BANK2 XECORE5",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "ICACHE_HIT_BANK2_XECORE6", "ICACHE HIT BANK2 XECORE6",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "ICACHE_HIT_BANK2_XECORE7", "ICACHE HIT BANK2 XECORE7",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "ICACHE_MISS_BANK2_XECORE0", "ICACHE MISS BANK2 XECORE0",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "ICACHE_MISS_BANK2_XECORE1", "ICACHE MISS BANK2 XECORE1",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "ICACHE_MISS_BANK2_XECORE2", "ICACHE MISS BANK2 XECORE2",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "ICACHE_MISS_BANK2_XECORE3", "ICACHE MISS BANK2 XECORE3",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "ICACHE_MISS_BANK2_XECORE4", "ICACHE MISS BANK2 XECORE4",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "ICACHE_MISS_BANK2_XECORE5", "ICACHE MISS BANK2 XECORE5",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "ICACHE_MISS_BANK2_XECORE6", "ICACHE MISS BANK2 XECORE6",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "ICACHE_MISS_BANK2_XECORE7", "ICACHE MISS BANK2 XECORE7",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18820016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a20016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c20016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e20016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19820016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a20016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c20016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e20016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04820002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06820c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16820005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02834000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c20180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c20005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05820002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b820180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13820005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840810, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc20180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c20005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe20146, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e34000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e64000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff0e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009300c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a55a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014ff2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01076000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010903c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03086a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203200a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030047, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000eff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7ef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fbdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fdbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fe7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt905MetricSet::CExt905MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt905MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "ICACHE_HIT_BANK2_XECORE8", "ICACHE HIT BANK2 XECORE8",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "ICACHE_HIT_BANK2_XECORE9", "ICACHE HIT BANK2 XECORE9",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "ICACHE_HIT_BANK2_XECORE10", "ICACHE HIT BANK2 XECORE10",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "ICACHE_HIT_BANK2_XECORE11", "ICACHE HIT BANK2 XECORE11",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "ICACHE_HIT_BANK2_XECORE12", "ICACHE HIT BANK2 XECORE12",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "ICACHE_HIT_BANK2_XECORE13", "ICACHE HIT BANK2 XECORE13",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "ICACHE_HIT_BANK2_XECORE14", "ICACHE HIT BANK2 XECORE14",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "ICACHE_HIT_BANK2_XECORE15", "ICACHE HIT BANK2 XECORE15",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "ICACHE_MISS_BANK2_XECORE8", "ICACHE MISS BANK2 XECORE8",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "ICACHE_MISS_BANK2_XECORE9", "ICACHE MISS BANK2 XECORE9",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "ICACHE_MISS_BANK2_XECORE10", "ICACHE MISS BANK2 XECORE10",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "ICACHE_MISS_BANK2_XECORE11", "ICACHE MISS BANK2 XECORE11",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "ICACHE_MISS_BANK2_XECORE12", "ICACHE MISS BANK2 XECORE12",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "ICACHE_MISS_BANK2_XECORE13", "ICACHE MISS BANK2 XECORE13",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "ICACHE_MISS_BANK2_XECORE14", "ICACHE MISS BANK2 XECORE14",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "ICACHE_MISS_BANK2_XECORE15", "ICACHE MISS BANK2 XECORE15",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18820016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a20016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c20016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e20016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19820016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a20016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c20016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e20016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04820002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06820c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16820005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02834000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c20180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c20005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05820002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b820180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13820005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840810, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc20180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c20005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe20146, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e34000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e64000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff0e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009300c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a55a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014ff2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01076000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010903c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03086a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203200a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030047, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000eff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7ef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fbdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fdbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fe7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt906MetricSet::CExt906MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt906MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "ICACHE_HIT_BANK2_XECORE16", "ICACHE HIT BANK2 XECORE16",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "ICACHE_HIT_BANK2_XECORE17", "ICACHE HIT BANK2 XECORE17",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "ICACHE_HIT_BANK2_XECORE18", "ICACHE HIT BANK2 XECORE18",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "ICACHE_HIT_BANK2_XECORE19", "ICACHE HIT BANK2 XECORE19",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "ICACHE_HIT_BANK2_XECORE20", "ICACHE HIT BANK2 XECORE20",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "ICACHE_HIT_BANK2_XECORE21", "ICACHE HIT BANK2 XECORE21",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "ICACHE_HIT_BANK2_XECORE22", "ICACHE HIT BANK2 XECORE22",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "ICACHE_HIT_BANK2_XECORE23", "ICACHE HIT BANK2 XECORE23",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "ICACHE_MISS_BANK2_XECORE16", "ICACHE MISS BANK2 XECORE16",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "ICACHE_MISS_BANK2_XECORE17", "ICACHE MISS BANK2 XECORE17",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "ICACHE_MISS_BANK2_XECORE18", "ICACHE MISS BANK2 XECORE18",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "ICACHE_MISS_BANK2_XECORE19", "ICACHE MISS BANK2 XECORE19",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "ICACHE_MISS_BANK2_XECORE20", "ICACHE MISS BANK2 XECORE20",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "ICACHE_MISS_BANK2_XECORE21", "ICACHE MISS BANK2 XECORE21",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "ICACHE_MISS_BANK2_XECORE22", "ICACHE MISS BANK2 XECORE22",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "ICACHE_MISS_BANK2_XECORE23", "ICACHE MISS BANK2 XECORE23",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18820016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a20016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c20016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e20016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19820016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a20016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c20016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e20016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04820002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06820c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16820005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02834000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c20180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c20005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05820002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b820180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13820005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840810, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc20180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c20005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe20146, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e34000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e64000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff0e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009300c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a55a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014ff2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01076000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010903c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03086a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203200a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030047, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000eff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7ef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fbdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fdbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fe7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt907MetricSet::CExt907MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt907MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "ICACHE_HIT_BANK2_XECORE24", "ICACHE HIT BANK2 XECORE24",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "ICACHE_HIT_BANK2_XECORE25", "ICACHE HIT BANK2 XECORE25",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "ICACHE_HIT_BANK2_XECORE26", "ICACHE HIT BANK2 XECORE26",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "ICACHE_HIT_BANK2_XECORE27", "ICACHE HIT BANK2 XECORE27",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "ICACHE_HIT_BANK2_XECORE28", "ICACHE HIT BANK2 XECORE28",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "ICACHE_HIT_BANK2_XECORE29", "ICACHE HIT BANK2 XECORE29",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "ICACHE_HIT_BANK2_XECORE30", "ICACHE HIT BANK2 XECORE30",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "ICACHE_HIT_BANK2_XECORE31", "ICACHE HIT BANK2 XECORE31",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "ICACHE_MISS_BANK2_XECORE24", "ICACHE MISS BANK2 XECORE24",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "ICACHE_MISS_BANK2_XECORE25", "ICACHE MISS BANK2 XECORE25",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "ICACHE_MISS_BANK2_XECORE26", "ICACHE MISS BANK2 XECORE26",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "ICACHE_MISS_BANK2_XECORE27", "ICACHE MISS BANK2 XECORE27",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "ICACHE_MISS_BANK2_XECORE28", "ICACHE MISS BANK2 XECORE28",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "ICACHE_MISS_BANK2_XECORE29", "ICACHE MISS BANK2 XECORE29",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "ICACHE_MISS_BANK2_XECORE30", "ICACHE MISS BANK2 XECORE30",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "ICACHE_MISS_BANK2_XECORE31", "ICACHE MISS BANK2 XECORE31",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18820016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a20016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c20016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e20016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19820016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a20016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c20016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e20016, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04820002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06820c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16820005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02834000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c20180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c20005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05820002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b820180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13820005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840810, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc20180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c20005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe20146, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e34000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e64000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff0e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009300c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a55a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014ff2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01076000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010903c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03086a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203200a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030047, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000eff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7ef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fbdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fdbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fe7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt908MetricSet::CExt908MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt908MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "ICACHE_HIT_BANK3_XECORE0", "ICACHE HIT BANK3 XECORE0",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "ICACHE_HIT_BANK3_XECORE1", "ICACHE HIT BANK3 XECORE1",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "ICACHE_HIT_BANK3_XECORE2", "ICACHE HIT BANK3 XECORE2",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "ICACHE_HIT_BANK3_XECORE3", "ICACHE HIT BANK3 XECORE3",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "ICACHE_HIT_BANK3_XECORE4", "ICACHE HIT BANK3 XECORE4",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "ICACHE_HIT_BANK3_XECORE5", "ICACHE HIT BANK3 XECORE5",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "ICACHE_HIT_BANK3_XECORE6", "ICACHE HIT BANK3 XECORE6",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "ICACHE_HIT_BANK3_XECORE7", "ICACHE HIT BANK3 XECORE7",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "ICACHE_MISS_BANK3_XECORE0", "ICACHE MISS BANK3 XECORE0",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "ICACHE_MISS_BANK3_XECORE1", "ICACHE MISS BANK3 XECORE1",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "ICACHE_MISS_BANK3_XECORE2", "ICACHE MISS BANK3 XECORE2",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "ICACHE_MISS_BANK3_XECORE3", "ICACHE MISS BANK3 XECORE3",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "ICACHE_MISS_BANK3_XECORE4", "ICACHE MISS BANK3 XECORE4",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "ICACHE_MISS_BANK3_XECORE5", "ICACHE MISS BANK3 XECORE5",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "ICACHE_MISS_BANK3_XECORE6", "ICACHE MISS BANK3 XECORE6",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "ICACHE_MISS_BANK3_XECORE7", "ICACHE MISS BANK3 XECORE7",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1882001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a2001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c2001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e2001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1982001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a2001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c2001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e2001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04820002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06820c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16820005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02834000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c20180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c20005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05820002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b820180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13820005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840810, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc20180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c20005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe20146, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e34000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e64000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff0e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009300c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a55a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014ff2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01076000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010903c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03086a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203200a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030047, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000eff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7ef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fbdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fdbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fe7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt909MetricSet::CExt909MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt909MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "ICACHE_HIT_BANK3_XECORE8", "ICACHE HIT BANK3 XECORE8",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "ICACHE_HIT_BANK3_XECORE9", "ICACHE HIT BANK3 XECORE9",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "ICACHE_HIT_BANK3_XECORE10", "ICACHE HIT BANK3 XECORE10",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "ICACHE_HIT_BANK3_XECORE11", "ICACHE HIT BANK3 XECORE11",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "ICACHE_HIT_BANK3_XECORE12", "ICACHE HIT BANK3 XECORE12",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "ICACHE_HIT_BANK3_XECORE13", "ICACHE HIT BANK3 XECORE13",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "ICACHE_HIT_BANK3_XECORE14", "ICACHE HIT BANK3 XECORE14",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "ICACHE_HIT_BANK3_XECORE15", "ICACHE HIT BANK3 XECORE15",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "ICACHE_MISS_BANK3_XECORE8", "ICACHE MISS BANK3 XECORE8",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "ICACHE_MISS_BANK3_XECORE9", "ICACHE MISS BANK3 XECORE9",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "ICACHE_MISS_BANK3_XECORE10", "ICACHE MISS BANK3 XECORE10",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "ICACHE_MISS_BANK3_XECORE11", "ICACHE MISS BANK3 XECORE11",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "ICACHE_MISS_BANK3_XECORE12", "ICACHE MISS BANK3 XECORE12",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "ICACHE_MISS_BANK3_XECORE13", "ICACHE MISS BANK3 XECORE13",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "ICACHE_MISS_BANK3_XECORE14", "ICACHE MISS BANK3 XECORE14",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "ICACHE_MISS_BANK3_XECORE15", "ICACHE MISS BANK3 XECORE15",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1882001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a2001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c2001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e2001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1982001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a2001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c2001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e2001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04820002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06820c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16820005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02834000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c20180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c20005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05820002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b820180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13820005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840810, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc20180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c20005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe20146, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e34000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e64000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff0e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009300c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a55a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014ff2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01076000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010903c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03086a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203200a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030047, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000eff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7ef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fbdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fdbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fe7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt910MetricSet::CExt910MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt910MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "ICACHE_HIT_BANK3_XECORE16", "ICACHE HIT BANK3 XECORE16",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "ICACHE_HIT_BANK3_XECORE17", "ICACHE HIT BANK3 XECORE17",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "ICACHE_HIT_BANK3_XECORE18", "ICACHE HIT BANK3 XECORE18",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "ICACHE_HIT_BANK3_XECORE19", "ICACHE HIT BANK3 XECORE19",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "ICACHE_HIT_BANK3_XECORE20", "ICACHE HIT BANK3 XECORE20",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "ICACHE_HIT_BANK3_XECORE21", "ICACHE HIT BANK3 XECORE21",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "ICACHE_HIT_BANK3_XECORE22", "ICACHE HIT BANK3 XECORE22",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "ICACHE_HIT_BANK3_XECORE23", "ICACHE HIT BANK3 XECORE23",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "ICACHE_MISS_BANK3_XECORE16", "ICACHE MISS BANK3 XECORE16",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "ICACHE_MISS_BANK3_XECORE17", "ICACHE MISS BANK3 XECORE17",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "ICACHE_MISS_BANK3_XECORE18", "ICACHE MISS BANK3 XECORE18",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "ICACHE_MISS_BANK3_XECORE19", "ICACHE MISS BANK3 XECORE19",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "ICACHE_MISS_BANK3_XECORE20", "ICACHE MISS BANK3 XECORE20",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "ICACHE_MISS_BANK3_XECORE21", "ICACHE MISS BANK3 XECORE21",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "ICACHE_MISS_BANK3_XECORE22", "ICACHE MISS BANK3 XECORE22",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "ICACHE_MISS_BANK3_XECORE23", "ICACHE MISS BANK3 XECORE23",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1882001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a2001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c2001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e2001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1982001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a2001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c2001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e2001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04820002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06820c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16820005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02834000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c20180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c20005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05820002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b820180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13820005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840810, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc20180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c20005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe20146, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e34000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e64000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff0e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009300c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a55a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014ff2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01076000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010903c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03086a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203200a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030047, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000eff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7ef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fbdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fdbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fe7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt911MetricSet::CExt911MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt911MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "ICACHE_HIT_BANK3_XECORE24", "ICACHE HIT BANK3 XECORE24",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "ICACHE_HIT_BANK3_XECORE25", "ICACHE HIT BANK3 XECORE25",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "ICACHE_HIT_BANK3_XECORE26", "ICACHE HIT BANK3 XECORE26",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "ICACHE_HIT_BANK3_XECORE27", "ICACHE HIT BANK3 XECORE27",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "ICACHE_HIT_BANK3_XECORE28", "ICACHE HIT BANK3 XECORE28",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "ICACHE_HIT_BANK3_XECORE29", "ICACHE HIT BANK3 XECORE29",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "ICACHE_HIT_BANK3_XECORE30", "ICACHE HIT BANK3 XECORE30",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "ICACHE_HIT_BANK3_XECORE31", "ICACHE HIT BANK3 XECORE31",
                          "Number of Instruction Cache Hits",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "ICACHE_MISS_BANK3_XECORE24", "ICACHE MISS BANK3 XECORE24",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "ICACHE_MISS_BANK3_XECORE25", "ICACHE MISS BANK3 XECORE25",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "ICACHE_MISS_BANK3_XECORE26", "ICACHE MISS BANK3 XECORE26",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a8" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "ICACHE_MISS_BANK3_XECORE27", "ICACHE MISS BANK3 XECORE27",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1a0" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "ICACHE_MISS_BANK3_XECORE28", "ICACHE MISS BANK3 XECORE28",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xec" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x198" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "ICACHE_MISS_BANK3_XECORE29", "ICACHE MISS BANK3 XECORE29",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x190" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "ICACHE_MISS_BANK3_XECORE30", "ICACHE MISS BANK3 XECORE30",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x188" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "ICACHE_MISS_BANK3_XECORE31", "ICACHE MISS BANK3 XECORE31",
                          "Number of Instruction Cache Misses",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x180" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1882001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a2001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c2001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e2001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1982001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a2001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c2001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e2001b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04820002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06820c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16820005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00830001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02834000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00848001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00860001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02864000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a44002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c20180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c20005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c42004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e30040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e30100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e41008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e60040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e60100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05820002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b820180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13820005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03820000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01830100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03830040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01840810, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01860100, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03860040, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da20006, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a20140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a30400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a30010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a40420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a60400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a60010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc20180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c20005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c31000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c30004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c40240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c61000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e20002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe20146, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e20000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e34000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e30001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e40180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e64000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e60001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00030ff0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00070060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02070900, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ff0e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208b0ff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009300c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a55a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5a55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00014ff2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baa04, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b10aa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00022004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01076000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03070009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01080e00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800b0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010903c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aa500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a005a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b0400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01020240, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c1000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e03086a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203200a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030047, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x480300a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a03000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18031000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030107, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000000a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x00007ffe, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000012, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000bffd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000022, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000dffb, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000042, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000eff7, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000082, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000f7ef, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000102, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000fbdf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000202, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000fdbf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00000402, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x0000fe7f, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt912MetricSet::CExt912MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt912MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT_XECORE0", "SLM BANK CONFLICT COUNT XECORE0",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD dw@0xec UADD 2 dw@0xe8 UMUL UADD 4 dw@0xe4 UMUL UADD 8 dw@0xe0 UMUL UADD dw@0xdc UADD 2 dw@0xd8 UMUL UADD 4 dw@0xd4 UMUL UADD 8 dw@0xd0 UMUL UADD dw@0xcc UADD 2 dw@0xc8 UMUL UADD 4 dw@0xc4 UMUL UADD 8 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD qw@0x198 UADD 2 qw@0x190 UMUL UADD 4 qw@0x188 UMUL UADD 8 qw@0x180 UMUL UADD qw@0x178 UADD 2 qw@0x170 UMUL UADD 4 qw@0x168 UMUL UADD 8 qw@0x160 UMUL UADD qw@0x158 UADD 2 qw@0x150 UMUL UADD 4 qw@0x148 UMUL UADD 8 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x188914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e8900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22891800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x288914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02893254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e890411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1089079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1489038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt913MetricSet::CExt913MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt913MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT_XECORE1", "SLM BANK CONFLICT COUNT XECORE1",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD dw@0xec UADD 2 dw@0xe8 UMUL UADD 4 dw@0xe4 UMUL UADD 8 dw@0xe0 UMUL UADD dw@0xdc UADD 2 dw@0xd8 UMUL UADD 4 dw@0xd4 UMUL UADD 8 dw@0xd0 UMUL UADD dw@0xcc UADD 2 dw@0xc8 UMUL UADD 4 dw@0xc4 UMUL UADD 8 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD qw@0x198 UADD 2 qw@0x190 UMUL UADD 4 qw@0x188 UMUL UADD 8 qw@0x180 UMUL UADD qw@0x178 UADD 2 qw@0x170 UMUL UADD 4 qw@0x168 UMUL UADD 8 qw@0x160 UMUL UADD qw@0x158 UADD 2 qw@0x150 UMUL UADD 4 qw@0x148 UMUL UADD 8 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22a91800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28a914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a90c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a90fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa90821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca90baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a9079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a9038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt914MetricSet::CExt914MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt914MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT_XECORE2", "SLM BANK CONFLICT COUNT XECORE2",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD dw@0xec UADD 2 dw@0xe8 UMUL UADD 4 dw@0xe4 UMUL UADD 8 dw@0xe0 UMUL UADD dw@0xdc UADD 2 dw@0xd8 UMUL UADD 4 dw@0xd4 UMUL UADD 8 dw@0xd0 UMUL UADD dw@0xcc UADD 2 dw@0xc8 UMUL UADD 4 dw@0xc4 UMUL UADD 8 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD qw@0x198 UADD 2 qw@0x190 UMUL UADD 4 qw@0x188 UMUL UADD 8 qw@0x180 UMUL UADD qw@0x178 UADD 2 qw@0x170 UMUL UADD 4 qw@0x168 UMUL UADD 8 qw@0x160 UMUL UADD qw@0x158 UADD 2 qw@0x150 UMUL UADD 4 qw@0x148 UMUL UADD 8 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c91800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28c914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c90fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec90411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c9079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c9038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt915MetricSet::CExt915MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt915MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT_XECORE3", "SLM BANK CONFLICT COUNT XECORE3",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD dw@0xec UADD 2 dw@0xe8 UMUL UADD 4 dw@0xe4 UMUL UADD 8 dw@0xe0 UMUL UADD dw@0xdc UADD 2 dw@0xd8 UMUL UADD 4 dw@0xd4 UMUL UADD 8 dw@0xd0 UMUL UADD dw@0xcc UADD 2 dw@0xc8 UMUL UADD 4 dw@0xc4 UMUL UADD 8 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD qw@0x198 UADD 2 qw@0x190 UMUL UADD 4 qw@0x188 UMUL UADD 8 qw@0x180 UMUL UADD qw@0x178 UADD 2 qw@0x170 UMUL UADD 4 qw@0x168 UMUL UADD 8 qw@0x160 UMUL UADD qw@0x158 UADD 2 qw@0x150 UMUL UADD 4 qw@0x148 UMUL UADD 8 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22e91800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28e914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e90fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae90821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce90baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e9079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e9038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt916MetricSet::CExt916MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt916MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT_XECORE4", "SLM BANK CONFLICT COUNT XECORE4",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD dw@0xec UADD 2 dw@0xe8 UMUL UADD 4 dw@0xe4 UMUL UADD 8 dw@0xe0 UMUL UADD dw@0xdc UADD 2 dw@0xd8 UMUL UADD 4 dw@0xd4 UMUL UADD 8 dw@0xd0 UMUL UADD dw@0xcc UADD 2 dw@0xc8 UMUL UADD 4 dw@0xc4 UMUL UADD 8 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD qw@0x198 UADD 2 qw@0x190 UMUL UADD 4 qw@0x188 UMUL UADD 8 qw@0x180 UMUL UADD qw@0x178 UADD 2 qw@0x170 UMUL UADD 4 qw@0x168 UMUL UADD 8 qw@0x160 UMUL UADD qw@0x158 UADD 2 qw@0x150 UMUL UADD 4 qw@0x148 UMUL UADD 8 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x198914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f8900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23891800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x298914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0387aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03893254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09890fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f890411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1189079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1589038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt917MetricSet::CExt917MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt917MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT_XECORE5", "SLM BANK CONFLICT COUNT XECORE5",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD dw@0xec UADD 2 dw@0xe8 UMUL UADD 4 dw@0xe4 UMUL UADD 8 dw@0xe0 UMUL UADD dw@0xdc UADD 2 dw@0xd8 UMUL UADD 4 dw@0xd4 UMUL UADD 8 dw@0xd0 UMUL UADD dw@0xcc UADD 2 dw@0xc8 UMUL UADD 4 dw@0xc4 UMUL UADD 8 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD qw@0x198 UADD 2 qw@0x190 UMUL UADD 4 qw@0x188 UMUL UADD 8 qw@0x180 UMUL UADD qw@0x178 UADD 2 qw@0x170 UMUL UADD 4 qw@0x168 UMUL UADD 8 qw@0x160 UMUL UADD qw@0x158 UADD 2 qw@0x150 UMUL UADD 4 qw@0x148 UMUL UADD 8 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23a91800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29a914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a90c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a90fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba90821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da90baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a9079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a9038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt918MetricSet::CExt918MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt918MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT_XECORE6", "SLM BANK CONFLICT COUNT XECORE6",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD dw@0xec UADD 2 dw@0xe8 UMUL UADD 4 dw@0xe4 UMUL UADD 8 dw@0xe0 UMUL UADD dw@0xdc UADD 2 dw@0xd8 UMUL UADD 4 dw@0xd4 UMUL UADD 8 dw@0xd0 UMUL UADD dw@0xcc UADD 2 dw@0xc8 UMUL UADD 4 dw@0xc4 UMUL UADD 8 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD qw@0x198 UADD 2 qw@0x190 UMUL UADD 4 qw@0x188 UMUL UADD 8 qw@0x180 UMUL UADD qw@0x178 UADD 2 qw@0x170 UMUL UADD 4 qw@0x168 UMUL UADD 8 qw@0x160 UMUL UADD qw@0x158 UADD 2 qw@0x150 UMUL UADD 4 qw@0x148 UMUL UADD 8 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c91800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29c914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c90c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c90fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc90411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c9079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c9038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt919MetricSet::CExt919MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt919MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT_XECORE7", "SLM BANK CONFLICT COUNT XECORE7",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD dw@0xec UADD 2 dw@0xe8 UMUL UADD 4 dw@0xe4 UMUL UADD 8 dw@0xe0 UMUL UADD dw@0xdc UADD 2 dw@0xd8 UMUL UADD 4 dw@0xd4 UMUL UADD 8 dw@0xd0 UMUL UADD dw@0xcc UADD 2 dw@0xc8 UMUL UADD 4 dw@0xc4 UMUL UADD 8 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD qw@0x198 UADD 2 qw@0x190 UMUL UADD 4 qw@0x188 UMUL UADD 8 qw@0x180 UMUL UADD qw@0x178 UADD 2 qw@0x170 UMUL UADD 4 qw@0x168 UMUL UADD 8 qw@0x160 UMUL UADD qw@0x158 UADD 2 qw@0x150 UMUL UADD 4 qw@0x148 UMUL UADD 8 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23e91800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29e914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e90fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be90821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de90baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe90411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e9079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e9038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt920MetricSet::CExt920MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt920MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT_XECORE8", "SLM BANK CONFLICT COUNT XECORE8",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD dw@0xec UADD 2 dw@0xe8 UMUL UADD 4 dw@0xe4 UMUL UADD 8 dw@0xe0 UMUL UADD dw@0xdc UADD 2 dw@0xd8 UMUL UADD 4 dw@0xd4 UMUL UADD 8 dw@0xd0 UMUL UADD dw@0xcc UADD 2 dw@0xc8 UMUL UADD 4 dw@0xc4 UMUL UADD 8 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD qw@0x198 UADD 2 qw@0x190 UMUL UADD 4 qw@0x188 UMUL UADD 8 qw@0x180 UMUL UADD qw@0x178 UADD 2 qw@0x170 UMUL UADD 4 qw@0x168 UMUL UADD 8 qw@0x160 UMUL UADD qw@0x158 UADD 2 qw@0x150 UMUL UADD 4 qw@0x148 UMUL UADD 8 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x188914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e8900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22891800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x288914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02893254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e890411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1089079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1489038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt921MetricSet::CExt921MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt921MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT_XECORE9", "SLM BANK CONFLICT COUNT XECORE9",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD dw@0xec UADD 2 dw@0xe8 UMUL UADD 4 dw@0xe4 UMUL UADD 8 dw@0xe0 UMUL UADD dw@0xdc UADD 2 dw@0xd8 UMUL UADD 4 dw@0xd4 UMUL UADD 8 dw@0xd0 UMUL UADD dw@0xcc UADD 2 dw@0xc8 UMUL UADD 4 dw@0xc4 UMUL UADD 8 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD qw@0x198 UADD 2 qw@0x190 UMUL UADD 4 qw@0x188 UMUL UADD 8 qw@0x180 UMUL UADD qw@0x178 UADD 2 qw@0x170 UMUL UADD 4 qw@0x168 UMUL UADD 8 qw@0x160 UMUL UADD qw@0x158 UADD 2 qw@0x150 UMUL UADD 4 qw@0x148 UMUL UADD 8 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22a91800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28a914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a90c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a90fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa90821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca90baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a9079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a9038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt922MetricSet::CExt922MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt922MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT_XECORE10", "SLM BANK CONFLICT COUNT XECORE10",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD dw@0xec UADD 2 dw@0xe8 UMUL UADD 4 dw@0xe4 UMUL UADD 8 dw@0xe0 UMUL UADD dw@0xdc UADD 2 dw@0xd8 UMUL UADD 4 dw@0xd4 UMUL UADD 8 dw@0xd0 UMUL UADD dw@0xcc UADD 2 dw@0xc8 UMUL UADD 4 dw@0xc4 UMUL UADD 8 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD qw@0x198 UADD 2 qw@0x190 UMUL UADD 4 qw@0x188 UMUL UADD 8 qw@0x180 UMUL UADD qw@0x178 UADD 2 qw@0x170 UMUL UADD 4 qw@0x168 UMUL UADD 8 qw@0x160 UMUL UADD qw@0x158 UADD 2 qw@0x150 UMUL UADD 4 qw@0x148 UMUL UADD 8 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c91800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28c914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c90fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec90411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c9079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c9038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt923MetricSet::CExt923MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt923MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT_XECORE11", "SLM BANK CONFLICT COUNT XECORE11",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD dw@0xec UADD 2 dw@0xe8 UMUL UADD 4 dw@0xe4 UMUL UADD 8 dw@0xe0 UMUL UADD dw@0xdc UADD 2 dw@0xd8 UMUL UADD 4 dw@0xd4 UMUL UADD 8 dw@0xd0 UMUL UADD dw@0xcc UADD 2 dw@0xc8 UMUL UADD 4 dw@0xc4 UMUL UADD 8 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD qw@0x198 UADD 2 qw@0x190 UMUL UADD 4 qw@0x188 UMUL UADD 8 qw@0x180 UMUL UADD qw@0x178 UADD 2 qw@0x170 UMUL UADD 4 qw@0x168 UMUL UADD 8 qw@0x160 UMUL UADD qw@0x158 UADD 2 qw@0x150 UMUL UADD 4 qw@0x148 UMUL UADD 8 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22e91800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28e914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e90fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae90821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce90baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e9079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e9038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt924MetricSet::CExt924MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt924MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT_XECORE12", "SLM BANK CONFLICT COUNT XECORE12",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD dw@0xec UADD 2 dw@0xe8 UMUL UADD 4 dw@0xe4 UMUL UADD 8 dw@0xe0 UMUL UADD dw@0xdc UADD 2 dw@0xd8 UMUL UADD 4 dw@0xd4 UMUL UADD 8 dw@0xd0 UMUL UADD dw@0xcc UADD 2 dw@0xc8 UMUL UADD 4 dw@0xc4 UMUL UADD 8 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD qw@0x198 UADD 2 qw@0x190 UMUL UADD 4 qw@0x188 UMUL UADD 8 qw@0x180 UMUL UADD qw@0x178 UADD 2 qw@0x170 UMUL UADD 4 qw@0x168 UMUL UADD 8 qw@0x160 UMUL UADD qw@0x158 UADD 2 qw@0x150 UMUL UADD 4 qw@0x148 UMUL UADD 8 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x198914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f8900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23891800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x298914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0387aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03893254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09890fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f890411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1189079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1589038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt925MetricSet::CExt925MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt925MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT_XECORE13", "SLM BANK CONFLICT COUNT XECORE13",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD dw@0xec UADD 2 dw@0xe8 UMUL UADD 4 dw@0xe4 UMUL UADD 8 dw@0xe0 UMUL UADD dw@0xdc UADD 2 dw@0xd8 UMUL UADD 4 dw@0xd4 UMUL UADD 8 dw@0xd0 UMUL UADD dw@0xcc UADD 2 dw@0xc8 UMUL UADD 4 dw@0xc4 UMUL UADD 8 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD qw@0x198 UADD 2 qw@0x190 UMUL UADD 4 qw@0x188 UMUL UADD 8 qw@0x180 UMUL UADD qw@0x178 UADD 2 qw@0x170 UMUL UADD 4 qw@0x168 UMUL UADD 8 qw@0x160 UMUL UADD qw@0x158 UADD 2 qw@0x150 UMUL UADD 4 qw@0x148 UMUL UADD 8 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23a91800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29a914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a90c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a90fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba90821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da90baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a9079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a9038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt926MetricSet::CExt926MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt926MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT_XECORE14", "SLM BANK CONFLICT COUNT XECORE14",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD dw@0xec UADD 2 dw@0xe8 UMUL UADD 4 dw@0xe4 UMUL UADD 8 dw@0xe0 UMUL UADD dw@0xdc UADD 2 dw@0xd8 UMUL UADD 4 dw@0xd4 UMUL UADD 8 dw@0xd0 UMUL UADD dw@0xcc UADD 2 dw@0xc8 UMUL UADD 4 dw@0xc4 UMUL UADD 8 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD qw@0x198 UADD 2 qw@0x190 UMUL UADD 4 qw@0x188 UMUL UADD 8 qw@0x180 UMUL UADD qw@0x178 UADD 2 qw@0x170 UMUL UADD 4 qw@0x168 UMUL UADD 8 qw@0x160 UMUL UADD qw@0x158 UADD 2 qw@0x150 UMUL UADD 4 qw@0x148 UMUL UADD 8 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c91800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29c914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c90c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c90fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc90411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c9079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c9038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt927MetricSet::CExt927MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt927MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT_XECORE15", "SLM BANK CONFLICT COUNT XECORE15",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD dw@0xec UADD 2 dw@0xe8 UMUL UADD 4 dw@0xe4 UMUL UADD 8 dw@0xe0 UMUL UADD dw@0xdc UADD 2 dw@0xd8 UMUL UADD 4 dw@0xd4 UMUL UADD 8 dw@0xd0 UMUL UADD dw@0xcc UADD 2 dw@0xc8 UMUL UADD 4 dw@0xc4 UMUL UADD 8 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD qw@0x198 UADD 2 qw@0x190 UMUL UADD 4 qw@0x188 UMUL UADD 8 qw@0x180 UMUL UADD qw@0x178 UADD 2 qw@0x170 UMUL UADD 4 qw@0x168 UMUL UADD 8 qw@0x160 UMUL UADD qw@0x158 UADD 2 qw@0x150 UMUL UADD 4 qw@0x148 UMUL UADD 8 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23e91800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29e914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e90fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be90821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de90baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe90411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e9079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e9038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt928MetricSet::CExt928MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt928MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT_XECORE16", "SLM BANK CONFLICT COUNT XECORE16",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD dw@0xec UADD 2 dw@0xe8 UMUL UADD 4 dw@0xe4 UMUL UADD 8 dw@0xe0 UMUL UADD dw@0xdc UADD 2 dw@0xd8 UMUL UADD 4 dw@0xd4 UMUL UADD 8 dw@0xd0 UMUL UADD dw@0xcc UADD 2 dw@0xc8 UMUL UADD 4 dw@0xc4 UMUL UADD 8 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD qw@0x198 UADD 2 qw@0x190 UMUL UADD 4 qw@0x188 UMUL UADD 8 qw@0x180 UMUL UADD qw@0x178 UADD 2 qw@0x170 UMUL UADD 4 qw@0x168 UMUL UADD 8 qw@0x160 UMUL UADD qw@0x158 UADD 2 qw@0x150 UMUL UADD 4 qw@0x148 UMUL UADD 8 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x188914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e8900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22891800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x288914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02893254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e890411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1089079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1489038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt929MetricSet::CExt929MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt929MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT_XECORE17", "SLM BANK CONFLICT COUNT XECORE17",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD dw@0xec UADD 2 dw@0xe8 UMUL UADD 4 dw@0xe4 UMUL UADD 8 dw@0xe0 UMUL UADD dw@0xdc UADD 2 dw@0xd8 UMUL UADD 4 dw@0xd4 UMUL UADD 8 dw@0xd0 UMUL UADD dw@0xcc UADD 2 dw@0xc8 UMUL UADD 4 dw@0xc4 UMUL UADD 8 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD qw@0x198 UADD 2 qw@0x190 UMUL UADD 4 qw@0x188 UMUL UADD 8 qw@0x180 UMUL UADD qw@0x178 UADD 2 qw@0x170 UMUL UADD 4 qw@0x168 UMUL UADD 8 qw@0x160 UMUL UADD qw@0x158 UADD 2 qw@0x150 UMUL UADD 4 qw@0x148 UMUL UADD 8 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22a91800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28a914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a90c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a90fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa90821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca90baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a9079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a9038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt930MetricSet::CExt930MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt930MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT_XECORE18", "SLM BANK CONFLICT COUNT XECORE18",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD dw@0xec UADD 2 dw@0xe8 UMUL UADD 4 dw@0xe4 UMUL UADD 8 dw@0xe0 UMUL UADD dw@0xdc UADD 2 dw@0xd8 UMUL UADD 4 dw@0xd4 UMUL UADD 8 dw@0xd0 UMUL UADD dw@0xcc UADD 2 dw@0xc8 UMUL UADD 4 dw@0xc4 UMUL UADD 8 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD qw@0x198 UADD 2 qw@0x190 UMUL UADD 4 qw@0x188 UMUL UADD 8 qw@0x180 UMUL UADD qw@0x178 UADD 2 qw@0x170 UMUL UADD 4 qw@0x168 UMUL UADD 8 qw@0x160 UMUL UADD qw@0x158 UADD 2 qw@0x150 UMUL UADD 4 qw@0x148 UMUL UADD 8 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c91800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28c914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c90fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec90411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c9079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c9038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt931MetricSet::CExt931MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt931MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT_XECORE19", "SLM BANK CONFLICT COUNT XECORE19",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD dw@0xec UADD 2 dw@0xe8 UMUL UADD 4 dw@0xe4 UMUL UADD 8 dw@0xe0 UMUL UADD dw@0xdc UADD 2 dw@0xd8 UMUL UADD 4 dw@0xd4 UMUL UADD 8 dw@0xd0 UMUL UADD dw@0xcc UADD 2 dw@0xc8 UMUL UADD 4 dw@0xc4 UMUL UADD 8 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD qw@0x198 UADD 2 qw@0x190 UMUL UADD 4 qw@0x188 UMUL UADD 8 qw@0x180 UMUL UADD qw@0x178 UADD 2 qw@0x170 UMUL UADD 4 qw@0x168 UMUL UADD 8 qw@0x160 UMUL UADD qw@0x158 UADD 2 qw@0x150 UMUL UADD 4 qw@0x148 UMUL UADD 8 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22e91800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28e914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e90fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae90821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce90baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e9079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e9038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt932MetricSet::CExt932MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt932MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT_XECORE20", "SLM BANK CONFLICT COUNT XECORE20",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD dw@0xec UADD 2 dw@0xe8 UMUL UADD 4 dw@0xe4 UMUL UADD 8 dw@0xe0 UMUL UADD dw@0xdc UADD 2 dw@0xd8 UMUL UADD 4 dw@0xd4 UMUL UADD 8 dw@0xd0 UMUL UADD dw@0xcc UADD 2 dw@0xc8 UMUL UADD 4 dw@0xc4 UMUL UADD 8 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD qw@0x198 UADD 2 qw@0x190 UMUL UADD 4 qw@0x188 UMUL UADD 8 qw@0x180 UMUL UADD qw@0x178 UADD 2 qw@0x170 UMUL UADD 4 qw@0x168 UMUL UADD 8 qw@0x160 UMUL UADD qw@0x158 UADD 2 qw@0x150 UMUL UADD 4 qw@0x148 UMUL UADD 8 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x198914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f8900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23891800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x298914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0387aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03893254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09890fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f890411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1189079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1589038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt933MetricSet::CExt933MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt933MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT_XECORE21", "SLM BANK CONFLICT COUNT XECORE21",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD dw@0xec UADD 2 dw@0xe8 UMUL UADD 4 dw@0xe4 UMUL UADD 8 dw@0xe0 UMUL UADD dw@0xdc UADD 2 dw@0xd8 UMUL UADD 4 dw@0xd4 UMUL UADD 8 dw@0xd0 UMUL UADD dw@0xcc UADD 2 dw@0xc8 UMUL UADD 4 dw@0xc4 UMUL UADD 8 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD qw@0x198 UADD 2 qw@0x190 UMUL UADD 4 qw@0x188 UMUL UADD 8 qw@0x180 UMUL UADD qw@0x178 UADD 2 qw@0x170 UMUL UADD 4 qw@0x168 UMUL UADD 8 qw@0x160 UMUL UADD qw@0x158 UADD 2 qw@0x150 UMUL UADD 4 qw@0x148 UMUL UADD 8 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23a91800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29a914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a90c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a90fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba90821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da90baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a9079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a9038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt934MetricSet::CExt934MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt934MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT_XECORE22", "SLM BANK CONFLICT COUNT XECORE22",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD dw@0xec UADD 2 dw@0xe8 UMUL UADD 4 dw@0xe4 UMUL UADD 8 dw@0xe0 UMUL UADD dw@0xdc UADD 2 dw@0xd8 UMUL UADD 4 dw@0xd4 UMUL UADD 8 dw@0xd0 UMUL UADD dw@0xcc UADD 2 dw@0xc8 UMUL UADD 4 dw@0xc4 UMUL UADD 8 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD qw@0x198 UADD 2 qw@0x190 UMUL UADD 4 qw@0x188 UMUL UADD 8 qw@0x180 UMUL UADD qw@0x178 UADD 2 qw@0x170 UMUL UADD 4 qw@0x168 UMUL UADD 8 qw@0x160 UMUL UADD qw@0x158 UADD 2 qw@0x150 UMUL UADD 4 qw@0x148 UMUL UADD 8 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c91800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29c914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c90c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c90fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc90411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c9079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c9038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt935MetricSet::CExt935MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt935MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT_XECORE23", "SLM BANK CONFLICT COUNT XECORE23",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD dw@0xec UADD 2 dw@0xe8 UMUL UADD 4 dw@0xe4 UMUL UADD 8 dw@0xe0 UMUL UADD dw@0xdc UADD 2 dw@0xd8 UMUL UADD 4 dw@0xd4 UMUL UADD 8 dw@0xd0 UMUL UADD dw@0xcc UADD 2 dw@0xc8 UMUL UADD 4 dw@0xc4 UMUL UADD 8 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD qw@0x198 UADD 2 qw@0x190 UMUL UADD 4 qw@0x188 UMUL UADD 8 qw@0x180 UMUL UADD qw@0x178 UADD 2 qw@0x170 UMUL UADD 4 qw@0x168 UMUL UADD 8 qw@0x160 UMUL UADD qw@0x158 UADD 2 qw@0x150 UMUL UADD 4 qw@0x148 UMUL UADD 8 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23e91800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29e914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e90fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be90821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de90baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe90411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e9079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e9038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt936MetricSet::CExt936MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt936MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT_XECORE24", "SLM BANK CONFLICT COUNT XECORE24",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD dw@0xec UADD 2 dw@0xe8 UMUL UADD 4 dw@0xe4 UMUL UADD 8 dw@0xe0 UMUL UADD dw@0xdc UADD 2 dw@0xd8 UMUL UADD 4 dw@0xd4 UMUL UADD 8 dw@0xd0 UMUL UADD dw@0xcc UADD 2 dw@0xc8 UMUL UADD 4 dw@0xc4 UMUL UADD 8 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD qw@0x198 UADD 2 qw@0x190 UMUL UADD 4 qw@0x188 UMUL UADD 8 qw@0x180 UMUL UADD qw@0x178 UADD 2 qw@0x170 UMUL UADD 4 qw@0x168 UMUL UADD 8 qw@0x160 UMUL UADD qw@0x158 UADD 2 qw@0x150 UMUL UADD 4 qw@0x148 UMUL UADD 8 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x188914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e8900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22891800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x288914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02893254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e890411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1089079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1489038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt937MetricSet::CExt937MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt937MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT_XECORE25", "SLM BANK CONFLICT COUNT XECORE25",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD dw@0xec UADD 2 dw@0xe8 UMUL UADD 4 dw@0xe4 UMUL UADD 8 dw@0xe0 UMUL UADD dw@0xdc UADD 2 dw@0xd8 UMUL UADD 4 dw@0xd4 UMUL UADD 8 dw@0xd0 UMUL UADD dw@0xcc UADD 2 dw@0xc8 UMUL UADD 4 dw@0xc4 UMUL UADD 8 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD qw@0x198 UADD 2 qw@0x190 UMUL UADD 4 qw@0x188 UMUL UADD 8 qw@0x180 UMUL UADD qw@0x178 UADD 2 qw@0x170 UMUL UADD 4 qw@0x168 UMUL UADD 8 qw@0x160 UMUL UADD qw@0x158 UADD 2 qw@0x150 UMUL UADD 4 qw@0x148 UMUL UADD 8 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22a91800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28a914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a90c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a90fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa90821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca90baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea90411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a9079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a9038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt938MetricSet::CExt938MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt938MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT_XECORE26", "SLM BANK CONFLICT COUNT XECORE26",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD dw@0xec UADD 2 dw@0xe8 UMUL UADD 4 dw@0xe4 UMUL UADD 8 dw@0xe0 UMUL UADD dw@0xdc UADD 2 dw@0xd8 UMUL UADD 4 dw@0xd4 UMUL UADD 8 dw@0xd0 UMUL UADD dw@0xcc UADD 2 dw@0xc8 UMUL UADD 4 dw@0xc4 UMUL UADD 8 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD qw@0x198 UADD 2 qw@0x190 UMUL UADD 4 qw@0x188 UMUL UADD 8 qw@0x180 UMUL UADD qw@0x178 UADD 2 qw@0x170 UMUL UADD 4 qw@0x168 UMUL UADD 8 qw@0x160 UMUL UADD qw@0x158 UADD 2 qw@0x150 UMUL UADD 4 qw@0x148 UMUL UADD 8 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c91800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28c914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c90fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec90411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c9079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c9038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt939MetricSet::CExt939MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt939MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT_XECORE27", "SLM BANK CONFLICT COUNT XECORE27",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD dw@0xec UADD 2 dw@0xe8 UMUL UADD 4 dw@0xe4 UMUL UADD 8 dw@0xe0 UMUL UADD dw@0xdc UADD 2 dw@0xd8 UMUL UADD 4 dw@0xd4 UMUL UADD 8 dw@0xd0 UMUL UADD dw@0xcc UADD 2 dw@0xc8 UMUL UADD 4 dw@0xc4 UMUL UADD 8 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD qw@0x198 UADD 2 qw@0x190 UMUL UADD 4 qw@0x188 UMUL UADD 8 qw@0x180 UMUL UADD qw@0x178 UADD 2 qw@0x170 UMUL UADD 4 qw@0x168 UMUL UADD 8 qw@0x160 UMUL UADD qw@0x158 UADD 2 qw@0x150 UMUL UADD 4 qw@0x148 UMUL UADD 8 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22e91800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28e914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e90fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae90821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce90baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee90411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e9079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e9038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt940MetricSet::CExt940MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt940MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT_XECORE28", "SLM BANK CONFLICT COUNT XECORE28",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD dw@0xec UADD 2 dw@0xe8 UMUL UADD 4 dw@0xe4 UMUL UADD 8 dw@0xe0 UMUL UADD dw@0xdc UADD 2 dw@0xd8 UMUL UADD 4 dw@0xd4 UMUL UADD 8 dw@0xd0 UMUL UADD dw@0xcc UADD 2 dw@0xc8 UMUL UADD 4 dw@0xc4 UMUL UADD 8 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD qw@0x198 UADD 2 qw@0x190 UMUL UADD 4 qw@0x188 UMUL UADD 8 qw@0x180 UMUL UADD qw@0x178 UADD 2 qw@0x170 UMUL UADD 4 qw@0x168 UMUL UADD 8 qw@0x160 UMUL UADD qw@0x158 UADD 2 qw@0x150 UMUL UADD 4 qw@0x148 UMUL UADD 8 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x198914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1f8900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23891800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25890005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x298914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0183aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0383aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0184ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0187aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0387aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03893254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05890208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07890c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09890fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0b890821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d890baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0f890411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1189079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13890001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1589038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt941MetricSet::CExt941MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt941MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT_XECORE29", "SLM BANK CONFLICT COUNT XECORE29",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD dw@0xec UADD 2 dw@0xe8 UMUL UADD 4 dw@0xe4 UMUL UADD 8 dw@0xe0 UMUL UADD dw@0xdc UADD 2 dw@0xd8 UMUL UADD 4 dw@0xd4 UMUL UADD 8 dw@0xd0 UMUL UADD dw@0xcc UADD 2 dw@0xc8 UMUL UADD 4 dw@0xc4 UMUL UADD 8 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD qw@0x198 UADD 2 qw@0x190 UMUL UADD 4 qw@0x188 UMUL UADD 8 qw@0x180 UMUL UADD qw@0x178 UADD 2 qw@0x170 UMUL UADD 4 qw@0x168 UMUL UADD 8 qw@0x160 UMUL UADD qw@0x158 UADD 2 qw@0x150 UMUL UADD 4 qw@0x148 UMUL UADD 8 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19a914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fa900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23a91800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25a90005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29a914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05a90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a90c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09a90fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ba90821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0da90baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa90411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11a9079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13a90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15a9038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0108ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0308ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0101ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt942MetricSet::CExt942MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt942MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT_XECORE30", "SLM BANK CONFLICT COUNT XECORE30",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD dw@0xec UADD 2 dw@0xe8 UMUL UADD 4 dw@0xe4 UMUL UADD 8 dw@0xe0 UMUL UADD dw@0xdc UADD 2 dw@0xd8 UMUL UADD 4 dw@0xd4 UMUL UADD 8 dw@0xd0 UMUL UADD dw@0xcc UADD 2 dw@0xc8 UMUL UADD 4 dw@0xc4 UMUL UADD 8 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD qw@0x198 UADD 2 qw@0x190 UMUL UADD 4 qw@0x188 UMUL UADD 8 qw@0x180 UMUL UADD qw@0x178 UADD 2 qw@0x170 UMUL UADD 4 qw@0x168 UMUL UADD 8 qw@0x160 UMUL UADD qw@0x158 UADD 2 qw@0x150 UMUL UADD 4 qw@0x148 UMUL UADD 8 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19c914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fc900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23c91800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25c90005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29c914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05c90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c90c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09c90fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0bc90821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0dc90baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fc90411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c9079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13c90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15c9038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0107aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0307aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0102ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt943MetricSet::CExt943MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt943MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "SLM_BANK_CONFLICT_COUNT_XECORE31", "SLM BANK CONFLICT COUNT XECORE31",
                          "Number of SLM accesses resulting in a bank conflict.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD dw@0xec UADD 2 dw@0xe8 UMUL UADD 4 dw@0xe4 UMUL UADD 8 dw@0xe0 UMUL UADD dw@0xdc UADD 2 dw@0xd8 UMUL UADD 4 dw@0xd4 UMUL UADD 8 dw@0xd0 UMUL UADD dw@0xcc UADD 2 dw@0xc8 UMUL UADD 4 dw@0xc4 UMUL UADD 8 dw@0xc0 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD qw@0x198 UADD 2 qw@0x190 UMUL UADD 4 qw@0x188 UMUL UADD 8 qw@0x180 UMUL UADD qw@0x178 UADD 2 qw@0x170 UMUL UADD 4 qw@0x168 UMUL UADD 8 qw@0x160 UMUL UADD qw@0x158 UADD 2 qw@0x150 UMUL UADD 4 qw@0x148 UMUL UADD 8 qw@0x140 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x19e914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1fe900a6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x23e91800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x25e90005, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x29e914c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e4ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e93254, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x05e90208, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e90c31, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x09e90fbf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0be90821, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0de90baf, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fe90411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11e9079f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e90001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x15e9038f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x010aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt944MetricSet::CExt944MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt944MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "SLM_BYTE_READ_BANK0_XECORE0", "SLM BYTE READ BANK0 XECORE0",
                          "Number of bytes read from SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_READ_BANK0_XECORE0", "LOAD STORE CACHE BYTE READ BANK0 XECORE0",
                          "Number of bytes read out of the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16870253, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18891060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04870004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e870140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x108700c4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12870042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x148703c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890387, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a8902ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c89034c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt945MetricSet::CExt945MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt945MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "SLM_BYTE_READ_BANK0_XECORE1", "SLM BYTE READ BANK0 XECORE1",
                          "Number of bytes read from SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_READ_BANK0_XECORE1", "LOAD STORE CACHE BYTE READ BANK0 XECORE1",
                          "Number of bytes read out of the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a70253, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a91060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea70140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a700c4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a70042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a703c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a70000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a90387, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a90248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa902ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca9034c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt946MetricSet::CExt946MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt946MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "SLM_BYTE_READ_BANK0_XECORE2", "SLM BYTE READ BANK0 XECORE2",
                          "Number of bytes read from SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_READ_BANK0_XECORE2", "LOAD STORE CACHE BYTE READ BANK0 XECORE2",
                          "Number of bytes read out of the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c70253, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c91060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec70140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c700c4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c70042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c703c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90387, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c90248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac902ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc9034c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt947MetricSet::CExt947MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt947MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "SLM_BYTE_READ_BANK0_XECORE3", "SLM BYTE READ BANK0 XECORE3",
                          "Number of bytes read from SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_READ_BANK0_XECORE3", "LOAD STORE CACHE BYTE READ BANK0 XECORE3",
                          "Number of bytes read out of the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e70253, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e91060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e70004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee70140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e700c4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e70042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e703c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90387, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e90248, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae902ca, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce9034c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt948MetricSet::CExt948MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt948MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "SLM_BYTE_READ_BANK1_XECORE0", "SLM BYTE READ BANK1 XECORE0",
                          "Number of bytes read from SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_READ_BANK1_XECORE0", "LOAD STORE CACHE BYTE READ BANK1 XECORE0",
                          "Number of bytes read out of the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a870253, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x048700e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e870540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x108704d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12870452, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x148707d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02893200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890797, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890658, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a8906da, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c89075c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt949MetricSet::CExt949MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt949MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "SLM_BYTE_READ_BANK1_XECORE1", "SLM BYTE READ BANK1 XECORE1",
                          "Number of bytes read from SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_READ_BANK1_XECORE1", "LOAD STORE CACHE BYTE READ BANK1 XECORE1",
                          "Number of bytes read out of the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa70253, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a700e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea70540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a704d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a70452, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a707d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a70000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a93200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a90797, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a90658, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa906da, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca9075c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt950MetricSet::CExt950MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt950MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "SLM_BYTE_READ_BANK1_XECORE2", "SLM BYTE READ BANK1 XECORE2",
                          "Number of bytes read from SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_READ_BANK1_XECORE2", "LOAD STORE CACHE BYTE READ BANK1 XECORE2",
                          "Number of bytes read out of the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac70253, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c700e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec70540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c704d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c70452, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c707d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c93200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90797, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c90658, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac906da, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc9075c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt951MetricSet::CExt951MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt951MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "SLM_BYTE_READ_BANK1_XECORE3", "SLM BYTE READ BANK1 XECORE3",
                          "Number of bytes read from SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_READ_BANK1_XECORE3", "LOAD STORE CACHE BYTE READ BANK1 XECORE3",
                          "Number of bytes read out of the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae70253, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e700e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee70540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e704d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e70452, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e707d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e93200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90797, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e90658, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae906da, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce9075c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt952MetricSet::CExt952MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt952MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "SLM_BYTE_READ_BANK2_XECORE0", "SLM BYTE READ BANK2 XECORE0",
                          "Number of bytes read from SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_READ_BANK2_XECORE0", "LOAD STORE CACHE BYTE READ BANK2 XECORE0",
                          "Number of bytes read out of the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12880253, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22890c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00880004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a880140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c8800c4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e880042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x108803c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890ba7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890a68, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890aea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890b6c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0089fe00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt953MetricSet::CExt953MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt953MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "SLM_BYTE_READ_BANK2_XECORE1", "SLM BYTE READ BANK2 XECORE1",
                          "Number of bytes read from SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_READ_BANK2_XECORE1", "LOAD STORE CACHE BYTE READ BANK2 XECORE1",
                          "Number of bytes read out of the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a80253, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22a90c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa80140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca800c4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea80042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a803c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a90ba7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a90a68, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa90aea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca90b6c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a9fe00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt954MetricSet::CExt954MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt954MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "SLM_BYTE_READ_BANK2_XECORE2", "SLM BYTE READ BANK2 XECORE2",
                          "Number of bytes read from SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_READ_BANK2_XECORE2", "LOAD STORE CACHE BYTE READ BANK2 XECORE2",
                          "Number of bytes read out of the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c80253, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c90c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c7aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac80140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc800c4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec80042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c803c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90ba7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c90a68, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90aea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90b6c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c9fe00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt955MetricSet::CExt955MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt955MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "SLM_BYTE_READ_BANK2_XECORE3", "SLM BYTE READ BANK2 XECORE3",
                          "Number of bytes read from SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_READ_BANK2_XECORE3", "LOAD STORE CACHE BYTE READ BANK2 XECORE3",
                          "Number of bytes read out of the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e80253, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22e90c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae80140, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce800c4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee80042, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e803c0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90ba7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e90a68, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae90aea, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce90b6c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e9fe00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt956MetricSet::CExt956MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt956MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "SLM_BYTE_READ_BANK3_XECORE0", "SLM BYTE READ BANK3 XECORE0",
                          "Number of bytes read from SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_READ_BANK3_XECORE0", "LOAD STORE CACHE BYTE READ BANK3 XECORE0",
                          "Number of bytes read out of the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16880253, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28891060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x008800e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a880540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c8804d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e880452, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x108807d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890fb7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890e78, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890efa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890f7c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0089fe00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt957MetricSet::CExt957MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt957MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "SLM_BYTE_READ_BANK3_XECORE1", "SLM BYTE READ BANK3 XECORE1",
                          "Number of bytes read from SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_READ_BANK3_XECORE1", "LOAD STORE CACHE BYTE READ BANK3 XECORE1",
                          "Number of bytes read out of the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a80253, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28a91060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a800e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa80540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca804d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea80452, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a807d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a90fb7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a90e78, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa90efa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca90f7c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a9fe00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt958MetricSet::CExt958MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt958MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "SLM_BYTE_READ_BANK3_XECORE2", "SLM BYTE READ BANK3 XECORE2",
                          "Number of bytes read from SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_READ_BANK3_XECORE2", "LOAD STORE CACHE BYTE READ BANK3 XECORE2",
                          "Number of bytes read out of the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c80253, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28c91060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c7aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c800e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac80540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc804d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec80452, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c807d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90fb7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c90e78, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90efa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90f7c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c9fe00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt959MetricSet::CExt959MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt959MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "SLM_BYTE_READ_BANK3_XECORE3", "SLM BYTE READ BANK3 XECORE3",
                          "Number of bytes read from SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_READ_BANK3_XECORE3", "LOAD STORE CACHE BYTE READ BANK3 XECORE3",
                          "Number of bytes read out of the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e80253, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28e91060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e800e0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae80540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce804d4, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee80452, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e807d0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90fb7, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e90e78, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae90efa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce90f7c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e9fe00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt960MetricSet::CExt960MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt960MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "SLM_BYTE_WRITE_BANK0_XECORE0", "SLM BYTE WRITE BANK0 XECORE0",
                          "Number of bytes written to SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_WRITE_BANK0_XECORE0", "LOAD STORE CACHE BYTE WRITE BANK0 XECORE0",
                          "Number of bytes written to the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16870012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18891060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04870000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e870180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10870105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12870083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14870001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02890054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt961MetricSet::CExt961MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt961MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "SLM_BYTE_WRITE_BANK0_XECORE1", "SLM BYTE WRITE BANK0 XECORE1",
                          "Number of bytes written to SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_WRITE_BANK0_XECORE1", "LOAD STORE CACHE BYTE WRITE BANK0 XECORE1",
                          "Number of bytes written to the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a70012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a91060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a70000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea70180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a70105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a70083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a70000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a90054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a90081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa90103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca90185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt962MetricSet::CExt962MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt962MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "SLM_BYTE_WRITE_BANK0_XECORE2", "SLM BYTE WRITE BANK0 XECORE2",
                          "Number of bytes written to SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_WRITE_BANK0_XECORE2", "LOAD STORE CACHE BYTE WRITE BANK0 XECORE2",
                          "Number of bytes written to the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c70012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c91060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c70000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec70180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c70105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c70083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c90054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c90081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt963MetricSet::CExt963MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt963MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "SLM_BYTE_WRITE_BANK0_XECORE3", "SLM BYTE WRITE BANK0 XECORE3",
                          "Number of bytes written to SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_WRITE_BANK0_XECORE3", "LOAD STORE CACHE BYTE WRITE BANK0 XECORE3",
                          "Number of bytes written to the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e70012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e91060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e70000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee70180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e70105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e70083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e70001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e90054, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90380, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e90081, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae90103, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce90185, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt964MetricSet::CExt964MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt964MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "SLM_BYTE_WRITE_BANK1_XECORE0", "SLM BYTE WRITE BANK1 XECORE0",
                          "Number of bytes written to SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_WRITE_BANK1_XECORE0", "LOAD STORE CACHE BYTE WRITE BANK1 XECORE0",
                          "Number of bytes written to the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a870012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e890083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04870020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e870580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10870515, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12870493, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14870411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02870000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02893200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890790, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890491, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890513, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890595, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00890000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt965MetricSet::CExt965MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt965MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "SLM_BYTE_WRITE_BANK1_XECORE1", "SLM BYTE WRITE BANK1 XECORE1",
                          "Number of bytes written to SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_WRITE_BANK1_XECORE1", "LOAD STORE CACHE BYTE WRITE BANK1 XECORE1",
                          "Number of bytes written to the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa70012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ea90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea70580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a70515, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a70493, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a70411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a70000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a93200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a90790, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a90491, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa90513, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca90595, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt966MetricSet::CExt966MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt966MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "SLM_BYTE_WRITE_BANK1_XECORE2", "SLM BYTE WRITE BANK1 XECORE2",
                          "Number of bytes written to SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_WRITE_BANK1_XECORE2", "LOAD STORE CACHE BYTE WRITE BANK1 XECORE2",
                          "Number of bytes written to the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac70012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ec90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec70580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c70515, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c70493, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c70411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c70000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c93200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90790, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c90491, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90513, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90595, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt967MetricSet::CExt967MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt967MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "SLM_BYTE_WRITE_BANK1_XECORE3", "SLM BYTE WRITE BANK1 XECORE3",
                          "Number of bytes written to SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_WRITE_BANK1_XECORE3", "LOAD STORE CACHE BYTE WRITE BANK1 XECORE3",
                          "Number of bytes written to the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae70012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ee90083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e70020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee70580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e70515, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e70493, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e70411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e70000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e93200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90790, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e90491, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae90513, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce90595, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e90000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c60, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030600, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030c63, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt968MetricSet::CExt968MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt968MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "SLM_BYTE_WRITE_BANK2_XECORE0", "SLM BYTE WRITE BANK2 XECORE0",
                          "Number of bytes written to SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_WRITE_BANK2_XECORE0", "LOAD STORE CACHE BYTE WRITE BANK2 XECORE0",
                          "Number of bytes written to the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12880012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22890c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24890004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00880000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a880180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c880105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e880083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10880001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890ba0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x088908a1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890923, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c8909a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0089fe00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt969MetricSet::CExt969MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt969MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "SLM_BYTE_WRITE_BANK2_XECORE1", "SLM BYTE WRITE BANK2 XECORE1",
                          "Number of bytes written to SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_WRITE_BANK2_XECORE1", "LOAD STORE CACHE BYTE WRITE BANK2 XECORE1",
                          "Number of bytes written to the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a80012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22a90c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24a90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a80000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa80180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca80105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea80083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a80001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a90ba0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a908a1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa90923, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca909a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a9fe00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt970MetricSet::CExt970MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt970MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "SLM_BYTE_WRITE_BANK2_XECORE2", "SLM BYTE WRITE BANK2 XECORE2",
                          "Number of bytes written to SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_WRITE_BANK2_XECORE2", "LOAD STORE CACHE BYTE WRITE BANK2 XECORE2",
                          "Number of bytes written to the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c80012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22c90c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24c90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c7aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac80180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc80105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec80083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c80001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90ba0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c908a1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90923, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc909a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c9fe00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt971MetricSet::CExt971MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt971MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "SLM_BYTE_WRITE_BANK2_XECORE3", "SLM BYTE WRITE BANK2 XECORE3",
                          "Number of bytes written to SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_WRITE_BANK2_XECORE3", "LOAD STORE CACHE BYTE WRITE BANK2 XECORE3",
                          "Number of bytes written to the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e80012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x22e90c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x24e90004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae80180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce80105, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee80083, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e80001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90ba0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e908a1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae90923, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce909a5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e9fe00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt972MetricSet::CExt972MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt972MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "SLM_BYTE_WRITE_BANK3_XECORE0", "SLM BYTE WRITE BANK3 XECORE0",
                          "Number of bytes written to SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_WRITE_BANK3_XECORE0", "LOAD STORE CACHE BYTE WRITE BANK3 XECORE0",
                          "Number of bytes written to the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16880012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28891060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0083aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0283aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0084feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00865555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02865554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0087aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0287aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00880020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a880580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c880515, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e880493, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10880411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04890200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06890fb0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08890cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a890d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c890db5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0089fe00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt973MetricSet::CExt973MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt973MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "SLM_BYTE_WRITE_BANK3_XECORE1", "SLM BYTE WRITE BANK3 XECORE1",
                          "Number of bytes written to SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_WRITE_BANK3_XECORE1", "LOAD STORE CACHE BYTE WRITE BANK3 XECORE1",
                          "Number of bytes written to the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a80012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28a91060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a7aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa80580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca80515, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea80493, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a80411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04a90200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a90fb0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a90cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa90d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca90db5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a9fe00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208fffc, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt974MetricSet::CExt974MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt974MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "SLM_BYTE_WRITE_BANK3_XECORE2", "SLM BYTE WRITE BANK3 XECORE2",
                          "Number of bytes written to SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_WRITE_BANK3_XECORE2", "LOAD STORE CACHE BYTE WRITE BANK3 XECORE2",
                          "Number of bytes written to the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c80012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28c91060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c7aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac80580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc80515, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec80493, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c80411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04c90200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c90fb0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c90cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac90d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc90db5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c9fe00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0007aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0207aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020c5554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt975MetricSet::CExt975MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt975MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "SLM_BYTE_WRITE_BANK3_XECORE3", "SLM BYTE WRITE BANK3 XECORE3",
                          "Number of bytes written to SLM",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xfc 2 dw@0xf8 UMUL UADD 4 dw@0xf4 UMUL UADD 8 dw@0xf0 UMUL UADD 16 dw@0xec UMUL UADD 32 dw@0xe8 UMUL UADD 64 dw@0xe4 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x1b8 2 qw@0x1b0 UMUL UADD 4 qw@0x1a8 UMUL UADD 8 qw@0x1a0 UMUL UADD 16 qw@0x198 UMUL UADD 32 qw@0x190 UMUL UADD 64 qw@0x188 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "LOAD_STORE_CACHE_BYTE_WRITE_BANK3_XECORE3", "LOAD STORE CACHE BYTE WRITE BANK3 XECORE3",
                          "Number of bytes written to the Load Store Cache, excluding SLM accesses.",
                          "L1Cache", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_THROUGHPUT, RESULT_UINT64, "bytes", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 2 dw@0xc4 UMUL UADD 4 dw@0xc8 UMUL UADD 8 dw@0xcc UMUL UADD 16 dw@0xd0 UMUL UADD 32 dw@0xd4 UMUL UADD 64 dw@0xd8 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 2 qw@0x148 UMUL UADD 4 qw@0x150 UMUL UADD 8 qw@0x158 UMUL UADD 16 qw@0x160 UMUL UADD 32 qw@0x168 UMUL UADD 64 qw@0x170 UMUL UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e80012, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x28e91060, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e3aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e3aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e4feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e65555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e65554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e7aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e7aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e80020, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae80580, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce80515, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee80493, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e80411, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04e90200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e90fb0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e90cb1, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae90d33, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce90db5, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e9fe00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02075554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0009feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020aaaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032092, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001feff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055554, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaa8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x70800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001a, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000032, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff9, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000052, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000fff5, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000092, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ffed, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00000112, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000ffdd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00000212, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000ffbd, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00000412, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000ff7d, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt976MetricSet::CExt976MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt976MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore0";
        metric               = AddMetric( "RT_INPUT_AVAILABLE_XECORE0", "RT INPUT AVAILABLE XECORE0",
                          "Percentage of time in which new message is accepted by Ray Tracing Frontend",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore1";
        metric               = AddMetric( "RT_INPUT_AVAILABLE_XECORE1", "RT INPUT AVAILABLE XECORE1",
                          "Percentage of time in which new message is accepted by Ray Tracing Frontend",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore2";
        metric               = AddMetric( "RT_INPUT_AVAILABLE_XECORE2", "RT INPUT AVAILABLE XECORE2",
                          "Percentage of time in which new message is accepted by Ray Tracing Frontend",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice0XeCore3";
        metric               = AddMetric( "RT_INPUT_AVAILABLE_XECORE3", "RT INPUT AVAILABLE XECORE3",
                          "Percentage of time in which new message is accepted by Ray Tracing Frontend",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore0";
        metric               = AddMetric( "RT_INPUT_AVAILABLE_XECORE4", "RT INPUT AVAILABLE XECORE4",
                          "Percentage of time in which new message is accepted by Ray Tracing Frontend",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore1";
        metric               = AddMetric( "RT_INPUT_AVAILABLE_XECORE5", "RT INPUT AVAILABLE XECORE5",
                          "Percentage of time in which new message is accepted by Ray Tracing Frontend",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore2";
        metric               = AddMetric( "RT_INPUT_AVAILABLE_XECORE6", "RT INPUT AVAILABLE XECORE6",
                          "Percentage of time in which new message is accepted by Ray Tracing Frontend",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice1XeCore3";
        metric               = AddMetric( "RT_INPUT_AVAILABLE_XECORE7", "RT INPUT AVAILABLE XECORE7",
                          "Percentage of time in which new message is accepted by Ray Tracing Frontend",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x168502a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a502a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c502a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e502a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x178502a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a502a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c502a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e502a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02850004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04850c20, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0086000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a500c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a600a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c500c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae500c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e6a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03850004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d8500c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0386000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa500c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a600a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c500c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e500c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff0c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01023000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030ee8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030277, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000008, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000065, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000185, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000605, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001805, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006005, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018005, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060005, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt977MetricSet::CExt977MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt977MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore0";
        metric               = AddMetric( "RT_INPUT_AVAILABLE_XECORE8", "RT INPUT AVAILABLE XECORE8",
                          "Percentage of time in which new message is accepted by Ray Tracing Frontend",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore1";
        metric               = AddMetric( "RT_INPUT_AVAILABLE_XECORE9", "RT INPUT AVAILABLE XECORE9",
                          "Percentage of time in which new message is accepted by Ray Tracing Frontend",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore2";
        metric               = AddMetric( "RT_INPUT_AVAILABLE_XECORE10", "RT INPUT AVAILABLE XECORE10",
                          "Percentage of time in which new message is accepted by Ray Tracing Frontend",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice2XeCore3";
        metric               = AddMetric( "RT_INPUT_AVAILABLE_XECORE11", "RT INPUT AVAILABLE XECORE11",
                          "Percentage of time in which new message is accepted by Ray Tracing Frontend",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore0";
        metric               = AddMetric( "RT_INPUT_AVAILABLE_XECORE12", "RT INPUT AVAILABLE XECORE12",
                          "Percentage of time in which new message is accepted by Ray Tracing Frontend",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore1";
        metric               = AddMetric( "RT_INPUT_AVAILABLE_XECORE13", "RT INPUT AVAILABLE XECORE13",
                          "Percentage of time in which new message is accepted by Ray Tracing Frontend",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore2";
        metric               = AddMetric( "RT_INPUT_AVAILABLE_XECORE14", "RT INPUT AVAILABLE XECORE14",
                          "Percentage of time in which new message is accepted by Ray Tracing Frontend",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice3XeCore3";
        metric               = AddMetric( "RT_INPUT_AVAILABLE_XECORE15", "RT INPUT AVAILABLE XECORE15",
                          "Percentage of time in which new message is accepted by Ray Tracing Frontend",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x168502a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a502a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c502a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e502a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x178502a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a502a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c502a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e502a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02850004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04850c20, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0086000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a500c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a600a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c500c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae500c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e6a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03850004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d8500c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0386000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa500c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a600a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c500c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e500c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff0c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01023000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04032492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030ee8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030277, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000009, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000065, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000185, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000605, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001805, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006005, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018005, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060005, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt978MetricSet::CExt978MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt978MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore0";
        metric               = AddMetric( "RT_INPUT_AVAILABLE_XECORE16", "RT INPUT AVAILABLE XECORE16",
                          "Percentage of time in which new message is accepted by Ray Tracing Frontend",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore1";
        metric               = AddMetric( "RT_INPUT_AVAILABLE_XECORE17", "RT INPUT AVAILABLE XECORE17",
                          "Percentage of time in which new message is accepted by Ray Tracing Frontend",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore2";
        metric               = AddMetric( "RT_INPUT_AVAILABLE_XECORE18", "RT INPUT AVAILABLE XECORE18",
                          "Percentage of time in which new message is accepted by Ray Tracing Frontend",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice4XeCore3";
        metric               = AddMetric( "RT_INPUT_AVAILABLE_XECORE19", "RT INPUT AVAILABLE XECORE19",
                          "Percentage of time in which new message is accepted by Ray Tracing Frontend",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore0";
        metric               = AddMetric( "RT_INPUT_AVAILABLE_XECORE20", "RT INPUT AVAILABLE XECORE20",
                          "Percentage of time in which new message is accepted by Ray Tracing Frontend",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore1";
        metric               = AddMetric( "RT_INPUT_AVAILABLE_XECORE21", "RT INPUT AVAILABLE XECORE21",
                          "Percentage of time in which new message is accepted by Ray Tracing Frontend",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore2";
        metric               = AddMetric( "RT_INPUT_AVAILABLE_XECORE22", "RT INPUT AVAILABLE XECORE22",
                          "Percentage of time in which new message is accepted by Ray Tracing Frontend",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice5XeCore3";
        metric               = AddMetric( "RT_INPUT_AVAILABLE_XECORE23", "RT INPUT AVAILABLE XECORE23",
                          "Percentage of time in which new message is accepted by Ray Tracing Frontend",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000e, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x168502a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a502a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c502a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e502a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x178502a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a502a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c502a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e502a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02850004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04850c20, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0086000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a500c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a600a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c500c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae500c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e6a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03850004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d8500c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0386000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa500c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a600a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c500c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e500c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff0c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01023000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030ee8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030277, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000065, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000185, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000605, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001805, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006005, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018005, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060005, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt979MetricSet::CExt979MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt979MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore0";
        metric               = AddMetric( "RT_INPUT_AVAILABLE_XECORE24", "RT INPUT AVAILABLE XECORE24",
                          "Percentage of time in which new message is accepted by Ray Tracing Frontend",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore1";
        metric               = AddMetric( "RT_INPUT_AVAILABLE_XECORE25", "RT INPUT AVAILABLE XECORE25",
                          "Percentage of time in which new message is accepted by Ray Tracing Frontend",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x148" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore2";
        metric               = AddMetric( "RT_INPUT_AVAILABLE_XECORE26", "RT INPUT AVAILABLE XECORE26",
                          "Percentage of time in which new message is accepted by Ray Tracing Frontend",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x150" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice6XeCore3";
        metric               = AddMetric( "RT_INPUT_AVAILABLE_XECORE27", "RT INPUT AVAILABLE XECORE27",
                          "Percentage of time in which new message is accepted by Ray Tracing Frontend",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xcc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x158" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore0";
        metric               = AddMetric( "RT_INPUT_AVAILABLE_XECORE28", "RT INPUT AVAILABLE XECORE28",
                          "Percentage of time in which new message is accepted by Ray Tracing Frontend",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x160" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore1";
        metric               = AddMetric( "RT_INPUT_AVAILABLE_XECORE29", "RT INPUT AVAILABLE XECORE29",
                          "Percentage of time in which new message is accepted by Ray Tracing Frontend",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd4" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x168" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore2";
        metric               = AddMetric( "RT_INPUT_AVAILABLE_XECORE30", "RT INPUT AVAILABLE XECORE30",
                          "Percentage of time in which new message is accepted by Ray Tracing Frontend",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x170" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = "$GtSlice7XeCore3";
        metric               = AddMetric( "RT_INPUT_AVAILABLE_XECORE31", "RT INPUT AVAILABLE XECORE31",
                          "Percentage of time in which new message is accepted by Ray Tracing Frontend",
                          "RayTracing", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_DUALSUBSLICE, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xdc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x178" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "GpuDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x168502a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a502a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c502a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e502a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x178502a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17a502a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17c502a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x17e502a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02850004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04850c20, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0086000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a500c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a600a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c500c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c60a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae500c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e6a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03850004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0d8500c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01850000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0386000a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0fa500c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01a50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03a600a0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x11c500c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01c50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03c60a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e50004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x13e500c2, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x07e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01e50000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03e6a000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0003ff00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000900f0, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a5555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ff0c, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020baaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00020030, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x03075a00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030800fa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0109f000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030aaa55, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01010c00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030b0050, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x01023000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x030c0500, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0002aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0202aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04031249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030c6a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4203014a, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32037000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030d00, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38033000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030ee8, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030277, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030422, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40032800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x0000000b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0001ffff, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02025555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02045555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02055555, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0008aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0208aaaa, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0xf0800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x0000001d, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000fffc, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x00000065, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x0000fff3, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd950, 0x00000185, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd954, 0x0000ffcf, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd958, 0x00000605, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd95c, 0x0000ff3f, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd960, 0x00001805, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd964, 0x0000fcff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd968, 0x00006005, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd96c, 0x0000f3ff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd970, 0x00018005, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd974, 0x0000cfff, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd978, 0x00060005, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd97c, 0x00003fff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt980MetricSet::CExt980MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt980MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_L3_READ_SQIDI0", "GPU MEMORY L3 READ SQIDI0",
                          "Number of GTI memory reads from L3 caused by L3 Cache misses",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a012540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18213800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a21000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02010128, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06011400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08010288, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a01030b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c01038d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e01000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x022100e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e210180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10210288, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1221030b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1421038d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1621000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00034924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02034924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04034924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a2492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040a2492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060a0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b1249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b2449, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b2492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ca, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ff00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0000c802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x000000ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt981MetricSet::CExt981MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt981MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_L3_READ_SQIDI1", "GPU MEMORY L3 READ SQIDI1",
                          "Number of GTI memory reads from L3 caused by L3 Cache misses",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18013800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a01000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a212540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020100e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e010180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10010288, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1201030b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1401038d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1601000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00010000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02210128, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06211400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08210288, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a21030b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c21038d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e21000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00210000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00034924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02034924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04034924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a2492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040a2492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060a0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b2492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b1292, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b1249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ca, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ff00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0000c802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x000000ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt982MetricSet::CExt982MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt982MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_L3_READ_SQIDI2", "GPU MEMORY L3 READ SQIDI2",
                          "Number of GTI memory reads from L3 caused by L3 Cache misses",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a412540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18613800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a61000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02410128, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06411400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08410288, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a41030b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c41038d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e41000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00410000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x026100e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e610180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10610288, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1261030b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1461038d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1661000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00610000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00034924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02034924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04034924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a2492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040a2492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060a0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b36db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b48db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b4924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b0004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ca, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ff00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0000c802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x000000ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt983MetricSet::CExt983MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt983MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_L3_READ_SQIDI3", "GPU MEMORY L3 READ SQIDI3",
                          "Number of GTI memory reads from L3 caused by L3 Cache misses",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18413800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a41000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a612540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x024100e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e410180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10410288, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1241030b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1441038d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1641000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00410000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02610128, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06611400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08610288, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a61030b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c61038d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e61000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00610000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00034924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02034924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04034924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a2492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a2492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040a2492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060a0002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000b4924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020b3724, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040b36db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060b0003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ca, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ff00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0000c802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x000000ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt984MetricSet::CExt984MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt984MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_L3_READ_SQIDI4", "GPU MEMORY L3 READ SQIDI4",
                          "Number of GTI memory reads from L3 caused by L3 Cache misses",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a812540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18a13800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa1000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02810128, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06811400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08810288, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0a81030b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0c81038d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e81000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a100e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea10180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10a10288, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12a1030b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14a1038d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16a1000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00034924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02034924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04034924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00091249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02092449, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04092492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06090002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a1249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040a1249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030421, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ca, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ff00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0000c802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x000000ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt985MetricSet::CExt985MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt985MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_L3_READ_SQIDI5", "GPU MEMORY L3 READ SQIDI5",
                          "Number of GTI memory reads from L3 caused by L3 Cache misses",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18813800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a81000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1aa12540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x028100e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0e810180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10810288, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1281030b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1481038d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1681000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00810000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02a10128, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06a11400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08a10288, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0aa1030b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ca1038d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ea1000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00a10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00034924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02034924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04034924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00092492, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02091292, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04091249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06090001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a1249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040a1249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030420, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030021, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030201, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030010, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ca, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ff00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0000c802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x000000ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt986MetricSet::CExt986MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt986MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_L3_READ_SQIDI6", "GPU MEMORY L3 READ SQIDI6",
                          "Number of GTI memory reads from L3 caused by L3 Cache misses",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac12540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18e13800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae1000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c10128, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06c11400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08c10288, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ac1030b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0cc1038d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec1000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e100e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee10180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10e10288, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12e1030b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14e1038d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16e1000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00034924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02034924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04034924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000936db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020948db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04094924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06090004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a1249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040a1249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ca, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ff00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0000c802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x000000ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt987MetricSet::CExt987MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt987MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GPU_MEMORY_L3_READ_SQIDI7", "GPU MEMORY L3 READ SQIDI7",
                          "Number of GTI memory reads from L3 caused by L3 Cache misses",
                          "Memory", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0xc0 dw@0xc4 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x140 qw@0x148 UADD" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0x0d04, 0x00000200, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18c13800, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ac1000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1ae12540, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02c100e6, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ec10180, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x10c10288, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x12c1030b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14c1038d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16c1000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00c10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02e10128, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06e11400, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x08e10288, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ae1030b, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ce1038d, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x0ee1000f, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00e10000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00034924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02034924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x04034924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06030004, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x00094924, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x02093724, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040936db, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x06090003, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x000a1249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x020a1249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x040a1249, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x060a0001, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x14030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x3e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x26030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x42030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x2c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x32030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x44030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x38030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x46030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x48030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x4a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x16030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x18030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1a030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x40030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1c030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x1e030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x20030000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9884, 0x00000000, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0x9888, 0x5c030002, REGISTER_TYPE_NOA );
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x30800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd940, 0x000000ca, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd944, 0x0000ff00, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd948, 0x0000c802, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd94c, 0x000000ff, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt1000MetricSet::CExt1000MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt1000MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_ACTIVE", "XVE ACTIVE",
                          "Percentage of time in which at least one pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x2c:0xa7" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x48" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL", "XVE STALL",
                          "Percentage of time in which any threads are loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x30:0xa8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x50" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_THREADS_OCCUPANCY_ALL", "XVE THREADS OCCUPANCY ALL",
                          "Percentage of thread slots occupied",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "DS|TES", nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "8 rd40@0x48:0xae FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "8 qw@0x80 FMUL $VectorEngineThreadsCount FDIV" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_ALL", "XVE INST EXECUTED ALU0 ALL",
                          "Number of execution slots taken by instructions executed on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x34:0xa9" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x58" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_ALL", "XVE INST EXECUTED ALU1 ALL",
                          "Number of execution slots taken by instructions executed on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x38:0xaa" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x60" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_ALL", "XVE INST EXECUTED XMX ALL",
                          "Number of execution slots taken by instructions executed in XMX pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x3c:0xab" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x68" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_ALL", "XVE INST EXECUTED SEND ALL",
                          "Number of instructions executed on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x40:0xac" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x70" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_CONTROL_ALL", "XVE INST EXECUTED CONTROL ALL",
                          "Number of instructions executed on Jump Pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x44:0xad" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x78" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_PIPE_ALU0_AND_ALU1_ACTIVE", "XVE PIPE ALU0 AND ALU1 ACTIVE",
                          "Percentage of time in which ALU0 and ALU1 pipes are both actively executing a Gen ISA instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x50:0xb0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x90" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_PIPE_ALU0_AND_XMX_ACTIVE", "XVE PIPE ALU0 AND XMX ACTIVE",
                          "Percentage of time in which ALU0 and XMX pipes are both actively executing a Gen ISA instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x4c:0xaf" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x88" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_ALL_UTILIZATION", "XVE INST EXECUTED ALU0 ALL UTILIZATION",
                          "Percentage of execution slots taken by instructions executed on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x34:0xa9" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x58" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_ALL_UTILIZATION", "XVE INST EXECUTED ALU1 ALL UTILIZATION",
                          "Percentage of execution slots taken by instructions executed on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x38:0xaa" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x60" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_ALL_UTILIZATION", "XVE INST EXECUTED XMX ALL UTILIZATION",
                          "Percentage of execution slots taken by instructions executed in XMX pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x3c:0xab" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x68" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_ALL_UTILIZATION", "XVE INST EXECUTED SEND ALL UTILIZATION",
                          "Percentage of time taken by instructions executed on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x40:0xac" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x70" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_CONTROL_ALL_UTILIZATION", "XVE INST EXECUTED CONTROL ALL UTILIZATION",
                          "Percentage of time taken by instructions executed on Jump Pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x44:0xad" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x78" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_ACTIVE_CYCLES", "XVE ACTIVE CYCLES",
                          "Number of cycles at least one pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$XVE_ACTIVE" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL_CYCLES", "XVE STALL CYCLES",
                          "Number of cycles any threads are loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$XVE_STALL" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_THREADS_OCCUPANCY_CYCLES_ALL", "XVE THREADS OCCUPANCY CYCLES ALL",
                          "Number of thread slots occupied",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "DS|TES", nullptr, 20 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x48:0xae" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x80" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "8 $Self UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount $VectorEngineThreadsCount UMUL UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_PIPE_ALU0_AND_ALU1_ACTIVE_CYCLES", "XVE PIPE ALU0 AND ALU1 ACTIVE CYCLES",
                          "Number of cycles in ALU0 and ALU1 pipes are both actively executing a Gen ISA instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 21 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$XVE_PIPE_ALU0_AND_ALU1_ACTIVE" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_PIPE_ALU0_AND_XMX_ACTIVE_CYCLES", "XVE PIPE ALU0 AND XMX ACTIVE CYCLES",
                          "Number of cycles ALU0 and XMX pipes are both actively executing a Gen ISA instruction",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 22 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$XVE_PIPE_ALU0_AND_XMX_ACTIVE" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xe458, 0x00005004, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe558, 0x00001000, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe658, 0x00002009, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe758, 0x01008001, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe45c, 0x0000300a, REGISTER_TYPE_FLEX );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt1001MetricSet::CExt1001MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt1001MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_VS", "XVE INST EXECUTED ALU0 VS",
                          "Number of execution slots taken by instructions executed by Vertex Shader on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x2c:0xa7" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x48" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_HS", "XVE INST EXECUTED ALU0 HS",
                          "Number of execution slots taken by instructions executed by Hull Shader on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "Hull|Control,HS|TCS", nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x30:0xa8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x50" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_DS", "XVE INST EXECUTED ALU0 DS",
                          "Number of execution slots taken by instructions executed by Domain Shader on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "Domain|Evaluation,DS|TES", nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x34:0xa9" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x58" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_PS", "XVE INST EXECUTED ALU0 PS",
                          "Number of execution slots taken by instructions executed by Pixel Shader on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x38:0xaa" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x60" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_CS", "XVE INST EXECUTED ALU0 CS",
                          "Number of execution slots taken by instructions executed by Compute Shader (from Render Engine) on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x3c:0xab" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x68" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_ASYNC_CS", "XVE INST EXECUTED ALU0 ASYNC CS",
                          "Number of execution slots taken by instructions executed by Async Compute Shader on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x40:0xac" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x70" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_VS", "XVE INST EXECUTED ALU1 VS",
                          "Number of execution slots taken by instructions executed by Vertex Shader on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x44:0xad" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x78" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_HS", "XVE INST EXECUTED ALU1 HS",
                          "Number of execution slots taken by instructions executed by Hull Shader on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "Hull|Control,HS|TCS", nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x4c:0xaf" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x88" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_DS", "XVE INST EXECUTED ALU1 DS",
                          "Number of execution slots taken by instructions executed by Domain Shader on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "Domain|Evaluation,DS|TES", nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x48:0xae" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x80" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_PS", "XVE INST EXECUTED ALU1 PS",
                          "Number of execution slots taken by instructions executed by Pixel Shader on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x50:0xb0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x90" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_CS", "XVE INST EXECUTED ALU1 CS",
                          "Number of execution slots taken by instructions executed by Compute Shader (from Render Engine) on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x54:0xb1" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x98" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_ASYNC_CS", "XVE INST EXECUTED ALU1 ASYNC CS",
                          "Number of execution slots taken by instructions executed by Async Compute Shader on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x58:0xb2" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0xa0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_VS_UTILIZATION", "XVE INST EXECUTED ALU0 VS UTILIZATION",
                          "Percentage of execution slots taken by instructions executed by Vertex Shader on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x2c:0xa7" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x48" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_HS_UTILIZATION", "XVE INST EXECUTED ALU0 HS UTILIZATION",
                          "Percentage of execution slots taken by instructions executed by Hull Shader on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "Hull|Control,HS|TCS", nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x30:0xa8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x50" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_DS_UTILIZATION", "XVE INST EXECUTED ALU0 DS UTILIZATION",
                          "Percentage of execution slots taken by instructions executed by Domain Shader on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "Domain|Evaluation,DS|TES", nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x34:0xa9" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x58" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_PS_UTILIZATION", "XVE INST EXECUTED ALU0 PS UTILIZATION",
                          "Percentage of execution slots taken by instructions executed by Pixel Shader on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x38:0xaa" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x60" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_CS_UTILIZATION", "XVE INST EXECUTED ALU0 CS UTILIZATION",
                          "Percentage of execution slots taken by instructions executed by Compute Shader (from Render Engine) on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x3c:0xab" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x68" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_ASYNC_CS_UTILIZATION", "XVE INST EXECUTED ALU0 ASYNC CS UTILIZATION",
                          "Percentage of execution slots taken by instructions executed by Async Compute Shader on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 20 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x40:0xac" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x70" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_VS_UTILIZATION", "XVE INST EXECUTED ALU1 VS UTILIZATION",
                          "Percentage of execution slots taken by instructions executed by Vertex Shader on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 21 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x44:0xad" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x78" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_HS_UTILIZATION", "XVE INST EXECUTED ALU1 HS UTILIZATION",
                          "Percentage of execution slots taken by instructions executed by Hull Shader on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "Hull|Control,HS|TCS", nullptr, 22 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x4c:0xaf" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x88" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_DS_UTILIZATION", "XVE INST EXECUTED ALU1 DS UTILIZATION",
                          "Percentage of execution slots taken by instructions executed by Domain Shader on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "Domain|Evaluation,DS|TES", nullptr, 23 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x48:0xae" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x80" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_PS_UTILIZATION", "XVE INST EXECUTED ALU1 PS UTILIZATION",
                          "Percentage of execution slots taken by instructions executed by Pixel Shader on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 24 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x50:0xb0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x90" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_CS_UTILIZATION", "XVE INST EXECUTED ALU1 CS UTILIZATION",
                          "Percentage of execution slots taken by instructions executed by Compute Shader (from Render Engine) on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 25 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x54:0xb1" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x98" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_ASYNC_CS_UTILIZATION", "XVE INST EXECUTED ALU1 ASYNC CS UTILIZATION",
                          "Percentage of execution slots taken by instructions executed by Async Compute Shader on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 26 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x58:0xb2" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0xa0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xe458, 0x00020010, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe558, 0x00050030, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe658, 0x00090060, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe758, 0x00031011, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe45c, 0x00051021, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe55c, 0x00091061, REGISTER_TYPE_FLEX );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt1002MetricSet::CExt1002MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt1002MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_RT_AHS_UTILIZATION", "XVE INST EXECUTED ALU0 RT AHS UTILIZATION",
                          "Percentage of execution slots taken by instructions executed by BTD Any Hit Shader on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "HS|TCS", nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x2c:0xa7" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x48" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_RT_AHS_UTILIZATION", "XVE INST EXECUTED ALU1 RT AHS UTILIZATION",
                          "Percentage of execution slots taken by instructions executed by BTD Any Hit Shader on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "HS|TCS", nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x30:0xa8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x50" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_RT_AHS_UTILIZATION", "XVE INST EXECUTED SEND RT AHS UTILIZATION",
                          "Percentage of time taken by instructions executed by BTD Any Hit Shader threads on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "HS|TCS", nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x34:0xa9" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x58" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_RT_CHS_UTILIZATION", "XVE INST EXECUTED ALU0 RT CHS UTILIZATION",
                          "Percentage of execution slots taken by instructions executed by BTD Closest Hit Shader on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "HS|TCS", nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x38:0xaa" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x60" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_RT_CHS_UTILIZATION", "XVE INST EXECUTED ALU1 RT CHS UTILIZATION",
                          "Percentage of execution slots taken by instructions executed by BTD Closest Hit Shader on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "HS|TCS", nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x3c:0xab" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x68" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_RT_CHS_UTILIZATION", "XVE INST EXECUTED SEND RT CHS UTILIZATION",
                          "Percentage of time taken by instructions executed by BTD Closest Hit Shader threads on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "HS|TCS", nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x40:0xac" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x70" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_RT_MS_UTILIZATION", "XVE INST EXECUTED ALU0 RT MS UTILIZATION",
                          "Percentage of execution slots taken by instructions executed by BTD Miss Shader on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x44:0xad" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x78" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_RT_MS_UTILIZATION", "XVE INST EXECUTED ALU1 RT MS UTILIZATION",
                          "Percentage of execution slots taken by instructions executed by BTD Miss Shader on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x48:0xae" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x80" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_RT_MS_UTILIZATION", "XVE INST EXECUTED SEND RT MS UTILIZATION",
                          "Percentage of time taken by instructions executed by BTD Miss Shader threads on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x4c:0xaf" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x88" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_RT_AHS", "XVE INST EXECUTED ALU0 RT AHS",
                          "Number of execution slots taken by instructions executed by BTD Any Hit Shader on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "HS|TCS", nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$XVE_INST_EXECUTED_ALU0_RT_AHS_UTILIZATION" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_RT_AHS", "XVE INST EXECUTED ALU1 RT AHS",
                          "Number of execution slots taken by instructions executed by BTD Any Hit Shader on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "HS|TCS", nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$XVE_INST_EXECUTED_ALU1_RT_AHS_UTILIZATION" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_RT_AHS", "XVE INST EXECUTED SEND RT AHS",
                          "Number of instructions executed by BTD Any Hit Shader threads on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "HS|TCS", nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$XVE_INST_EXECUTED_SEND_RT_AHS_UTILIZATION" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_RT_CHS", "XVE INST EXECUTED ALU0 RT CHS",
                          "Number of execution slots taken by instructions executed by BTD Closest Hit Shader on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "HS|TCS", nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$XVE_INST_EXECUTED_ALU0_RT_CHS_UTILIZATION" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_RT_CHS", "XVE INST EXECUTED ALU1 RT CHS",
                          "Number of execution slots taken by instructions executed by BTD Closest Hit Shader on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "HS|TCS", nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$XVE_INST_EXECUTED_ALU1_RT_CHS_UTILIZATION" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_RT_CHS", "XVE INST EXECUTED SEND RT CHS",
                          "Number of instructions executed by BTD Closest Hit Shader threads on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "HS|TCS", nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$XVE_INST_EXECUTED_SEND_RT_CHS_UTILIZATION" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_RT_MS", "XVE INST EXECUTED ALU0 RT MS",
                          "Number of execution slots taken by instructions executed by BTD Miss Shader on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$XVE_INST_EXECUTED_ALU0_RT_MS_UTILIZATION" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_RT_MS", "XVE INST EXECUTED ALU1 RT MS",
                          "Number of execution slots taken by instructions executed by BTD Miss Shader on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$XVE_INST_EXECUTED_ALU1_RT_MS_UTILIZATION" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_RT_MS", "XVE INST EXECUTED SEND RT MS",
                          "Number of instructions executed by BTD Miss Shader threads on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 20 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$XVE_INST_EXECUTED_SEND_RT_MS_UTILIZATION" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xe458, 0x000c10c0, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe558, 0x000d00c2, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe658, 0x000d20d1, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe758, 0x000e10e0, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe45c, 0x000000e2, REGISTER_TYPE_FLEX );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt1004MetricSet::CExt1004MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt1004MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL", "XVE STALL",
                          "Percentage of time in which any threads are loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x2c:0xa7" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x48" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL_ASYNC_CS", "XVE STALL ASYNC CS",
                          "Percentage of time in which there are Async Compute Shader threads loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x4c:0xaf" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x88" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL_CS", "XVE STALL CS",
                          "Percentage of time in which there are Compute Shader (from Render Engine) threads loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x48:0xae" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x80" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL_DS", "XVE STALL DS",
                          "Percentage of time in which there are Domain Shader threads loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "Domain|Evaluation,DS|TES", nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x44:0xad" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x78" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL_HS", "XVE STALL HS",
                          "Percentage of time in which there are Hull Shader threads loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "Hull|Control,HS|TCS", nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x40:0xac" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x70" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL_MS", "XVE STALL MS",
                          "Percentage of time in which there are Mesh Shader threads loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x3c:0xab" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x68" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL_PS", "XVE STALL PS",
                          "Percentage of time in which there are Pixel Shader threads loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x38:0xaa" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x60" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL_TS", "XVE STALL TS",
                          "Percentage of time in which there are Task Shader threads loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x34:0xa9" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x58" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL_VS", "XVE STALL VS",
                          "Percentage of time in which there are Vertex Shader threads loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x30:0xa8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x50" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL_RT", "XVE STALL RT",
                          "Percentage of time in which there are Ray Tracing Shader threads loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x58:0xb2" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0xa0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL_CYCLES", "XVE STALL CYCLES",
                          "Number of cycles any threads are loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_2 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$XVE_STALL" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL_CYCLES_ASYNC_CS", "XVE STALL CYCLES ASYNC CS",
                          "Number of cycles there are Async Compute Shader threads loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$XVE_STALL_ASYNC_CS" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL_CYCLES_CS", "XVE STALL CYCLES CS",
                          "Number of cycles there are Compute Shader (from Render Engine) threads loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$XVE_STALL_CS" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL_CYCLES_DS", "XVE STALL CYCLES DS",
                          "Number of cycles there are Domain Shader threads loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "Domain|Evaluation,DS|TES", nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$XVE_STALL_DS" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL_CYCLES_HS", "XVE STALL CYCLES HS",
                          "Number of cycles there are Hull Shader threads loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "Hull|Control,HS|TCS", nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$XVE_STALL_HS" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL_CYCLES_MS", "XVE STALL CYCLES MS",
                          "Number of cycles there are Mesh Shader threads loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$XVE_STALL_MS" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL_CYCLES_PS", "XVE STALL CYCLES PS",
                          "Number of cycles there are Pixel Shader threads loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$XVE_STALL_PS" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL_CYCLES_TS", "XVE STALL CYCLES TS",
                          "Number of cycles there are Task Shader threads loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 20 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$XVE_STALL_TS" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL_CYCLES_VS", "XVE STALL CYCLES VS",
                          "Number of cycles there are Vertex Shader threads loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 21 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$XVE_STALL_VS" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL_CYCLES_RT", "XVE STALL CYCLES RT",
                          "Number of cycles there are Ray Tracing Shader threads loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 22 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$XVE_STALL_RT" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xe458, 0x00015005, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe558, 0x000550a5, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe658, 0x000250b5, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe758, 0x00065035, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe45c, 0x00000095, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe55c, 0x000c5000, REGISTER_TYPE_FLEX );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt1005MetricSet::CExt1005MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt1005MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_ALL", "XVE INST EXECUTED ALU0 ALL",
                          "Number of execution slots taken by instructions executed on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x50:0xb0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x90" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_FP16", "XVE INST EXECUTED FP16",
                          "Number of execution slots taken by FP16 ALU instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x34:0xa9" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x58" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_FP32", "XVE INST EXECUTED FP32",
                          "Number of execution slots taken by FP32 ALU instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x30:0xa8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x50" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_FP64", "XVE INST EXECUTED FP64",
                          "The number of FLT64 instructions executed in ALU0 INT64 pipeline.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x2c:0xa7" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x48" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_ALL", "XVE INST EXECUTED ALU1 ALL",
                          "Number of execution slots taken by instructions executed on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x54:0xb1" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x98" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_INT16", "XVE INST EXECUTED INT16",
                          "Number of execution slots taken by INT16 ALU instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x40:0xac" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x70" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_INT32", "XVE INST EXECUTED INT32",
                          "Number of execution slots taken by INT32 ALU instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x3c:0xab" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x68" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_MATH", "XVE INST EXECUTED MATH",
                          "Number of execution slots taken by extended math instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x38:0xaa" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x60" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_ALL", "XVE INST EXECUTED XMX ALL",
                          "Number of execution slots taken by instructions executed in XMX pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x58:0xb2" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0xa0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_BF16", "XVE INST EXECUTED XMX BF16",
                          "Number of execution slots taken by BF16 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x4c:0xaf" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x88" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_FP16", "XVE INST EXECUTED XMX FP16",
                          "Number of execution slots taken by FP16 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x48:0xae" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x80" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT8", "XVE INST EXECUTED XMX INT8",
                          "Number of execution slots taken by INT8 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x44:0xad" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x78" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_ALL_UTILIZATION", "XVE INST EXECUTED ALU0 ALL UTILIZATION",
                          "Percentage of execution slots taken by instructions executed on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x50:0xb0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x90" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_FP16_UTILIZATION", "XVE INST EXECUTED FP16 UTILIZATION",
                          "Percentage of execution slots taken by FP16 ALU instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x34:0xa9" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x58" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_FP32_UTILIZATION", "XVE INST EXECUTED FP32 UTILIZATION",
                          "Percentage of execution slots taken by FP32 ALU instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x30:0xa8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x50" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_FP64_UTILIZATION", "XVE INST EXECUTED FP64 UTILIZATION",
                          "The percentage of time in which FLT64 instruction were processed actively on FPU INT64 pipeline.",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x2c:0xa7" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x48" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_ALL_UTILIZATION", "XVE INST EXECUTED ALU1 ALL UTILIZATION",
                          "Percentage of execution slots taken by instructions executed on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x54:0xb1" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x98" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_INT16_UTILIZATION", "XVE INST EXECUTED INT16 UTILIZATION",
                          "Percentage of execution slots taken by INT16 ALU instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 20 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x40:0xac" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x70" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_INT32_UTILIZATION", "XVE INST EXECUTED INT32 UTILIZATION",
                          "Percentage of execution slots taken by INT32 ALU instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 21 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x3c:0xab" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x68" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_MATH_UTILIZATION", "XVE INST EXECUTED MATH UTILIZATION",
                          "Percentage of execution slots taken by extended math instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_4 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 22 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x38:0xaa" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x60" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_ALL_UTILIZATION", "XVE INST EXECUTED XMX ALL UTILIZATION",
                          "Percentage of execution slots taken by instructions executed in XMX pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 23 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x58:0xb2" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0xa0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_BF16_UTILIZATION", "XVE INST EXECUTED XMX BF16 UTILIZATION",
                          "Percentage of execution slots taken by BF16 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 24 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x4c:0xaf" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x88" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_FP16_UTILIZATION", "XVE INST EXECUTED XMX FP16 UTILIZATION",
                          "Percentage of execution slots taken by FP16 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 25 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x48:0xae" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x80" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_XMX_INT8_UTILIZATION", "XVE INST EXECUTED XMX INT8 UTILIZATION",
                          "Percentage of execution slots taken by INT8 XMX instructions",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 26 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x44:0xad" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x78" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xe458, 0x0000700b, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe558, 0x02000006, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe658, 0x0000c00d, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe758, 0x0200200f, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe45c, 0x0000000e, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe55c, 0x00009001, REGISTER_TYPE_FLEX );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt1006MetricSet::CExt1006MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt1006MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_ALL", "XVE INST EXECUTED SEND ALL",
                          "Number of instructions executed on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x50:0xb0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x90" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_ASYNC_CS", "XVE INST EXECUTED SEND ASYNC CS",
                          "Number of instructions executed by Async Compute Shader threads on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x4c:0xaf" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x88" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_CS", "XVE INST EXECUTED SEND CS",
                          "Number of instructions executed by Compute Shader (from Render Engine) threads on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x48:0xae" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x80" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_DS", "XVE INST EXECUTED SEND DS",
                          "Number of instructions executed by Domain Shader threads on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "Domain|Evaluation,DS|TES", nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x44:0xad" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x78" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_GS", "XVE INST EXECUTED SEND GS",
                          "Number of instructions executed by Geometry Shader threads on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x40:0xac" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x70" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_HS", "XVE INST EXECUTED SEND HS",
                          "Number of instructions executed by Hull Shader threads on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "Hull|Control,HS|TCS", nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x3c:0xab" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x68" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_MS", "XVE INST EXECUTED SEND MS",
                          "Number of instructions executed by Mesh Shader threads on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x38:0xaa" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x60" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_PS", "XVE INST EXECUTED SEND PS",
                          "Number of instructions executed by Pixel Shader threads on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x34:0xa9" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x58" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_TS", "XVE INST EXECUTED SEND TS",
                          "Number of instructions executed by Task Shader threads on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x30:0xa8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x50" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_VS", "XVE INST EXECUTED SEND VS",
                          "Number of instructions executed by Vertex Shader threads on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x2c:0xa7" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x48" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_ALL_UTILIZATION", "XVE INST EXECUTED SEND ALL UTILIZATION",
                          "Percentage of time taken by instructions executed on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x50:0xb0" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x90" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_ASYNC_CS_UTILIZATION", "XVE INST EXECUTED SEND ASYNC CS UTILIZATION",
                          "Percentage of time taken by instructions executed by Async Compute Shader threads on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x4c:0xaf" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x88" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_CS_UTILIZATION", "XVE INST EXECUTED SEND CS UTILIZATION",
                          "Percentage of time taken by instructions executed by Compute Shader (from Render Engine) threads on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x48:0xae" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x80" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_DS_UTILIZATION", "XVE INST EXECUTED SEND DS UTILIZATION",
                          "Percentage of time taken by instructions executed by Domain Shader threads on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "Domain|Evaluation,DS|TES", nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x44:0xad" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x78" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_GS_UTILIZATION", "XVE INST EXECUTED SEND GS UTILIZATION",
                          "Percentage of time taken by instructions executed by Geometry Shader threads on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 17 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x40:0xac" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x70" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_HS_UTILIZATION", "XVE INST EXECUTED SEND HS UTILIZATION",
                          "Percentage of time taken by instructions executed by Hull Shader threads on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "Hull|Control,HS|TCS", nullptr, 18 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x3c:0xab" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x68" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_MS_UTILIZATION", "XVE INST EXECUTED SEND MS UTILIZATION",
                          "Percentage of time taken by instructions executed by Mesh Shader threads on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 19 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x38:0xaa" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x60" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_PS_UTILIZATION", "XVE INST EXECUTED SEND PS UTILIZATION",
                          "Percentage of time taken by instructions executed by Pixel Shader threads on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, "Pixel|Fragment,PS|FS", nullptr, 20 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x34:0xa9" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x58" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_TS_UTILIZATION", "XVE INST EXECUTED SEND TS UTILIZATION",
                          "Percentage of time taken by instructions executed by Task Shader threads on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 21 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x30:0xa8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x50" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_SEND_VS_UTILIZATION", "XVE INST EXECUTED SEND VS UTILIZATION",
                          "Percentage of time taken by instructions executed by Vertex Shader threads on SEND pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 22 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x2c:0xa7" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x48" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xe458, 0x000a2012, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe558, 0x000b2052, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe658, 0x00042022, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe758, 0x00062032, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe45c, 0x00002092, REGISTER_TYPE_FLEX );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt1007MetricSet::CExt1007MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt1007MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL_GS", "XVE STALL GS",
                          "Percentage of time in which there are Geometry Shader threads loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x30:0xa8" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x50" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_GS", "XVE INST EXECUTED ALU0 GS",
                          "Number of execution slots taken by instructions executed by Geometry Shader on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x38:0xaa" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x60" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_GS", "XVE INST EXECUTED ALU1 GS",
                          "Number of execution slots taken by instructions executed by Geometry Shader on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x34:0xa9" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x58" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_STALL_CYCLES_GS", "XVE STALL CYCLES GS",
                          "Number of cycles there are Geometry Shader threads loaded but not even a single pipe is active in XVE",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$XVE_STALL_GS" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_MS", "XVE INST EXECUTED ALU0 MS",
                          "Number of execution slots taken by instructions executed by Mesh Shader on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x48:0xae" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x80" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_TS", "XVE INST EXECUTED ALU0 TS",
                          "Number of execution slots taken by instructions executed by Task Shader on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 8 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x44:0xad" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x78" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_MS", "XVE INST EXECUTED ALU1 MS",
                          "Number of execution slots taken by instructions executed by Mesh Shader on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 9 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x40:0xac" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x70" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_TS", "XVE INST EXECUTED ALU1 TS",
                          "Number of execution slots taken by instructions executed by Task Shader on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "events", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 10 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x3c:0xab" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x68" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "$GpuCoreClocks $VectorEngineTotalCount UMUL" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_GS_UTILIZATION", "XVE INST EXECUTED ALU0 GS UTILIZATION",
                          "Percentage of execution slots taken by instructions executed by Geometry Shader on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 11 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x38:0xaa" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x60" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_GS_UTILIZATION", "XVE INST EXECUTED ALU1 GS UTILIZATION",
                          "Percentage of execution slots taken by instructions executed by Geometry Shader on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 12 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x34:0xa9" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x58" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_MS_UTILIZATION", "XVE INST EXECUTED ALU0 MS UTILIZATION",
                          "Percentage of execution slots taken by instructions executed by Mesh Shader on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 13 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x48:0xae" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x80" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU0_TS_UTILIZATION", "XVE INST EXECUTED ALU0 TS UTILIZATION",
                          "Percentage of execution slots taken by instructions executed by Task Shader on ALU0 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 14 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x44:0xad" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x78" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_MS_UTILIZATION", "XVE INST EXECUTED ALU1 MS UTILIZATION",
                          "Percentage of execution slots taken by instructions executed by Mesh Shader on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 15 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x40:0xac" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x70" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "XVE_INST_EXECUTED_ALU1_TS_UTILIZATION", "XVE INST EXECUTED ALU1 TS UTILIZATION",
                          "Percentage of execution slots taken by instructions executed by Task Shader on ALU1 pipe",
                          "VectorEngine", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_FLOAT, "percent", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, nullptr, 16 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x3c:0xab" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x68" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "EuAggrDuration" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
            MD_CHECK_CC( ( metric->SetMaxValueEquation( "100" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xe458, 0x00045000, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe558, 0x00040041, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe658, 0x000b10a1, REGISTER_TYPE_FLEX );
            AddStartConfigRegister( 0xe758, 0x000b00a0, REGISTER_TYPE_FLEX );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
    CExt1010MetricSet::CExt1010MetricSet( CMetricsDevice* device, CConcurrentGroup* concurrentGroup, const char* symbolicName, const char* shortName, uint32_t apiMask, uint32_t category, uint32_t snapshotReportSize, uint32_t deltaReportSize, TReportType reportType, TByteArrayLatest* platformMask, uint32_t gtMask /*= GT_TYPE_ALL*/, bool isCustom /*= false*/ )
        : CMetricSet( device, concurrentGroup, symbolicName, shortName, apiMask, category, snapshotReportSize, deltaReportSize, reportType, platformMask, gtMask, isCustom )
    {
    }
    TCompletionCode CExt1010MetricSet::Initialize()
    {
        TCompletionCode ret                  = CC_OK;
        CMetric*        metric               = nullptr;
        CInformation*   information          = nullptr;
        const char*     availabilityEquation = nullptr;
        m_params_1_0.InformationCount        = m_concurrentGroup->GetInformationCount();
        MD_CHECK_CC( SetApiSpecificId( "GPAV", 0, 0x40000000, 0x80000203, 0, 0, "Intel Performance Counters for GT Set Dynamic", 0, "Intel_Raw_Hardware_Counters_Set_0_Query", 0 ) );

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuTime", "GPU Time Elapsed",
                          "Time elapsed on the GPU during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_DURATION, RESULT_UINT64, "ns", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 0 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x04 1000000000 UMUL $GpuTimestampFrequency UDIV" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x00" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "NS_TIME" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "GpuCoreClocks", "GPU Core Clocks",
                          "The total number of GPU core clocks elapsed during the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "cycles", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 1 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x0c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0x08" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "AvgGpuCoreFrequencyMHz", "AVG GPU Core Frequency",
                          "Average GPU Core Frequency in the measurement.",
                          "GPU", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_1 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_SYSTEM | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "MHz", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 2 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$GpuCoreClocks 1000 UMUL $$GpuTime UDIV" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "SAMPLER_2X2_READ", "SAMPLER 2X2 READ",
                          "Number of 2x2 texel block requested from Sampler",
                          "Sampler", ( METRIC_GROUP_NAME_ID_SAMPLER * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "texels", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 3 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x80:0xbc" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0xf0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 4 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PIXEL_WRITE", "PIXEL WRITE",
                          "Number of 2x2 pixels written to all render targets",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "pixels", 0, 0, HW_UNIT_GPU, availabilityEquation, "pixel|fragment", "oa.fixed", 4 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x78" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0xe0" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 4 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "PIXEL_BLEND", "PIXEL BLEND",
                          "Number of blended 2x2 pixels written to all render targets",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_OVERVIEW | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "pixels", 0, 0, HW_UNIT_GPU, availabilityEquation, "pixel|fragment", "oa.fixed", 5 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x7c" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0xe8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 4 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "RASTERIZER_SAMPLE_OUTPUT", "RASTERIZER SAMPLE OUTPUT",
                          "Number of lit samples emitted by Rasterizer",
                          "Rasterizer", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "pixels", 0, 0, HW_UNIT_GPU, availabilityEquation, nullptr, "oa.fixed", 6 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "rd40@0x64:0xb5" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0xb8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 4 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 40" ) ) );
        }

        availabilityEquation = nullptr;
        metric               = AddMetric( "POSTPS_DEPTH_STENCIL_ALPHA_TEST_FAIL", "POSTPS DEPTH STENCIL ALPHA TEST FAIL",
                          "Number of 2x2 that were lit from Rasterizer but failed the depth stencil test or alpha test",
                          "ColorPipe", ( METRIC_GROUP_NAME_ID_GPU * 0x1000000 ), USAGE_FLAG_TIER_3 | USAGE_FLAG_FRAME | USAGE_FLAG_BATCH | USAGE_FLAG_DRAW, API_TYPE_DX9 | API_TYPE_DX10 | API_TYPE_DX11 | API_TYPE_DX12 | API_TYPE_VULKAN | API_TYPE_OGL | API_TYPE_OGL4_X | API_TYPE_OCL | API_TYPE_IOSTREAM,
                          METRIC_TYPE_EVENT, RESULT_UINT64, "pixels", 0, 0, HW_UNIT_GPU, availabilityEquation, "PS|FS", "oa.fixed", 7 );
        if( metric )
        {
            MD_CHECK_CC( ( metric->SetSnapshotReportReadEquation( "dw@0x74" ) ) );
            MD_CHECK_CC( ( metric->SetDeltaReportReadEquation( "qw@0xd8" ) ) );
            MD_CHECK_CC( ( metric->SetNormalizationEquation( "$Self 4 UMUL" ) ) );
            MD_CHECK_CC( ( metric->SetSnapshotReportDeltaFunction( "DELTA 32" ) ) );
        }

        availabilityEquation = nullptr;
        if( AddStartRegisterSet( 0, 0, availabilityEquation ) == CC_OK )
        {
            AddStartConfigRegister( 0xd900, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd904, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd910, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd914, 0x00800000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xd920, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdc40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0xdd40, 0x00000000, REGISTER_TYPE_OA );
            AddStartConfigRegister( 0x2b2c, 0x00000000, REGISTER_TYPE_OA );
        }
        RefreshConfigRegisters();
        return CC_OK;

    exception:
        return ret;
    }
} // namespace MetricsDiscoveryInternal::MetricSets_ACM_GT3_OA

#endif
